/* selection-toolbar.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from selection-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_SELECTION_TOOLBAR (boxes_selection_toolbar_get_type ())
#define BOXES_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbar))
#define BOXES_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbarClass))
#define BOXES_IS_SELECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTION_TOOLBAR))
#define BOXES_IS_SELECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTION_TOOLBAR))
#define BOXES_SELECTION_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbarClass))

typedef struct _BoxesSelectionToolbar BoxesSelectionToolbar;
typedef struct _BoxesSelectionToolbarClass BoxesSelectionToolbarClass;
typedef struct _BoxesSelectionToolbarPrivate BoxesSelectionToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _BoxesSelectionToolbar {
	GtkHeaderBar parent_instance;
	BoxesSelectionToolbarPrivate * priv;
};

struct _BoxesSelectionToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesSelectionToolbarPrivate {
	GtkButton* search_btn;
	GtkLabel* menu_button_label;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_selection_toolbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;
extern BoxesAppWindow* boxes_app_window;

GType boxes_selection_toolbar_get_type (void) G_GNUC_CONST;
#define BOXES_SELECTION_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbarPrivate))
enum  {
	BOXES_SELECTION_TOOLBAR_DUMMY_PROPERTY
};
static void boxes_selection_toolbar_on_cancel_btn_clicked (BoxesSelectionToolbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void _boxes_selection_toolbar_on_cancel_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_selection_toolbar_setup_ui (BoxesSelectionToolbar* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void boxes_selection_toolbar_update_selection_label (BoxesSelectionToolbar* self);
static void boxes_selection_toolbar_update_search_btn (BoxesSelectionToolbar* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
static void _boxes_selection_toolbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_selection_toolbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
BoxesSelectionToolbar* boxes_selection_toolbar_new (void);
BoxesSelectionToolbar* boxes_selection_toolbar_construct (GType object_type);
static GObject * boxes_selection_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_selection_toolbar___lambda84_ (BoxesSelectionToolbar* self);
static void __boxes_selection_toolbar___lambda84__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_selection_toolbar_finalize (GObject* obj);


static void boxes_selection_toolbar_on_cancel_btn_clicked (BoxesSelectionToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_app_set_selection_mode (_tmp0_, FALSE);
#line 311 "selection-toolbar.c"
}


static void _boxes_selection_toolbar_on_cancel_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_on_cancel_btn_clicked ((BoxesSelectionToolbar*) self);
#line 318 "selection-toolbar.c"
}


static void _boxes_selection_toolbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_update_search_btn ((BoxesSelectionToolbar*) self);
#line 325 "selection-toolbar.c"
}


static void _boxes_selection_toolbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_update_search_btn ((BoxesSelectionToolbar*) self);
#line 332 "selection-toolbar.c"
}


void boxes_selection_toolbar_setup_ui (BoxesSelectionToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesSearchbar* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
	BoxesCollection* _tmp4_ = NULL;
	BoxesApp* _tmp5_ = NULL;
	BoxesCollection* _tmp6_ = NULL;
	GtkButton* _tmp7_ = NULL;
	BoxesAppWindow* _tmp8_ = NULL;
	BoxesSearchbar* _tmp9_ = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp0_ = boxes_app_window;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_vala_assert (_tmp0_ != NULL, "App.window != null");
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp1_ = boxes_app_window;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp2_ = _tmp1_->searchbar;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_vala_assert (_tmp2_ != NULL, "App.window.searchbar != null");
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_update_selection_label (self);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_update_search_btn (self);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp3_ = boxes_app_app;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp4_ = _tmp3_->collection;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_signal_connect_object (_tmp4_, "item-added", (GCallback) _boxes_selection_toolbar_update_search_btn_boxes_collection_item_added, self, 0);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp5_ = boxes_app_app;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp6_ = _tmp5_->collection;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_signal_connect_object (_tmp6_, "item-removed", (GCallback) _boxes_selection_toolbar_update_search_btn_boxes_collection_item_removed, self, 0);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp7_ = self->priv->search_btn;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp8_ = boxes_app_window;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp9_ = _tmp8_->searchbar;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp7_, "active", (GObject*) _tmp9_, "search-mode-enabled", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 383 "selection-toolbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 390 "selection-toolbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_list_free (self);
#line 399 "selection-toolbar.c"
}


static void boxes_selection_toolbar_update_selection_label (BoxesSelectionToolbar* self) {
	guint items = 0U;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	guint _tmp5_ = 0U;
	guint _tmp6_ = 0U;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	items = _tmp5_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp6_ = items;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	if (_tmp6_ > ((guint) 0)) {
#line 434 "selection-toolbar.c"
		GtkLabel* _tmp7_ = NULL;
		guint _tmp8_ = 0U;
		const gchar* _tmp9_ = NULL;
		guint _tmp10_ = 0U;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp7_ = self->priv->menu_button_label;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp8_ = items;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp9_ = ngettext ("%d selected", "%d selected", (gulong) _tmp8_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp10_ = items;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp11_ = g_strdup_printf (_tmp9_, _tmp10_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp12_ = _tmp11_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		gtk_label_set_label (_tmp7_, _tmp12_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_g_free0 (_tmp12_);
#line 457 "selection-toolbar.c"
	} else {
		GtkLabel* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp13_ = self->priv->menu_button_label;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		_tmp14_ = _ ("(Click on items to select them)");
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
		gtk_label_set_label (_tmp13_, _tmp14_);
#line 467 "selection-toolbar.c"
	}
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 483 "selection-toolbar.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 495 "selection-toolbar.c"
}


static void boxes_selection_toolbar_update_search_btn (BoxesSelectionToolbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp0_ = self->priv->search_btn;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp1_ = boxes_app_app;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp3_ = _tmp2_->items;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 522 "selection-toolbar.c"
}


BoxesSelectionToolbar* boxes_selection_toolbar_construct (GType object_type) {
	BoxesSelectionToolbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	self = (BoxesSelectionToolbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	return self;
#line 532 "selection-toolbar.c"
}


BoxesSelectionToolbar* boxes_selection_toolbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	return boxes_selection_toolbar_construct (BOXES_TYPE_SELECTION_TOOLBAR);
#line 539 "selection-toolbar.c"
}


static void _boxes_selection_toolbar___lambda84_ (BoxesSelectionToolbar* self) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_update_selection_label (self);
#line 546 "selection-toolbar.c"
}


static void __boxes_selection_toolbar___lambda84__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_boxes_selection_toolbar___lambda84_ ((BoxesSelectionToolbar*) self);
#line 553 "selection-toolbar.c"
}


static GObject * boxes_selection_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSelectionToolbar * self;
	BoxesApp* _tmp0_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_selection_toolbar_parent_class);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbar);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::selected-items", (GCallback) __boxes_selection_toolbar___lambda84__g_object_notify, self, 0);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	return obj;
#line 574 "selection-toolbar.c"
}


static void boxes_selection_toolbar_class_init (BoxesSelectionToolbarClass * klass) {
	gint BoxesSelectionToolbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	boxes_selection_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSelectionToolbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_selection_toolbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_selection_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	BoxesSelectionToolbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/selection-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "search_btn", FALSE, BoxesSelectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionToolbarPrivate, search_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "menu_button_label", FALSE, BoxesSelectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionToolbarPrivate, menu_button_label));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_cancel_btn_clicked", G_CALLBACK(_boxes_selection_toolbar_on_cancel_btn_clicked_gtk_button_clicked));
#line 598 "selection-toolbar.c"
}


static void boxes_selection_toolbar_instance_init (BoxesSelectionToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	self->priv = BOXES_SELECTION_TOOLBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 607 "selection-toolbar.c"
}


static void boxes_selection_toolbar_finalize (GObject* obj) {
	BoxesSelectionToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTION_TOOLBAR, BoxesSelectionToolbar);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_g_object_unref0 (self->priv->search_btn);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	_g_object_unref0 (self->priv->menu_button_label);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/selection-toolbar.vala"
	G_OBJECT_CLASS (boxes_selection_toolbar_parent_class)->finalize (obj);
#line 621 "selection-toolbar.c"
}


GType boxes_selection_toolbar_get_type (void) {
	static volatile gsize boxes_selection_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selection_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSelectionToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_selection_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSelectionToolbar), 0, (GInstanceInitFunc) boxes_selection_toolbar_instance_init, NULL };
		GType boxes_selection_toolbar_type_id;
		boxes_selection_toolbar_type_id = g_type_register_static (GTK_TYPE_HEADER_BAR, "BoxesSelectionToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_selection_toolbar_type_id__volatile, boxes_selection_toolbar_type_id);
	}
	return boxes_selection_toolbar_type_id__volatile;
}



