/* wizard-toolbar.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from wizard-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <gio/gio.h>


#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesWizardToolbarPrivate BoxesWizardToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())

struct _BoxesWizardToolbar {
	GtkHeaderBar parent_instance;
	BoxesWizardToolbarPrivate * priv;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* continue_btn;
	GtkButton* create_btn;
};

struct _BoxesWizardToolbarClass {
	GtkHeaderBarClass parent_class;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;


static gpointer boxes_wizard_toolbar_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;

GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_WIZARD_TOOLBAR_DUMMY_PROPERTY
};
void boxes_wizard_toolbar_click_back_button (BoxesWizardToolbar* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
void boxes_wizard_toolbar_click_forward_button (BoxesWizardToolbar* self);
BoxesWizardToolbar* boxes_wizard_toolbar_new (void);
BoxesWizardToolbar* boxes_wizard_toolbar_construct (GType object_type);
static void boxes_wizard_toolbar_finalize (GObject* obj);


void boxes_wizard_toolbar_click_back_button (BoxesWizardToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesWizard* _tmp1_ = NULL;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage _tmp3_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp0_ = boxes_app_window;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp1_ = _tmp0_->wizard;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp2_ = boxes_wizard_get_page (_tmp1_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	if (_tmp3_ != BOXES_WIZARD_PAGE_INTRODUCTION) {
#line 244 "wizard-toolbar.c"
		GtkButton* _tmp4_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		_tmp4_ = self->back_btn;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		gtk_button_clicked (_tmp4_);
#line 250 "wizard-toolbar.c"
	}
}


void boxes_wizard_toolbar_click_forward_button (BoxesWizardToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesWizard* _tmp1_ = NULL;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage _tmp3_ = 0;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp0_ = boxes_app_window;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp1_ = _tmp0_->wizard;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp2_ = boxes_wizard_get_page (_tmp1_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_tmp3_ = _tmp2_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	if (_tmp3_ != BOXES_WIZARD_PAGE_REVIEW) {
#line 272 "wizard-toolbar.c"
		GtkButton* _tmp4_ = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		_tmp4_ = self->continue_btn;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
		gtk_button_clicked (_tmp4_);
#line 278 "wizard-toolbar.c"
	}
}


BoxesWizardToolbar* boxes_wizard_toolbar_construct (GType object_type) {
	BoxesWizardToolbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	self = (BoxesWizardToolbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	return self;
#line 289 "wizard-toolbar.c"
}


BoxesWizardToolbar* boxes_wizard_toolbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	return boxes_wizard_toolbar_construct (BOXES_TYPE_WIZARD_TOOLBAR);
#line 296 "wizard-toolbar.c"
}


static void boxes_wizard_toolbar_class_init (BoxesWizardToolbarClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	boxes_wizard_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cancel_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, cancel_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, back_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "continue_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, continue_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "create_btn", FALSE, G_STRUCT_OFFSET (BoxesWizardToolbar, create_btn));
#line 315 "wizard-toolbar.c"
}


static void boxes_wizard_toolbar_instance_init (BoxesWizardToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 322 "wizard-toolbar.c"
}


static void boxes_wizard_toolbar_finalize (GObject* obj) {
	BoxesWizardToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->cancel_btn);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->back_btn);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->continue_btn);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	_g_object_unref0 (self->create_btn);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-toolbar.vala"
	G_OBJECT_CLASS (boxes_wizard_toolbar_parent_class)->finalize (obj);
#line 340 "wizard-toolbar.c"
}


GType boxes_wizard_toolbar_get_type (void) {
	static volatile gsize boxes_wizard_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardToolbar), 0, (GInstanceInitFunc) boxes_wizard_toolbar_instance_init, NULL };
		GType boxes_wizard_toolbar_type_id;
		boxes_wizard_toolbar_type_id = g_type_register_static (GTK_TYPE_HEADER_BAR, "BoxesWizardToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_toolbar_type_id__volatile, boxes_wizard_toolbar_type_id);
	}
	return boxes_wizard_toolbar_type_id__volatile;
}



