/* display-page.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from display-page.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <cairo.h>
#include <libgd/gd.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>


#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;

#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block14Data Block14Data;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

struct _BoxesDisplayPage {
	GtkBox parent_instance;
	BoxesDisplayPagePrivate * priv;
	BoxesDisplayToolbar* toolbar;
};

struct _BoxesDisplayPageClass {
	GtkBoxClass parent_class;
};

struct _BoxesDisplayPagePrivate {
	GtkEventBox* event_box;
	BoxesDisplayToolbar* overlay_toolbar;
	GtkEventBox* overlay_toolbar_box;
	guint toolbar_hide_id;
	guint toolbar_show_id;
	gulong cursor_id;
	guint overlay_toolbar_invisible_timeout;
	BoxesDisplay* display;
	gulong display_can_grab_id;
	gulong display_grabbed_id;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block14Data {
	int _ref_count_;
	BoxesDisplayPage* self;
	gulong draw_id;
	GtkWidget* widget;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};


static gpointer boxes_display_page_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;
extern BoxesApp* boxes_app_app;

GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPagePrivate))
enum  {
	BOXES_DISPLAY_PAGE_DUMMY_PROPERTY
};
static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self);
void boxes_display_page_setup_ui (BoxesDisplayPage* self);
#define BOXES_APP_WINDOW_TRANSITION_DURATION ((guint) 400)
GType boxes_app_window_get_type (void) G_GNUC_CONST;
static gboolean __lambda11_ (BoxesDisplayPage* self, GdkEventWindowState* event);
static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self);
static gboolean ___lambda11__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
gboolean boxes_app_window_get_fullscreened (BoxesAppWindow* self);
static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self);
static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible);
void boxes_display_page_update_title (BoxesDisplayPage* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static gboolean boxes_display_page_get_grabbed (BoxesDisplayPage* self);
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
static Block14Data* block14_data_ref (Block14Data* _data14_);
static void block14_data_unref (void * _userdata_);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
static void __lambda12_ (BoxesDisplayPage* self);
static gboolean __lambda13_ (BoxesDisplayPage* self);
static gboolean ___lambda13__gsource_func (gpointer self);
static void ___lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda14_ (BoxesDisplayPage* self);
static void ___lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda15_ (BoxesDisplayPage* self);
static gboolean ___lambda15__gsource_func (gpointer self);
static gboolean __lambda16_ (Block14Data* _data14_);
static void __lambda17_ (Block14Data* _data14_);
static void ___lambda17__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean ___lambda16__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static gboolean boxes_display_page_on_event_box_event (BoxesDisplayPage* self, GdkEvent* event);
static gboolean _____lambda18_ (BoxesDisplayPage* self);
static gboolean ______lambda18__gsource_func (gpointer self);
static gboolean _____lambda19_ (BoxesDisplayPage* self);
static gboolean ______lambda19__gsource_func (gpointer self);
static gboolean _boxes_display_page_on_event_box_event_gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self);
BoxesDisplayPage* boxes_display_page_new (void);
BoxesDisplayPage* boxes_display_page_construct (GType object_type);
gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self);
gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self);
static void boxes_display_page_finalize (GObject* obj);
static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static gboolean __lambda11_ (BoxesDisplayPage* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 366 "display-page.c"
}


static gboolean ___lambda11__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = __lambda11_ ((BoxesDisplayPage*) self, event);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 375 "display-page.c"
}


void boxes_display_page_setup_ui (BoxesDisplayPage* self) {
	GtkEventBox* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesDisplayToolbar* _tmp2_ = NULL;
	BoxesDisplayToolbar* _tmp3_ = NULL;
	BoxesDisplayToolbar* _tmp4_ = NULL;
	BoxesDisplayToolbar* _tmp5_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = BOXES_APP_WINDOW_TRANSITION_DURATION;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->event_box;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events ((GtkWidget*) _tmp0_, (gint) (GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK));
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_window;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_connect_object ((GtkWidget*) _tmp1_, "window-state-event", (GCallback) ___lambda11__gtk_widget_window_state_event, self, 0);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->toolbar;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->overlay_toolbar;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp2_, "title", (GObject*) _tmp3_, "title", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = self->toolbar;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = self->priv->overlay_toolbar;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp4_, "subtitle", (GObject*) _tmp5_, "subtitle", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 410 "display-page.c"
}


static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self) {
	gboolean _tmp0_ = FALSE;
	BoxesAppWindow* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_window;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (_tmp1_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 429 "display-page.c"
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = boxes_display_page_get_can_grab_mouse (self);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp5_;
#line 438 "display-page.c"
	} else {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 442 "display-page.c"
	}
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 446 "display-page.c"
		BoxesDisplayToolbar* _tmp6_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = self->toolbar;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp6_, TRUE);
#line 452 "display-page.c"
	} else {
		BoxesDisplayToolbar* _tmp7_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->toolbar;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, FALSE);
#line 459 "display-page.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 463 "display-page.c"
}


static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEventBox* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = visible;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_) {
#line 478 "display-page.c"
		BoxesDisplayToolbar* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->toolbar;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = gtk_widget_get_visible ((GtkWidget*) _tmp2_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 490 "display-page.c"
	} else {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 494 "display-page.c"
	}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_debug ("display-page.vala:61: toolbar is visible, don't show overlay toolbar");
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 502 "display-page.c"
	}
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = self->priv->overlay_toolbar_box;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = visible;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp5_, _tmp6_);
#line 510 "display-page.c"
}


static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self) {
	guint _tmp0_ = 0U;
	guint _tmp2_ = 0U;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->toolbar_hide_id;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 523 "display-page.c"
		guint _tmp1_ = 0U;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->toolbar_hide_id;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp1_);
#line 529 "display-page.c"
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->toolbar_show_id;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 537 "display-page.c"
		guint _tmp3_ = 0U;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = self->priv->toolbar_show_id;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp3_);
#line 543 "display-page.c"
	}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_show_id = (guint) 0;
#line 547 "display-page.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self ? g_object_ref (self) : NULL;
#line 554 "display-page.c"
}


void boxes_display_page_update_title (BoxesDisplayPage* self) {
	BoxesMachine* machine = NULL;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	gchar* title = NULL;
	BoxesMachine* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* hint = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	BoxesDisplayToolbar* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	BoxesDisplayToolbar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->current_item;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	machine = _tmp2_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = machine;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (_tmp3_ != NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = machine;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp4_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	title = _tmp7_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	hint = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = boxes_display_page_get_grabbed (self);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = _tmp8_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp9_) {
#line 608 "display-page.c"
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = _ ("(press [left] Ctrl+Alt keys to ungrab)");
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_free0 (hint);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		hint = _tmp11_;
#line 619 "display-page.c"
	}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = self->toolbar;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = title;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_header_bar_set_title ((GtkHeaderBar*) _tmp12_, _tmp13_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = self->toolbar;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = hint;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_header_bar_set_subtitle ((GtkHeaderBar*) _tmp14_, _tmp15_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_free0 (hint);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_free0 (title);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (machine);
#line 639 "display-page.c"
}


static Block14Data* block14_data_ref (Block14Data* _data14_) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data14_->_ref_count_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return _data14_;
#line 648 "display-page.c"
}


static void block14_data_unref (void * _userdata_) {
	Block14Data* _data14_;
	_data14_ = (Block14Data*) _userdata_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data14_->_ref_count_)) {
#line 657 "display-page.c"
		BoxesDisplayPage* self;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self = _data14_->self;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (_data14_->widget);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (self);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_slice_free (Block14Data, _data14_);
#line 667 "display-page.c"
	}
}


static gboolean __lambda13_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_title (self);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 680 "display-page.c"
}


static gboolean ___lambda13__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda13_ ((BoxesDisplayPage*) self);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 689 "display-page.c"
}


static void __lambda12_ (BoxesDisplayPage* self) {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_HIGH, ___lambda13__gsource_func, g_object_ref (self), g_object_unref);
#line 696 "display-page.c"
}


static void ___lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda12_ ((BoxesDisplayPage*) self);
#line 703 "display-page.c"
}


static void __lambda14_ (BoxesDisplayPage* self) {
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 710 "display-page.c"
}


static void ___lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda14_ ((BoxesDisplayPage*) self);
#line 717 "display-page.c"
}


static gboolean __lambda15_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = (guint) 1000;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_window;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_window_get_fullscreened (_tmp0_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _tmp1_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, _tmp2_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 742 "display-page.c"
}


static gboolean ___lambda15__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda15_ ((BoxesDisplayPage*) self);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 751 "display-page.c"
}


static void __lambda17_ (Block14Data* _data14_) {
	BoxesDisplayPage* self;
	GtkEventBox* _tmp0_ = NULL;
	GdkWindow* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
	GdkWindow* _tmp3_ = NULL;
	GdkCursor* _tmp4_ = NULL;
	GdkCursor* _tmp5_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data14_->self;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->event_box;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data14_->widget;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = gdk_window_get_cursor (_tmp3_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp4_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gdk_window_set_cursor (_tmp1_, _tmp5_);
#line 779 "display-page.c"
}


static void ___lambda17__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	__lambda17_ (self);
#line 786 "display-page.c"
}


static gboolean __lambda16_ (Block14Data* _data14_) {
	BoxesDisplayPage* self;
	gboolean result = FALSE;
	GtkWidget* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
	GtkWidget* _tmp2_ = NULL;
	GdkWindow* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = _data14_->self;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = _data14_->widget;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _data14_->draw_id;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data14_->widget;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = g_signal_connect_data ((GObject*) _tmp3_, "notify::cursor", (GCallback) ___lambda17__g_object_notify, block14_data_ref (_data14_), (GClosureNotify) block14_data_unref, 0);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->cursor_id = _tmp4_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 818 "display-page.c"
}


static gboolean ___lambda16__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda16_ (self);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 827 "display-page.c"
}


void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget) {
	Block14Data* _data14_;
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
	GtkEventBox* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	GtkWidget* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkWidget* _tmp6_ = NULL;
	BoxesDisplay* _tmp7_ = NULL;
	BoxesDisplay* _tmp8_ = NULL;
	BoxesDisplay* _tmp9_ = NULL;
	gulong _tmp10_ = 0UL;
	BoxesDisplay* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	GtkWidget* _tmp13_ = NULL;
	GtkWidget* _tmp14_ = NULL;
	gint _tmp15_ = 0;
	GtkEventBox* _tmp16_ = NULL;
	GtkWidget* _tmp17_ = NULL;
	GtkEventBox* _tmp18_ = NULL;
	GtkWidget* _tmp19_ = NULL;
	gulong _tmp20_ = 0UL;
	BoxesAppWindow* _tmp21_ = NULL;
	GtkStack* _tmp22_ = NULL;
	GtkWidget* _tmp23_ = NULL;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (display != NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_if_fail (widget != NULL);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_ = g_slice_new0 (Block14Data);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->_ref_count_ = 1;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->self = g_object_ref (self);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = widget;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_data14_->widget);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->widget = _tmp1_;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = self->priv->event_box;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_bin_get_child ((GtkBin*) _tmp2_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp4_ = _data14_->widget;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_ == _tmp4_) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		block14_data_unref (_data14_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_data14_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return;
#line 891 "display-page.c"
	}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_display_page_remove_display (self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp6_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = display;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display = _tmp8_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = display;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp10_ = g_signal_connect_object ((GObject*) _tmp9_, "notify::mouse-grabbed", (GCallback) ___lambda12__g_object_notify, self, 0);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display_grabbed_id = _tmp10_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp11_ = display;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp12_ = g_signal_connect_object ((GObject*) _tmp11_, "notify::can-grab-mouse", (GCallback) ___lambda14__g_object_notify, self, 0);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->display_can_grab_id = _tmp12_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda15__gsource_func, g_object_ref (self), g_object_unref);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_title (self);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = _data14_->widget;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp14_ = _data14_->widget;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp15_ = gtk_widget_get_events (_tmp14_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events (_tmp13_, _tmp15_ & (~GDK_POINTER_MOTION_MASK));
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp16_ = self->priv->event_box;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp17_ = _data14_->widget;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) _tmp16_, _tmp17_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp18_ = self->priv->event_box;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp18_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->draw_id = (gulong) 0;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp19_ = _data14_->widget;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp20_ = g_signal_connect_data (_tmp19_, "draw", (GCallback) ___lambda16__gtk_widget_draw, block14_data_ref (_data14_), (GClosureNotify) block14_data_unref, 0);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_->draw_id = _tmp20_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp21_ = boxes_app_window;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp22_ = _tmp21_->below_bin;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_stack_set_visible_child_name (_tmp22_, "display-page");
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp23_ = _data14_->widget;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_grab_focus (_tmp23_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	block14_data_unref (_data14_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_data14_ = NULL;
#line 965 "display-page.c"
}


GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self) {
	GtkWidget* result = NULL;
	gulong _tmp0_ = 0UL;
	gulong _tmp3_ = 0UL;
	GtkWidget* widget = NULL;
	GtkEventBox* _tmp6_ = NULL;
	GtkWidget* _tmp7_ = NULL;
	GtkWidget* _tmp8_ = NULL;
	gulong _tmp9_ = 0UL;
	GtkWidget* _tmp13_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->display_grabbed_id;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 985 "display-page.c"
		BoxesDisplay* _tmp1_ = NULL;
		gulong _tmp2_ = 0UL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->display;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display_grabbed_id;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->display_grabbed_id = (gulong) 0;
#line 996 "display-page.c"
	}
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->display_can_grab_id;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_ != ((gulong) 0)) {
#line 1002 "display-page.c"
		BoxesDisplay* _tmp4_ = NULL;
		gulong _tmp5_ = 0UL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = self->priv->display;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = self->priv->display_can_grab_id;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp4_, _tmp5_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->display_can_grab_id = (gulong) 0;
#line 1013 "display-page.c"
	}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->event_box;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp7_ = gtk_bin_get_child ((GtkBin*) _tmp6_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	widget = _tmp8_;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp9_ = self->priv->cursor_id;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp9_ != ((gulong) 0)) {
#line 1027 "display-page.c"
		GtkWidget* _tmp10_ = NULL;
		GdkWindow* _tmp11_ = NULL;
		gulong _tmp12_ = 0UL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp10_ = widget;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = gtk_widget_get_window (_tmp10_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp12_ = self->priv->cursor_id;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp11_, _tmp12_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		self->priv->cursor_id = (gulong) 0;
#line 1041 "display-page.c"
	}
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp13_ = widget;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp13_ != NULL) {
#line 1047 "display-page.c"
		GtkEventBox* _tmp14_ = NULL;
		GtkWidget* _tmp15_ = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp14_ = self->priv->event_box;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp15_ = widget;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_container_remove ((GtkContainer*) _tmp14_, _tmp15_);
#line 1056 "display-page.c"
	}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = widget;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1062 "display-page.c"
}


static gboolean _____lambda18_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, TRUE);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_show_id = (guint) 0;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1076 "display-page.c"
}


static gboolean ______lambda18__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda18_ ((BoxesDisplayPage*) self);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1085 "display-page.c"
}


static gboolean _____lambda19_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar_invisible_timeout = BOXES_APP_WINDOW_TRANSITION_DURATION;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1101 "display-page.c"
}


static gboolean ______lambda19__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda19_ ((BoxesDisplayPage*) self);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1110 "display-page.c"
}


static gboolean boxes_display_page_on_event_box_event (BoxesDisplayPage* self, GdkEvent* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesAppWindow* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GdkEvent* _tmp23_ = NULL;
	GdkEventType _tmp24_ = 0;
	GtkEventBox* _tmp25_ = NULL;
	GtkWidget* _tmp26_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_window;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_window_get_fullscreened (_tmp1_);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 1136 "display-page.c"
		GdkEvent* _tmp4_ = NULL;
		GdkEventType _tmp5_ = 0;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = event;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_->type;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp5_ == GDK_MOTION_NOTIFY;
#line 1145 "display-page.c"
	} else {
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1149 "display-page.c"
	}
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp0_) {
#line 1153 "display-page.c"
		gdouble y = 0.0;
		GdkEvent* _tmp6_ = NULL;
		GdkEventMotion* _tmp7_ = NULL;
		GdkEventMotion* _tmp8_ = NULL;
		gdouble _tmp9_ = 0.0;
		gboolean _tmp10_ = FALSE;
		gdouble _tmp11_ = 0.0;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp6_ = event;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp7_ = (GdkEventMotion *) (_tmp6_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp8_ = _tmp7_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp9_ = _tmp8_->y;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		y = _tmp9_;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp11_ = y;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp11_ <= ((gdouble) 0)) {
#line 1175 "display-page.c"
			guint _tmp12_ = 0U;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp12_ = self->priv->toolbar_show_id;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp10_ = _tmp12_ == ((guint) 0);
#line 1181 "display-page.c"
		} else {
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp10_ = FALSE;
#line 1185 "display-page.c"
		}
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		if (_tmp10_) {
#line 1189 "display-page.c"
			GdkEvent* _tmp13_ = NULL;
			GdkEventMotion* _tmp14_ = NULL;
			GdkEventMotion* _tmp15_ = NULL;
			GdkModifierType _tmp16_ = 0;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			boxes_display_page_toolbar_event_stop (self);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp13_ = event;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp14_ = (GdkEventMotion *) (_tmp13_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp15_ = _tmp14_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp16_ = _tmp15_->state;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			if ((_tmp16_ & ((((((((((GDK_SHIFT_MASK | GDK_CONTROL_MASK) | GDK_MOD1_MASK) | GDK_SUPER_MASK) | GDK_HYPER_MASK) | GDK_META_MASK) | GDK_BUTTON1_MASK) | GDK_BUTTON2_MASK) | GDK_BUTTON3_MASK) | GDK_BUTTON4_MASK) | GDK_BUTTON5_MASK)) == 0) {
#line 1206 "display-page.c"
				guint _tmp17_ = 0U;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp17_ = g_timeout_add_full (G_PRIORITY_DEFAULT, BOXES_APP_WINDOW_TRANSITION_DURATION, ______lambda18__gsource_func, g_object_ref (self), g_object_unref);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_show_id = _tmp17_;
#line 1212 "display-page.c"
			}
		} else {
			gboolean _tmp18_ = FALSE;
			gdouble _tmp19_ = 0.0;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			_tmp19_ = y;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			if (_tmp19_ > ((gdouble) 5)) {
#line 1221 "display-page.c"
				guint _tmp20_ = 0U;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp20_ = self->priv->toolbar_hide_id;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp18_ = _tmp20_ == ((guint) 0);
#line 1227 "display-page.c"
			} else {
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp18_ = FALSE;
#line 1231 "display-page.c"
			}
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
			if (_tmp18_) {
#line 1235 "display-page.c"
				guint _tmp21_ = 0U;
				guint _tmp22_ = 0U;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				boxes_display_page_toolbar_event_stop (self);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp21_ = self->priv->overlay_toolbar_invisible_timeout;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				_tmp22_ = g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp21_, ______lambda19__gsource_func, g_object_ref (self), g_object_unref);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_hide_id = _tmp22_;
#line 1246 "display-page.c"
			}
		}
	}
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp23_ = event;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp24_ = _tmp23_->type;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp24_ == GDK_GRAB_BROKEN) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		result = FALSE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		return result;
#line 1260 "display-page.c"
	}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp25_ = self->priv->event_box;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp26_ = gtk_bin_get_child ((GtkBin*) _tmp25_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp26_ != NULL) {
#line 1268 "display-page.c"
		GtkEventBox* _tmp27_ = NULL;
		GtkWidget* _tmp28_ = NULL;
		GdkEvent* _tmp29_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp27_ = self->priv->event_box;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp28_ = gtk_bin_get_child ((GtkBin*) _tmp27_);
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp29_ = event;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		gtk_widget_event (_tmp28_, _tmp29_);
#line 1280 "display-page.c"
	}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1286 "display-page.c"
}


static gboolean _boxes_display_page_on_event_box_event_gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self) {
	gboolean result;
	result = boxes_display_page_on_event_box_event ((BoxesDisplayPage*) self, event);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1295 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_construct (GType object_type) {
	BoxesDisplayPage * self = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayPage*) g_object_new (object_type, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return self;
#line 1305 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_new (void) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return boxes_display_page_construct (BOXES_TYPE_DISPLAY_PAGE);
#line 1312 "display-page.c"
}


static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_ = NULL;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 1326 "display-page.c"
		BoxesDisplay* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_can_grab_mouse (_tmp2_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1338 "display-page.c"
	} else {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1342 "display-page.c"
	}
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp0_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1348 "display-page.c"
}


static gboolean boxes_display_page_get_grabbed (BoxesDisplayPage* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesDisplay* _tmp1_ = NULL;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->display;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	if (_tmp1_ != NULL) {
#line 1362 "display-page.c"
		BoxesDisplay* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp3_ = boxes_display_get_mouse_grabbed (_tmp2_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1374 "display-page.c"
	} else {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1378 "display-page.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	result = _tmp0_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	return result;
#line 1384 "display-page.c"
}


static void boxes_display_page_class_init (BoxesDisplayPageClass * klass) {
	gint BoxesDisplayPage_private_offset;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayPagePrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_page_get_property;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_page_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	BoxesDisplayPage_private_offset = g_type_class_get_instance_private_offset (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/display-page.ui");
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "toolbar", FALSE, G_STRUCT_OFFSET (BoxesDisplayPage, toolbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "event_box", FALSE, BoxesDisplayPage_private_offset + G_STRUCT_OFFSET (BoxesDisplayPagePrivate, event_box));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "overlay_toolbar", FALSE, BoxesDisplayPage_private_offset + G_STRUCT_OFFSET (BoxesDisplayPagePrivate, overlay_toolbar));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "overlay_toolbar_box", FALSE, BoxesDisplayPage_private_offset + G_STRUCT_OFFSET (BoxesDisplayPagePrivate, overlay_toolbar_box));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_event_box_event", G_CALLBACK(_boxes_display_page_on_event_box_event_gtk_widget_event));
#line 1412 "display-page.c"
}


static void boxes_display_page_instance_init (BoxesDisplayPage * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self->priv = BOXES_DISPLAY_PAGE_GET_PRIVATE (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	g_type_ensure (BOXES_TYPE_DISPLAY_TOOLBAR);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1423 "display-page.c"
}


static void boxes_display_page_finalize (GObject* obj) {
	BoxesDisplayPage * self;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	boxes_display_page_toolbar_event_stop (self);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->toolbar);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->event_box);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar_box);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (boxes_display_page_parent_class)->finalize (obj);
#line 1445 "display-page.c"
}


GType boxes_display_page_get_type (void) {
	static volatile gsize boxes_display_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayPage), 0, (GInstanceInitFunc) boxes_display_page_instance_init, NULL };
		GType boxes_display_page_type_id;
		boxes_display_page_type_id = g_type_register_static (GTK_TYPE_BOX, "BoxesDisplayPage", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_page_type_id__volatile, boxes_display_page_type_id);
	}
	return boxes_display_page_type_id__volatile;
}


static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplayPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
	switch (property_id) {
#line 1466 "display-page.c"
		default:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display-page.vala"
		break;
#line 1472 "display-page.c"
	}
}



