/* display.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from display.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesDisplayPrivate BoxesDisplayPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

struct _BoxesDisplay {
	GObject parent_instance;
	BoxesDisplayPrivate * priv;
	gboolean connected;
	GHashTable* displays;
};

struct _BoxesDisplayClass {
	GObjectClass parent_class;
	GtkWidget* (*get_display) (BoxesDisplay* self, gint n);
	GdkPixbuf* (*get_pixbuf) (BoxesDisplay* self, gint n, GError** error);
	void (*set_enable_inputs) (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
	void (*set_enable_audio) (BoxesDisplay* self, gboolean enable);
	gboolean (*should_keep_alive) (BoxesDisplay* self);
	void (*connect_it) (BoxesDisplay* self, GError** error);
	void (*disconnect_it) (BoxesDisplay* self);
	void (*collect_logs) (BoxesDisplay* self, GString* builder);
	GList* (*get_properties) (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	const gchar* (*get_protocol) (BoxesDisplay* self);
	gchar* (*get_uri) (BoxesDisplay* self);
};

struct _BoxesDisplayPrivate {
	BoxesBoxConfig* _config;
	gboolean _can_grab_mouse;
	gboolean _mouse_grabbed;
	gboolean _need_password;
	gboolean _need_username;
	gchar* _password;
	gchar* _username;
	gint64 started_time;
};


static gpointer boxes_display_parent_class = NULL;
static BoxesIPropertiesProviderIface* boxes_display_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY, BoxesDisplayPrivate))
enum  {
	BOXES_DISPLAY_DUMMY_PROPERTY,
	BOXES_DISPLAY_PROTOCOL,
	BOXES_DISPLAY_URI,
	BOXES_DISPLAY_CONFIG,
	BOXES_DISPLAY_CAN_GRAB_MOUSE,
	BOXES_DISPLAY_MOUSE_GRABBED,
	BOXES_DISPLAY_NEED_PASSWORD,
	BOXES_DISPLAY_NEED_USERNAME,
	BOXES_DISPLAY_PASSWORD,
	BOXES_DISPLAY_USERNAME
};
void boxes_display_access_finish (BoxesDisplay* self);
GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n);
static GtkWidget* boxes_display_real_get_display (BoxesDisplay* self, gint n);
GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
static GdkPixbuf* boxes_display_real_get_pixbuf (BoxesDisplay* self, gint n, GError** error);
void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
static void boxes_display_real_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable);
void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable);
static void boxes_display_real_set_enable_audio (BoxesDisplay* self, gboolean enable);
gboolean boxes_display_should_keep_alive (BoxesDisplay* self);
static gboolean boxes_display_real_should_keep_alive (BoxesDisplay* self);
void boxes_display_connect_it (BoxesDisplay* self, GError** error);
static void boxes_display_real_connect_it (BoxesDisplay* self, GError** error);
void boxes_display_disconnect_it (BoxesDisplay* self);
static void boxes_display_real_disconnect_it (BoxesDisplay* self);
void boxes_display_collect_logs (BoxesDisplay* self, GString* builder);
static void boxes_display_real_collect_logs (BoxesDisplay* self, GString* builder);
GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
static GList* boxes_display_real_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
void boxes_display_access_start (BoxesDisplay* self);
BoxesBoxConfig* boxes_display_get_config (BoxesDisplay* self);
BoxesDisplay* boxes_display_construct (GType object_type);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
gchar* boxes_display_get_uri (BoxesDisplay* self);
void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value);
gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self);
void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value);
gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self);
void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value);
gboolean boxes_display_get_need_password (BoxesDisplay* self);
void boxes_display_set_need_password (BoxesDisplay* self, gboolean value);
gboolean boxes_display_get_need_username (BoxesDisplay* self);
void boxes_display_set_need_username (BoxesDisplay* self, gboolean value);
const gchar* boxes_display_get_password (BoxesDisplay* self);
void boxes_display_set_password (BoxesDisplay* self, const gchar* value);
const gchar* boxes_display_get_username (BoxesDisplay* self);
void boxes_display_set_username (BoxesDisplay* self, const gchar* value);
static GObject * boxes_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _g_object_unref0_ (gpointer var);
static void boxes_display_finalize (GObject* obj);
static void _vala_boxes_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static GtkWidget* boxes_display_real_get_display (BoxesDisplay* self, gint n) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_get_display'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return NULL;
#line 174 "display.c"
}


GtkWidget* boxes_display_get_display (BoxesDisplay* self, gint n) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_display (self, n);
#line 183 "display.c"
}


static GdkPixbuf* boxes_display_real_get_pixbuf (BoxesDisplay* self, gint n, GError** error) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_get_pixbuf'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return NULL;
#line 192 "display.c"
}


GdkPixbuf* boxes_display_get_pixbuf (BoxesDisplay* self, gint n, GError** error) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_pixbuf (self, n, error);
#line 201 "display.c"
}


static void boxes_display_real_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_set_enable_inputs'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return;
#line 210 "display.c"
}


void boxes_display_set_enable_inputs (BoxesDisplay* self, GtkWidget* widget, gboolean enable) {
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->set_enable_inputs (self, widget, enable);
#line 219 "display.c"
}


static void boxes_display_real_set_enable_audio (BoxesDisplay* self, gboolean enable) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_set_enable_audio'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return;
#line 228 "display.c"
}


void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->set_enable_audio (self, enable);
#line 237 "display.c"
}


static gboolean boxes_display_real_should_keep_alive (BoxesDisplay* self) {
	gboolean result = FALSE;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = FALSE;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 247 "display.c"
}


gboolean boxes_display_should_keep_alive (BoxesDisplay* self) {
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->should_keep_alive (self);
#line 256 "display.c"
}


static void boxes_display_real_connect_it (BoxesDisplay* self, GError** error) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_connect_it'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return;
#line 265 "display.c"
}


void boxes_display_connect_it (BoxesDisplay* self, GError** error) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->connect_it (self, error);
#line 274 "display.c"
}


static void boxes_display_real_disconnect_it (BoxesDisplay* self) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_disconnect_it'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return;
#line 283 "display.c"
}


void boxes_display_disconnect_it (BoxesDisplay* self) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->disconnect_it (self);
#line 292 "display.c"
}


static void boxes_display_real_collect_logs (BoxesDisplay* self, GString* builder) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (builder != NULL);
#line 299 "display.c"
}


void boxes_display_collect_logs (BoxesDisplay* self, GString* builder) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_GET_CLASS (self)->collect_logs (self, builder);
#line 308 "display.c"
}


static GList* boxes_display_real_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_critical ("Type `%s' does not implement abstract method `boxes_display_get_properties'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return NULL;
#line 317 "display.c"
}


GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_properties (self, page, flags);
#line 326 "display.c"
}


void boxes_display_access_start (BoxesDisplay* self) {
	gint64 _tmp0_ = 0LL;
	gint64 _tmp1_ = 0LL;
	BoxesBoxConfig* _tmp2_ = NULL;
	gint64 _tmp3_ = 0LL;
	BoxesBoxConfig* _tmp4_ = NULL;
	BoxesBoxConfig* _tmp5_ = NULL;
	gint64 _tmp6_ = 0LL;
	gint64 _tmp7_ = 0LL;
	BoxesBoxConfig* _tmp8_ = NULL;
	gint64 _tmp9_ = 0LL;
	gint64 _tmp10_ = 0LL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->started_time;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	if (_tmp0_ != ((gint64) 0)) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		return;
#line 350 "display.c"
	}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp1_ = g_get_monotonic_time ();
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->started_time = _tmp1_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp2_ = self->priv->_config;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp3_ = g_get_real_time ();
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	boxes_box_config_set_access_last_time (_tmp2_, _tmp3_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp4_ = self->priv->_config;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp5_ = self->priv->_config;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp6_ = boxes_box_config_get_access_ntimes (_tmp5_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp7_ = _tmp6_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	boxes_box_config_set_access_ntimes (_tmp5_, _tmp7_ + 1);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp8_ = self->priv->_config;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp9_ = boxes_box_config_get_access_first_time (_tmp8_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp10_ = _tmp9_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	if (_tmp10_ == ((gint64) 0)) {
#line 380 "display.c"
		BoxesBoxConfig* _tmp11_ = NULL;
		BoxesBoxConfig* _tmp12_ = NULL;
		gint64 _tmp13_ = 0LL;
		gint64 _tmp14_ = 0LL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		_tmp11_ = self->priv->_config;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		_tmp12_ = self->priv->_config;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		_tmp13_ = boxes_box_config_get_access_last_time (_tmp12_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		_tmp14_ = _tmp13_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_box_config_set_access_first_time (_tmp11_, _tmp14_);
#line 395 "display.c"
	}
}


void boxes_display_access_finish (BoxesDisplay* self) {
	gint64 _tmp0_ = 0LL;
	gint64 duration = 0LL;
	gint64 _tmp1_ = 0LL;
	gint64 _tmp2_ = 0LL;
	gint64 _tmp3_ = 0LL;
	BoxesBoxConfig* _tmp4_ = NULL;
	BoxesBoxConfig* _tmp5_ = NULL;
	gint64 _tmp6_ = 0LL;
	gint64 _tmp7_ = 0LL;
	gint64 _tmp8_ = 0LL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->started_time;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	if (_tmp0_ == ((gint64) 0)) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		return;
#line 419 "display.c"
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp1_ = g_get_monotonic_time ();
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp2_ = self->priv->started_time;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	duration = _tmp1_ - _tmp2_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp3_ = duration;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	duration = _tmp3_ / 1000000;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp4_ = self->priv->_config;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp5_ = self->priv->_config;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp6_ = boxes_box_config_get_access_total_time (_tmp5_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp7_ = _tmp6_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp8_ = duration;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	boxes_box_config_set_access_total_time (_tmp5_, _tmp7_ + _tmp8_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->started_time = (gint64) 0;
#line 445 "display.c"
}


BoxesDisplay* boxes_display_construct (GType object_type) {
	BoxesDisplay * self = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self = (BoxesDisplay*) g_object_new (object_type, NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return self;
#line 455 "display.c"
}


const gchar* boxes_display_get_protocol (BoxesDisplay* self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_protocol (self);
#line 464 "display.c"
}


gchar* boxes_display_get_uri (BoxesDisplay* self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return BOXES_DISPLAY_GET_CLASS (self)->get_uri (self);
#line 473 "display.c"
}


BoxesBoxConfig* boxes_display_get_config (BoxesDisplay* self) {
	BoxesBoxConfig* result;
	BoxesBoxConfig* _tmp0_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_config;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 488 "display.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return self ? g_object_ref (self) : NULL;
#line 495 "display.c"
}


void boxes_display_set_config (BoxesDisplay* self, BoxesBoxConfig* value) {
	BoxesBoxConfig* _tmp0_ = NULL;
	BoxesBoxConfig* _tmp1_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_object_unref0 (self->priv->_config);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_config = _tmp1_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "config");
#line 514 "display.c"
}


gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_can_grab_mouse;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 529 "display.c"
}


void boxes_display_set_can_grab_mouse (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_can_grab_mouse = _tmp0_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "can-grab-mouse");
#line 543 "display.c"
}


gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_mouse_grabbed;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 558 "display.c"
}


void boxes_display_set_mouse_grabbed (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_mouse_grabbed = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "mouse-grabbed");
#line 572 "display.c"
}


gboolean boxes_display_get_need_password (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_need_password;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 587 "display.c"
}


void boxes_display_set_need_password (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_need_password = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "need-password");
#line 601 "display.c"
}


gboolean boxes_display_get_need_username (BoxesDisplay* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_need_username;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 616 "display.c"
}


void boxes_display_set_need_username (BoxesDisplay* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_need_username = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "need-username");
#line 630 "display.c"
}


const gchar* boxes_display_get_password (BoxesDisplay* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_password;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 645 "display.c"
}


void boxes_display_set_password (BoxesDisplay* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_password);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_password = _tmp1_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "password");
#line 664 "display.c"
}


const gchar* boxes_display_get_username (BoxesDisplay* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = self->priv->_username;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	result = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return result;
#line 679 "display.c"
}


void boxes_display_set_username (BoxesDisplay* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_return_if_fail (self != NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = value;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_username);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv->_username = _tmp1_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_notify ((GObject *) self, "username");
#line 698 "display.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 705 "display.c"
}


static GObject * boxes_display_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesDisplay * self;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	parent_class = G_OBJECT_CLASS (boxes_display_parent_class);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp0_ = g_direct_hash;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp1_ = g_direct_equal;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, NULL, _g_object_unref0_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_hash_table_unref0 (self->displays);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->displays = _tmp2_;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	return obj;
#line 734 "display.c"
}


static void boxes_display_class_init (BoxesDisplayClass * klass) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	boxes_display_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_display = boxes_display_real_get_display;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_pixbuf = boxes_display_real_get_pixbuf;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_inputs = boxes_display_real_set_enable_inputs;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->set_enable_audio = boxes_display_real_set_enable_audio;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->should_keep_alive = boxes_display_real_should_keep_alive;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->connect_it = boxes_display_real_connect_it;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->disconnect_it = boxes_display_real_disconnect_it;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->collect_logs = boxes_display_real_collect_logs;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	BOXES_DISPLAY_CLASS (klass)->get_properties = boxes_display_real_get_properties;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_display_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_display_constructor;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_PROTOCOL, g_param_spec_string ("protocol", "protocol", "protocol", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_CONFIG, g_param_spec_object ("config", "config", "config", BOXES_TYPE_BOX_CONFIG, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_CAN_GRAB_MOUSE, g_param_spec_boolean ("can-grab-mouse", "can-grab-mouse", "can-grab-mouse", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_MOUSE_GRABBED, g_param_spec_boolean ("mouse-grabbed", "mouse-grabbed", "mouse-grabbed", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_NEED_PASSWORD, g_param_spec_boolean ("need-password", "need-password", "need-password", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_NEED_USERNAME, g_param_spec_boolean ("need-username", "need-username", "need-username", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_PASSWORD, g_param_spec_string ("password", "password", "password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_USERNAME, g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_signal_new ("show", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_signal_new ("hide", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__INT, G_TYPE_NONE, 1, G_TYPE_INT);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_signal_new ("disconnected", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	g_signal_new ("got_error", BOXES_TYPE_DISPLAY, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 795 "display.c"
}


static void boxes_display_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	boxes_display_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_display_get_properties;
#line 804 "display.c"
}


static void boxes_display_instance_init (BoxesDisplay * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self->priv = BOXES_DISPLAY_GET_PRIVATE (self);
#line 811 "display.c"
}


static void boxes_display_finalize (GObject* obj) {
	BoxesDisplay * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	boxes_display_access_finish (self);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_object_unref0 (self->priv->_config);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_password);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_free0 (self->priv->_username);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	_g_hash_table_unref0 (self->displays);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	G_OBJECT_CLASS (boxes_display_parent_class)->finalize (obj);
#line 831 "display.c"
}


GType boxes_display_get_type (void) {
	static volatile gsize boxes_display_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplay), 0, (GInstanceInitFunc) boxes_display_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_display_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_display_type_id;
		boxes_display_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDisplay", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (boxes_display_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_display_type_id__volatile, boxes_display_type_id);
	}
	return boxes_display_type_id__volatile;
}


static void _vala_boxes_display_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CONFIG:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_object (value, boxes_display_get_config (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CAN_GRAB_MOUSE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_can_grab_mouse (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_MOUSE_GRABBED:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_mouse_grabbed (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_need_password (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_USERNAME:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_boolean (value, boxes_display_get_need_username (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_string (value, boxes_display_get_password (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_USERNAME:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		g_value_set_string (value, boxes_display_get_username (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 896 "display.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 902 "display.c"
	}
}


static void _vala_boxes_display_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesDisplay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY, BoxesDisplay);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CONFIG:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_config (self, g_value_get_object (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_CAN_GRAB_MOUSE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_can_grab_mouse (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_MOUSE_GRABBED:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_mouse_grabbed (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_need_password (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_NEED_USERNAME:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_need_username (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_password (self, g_value_get_string (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		case BOXES_DISPLAY_USERNAME:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		boxes_display_set_username (self, g_value_get_string (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 954 "display.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/display.vala"
		break;
#line 960 "display.c"
	}
}



