/* mini-graph.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from mini-graph.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <float.h>
#include <math.h>
#include <cairo.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;
typedef struct _BoxesMiniGraphPrivate BoxesMiniGraphPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _BoxesMiniGraph {
	GtkDrawingArea parent_instance;
	BoxesMiniGraphPrivate * priv;
};

struct _BoxesMiniGraphClass {
	GtkDrawingAreaClass parent_class;
};

struct _BoxesMiniGraphPrivate {
	gdouble* _points;
	gint _points_length1;
	gint __points_size_;
	gint _npoints;
	gdouble _ymax;
	gboolean ymax_set;
};


static gpointer boxes_mini_graph_parent_class = NULL;

GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
#define BOXES_MINI_GRAPH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphPrivate))
enum  {
	BOXES_MINI_GRAPH_DUMMY_PROPERTY,
	BOXES_MINI_GRAPH_NPOINTS,
	BOXES_MINI_GRAPH_YMAX
};
static gdouble boxes_mini_graph_max (BoxesMiniGraph* self);
gdouble* boxes_mini_graph_get_points (BoxesMiniGraph* self, int* result_length1);
static gboolean boxes_mini_graph_real_draw (GtkWidget* base, cairo_t* cr);
gint boxes_mini_graph_get_npoints (BoxesMiniGraph* self);
gdouble boxes_mini_graph_get_ymax (BoxesMiniGraph* self);
BoxesMiniGraph* boxes_mini_graph_new (void);
BoxesMiniGraph* boxes_mini_graph_construct (GType object_type);
void boxes_mini_graph_set_points (BoxesMiniGraph* self, gdouble* value, int value_length1);
static gdouble* _vala_array_dup2 (gdouble* self, int length);
void boxes_mini_graph_set_npoints (BoxesMiniGraph* self, gint value);
void boxes_mini_graph_set_ymax (BoxesMiniGraph* self, gdouble value);
static void boxes_mini_graph_finalize (GObject* obj);
static void _vala_boxes_mini_graph_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_mini_graph_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static gdouble boxes_mini_graph_max (BoxesMiniGraph* self) {
	gdouble result = 0.0;
	gdouble* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gdouble* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gdouble max = 0.0;
	gdouble* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gdouble* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gdouble _tmp4_ = 0.0;
	gdouble* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	gdouble* _tmp6_ = NULL;
	gint _tmp6__length1 = 0;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = boxes_mini_graph_get_points (self, &_tmp0__length1);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1_ = _tmp0_;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1__length1 = _tmp0__length1;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	if (_tmp1__length1 == 0) {
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		result = 1.0;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		return result;
#line 102 "mini-graph.c"
	}
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp2_ = boxes_mini_graph_get_points (self, &_tmp2__length1);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp3_ = _tmp2_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp3__length1 = _tmp2__length1;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp4_ = _tmp3_[0];
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	max = _tmp4_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp5_ = boxes_mini_graph_get_points (self, &_tmp5__length1);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp6_ = _tmp5_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp6__length1 = _tmp5__length1;
#line 120 "mini-graph.c"
	{
		gdouble* p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		p_collection = _tmp6_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		p_collection_length1 = _tmp6__length1;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		for (p_it = 0; p_it < _tmp6__length1; p_it = p_it + 1) {
#line 132 "mini-graph.c"
			gdouble p = 0.0;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
			p = p_collection[p_it];
#line 136 "mini-graph.c"
			{
				gdouble _tmp7_ = 0.0;
				gdouble _tmp8_ = 0.0;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp7_ = p;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp8_ = max;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				if (_tmp7_ > _tmp8_) {
#line 146 "mini-graph.c"
					gdouble _tmp9_ = 0.0;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp9_ = p;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					max = _tmp9_;
#line 152 "mini-graph.c"
				}
			}
		}
	}
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	result = max;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return result;
#line 161 "mini-graph.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return self ? g_object_ref (self) : NULL;
#line 168 "mini-graph.c"
}


static gboolean boxes_mini_graph_real_draw (GtkWidget* base, cairo_t* cr) {
	BoxesMiniGraph * self;
	gboolean result = FALSE;
	gint width = 0;
	gint _tmp0_ = 0;
	gint height = 0;
	gint _tmp1_ = 0;
	GtkStyleContext* style = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkStyleContext* _tmp3_ = NULL;
	cairo_t* _tmp4_ = NULL;
	GtkStyleContext* _tmp5_ = NULL;
	GtkStateFlags _tmp6_ = 0;
	GdkRGBA _tmp7_ = {0};
	cairo_t* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	cairo_t* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint _tmp13_ = 0;
	gint nstep = 0;
	gdouble _tmp17_ = 0.0;
	gboolean _tmp18_ = FALSE;
	gdouble ymax = 0.0;
	gdouble dy = 0.0;
	gdouble dx = 0.0;
	gint _tmp22_ = 0;
	gdouble _tmp25_ = 0.0;
	cairo_t* _tmp28_ = NULL;
	GtkStyleContext* _tmp29_ = NULL;
	GdkRGBA _tmp30_ = {0};
	gdouble x = 0.0;
	gdouble* _tmp31_ = NULL;
	gint _tmp31__length1 = 0;
	gdouble* _tmp32_ = NULL;
	gint _tmp32__length1 = 0;
	cairo_t* _tmp45_ = NULL;
	gdouble _tmp46_ = 0.0;
	gdouble _tmp47_ = 0.0;
	gint _tmp48_ = 0;
	cairo_t* _tmp49_ = NULL;
	gint _tmp50_ = 0;
	cairo_t* _tmp51_ = NULL;
	cairo_t* _tmp52_ = NULL;
	GtkStyleContext* _tmp53_ = NULL;
	GtkStateFlags _tmp54_ = 0;
	GdkRGBA _tmp55_ = {0};
	cairo_t* _tmp56_ = NULL;
	gdouble* _tmp57_ = NULL;
	gint _tmp57__length1 = 0;
	gdouble* _tmp58_ = NULL;
	gint _tmp58__length1 = 0;
	cairo_t* _tmp71_ = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self = (BoxesMiniGraph*) base;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = gtk_widget_get_allocated_width ((GtkWidget*) self);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	width = _tmp0_;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1_ = gtk_widget_get_allocated_height ((GtkWidget*) self);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	height = _tmp1_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	style = _tmp3_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp4_ = cr;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp5_ = style;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp6_ = gtk_widget_get_state_flags ((GtkWidget*) self);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gtk_style_context_get_background_color (_tmp5_, _tmp6_, &_tmp7_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gdk_cairo_set_source_rgba (_tmp4_, &_tmp7_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp8_ = cr;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp9_ = width;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp10_ = height;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_rectangle (_tmp8_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp9_, (gdouble) _tmp10_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp11_ = cr;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_fill (_tmp11_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp13_ = self->priv->_npoints;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	if (_tmp13_ == (-1)) {
#line 269 "mini-graph.c"
		gdouble* _tmp14_ = NULL;
		gint _tmp14__length1 = 0;
		gdouble* _tmp15_ = NULL;
		gint _tmp15__length1 = 0;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp14_ = boxes_mini_graph_get_points (self, &_tmp14__length1);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp15_ = _tmp14_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp15__length1 = _tmp14__length1;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp12_ = _tmp15__length1;
#line 282 "mini-graph.c"
	} else {
		gint _tmp16_ = 0;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp16_ = self->priv->_npoints;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp12_ = _tmp16_;
#line 289 "mini-graph.c"
	}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	nstep = _tmp12_ - 1;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp18_ = self->priv->ymax_set;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	if (_tmp18_) {
#line 297 "mini-graph.c"
		gdouble _tmp19_ = 0.0;
		gdouble _tmp20_ = 0.0;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp19_ = boxes_mini_graph_get_ymax (self);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp20_ = _tmp19_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp17_ = _tmp20_;
#line 306 "mini-graph.c"
	} else {
		gdouble _tmp21_ = 0.0;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp21_ = boxes_mini_graph_max (self);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp17_ = _tmp21_;
#line 313 "mini-graph.c"
	}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	ymax = _tmp17_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	dy = 0.0;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	dx = 0.0;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp22_ = nstep;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	if (_tmp22_ != 0) {
#line 325 "mini-graph.c"
		gint _tmp23_ = 0;
		gint _tmp24_ = 0;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp23_ = width;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp24_ = nstep;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		dx = ((gdouble) _tmp23_) / _tmp24_;
#line 334 "mini-graph.c"
	}
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp25_ = ymax;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	if (_tmp25_ != ((gdouble) 0)) {
#line 340 "mini-graph.c"
		gint _tmp26_ = 0;
		gdouble _tmp27_ = 0.0;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp26_ = height;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		_tmp27_ = ymax;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		dy = ((gdouble) _tmp26_) / _tmp27_;
#line 349 "mini-graph.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp28_ = cr;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp29_ = style;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gtk_style_context_get_color (_tmp29_, GTK_STATE_FLAG_NORMAL, &_tmp30_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gdk_cairo_set_source_rgba (_tmp28_, &_tmp30_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	x = 0.0;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp31_ = boxes_mini_graph_get_points (self, &_tmp31__length1);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp32_ = _tmp31_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp32__length1 = _tmp31__length1;
#line 367 "mini-graph.c"
	{
		gdouble* p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		p_collection = _tmp32_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		p_collection_length1 = _tmp32__length1;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		for (p_it = 0; p_it < _tmp32__length1; p_it = p_it + 1) {
#line 379 "mini-graph.c"
			gdouble p = 0.0;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
			p = p_collection[p_it];
#line 383 "mini-graph.c"
			{
				gdouble y = 0.0;
				gint _tmp33_ = 0;
				gdouble _tmp34_ = 0.0;
				gdouble _tmp35_ = 0.0;
				gdouble _tmp36_ = 0.0;
				gdouble _tmp43_ = 0.0;
				gdouble _tmp44_ = 0.0;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp33_ = height;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp34_ = p;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp35_ = dy;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				y = _tmp33_ - (_tmp34_ * _tmp35_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp36_ = x;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				if (_tmp36_ == 0.0) {
#line 404 "mini-graph.c"
					cairo_t* _tmp37_ = NULL;
					gdouble _tmp38_ = 0.0;
					gdouble _tmp39_ = 0.0;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp37_ = cr;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp38_ = x;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp39_ = y;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					cairo_move_to (_tmp37_, _tmp38_, _tmp39_);
#line 416 "mini-graph.c"
				} else {
					cairo_t* _tmp40_ = NULL;
					gdouble _tmp41_ = 0.0;
					gdouble _tmp42_ = 0.0;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp40_ = cr;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp41_ = x;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp42_ = y;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					cairo_line_to (_tmp40_, _tmp41_, _tmp42_);
#line 429 "mini-graph.c"
				}
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp43_ = x;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp44_ = dx;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				x = _tmp43_ + _tmp44_;
#line 437 "mini-graph.c"
			}
		}
	}
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp45_ = cr;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp46_ = x;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp47_ = dx;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp48_ = height;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_line_to (_tmp45_, _tmp46_ - _tmp47_, (gdouble) _tmp48_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp49_ = cr;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp50_ = height;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_line_to (_tmp49_, (gdouble) 0, (gdouble) _tmp50_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp51_ = cr;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_fill (_tmp51_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp52_ = cr;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp53_ = style;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp54_ = gtk_widget_get_state_flags ((GtkWidget*) self);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gtk_style_context_get_border_color (_tmp53_, _tmp54_, &_tmp55_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gdk_cairo_set_source_rgba (_tmp52_, &_tmp55_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp56_ = cr;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_set_line_width (_tmp56_, 1.0);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	x = 0.0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp57_ = boxes_mini_graph_get_points (self, &_tmp57__length1);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp58_ = _tmp57_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp58__length1 = _tmp57__length1;
#line 483 "mini-graph.c"
	{
		gdouble* p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		p_collection = _tmp58_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		p_collection_length1 = _tmp58__length1;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		for (p_it = 0; p_it < _tmp58__length1; p_it = p_it + 1) {
#line 495 "mini-graph.c"
			gdouble p = 0.0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
			p = p_collection[p_it];
#line 499 "mini-graph.c"
			{
				gdouble y = 0.0;
				gint _tmp59_ = 0;
				gdouble _tmp60_ = 0.0;
				gdouble _tmp61_ = 0.0;
				gdouble _tmp62_ = 0.0;
				gdouble _tmp69_ = 0.0;
				gdouble _tmp70_ = 0.0;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp59_ = height;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp60_ = p;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp61_ = dy;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				y = _tmp59_ - (_tmp60_ * _tmp61_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp62_ = x;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				if (_tmp62_ == 0.0) {
#line 520 "mini-graph.c"
					cairo_t* _tmp63_ = NULL;
					gdouble _tmp64_ = 0.0;
					gdouble _tmp65_ = 0.0;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp63_ = cr;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp64_ = x;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp65_ = y;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					cairo_move_to (_tmp63_, _tmp64_, _tmp65_);
#line 532 "mini-graph.c"
				} else {
					cairo_t* _tmp66_ = NULL;
					gdouble _tmp67_ = 0.0;
					gdouble _tmp68_ = 0.0;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp66_ = cr;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp67_ = x;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					_tmp68_ = y;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
					cairo_line_to (_tmp66_, _tmp67_, _tmp68_);
#line 545 "mini-graph.c"
				}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp69_ = x;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				_tmp70_ = dx;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
				x = _tmp69_ + _tmp70_;
#line 553 "mini-graph.c"
			}
		}
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp71_ = cr;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	cairo_stroke (_tmp71_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	result = TRUE;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_g_object_unref0 (style);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return result;
#line 567 "mini-graph.c"
}


BoxesMiniGraph* boxes_mini_graph_construct (GType object_type) {
	BoxesMiniGraph * self = NULL;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self = (BoxesMiniGraph*) g_object_new (object_type, NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return self;
#line 577 "mini-graph.c"
}


BoxesMiniGraph* boxes_mini_graph_new (void) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return boxes_mini_graph_construct (BOXES_TYPE_MINI_GRAPH);
#line 584 "mini-graph.c"
}


gdouble* boxes_mini_graph_get_points (BoxesMiniGraph* self, int* result_length1) {
	gdouble* result;
	gdouble* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gdouble* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = self->priv->_points;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0__length1 = self->priv->_points_length1;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1_ = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1__length1 = _tmp0__length1;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	if (result_length1) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		*result_length1 = _tmp1__length1;
#line 608 "mini-graph.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	result = _tmp1_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return result;
#line 614 "mini-graph.c"
}


static gdouble* _vala_array_dup2 (gdouble* self, int length) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return g_memdup (self, length * sizeof (gdouble));
#line 621 "mini-graph.c"
}


void boxes_mini_graph_set_points (BoxesMiniGraph* self, gdouble* value, int value_length1) {
	gdouble* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	gdouble* _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_if_fail (self != NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = value;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0__length1 = value_length1;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup2 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp1__length1 = _tmp0__length1;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_points = (g_free (self->priv->_points), NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_points = _tmp1_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_points_length1 = _tmp1__length1;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->__points_size_ = self->priv->_points_length1;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 650 "mini-graph.c"
}


gint boxes_mini_graph_get_npoints (BoxesMiniGraph* self) {
	gint result;
	gint _tmp0_ = 0;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = self->priv->_npoints;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	result = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return result;
#line 665 "mini-graph.c"
}


void boxes_mini_graph_set_npoints (BoxesMiniGraph* self, gint value) {
	gint _tmp0_ = 0;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_if_fail (self != NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = value;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_npoints = _tmp0_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_object_notify ((GObject *) self, "npoints");
#line 679 "mini-graph.c"
}


gdouble boxes_mini_graph_get_ymax (BoxesMiniGraph* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = self->priv->_ymax;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	return result;
#line 694 "mini-graph.c"
}


void boxes_mini_graph_set_ymax (BoxesMiniGraph* self, gdouble value) {
	gdouble _tmp0_ = 0.0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_ymax = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->ymax_set = TRUE;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_object_notify ((GObject *) self, "ymax");
#line 710 "mini-graph.c"
}


static void boxes_mini_graph_class_init (BoxesMiniGraphClass * klass) {
	gint BoxesMiniGraph_private_offset;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	boxes_mini_graph_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_type_class_add_private (klass, sizeof (BoxesMiniGraphPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	GTK_WIDGET_CLASS (klass)->draw = boxes_mini_graph_real_draw;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_mini_graph_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_mini_graph_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_mini_graph_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MINI_GRAPH_NPOINTS, g_param_spec_int ("npoints", "npoints", "npoints", G_MININT, G_MAXINT, -1, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MINI_GRAPH_YMAX, g_param_spec_double ("ymax", "ymax", "ymax", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	BoxesMiniGraph_private_offset = g_type_class_get_instance_private_offset (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/mini-graph.ui");
#line 736 "mini-graph.c"
}


static void boxes_mini_graph_instance_init (BoxesMiniGraph * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv = BOXES_MINI_GRAPH_GET_PRIVATE (self);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_npoints = -1;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->ymax_set = FALSE;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 749 "mini-graph.c"
}


static void boxes_mini_graph_finalize (GObject* obj) {
	BoxesMiniGraph * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	self->priv->_points = (g_free (self->priv->_points), NULL);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	G_OBJECT_CLASS (boxes_mini_graph_parent_class)->finalize (obj);
#line 761 "mini-graph.c"
}


GType boxes_mini_graph_get_type (void) {
	static volatile gsize boxes_mini_graph_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_mini_graph_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMiniGraphClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_mini_graph_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMiniGraph), 0, (GInstanceInitFunc) boxes_mini_graph_instance_init, NULL };
		GType boxes_mini_graph_type_id;
		boxes_mini_graph_type_id = g_type_register_static (GTK_TYPE_DRAWING_AREA, "BoxesMiniGraph", &g_define_type_info, 0);
		g_once_init_leave (&boxes_mini_graph_type_id__volatile, boxes_mini_graph_type_id);
	}
	return boxes_mini_graph_type_id__volatile;
}


static void _vala_boxes_mini_graph_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMiniGraph * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		case BOXES_MINI_GRAPH_NPOINTS:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		g_value_set_int (value, boxes_mini_graph_get_npoints (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		case BOXES_MINI_GRAPH_YMAX:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		g_value_set_double (value, boxes_mini_graph_get_ymax (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		break;
#line 794 "mini-graph.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		break;
#line 800 "mini-graph.c"
	}
}


static void _vala_boxes_mini_graph_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMiniGraph * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		case BOXES_MINI_GRAPH_NPOINTS:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		boxes_mini_graph_set_npoints (self, g_value_get_int (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		case BOXES_MINI_GRAPH_YMAX:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		boxes_mini_graph_set_ymax (self, g_value_get_double (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		break;
#line 822 "mini-graph.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/mini-graph.vala"
		break;
#line 828 "mini-graph.c"
	}
}



