/* unattended-setup-box.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from unattended-setup-box.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _BoxesUnattendedSetupBoxPrivate BoxesUnattendedSetupBoxPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _BoxesUnattendedSetupBox {
	GtkBox parent_instance;
	BoxesUnattendedSetupBoxPrivate * priv;
};

struct _BoxesUnattendedSetupBoxClass {
	GtkBoxClass parent_class;
};

struct _BoxesUnattendedSetupBoxPrivate {
	GtkGrid* setup_grid;
	GtkLabel* express_label;
	GtkSwitch* express_toggle;
	GtkImage* user_avatar;
	GtkEntry* username_entry;
	GtkNotebook* password_notebook;
	GtkEntry* password_entry;
	GtkLabel* product_key_label;
	GtkEntry* product_key_entry;
	gchar* product_key_format;
	gboolean we_inserted_text;
};


static gpointer boxes_unattended_setup_box_parent_class = NULL;

GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_SETUP_BOX_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxPrivate))
enum  {
	BOXES_UNATTENDED_SETUP_BOX_DUMMY_PROPERTY,
	BOXES_UNATTENDED_SETUP_BOX_READY_FOR_EXPRESS,
	BOXES_UNATTENDED_SETUP_BOX_READY_TO_CREATE,
	BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL,
	BOXES_UNATTENDED_SETUP_BOX_USERNAME,
	BOXES_UNATTENDED_SETUP_BOX_PASSWORD,
	BOXES_UNATTENDED_SETUP_BOX_HIDDEN_PASSWORD,
	BOXES_UNATTENDED_SETUP_BOX_PRODUCT_KEY,
	BOXES_UNATTENDED_SETUP_BOX_AVATAR_PATH
};
BoxesUnattendedSetupBox* boxes_unattended_setup_box_new (gboolean live, const gchar* product_key_format);
BoxesUnattendedSetupBox* boxes_unattended_setup_box_construct (GType object_type, gboolean live, const gchar* product_key_format);
static void boxes_unattended_setup_box_on_mandatory_input_changed (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_mandatory_input_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_unattended_setup_box_on_username_entry_activated (BoxesUnattendedSetupBox* self);
gboolean boxes_unattended_setup_box_get_ready_for_express (BoxesUnattendedSetupBox* self);
const gchar* boxes_unattended_setup_box_get_username (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_username_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_setup_box_on_password_button_clicked (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_password_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean boxes_unattended_setup_box_on_password_entry_focus_out (BoxesUnattendedSetupBox* self);
static gboolean _boxes_unattended_setup_box_on_password_entry_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void boxes_unattended_setup_box_on_password_entry_activated (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_password_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_setup_box_on_key_entry_activated (BoxesUnattendedSetupBox* self);
static void _boxes_unattended_setup_box_on_key_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_unattended_setup_box_on_key_text_inserted (BoxesUnattendedSetupBox* self, const gchar* text, gint text_length, gint* position);
static void _boxes_unattended_setup_box_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self);
gboolean boxes_unattended_setup_box_get_ready_to_create (BoxesUnattendedSetupBox* self);
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
void boxes_unattended_setup_box_set_express_install (BoxesUnattendedSetupBox* self, gboolean value);
gchar* boxes_unattended_setup_box_get_password (BoxesUnattendedSetupBox* self);
gchar* boxes_unattended_setup_box_get_hidden_password (BoxesUnattendedSetupBox* self);
gchar* boxes_unattended_setup_box_get_product_key (BoxesUnattendedSetupBox* self);
void boxes_unattended_setup_box_set_avatar_path (BoxesUnattendedSetupBox* self, const gchar* value);
static void boxes_unattended_setup_box_finalize (GObject* obj);
static void _vala_boxes_unattended_setup_box_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_unattended_setup_box_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


BoxesUnattendedSetupBox* boxes_unattended_setup_box_construct (GType object_type, gboolean live, const gchar* product_key_format) {
	BoxesUnattendedSetupBox * self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GtkSwitch* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GtkEntry* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GtkGrid* _tmp17_ = NULL;
	GList* _tmp18_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self = (BoxesUnattendedSetupBox*) g_object_new (object_type, NULL);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = product_key_format;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (self->priv->product_key_format);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self->priv->product_key_format = _tmp1_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = self->priv->express_toggle;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = live;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_switch_set_active (_tmp2_, !_tmp3_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp4_ = self->priv->username_entry;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp5_ = g_get_user_name ();
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_entry_set_text (_tmp4_, _tmp5_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp6_ = product_key_format;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp6_ != NULL) {
#line 138 "unattended-setup-box.c"
		GtkLabel* _tmp7_ = NULL;
		GtkEntry* _tmp8_ = NULL;
		GtkEntry* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		GtkEntry* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gint _tmp15_ = 0;
		gint _tmp16_ = 0;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp7_ = self->priv->product_key_label;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, TRUE);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp8_ = self->priv->product_key_entry;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp8_, TRUE);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp9_ = self->priv->product_key_entry;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp10_ = product_key_format;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp11_ = strlen (_tmp10_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp12_ = _tmp11_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_entry_set_width_chars (_tmp9_, _tmp12_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp13_ = self->priv->product_key_entry;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp14_ = product_key_format;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp15_ = strlen (_tmp14_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp16_ = _tmp15_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_entry_set_max_length (_tmp13_, _tmp16_);
#line 177 "unattended-setup-box.c"
	}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp17_ = self->priv->setup_grid;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp18_ = gtk_container_get_children ((GtkContainer*) _tmp17_);
#line 183 "unattended-setup-box.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		child_collection = _tmp18_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 191 "unattended-setup-box.c"
			GtkWidget* child = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			child = (GtkWidget*) child_it->data;
#line 195 "unattended-setup-box.c"
			{
				gboolean _tmp19_ = FALSE;
				GtkWidget* _tmp20_ = NULL;
				GtkLabel* _tmp21_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp20_ = child;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp21_ = self->priv->express_label;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp20_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GTK_TYPE_WIDGET, GtkWidget)) {
#line 206 "unattended-setup-box.c"
					GtkWidget* _tmp22_ = NULL;
					GtkSwitch* _tmp23_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp22_ = child;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp23_ = self->priv->express_toggle;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp19_ = _tmp22_ != G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GTK_TYPE_WIDGET, GtkWidget);
#line 215 "unattended-setup-box.c"
				} else {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp19_ = FALSE;
#line 219 "unattended-setup-box.c"
				}
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp19_) {
#line 223 "unattended-setup-box.c"
					GtkSwitch* _tmp24_ = NULL;
					GtkWidget* _tmp25_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp24_ = self->priv->express_toggle;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp25_ = child;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					g_object_bind_property_with_closures ((GObject*) _tmp24_, "active", (GObject*) _tmp25_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 232 "unattended-setup-box.c"
				}
			}
		}
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_list_free0 (child_collection);
#line 238 "unattended-setup-box.c"
	}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return self;
#line 242 "unattended-setup-box.c"
}


BoxesUnattendedSetupBox* boxes_unattended_setup_box_new (gboolean live, const gchar* product_key_format) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return boxes_unattended_setup_box_construct (BOXES_TYPE_UNATTENDED_SETUP_BOX, live, product_key_format);
#line 249 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_mandatory_input_changed (BoxesUnattendedSetupBox* self) {
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_notify ((GObject*) self, "ready-to-create");
#line 258 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_on_mandatory_input_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_mandatory_input_changed ((BoxesUnattendedSetupBox*) self);
#line 265 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_username_entry_activated (BoxesUnattendedSetupBox* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = _tmp0_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_signal_emit_by_name (self, "user-wants-to-create");
#line 282 "unattended-setup-box.c"
	} else {
		gboolean _tmp2_ = FALSE;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = boxes_unattended_setup_box_get_username (self);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _tmp3_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (g_strcmp0 (_tmp4_, "") != 0) {
#line 293 "unattended-setup-box.c"
			const gchar* _tmp5_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp5_ = self->priv->product_key_format;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp2_ = _tmp5_ != NULL;
#line 299 "unattended-setup-box.c"
		} else {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp2_ = FALSE;
#line 303 "unattended-setup-box.c"
		}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp2_) {
#line 307 "unattended-setup-box.c"
			GtkEntry* _tmp6_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp6_ = self->priv->product_key_entry;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 313 "unattended-setup-box.c"
		}
	}
}


static void _boxes_unattended_setup_box_on_username_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_username_entry_activated ((BoxesUnattendedSetupBox*) self);
#line 322 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_password_button_clicked (BoxesUnattendedSetupBox* self) {
	GtkNotebook* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_notebook;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_notebook_next_page (_tmp0_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->password_entry;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 339 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_on_password_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_password_button_clicked ((BoxesUnattendedSetupBox*) self);
#line 346 "unattended-setup-box.c"
}


static gboolean boxes_unattended_setup_box_on_password_entry_focus_out (BoxesUnattendedSetupBox* self) {
	gboolean result = FALSE;
	GtkEntry* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	guint _tmp2_ = 0U;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_entry;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text_length (_tmp0_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp2_ == ((guint) 0)) {
#line 365 "unattended-setup-box.c"
		GtkNotebook* _tmp3_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = self->priv->password_notebook;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_notebook_prev_page (_tmp3_);
#line 371 "unattended-setup-box.c"
	}
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = FALSE;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 377 "unattended-setup-box.c"
}


static gboolean _boxes_unattended_setup_box_on_password_entry_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = boxes_unattended_setup_box_on_password_entry_focus_out ((BoxesUnattendedSetupBox*) self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 386 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_password_entry_activated (BoxesUnattendedSetupBox* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = _tmp0_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_) {
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_signal_emit_by_name (self, "user-wants-to-create");
#line 403 "unattended-setup-box.c"
	} else {
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = boxes_unattended_setup_box_get_username (self);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = _tmp2_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (g_strcmp0 (_tmp3_, "") == 0) {
#line 413 "unattended-setup-box.c"
			GtkEntry* _tmp4_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp4_ = self->priv->username_entry;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp4_);
#line 419 "unattended-setup-box.c"
		} else {
			const gchar* _tmp5_ = NULL;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp5_ = self->priv->product_key_format;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			if (_tmp5_ != NULL) {
#line 426 "unattended-setup-box.c"
				GtkEntry* _tmp6_ = NULL;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp6_ = self->priv->product_key_entry;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 432 "unattended-setup-box.c"
			}
		}
	}
}


static void _boxes_unattended_setup_box_on_password_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_password_entry_activated ((BoxesUnattendedSetupBox*) self);
#line 442 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_key_entry_activated (BoxesUnattendedSetupBox* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = _tmp0_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_) {
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_signal_emit_by_name (self, "user-wants-to-create");
#line 459 "unattended-setup-box.c"
	} else {
		GtkEntry* _tmp2_ = NULL;
		guint _tmp3_ = 0U;
		guint _tmp4_ = 0U;
		const gchar* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->product_key_entry;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = gtk_entry_get_text_length (_tmp2_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _tmp3_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = self->priv->product_key_format;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp6_ = strlen (_tmp5_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp7_ = _tmp6_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp4_ == ((guint) _tmp7_)) {
#line 481 "unattended-setup-box.c"
			GtkEntry* _tmp8_ = NULL;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp8_ = self->priv->username_entry;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 487 "unattended-setup-box.c"
		}
	}
}


static void _boxes_unattended_setup_box_on_key_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_key_entry_activated ((BoxesUnattendedSetupBox*) self);
#line 496 "unattended-setup-box.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_ = 0L;
	gchar _tmp1_ = '\0';
#line 996 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 997 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 514 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_on_key_text_inserted (BoxesUnattendedSetupBox* self, const gchar* text, gint text_length, gint* position) {
	gboolean _tmp0_ = FALSE;
	gchar* _result_ = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp40_ = NULL;
	GtkEntry* _tmp48_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (text != NULL);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->we_inserted_text;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp0_) {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 534 "unattended-setup-box.c"
	}
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = g_strdup ("");
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_result_ = _tmp1_;
#line 540 "unattended-setup-box.c"
	{
		guint i = 0U;
		guint j = 0U;
		gint _tmp2_ = 0;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		i = (guint) 0;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = *position;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		j = (guint) _tmp2_;
#line 551 "unattended-setup-box.c"
		{
			gboolean _tmp3_ = FALSE;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp3_ = TRUE;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			while (TRUE) {
#line 558 "unattended-setup-box.c"
				gboolean _tmp4_ = FALSE;
				guint _tmp5_ = 0U;
				gint _tmp6_ = 0;
				gchar character = '\0';
				const gchar* _tmp11_ = NULL;
				guint _tmp12_ = 0U;
				gchar _tmp13_ = '\0';
				gchar allowed_char = '\0';
				const gchar* _tmp14_ = NULL;
				guint _tmp15_ = 0U;
				gchar _tmp16_ = '\0';
				gboolean skip_input_char = FALSE;
				gchar _tmp17_ = '\0';
				guint _tmp32_ = 0U;
				gboolean _tmp33_ = FALSE;
				const gchar* _tmp34_ = NULL;
				gchar _tmp35_ = '\0';
				gchar* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				guint _tmp39_ = 0U;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (!_tmp3_) {
#line 582 "unattended-setup-box.c"
				}
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp3_ = FALSE;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp5_ = i;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp6_ = text_length;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp5_ < ((guint) _tmp6_)) {
#line 592 "unattended-setup-box.c"
					guint _tmp7_ = 0U;
					const gchar* _tmp8_ = NULL;
					gint _tmp9_ = 0;
					gint _tmp10_ = 0;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp7_ = j;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp8_ = self->priv->product_key_format;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp9_ = strlen (_tmp8_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp10_ = _tmp9_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp4_ = _tmp7_ < ((guint) _tmp10_);
#line 607 "unattended-setup-box.c"
				} else {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp4_ = FALSE;
#line 611 "unattended-setup-box.c"
				}
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (!_tmp4_) {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					break;
#line 617 "unattended-setup-box.c"
				}
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp11_ = text;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp12_ = i;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp13_ = string_get (_tmp11_, (glong) _tmp12_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				character = _tmp13_;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp14_ = self->priv->product_key_format;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp15_ = j;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp16_ = string_get (_tmp14_, (glong) _tmp15_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				allowed_char = _tmp16_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				skip_input_char = FALSE;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp17_ = allowed_char;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				switch (_tmp17_) {
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '@':
#line 643 "unattended-setup-box.c"
					{
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 647 "unattended-setup-box.c"
					}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '%':
#line 651 "unattended-setup-box.c"
					{
						gchar _tmp18_ = '\0';
						gboolean _tmp19_ = FALSE;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp18_ = character;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp19_ = g_ascii_isalpha (_tmp18_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (!_tmp19_) {
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							skip_input_char = TRUE;
#line 663 "unattended-setup-box.c"
						}
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 667 "unattended-setup-box.c"
					}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '#':
#line 671 "unattended-setup-box.c"
					{
						gchar _tmp20_ = '\0';
						gboolean _tmp21_ = FALSE;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp20_ = character;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp21_ = g_ascii_isdigit (_tmp20_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (!_tmp21_) {
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							skip_input_char = TRUE;
#line 683 "unattended-setup-box.c"
						}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 687 "unattended-setup-box.c"
					}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					case '$':
#line 691 "unattended-setup-box.c"
					{
						gchar _tmp22_ = '\0';
						gboolean _tmp23_ = FALSE;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp22_ = character;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp23_ = g_ascii_isalnum (_tmp22_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (!_tmp23_) {
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							skip_input_char = TRUE;
#line 703 "unattended-setup-box.c"
						}
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 707 "unattended-setup-box.c"
					}
					default:
					{
						gchar _tmp24_ = '\0';
						gchar _tmp25_ = '\0';
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp24_ = character;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp25_ = allowed_char;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						if (_tmp24_ != _tmp25_) {
#line 719 "unattended-setup-box.c"
							const gchar* _tmp26_ = NULL;
							gchar _tmp27_ = '\0';
							gchar* _tmp28_ = NULL;
							gchar* _tmp29_ = NULL;
							gchar* _tmp30_ = NULL;
							guint _tmp31_ = 0U;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp26_ = _result_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp27_ = allowed_char;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp28_ = g_strdup_printf ("%c", _tmp27_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp29_ = _tmp28_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp30_ = g_strconcat (_tmp26_, _tmp29_, NULL);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_g_free0 (_result_);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_result_ = _tmp30_;
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_g_free0 (_tmp29_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							_tmp31_ = j;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							j = _tmp31_ + 1;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
							continue;
#line 748 "unattended-setup-box.c"
						}
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 752 "unattended-setup-box.c"
					}
				}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp32_ = i;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				i = _tmp32_ + 1;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp33_ = skip_input_char;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				if (_tmp33_) {
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					continue;
#line 765 "unattended-setup-box.c"
				}
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp34_ = _result_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp35_ = character;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp36_ = g_strdup_printf ("%c", _tmp35_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp37_ = _tmp36_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp38_ = g_strconcat (_tmp34_, _tmp37_, NULL);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_g_free0 (_result_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_result_ = _tmp38_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_g_free0 (_tmp37_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp39_ = j;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				j = _tmp39_ + 1;
#line 787 "unattended-setup-box.c"
			}
		}
	}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp40_ = _result_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (g_strcmp0 (_tmp40_, "") != 0) {
#line 795 "unattended-setup-box.c"
		GtkEntry* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		const gchar* _tmp45_ = NULL;
		gint _tmp46_ = 0;
		gint _tmp47_ = 0;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		self->priv->we_inserted_text = TRUE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp41_ = self->priv->product_key_entry;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp42_ = _result_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp43_ = g_utf8_strup (_tmp42_, (gssize) (-1));
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp44_ = _tmp43_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp45_ = _result_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp46_ = strlen (_tmp45_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp47_ = _tmp46_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		gtk_editable_insert_text ((GtkEditable*) _tmp41_, _tmp44_, _tmp47_, position);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_free0 (_tmp44_);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		self->priv->we_inserted_text = FALSE;
#line 825 "unattended-setup-box.c"
	}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp48_ = self->priv->product_key_entry;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_stop_emission_by_name (_tmp48_, "insert-text");
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (_result_);
#line 833 "unattended-setup-box.c"
}


static void _boxes_unattended_setup_box_on_key_text_inserted_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_on_key_text_inserted ((BoxesUnattendedSetupBox*) self, new_text, new_text_length, position);
#line 840 "unattended-setup-box.c"
}


gboolean boxes_unattended_setup_box_get_ready_for_express (BoxesUnattendedSetupBox* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = boxes_unattended_setup_box_get_username (self);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (g_strcmp0 (_tmp2_, "") != 0) {
#line 857 "unattended-setup-box.c"
		gboolean _tmp3_ = FALSE;
		const gchar* _tmp4_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = self->priv->product_key_format;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (_tmp4_ == NULL) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp3_ = TRUE;
#line 866 "unattended-setup-box.c"
		} else {
			GtkEntry* _tmp5_ = NULL;
			guint _tmp6_ = 0U;
			guint _tmp7_ = 0U;
			const gchar* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gint _tmp10_ = 0;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp5_ = self->priv->product_key_entry;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp6_ = gtk_entry_get_text_length (_tmp5_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp7_ = _tmp6_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp8_ = self->priv->product_key_format;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp9_ = strlen (_tmp8_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp10_ = _tmp9_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			_tmp3_ = _tmp7_ == ((guint) _tmp10_);
#line 888 "unattended-setup-box.c"
		}
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp3_;
#line 892 "unattended-setup-box.c"
	} else {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = FALSE;
#line 896 "unattended-setup-box.c"
	}
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 902 "unattended-setup-box.c"
}


gboolean boxes_unattended_setup_box_get_ready_to_create (BoxesUnattendedSetupBox* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	GtkSwitch* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->express_toggle;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = gtk_switch_get_active (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (!_tmp3_) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = TRUE;
#line 924 "unattended-setup-box.c"
	} else {
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = boxes_unattended_setup_box_get_ready_for_express (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp5_;
#line 934 "unattended-setup-box.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 940 "unattended-setup-box.c"
}


gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self) {
	gboolean result;
	GtkSwitch* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->express_toggle;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_switch_get_active (_tmp0_);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp2_;
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 961 "unattended-setup-box.c"
}


void boxes_unattended_setup_box_set_express_install (BoxesUnattendedSetupBox* self, gboolean value) {
	GtkSwitch* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->express_toggle;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = value;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_switch_set_active (_tmp0_, _tmp1_);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_notify ((GObject *) self, "express-install");
#line 978 "unattended-setup-box.c"
}


const gchar* boxes_unattended_setup_box_get_username (BoxesUnattendedSetupBox* self) {
	const gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->username_entry;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp2_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 999 "unattended-setup-box.c"
}


gchar* boxes_unattended_setup_box_get_password (BoxesUnattendedSetupBox* self) {
	gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_entry;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp3_;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1023 "unattended-setup-box.c"
}


static gchar* g_unichar_to_string (gunichar self) {
	gchar* result = NULL;
	gchar* str = NULL;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 857 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 7);
#line 857 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	str = (gchar*) _tmp0_;
#line 858 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = str;
#line 858 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_unichar_to_utf8 (self, _tmp1_);
#line 859 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = str;
#line 859 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1044 "unattended-setup-box.c"
}


gchar* boxes_unattended_setup_box_get_hidden_password (BoxesUnattendedSetupBox* self) {
	gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp0_ = self->priv->password_entry;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp2_ = _tmp1_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp3_ = strlen (_tmp2_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp4_ = _tmp3_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp4_ > 0) {
#line 1069 "unattended-setup-box.c"
		gchar* str = NULL;
		gchar* _tmp5_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = g_strdup ("");
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		str = _tmp5_;
#line 1076 "unattended-setup-box.c"
		{
			gint i = 0;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
			i = 0;
#line 1081 "unattended-setup-box.c"
			{
				gboolean _tmp6_ = FALSE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				_tmp6_ = TRUE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
				while (TRUE) {
#line 1088 "unattended-setup-box.c"
					gint _tmp8_ = 0;
					GtkEntry* _tmp9_ = NULL;
					guint _tmp10_ = 0U;
					guint _tmp11_ = 0U;
					const gchar* _tmp12_ = NULL;
					GtkEntry* _tmp13_ = NULL;
					gunichar _tmp14_ = 0U;
					gchar* _tmp15_ = NULL;
					gchar* _tmp16_ = NULL;
					gchar* _tmp17_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					if (!_tmp6_) {
#line 1101 "unattended-setup-box.c"
						gint _tmp7_ = 0;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						_tmp7_ = i;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						i = _tmp7_ + 1;
#line 1107 "unattended-setup-box.c"
					}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp6_ = FALSE;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp8_ = i;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp9_ = self->priv->password_entry;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp10_ = gtk_entry_get_text_length (_tmp9_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp11_ = _tmp10_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					if (!(((guint) _tmp8_) < _tmp11_)) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
						break;
#line 1123 "unattended-setup-box.c"
					}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp12_ = str;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp13_ = self->priv->password_entry;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp14_ = gtk_entry_get_invisible_char (_tmp13_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp15_ = g_unichar_to_string (_tmp14_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp16_ = _tmp15_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_tmp17_ = g_strconcat (_tmp12_, _tmp16_, NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_g_free0 (str);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					str = _tmp17_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
					_g_free0 (_tmp16_);
#line 1143 "unattended-setup-box.c"
				}
			}
		}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		result = str;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return result;
#line 1151 "unattended-setup-box.c"
	} else {
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp18_ = _ ("no password");
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp19_ = g_strdup (_tmp18_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		result = _tmp19_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return result;
#line 1163 "unattended-setup-box.c"
	}
}


gchar* boxes_unattended_setup_box_get_product_key (BoxesUnattendedSetupBox* self) {
	gchar* result;
	const gchar* _tmp0_ = NULL;
	GtkEntry* _tmp1_ = NULL;
	gchar* _tmp5_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp1_ = self->priv->product_key_entry;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (_tmp1_ != NULL) {
#line 1179 "unattended-setup-box.c"
		GtkEntry* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->product_key_entry;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _tmp3_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = _tmp4_;
#line 1191 "unattended-setup-box.c"
	} else {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = NULL;
#line 1195 "unattended-setup-box.c"
	}
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_tmp5_ = g_strdup (_tmp0_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	result = _tmp5_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	return result;
#line 1203 "unattended-setup-box.c"
}


void boxes_unattended_setup_box_set_avatar_path (BoxesUnattendedSetupBox* self, const gchar* value) {
	GError * _inner_error_ = NULL;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_return_if_fail (self != NULL);
#line 1211 "unattended-setup-box.c"
	{
		GdkPixbuf* pixbuf = NULL;
		const gchar* _tmp0_ = NULL;
		GdkPixbuf* _tmp1_ = NULL;
		GtkImage* _tmp2_ = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp0_ = value;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp1_ = gdk_pixbuf_new_from_file_at_scale (_tmp0_, 64, 64, TRUE, &_inner_error_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		pixbuf = _tmp1_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1225 "unattended-setup-box.c"
			goto __catch82_g_error;
		}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp2_ = self->priv->user_avatar;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_object_set (_tmp2_, "pixbuf", pixbuf, NULL);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_object_unref0 (pixbuf);
#line 1234 "unattended-setup-box.c"
	}
	goto __finally82;
	__catch82_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp3_ = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_error_ = _inner_error_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_inner_error_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp3_ = value;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp4_ = _error_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_tmp5_ = _tmp4_->message;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_debug ("unattended-setup-box.vala:62: Failed to load user avatar file '%s': %s", _tmp3_, _tmp5_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		_g_error_free0 (_error_);
#line 1257 "unattended-setup-box.c"
	}
	__finally82:
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_clear_error (&_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		return;
#line 1268 "unattended-setup-box.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_notify ((GObject *) self, "avatar-path");
#line 1272 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_class_init (BoxesUnattendedSetupBoxClass * klass) {
	gint BoxesUnattendedSetupBox_private_offset;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	boxes_unattended_setup_box_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedSetupBoxPrivate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_setup_box_get_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_unattended_setup_box_set_property;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_setup_box_finalize;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_READY_FOR_EXPRESS, g_param_spec_boolean ("ready-for-express", "ready-for-express", "ready-for-express", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_READY_TO_CREATE, g_param_spec_boolean ("ready-to-create", "ready-to-create", "ready-to-create", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL, g_param_spec_boolean ("express-install", "express-install", "express-install", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_USERNAME, g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_PASSWORD, g_param_spec_string ("password", "password", "password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_HIDDEN_PASSWORD, g_param_spec_string ("hidden-password", "hidden-password", "hidden-password", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_PRODUCT_KEY, g_param_spec_string ("product-key", "product-key", "product-key", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SETUP_BOX_AVATAR_PATH, g_param_spec_string ("avatar-path", "avatar-path", "avatar-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	BoxesUnattendedSetupBox_private_offset = g_type_class_get_instance_private_offset (klass);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/unattended-setup-box.ui");
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	g_signal_new ("user_wants_to_create", BOXES_TYPE_UNATTENDED_SETUP_BOX, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_grid", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, setup_grid));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "express_label", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, express_label));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "express_toggle", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, express_toggle));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "user_avatar", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, user_avatar));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "username_entry", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, username_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "password_notebook", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, password_notebook));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "password_entry", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, password_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "product_key_label", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, product_key_label));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "product_key_entry", FALSE, BoxesUnattendedSetupBox_private_offset + G_STRUCT_OFFSET (BoxesUnattendedSetupBoxPrivate, product_key_entry));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_mandatory_input_changed", G_CALLBACK(_boxes_unattended_setup_box_on_mandatory_input_changed_g_object_notify));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_username_entry_activated", G_CALLBACK(_boxes_unattended_setup_box_on_username_entry_activated_gtk_entry_activate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_button_clicked", G_CALLBACK(_boxes_unattended_setup_box_on_password_button_clicked_gtk_button_clicked));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_entry_focus_out", G_CALLBACK(_boxes_unattended_setup_box_on_password_entry_focus_out_gtk_widget_focus_out_event));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_entry_activated", G_CALLBACK(_boxes_unattended_setup_box_on_password_entry_activated_gtk_entry_activate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_key_entry_activated", G_CALLBACK(_boxes_unattended_setup_box_on_key_entry_activated_gtk_entry_activate));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_key_text_inserted", G_CALLBACK(_boxes_unattended_setup_box_on_key_text_inserted_gtk_editable_insert_text));
#line 1342 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_instance_init (BoxesUnattendedSetupBox * self) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self->priv = BOXES_UNATTENDED_SETUP_BOX_GET_PRIVATE (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1351 "unattended-setup-box.c"
}


static void boxes_unattended_setup_box_finalize (GObject* obj) {
	BoxesUnattendedSetupBox * self;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->setup_grid);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->express_label);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->express_toggle);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->user_avatar);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->password_notebook);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->product_key_label);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_object_unref0 (self->priv->product_key_entry);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	_g_free0 (self->priv->product_key_format);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	G_OBJECT_CLASS (boxes_unattended_setup_box_parent_class)->finalize (obj);
#line 1381 "unattended-setup-box.c"
}


GType boxes_unattended_setup_box_get_type (void) {
	static volatile gsize boxes_unattended_setup_box_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_setup_box_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedSetupBoxClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_setup_box_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedSetupBox), 0, (GInstanceInitFunc) boxes_unattended_setup_box_instance_init, NULL };
		GType boxes_unattended_setup_box_type_id;
		boxes_unattended_setup_box_type_id = g_type_register_static (GTK_TYPE_BOX, "BoxesUnattendedSetupBox", &g_define_type_info, 0);
		g_once_init_leave (&boxes_unattended_setup_box_type_id__volatile, boxes_unattended_setup_box_type_id);
	}
	return boxes_unattended_setup_box_type_id__volatile;
}


static void _vala_boxes_unattended_setup_box_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedSetupBox * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_READY_FOR_EXPRESS:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_boolean (value, boxes_unattended_setup_box_get_ready_for_express (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_READY_TO_CREATE:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_boolean (value, boxes_unattended_setup_box_get_ready_to_create (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_boolean (value, boxes_unattended_setup_box_get_express_install (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_USERNAME:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_set_string (value, boxes_unattended_setup_box_get_username (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_take_string (value, boxes_unattended_setup_box_get_password (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_HIDDEN_PASSWORD:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_take_string (value, boxes_unattended_setup_box_get_hidden_password (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_PRODUCT_KEY:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		g_value_take_string (value, boxes_unattended_setup_box_get_product_key (self));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 1444 "unattended-setup-box.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 1450 "unattended-setup-box.c"
	}
}


static void _vala_boxes_unattended_setup_box_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesUnattendedSetupBox * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
	switch (property_id) {
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_EXPRESS_INSTALL:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_express_install (self, g_value_get_boolean (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		case BOXES_UNATTENDED_SETUP_BOX_AVATAR_PATH:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		boxes_unattended_setup_box_set_avatar_path (self, g_value_get_string (value));
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 1472 "unattended-setup-box.c"
		default:
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-setup-box.vala"
		break;
#line 1478 "unattended-setup-box.c"
	}
}



