/* collection-toolbar.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from collection-toolbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_COLLECTION_TOOLBAR (boxes_collection_toolbar_get_type ())
#define BOXES_COLLECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbar))
#define BOXES_COLLECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbarClass))
#define BOXES_IS_COLLECTION_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_TOOLBAR))
#define BOXES_IS_COLLECTION_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_TOOLBAR))
#define BOXES_COLLECTION_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbarClass))

typedef struct _BoxesCollectionToolbar BoxesCollectionToolbar;
typedef struct _BoxesCollectionToolbarClass BoxesCollectionToolbarClass;
typedef struct _BoxesCollectionToolbarPrivate BoxesCollectionToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _BoxesCollectionToolbar {
	GtkHeaderBar parent_instance;
	BoxesCollectionToolbarPrivate * priv;
};

struct _BoxesCollectionToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesCollectionToolbarPrivate {
	GtkButton* search_btn;
	GtkButton* select_btn;
	GtkButton* back_btn;
	GtkImage* back_image;
	GtkButton* new_btn;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_collection_toolbar_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;
extern BoxesApp* boxes_app_app;

GType boxes_collection_toolbar_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbarPrivate))
enum  {
	BOXES_COLLECTION_TOOLBAR_DUMMY_PROPERTY
};
void boxes_collection_toolbar_setup_ui (BoxesCollectionToolbar* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
static void boxes_collection_toolbar_update_select_btn (BoxesCollectionToolbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
static void _boxes_collection_toolbar_update_select_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_collection_toolbar_update_select_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void boxes_collection_toolbar_update_search_btn (BoxesCollectionToolbar* self);
static void _boxes_collection_toolbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_collection_toolbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void boxes_collection_toolbar_on_new_btn_clicked (BoxesCollectionToolbar* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void _boxes_collection_toolbar_on_new_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_collection_toolbar_on_back_btn_clicked (BoxesCollectionToolbar* self);
static void _boxes_collection_toolbar_on_back_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_collection_toolbar_on_select_btn_clicked (BoxesCollectionToolbar* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void _boxes_collection_toolbar_on_select_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_collection_toolbar_click_back_button (BoxesCollectionToolbar* self);
static void boxes_collection_toolbar_ui_state_changed (BoxesCollectionToolbar* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesCollectionToolbar* boxes_collection_toolbar_new (void);
BoxesCollectionToolbar* boxes_collection_toolbar_construct (GType object_type);
static GObject * boxes_collection_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_collection_toolbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_toolbar_finalize (GObject* obj);


static void _boxes_collection_toolbar_update_select_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_update_select_btn ((BoxesCollectionToolbar*) self);
#line 313 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_update_select_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_update_select_btn ((BoxesCollectionToolbar*) self);
#line 320 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_update_search_btn_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_update_search_btn ((BoxesCollectionToolbar*) self);
#line 327 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_update_search_btn_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_update_search_btn ((BoxesCollectionToolbar*) self);
#line 334 "collection-toolbar.c"
}


void boxes_collection_toolbar_setup_ui (BoxesCollectionToolbar* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesSearchbar* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
	BoxesCollection* _tmp4_ = NULL;
	BoxesApp* _tmp5_ = NULL;
	BoxesCollection* _tmp6_ = NULL;
	BoxesApp* _tmp7_ = NULL;
	BoxesCollection* _tmp8_ = NULL;
	BoxesApp* _tmp9_ = NULL;
	BoxesCollection* _tmp10_ = NULL;
	GtkButton* _tmp11_ = NULL;
	BoxesAppWindow* _tmp12_ = NULL;
	BoxesSearchbar* _tmp13_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = boxes_app_window;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_vala_assert (_tmp0_ != NULL, "App.window != null");
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp1_ = boxes_app_window;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp2_ = _tmp1_->searchbar;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_vala_assert (_tmp2_ != NULL, "App.window.searchbar != null");
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_update_select_btn (self);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp3_ = boxes_app_app;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp4_ = _tmp3_->collection;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_signal_connect_object (_tmp4_, "item-added", (GCallback) _boxes_collection_toolbar_update_select_btn_boxes_collection_item_added, self, 0);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp5_ = boxes_app_app;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp6_ = _tmp5_->collection;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_signal_connect_object (_tmp6_, "item-removed", (GCallback) _boxes_collection_toolbar_update_select_btn_boxes_collection_item_removed, self, 0);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_update_search_btn (self);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp7_ = boxes_app_app;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp8_ = _tmp7_->collection;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_signal_connect_object (_tmp8_, "item-added", (GCallback) _boxes_collection_toolbar_update_search_btn_boxes_collection_item_added, self, 0);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp9_ = boxes_app_app;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp10_ = _tmp9_->collection;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_signal_connect_object (_tmp10_, "item-removed", (GCallback) _boxes_collection_toolbar_update_search_btn_boxes_collection_item_removed, self, 0);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp11_ = self->priv->search_btn;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp12_ = boxes_app_window;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp13_ = _tmp12_->searchbar;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp11_, "active", (GObject*) _tmp13_, "search-mode-enabled", G_BINDING_BIDIRECTIONAL, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 401 "collection-toolbar.c"
}


static void boxes_collection_toolbar_on_new_btn_clicked (BoxesCollectionToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 413 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_on_new_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_on_new_btn_clicked ((BoxesCollectionToolbar*) self);
#line 420 "collection-toolbar.c"
}


static void boxes_collection_toolbar_on_back_btn_clicked (BoxesCollectionToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 432 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_on_back_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_on_back_btn_clicked ((BoxesCollectionToolbar*) self);
#line 439 "collection-toolbar.c"
}


static void boxes_collection_toolbar_on_select_btn_clicked (BoxesCollectionToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_app_set_selection_mode (_tmp0_, TRUE);
#line 451 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_on_select_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_on_select_btn_clicked ((BoxesCollectionToolbar*) self);
#line 458 "collection-toolbar.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_ = 0U;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4410 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 473 "collection-toolbar.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_ = 0;
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = value;
#line 4411 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 485 "collection-toolbar.c"
}


static void boxes_collection_toolbar_update_search_btn (BoxesCollectionToolbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = self->priv->search_btn;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp1_ = boxes_app_app;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp3_ = _tmp2_->items;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 512 "collection-toolbar.c"
}


static void boxes_collection_toolbar_update_select_btn (BoxesCollectionToolbar* self) {
	GtkButton* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
	BoxesCollection* _tmp2_ = NULL;
	GPtrArray* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = self->priv->select_btn;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp1_ = boxes_app_app;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp3_ = _tmp2_->items;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp5_ = _tmp4_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 539 "collection-toolbar.c"
}


void boxes_collection_toolbar_click_back_button (BoxesCollectionToolbar* self) {
	GtkButton* _tmp0_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = self->priv->back_btn;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_button_clicked (_tmp0_);
#line 551 "collection-toolbar.c"
}


static void boxes_collection_toolbar_ui_state_changed (BoxesCollectionToolbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_return_if_fail (self != NULL);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp0_ = boxes_app_app;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp2_ = _tmp1_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	switch (_tmp2_) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 571 "collection-toolbar.c"
		{
			GtkButton* _tmp3_ = NULL;
			GtkButton* _tmp4_ = NULL;
			GtkButton* _tmp5_ = NULL;
			GtkButton* _tmp6_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp3_ = self->priv->back_btn;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp3_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp4_ = self->priv->select_btn;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp4_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp5_ = self->priv->search_btn;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp5_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp6_ = self->priv->new_btn;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp6_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			break;
#line 595 "collection-toolbar.c"
		}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 599 "collection-toolbar.c"
		{
			GtkButton* _tmp7_ = NULL;
			GtkButton* _tmp8_ = NULL;
			GtkButton* _tmp9_ = NULL;
			GtkButton* _tmp10_ = NULL;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp7_ = self->priv->new_btn;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp7_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp8_ = self->priv->back_btn;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp8_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp9_ = self->priv->select_btn;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp9_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			_tmp10_ = self->priv->search_btn;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp10_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			break;
#line 623 "collection-toolbar.c"
		}
		default:
		{
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
			break;
#line 629 "collection-toolbar.c"
		}
	}
}


BoxesCollectionToolbar* boxes_collection_toolbar_construct (GType object_type) {
	BoxesCollectionToolbar * self = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	self = (BoxesCollectionToolbar*) g_object_new (object_type, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	return self;
#line 641 "collection-toolbar.c"
}


BoxesCollectionToolbar* boxes_collection_toolbar_new (void) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	return boxes_collection_toolbar_construct (BOXES_TYPE_COLLECTION_TOOLBAR);
#line 648 "collection-toolbar.c"
}


static void _boxes_collection_toolbar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_ui_state_changed ((BoxesCollectionToolbar*) self);
#line 655 "collection-toolbar.c"
}


static GObject * boxes_collection_toolbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesCollectionToolbar * self;
	const gchar* _tmp0_ = NULL;
	GtkTextDirection _tmp1_ = 0;
	gchar* back_icon = NULL;
	gchar* _tmp2_ = NULL;
	GtkImage* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	BoxesApp* _tmp5_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_collection_toolbar_parent_class);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbar);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp1_ = gtk_widget_get_direction ((GtkWidget*) self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	if (_tmp1_ == GTK_TEXT_DIR_RTL) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
		_tmp0_ = "go-previous-rtl-symbolic";
#line 682 "collection-toolbar.c"
	} else {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
		_tmp0_ = "go-previous-symbolic";
#line 686 "collection-toolbar.c"
	}
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp2_ = g_strdup (_tmp0_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	back_icon = _tmp2_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp3_ = self->priv->back_image;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp4_ = back_icon;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_image_set_from_icon_name (_tmp3_, _tmp4_, GTK_ICON_SIZE_MENU);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_tmp5_ = boxes_app_app;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_signal_connect_object ((GObject*) _tmp5_, "notify::ui-state", (GCallback) _boxes_collection_toolbar_ui_state_changed_g_object_notify, self, 0);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_g_free0 (back_icon);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	return obj;
#line 706 "collection-toolbar.c"
}


static void boxes_collection_toolbar_class_init (BoxesCollectionToolbarClass * klass) {
	gint BoxesCollectionToolbar_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	boxes_collection_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionToolbarPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_collection_toolbar_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_toolbar_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	BoxesCollectionToolbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/collection-toolbar.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "search_btn", FALSE, BoxesCollectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesCollectionToolbarPrivate, search_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "select_btn", FALSE, BoxesCollectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesCollectionToolbarPrivate, select_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_btn", FALSE, BoxesCollectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesCollectionToolbarPrivate, back_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "back_image", FALSE, BoxesCollectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesCollectionToolbarPrivate, back_image));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "new_btn", FALSE, BoxesCollectionToolbar_private_offset + G_STRUCT_OFFSET (BoxesCollectionToolbarPrivate, new_btn));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_new_btn_clicked", G_CALLBACK(_boxes_collection_toolbar_on_new_btn_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_back_btn_clicked", G_CALLBACK(_boxes_collection_toolbar_on_back_btn_clicked_gtk_button_clicked));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_select_btn_clicked", G_CALLBACK(_boxes_collection_toolbar_on_select_btn_clicked_gtk_button_clicked));
#line 740 "collection-toolbar.c"
}


static void boxes_collection_toolbar_instance_init (BoxesCollectionToolbar * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	self->priv = BOXES_COLLECTION_TOOLBAR_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 749 "collection-toolbar.c"
}


static void boxes_collection_toolbar_finalize (GObject* obj) {
	BoxesCollectionToolbar * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_TOOLBAR, BoxesCollectionToolbar);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_g_object_unref0 (self->priv->search_btn);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_g_object_unref0 (self->priv->select_btn);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_g_object_unref0 (self->priv->back_btn);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_g_object_unref0 (self->priv->back_image);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	_g_object_unref0 (self->priv->new_btn);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-toolbar.vala"
	G_OBJECT_CLASS (boxes_collection_toolbar_parent_class)->finalize (obj);
#line 769 "collection-toolbar.c"
}


GType boxes_collection_toolbar_get_type (void) {
	static volatile gsize boxes_collection_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionToolbar), 0, (GInstanceInitFunc) boxes_collection_toolbar_instance_init, NULL };
		GType boxes_collection_toolbar_type_id;
		boxes_collection_toolbar_type_id = g_type_register_static (GTK_TYPE_HEADER_BAR, "BoxesCollectionToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_collection_toolbar_type_id__volatile, boxes_collection_toolbar_type_id);
	}
	return boxes_collection_toolbar_type_id__volatile;
}



