/* sidebar.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from sidebar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libgd/gd.h>
#include <gio/gio.h>


#define BOXES_TYPE_SIDEBAR_PAGE (boxes_sidebar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;
typedef struct _BoxesSidebarPrivate BoxesSidebarPrivate;

#define BOXES_TYPE_MINI_GRAPH (boxes_mini_graph_get_type ())
#define BOXES_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraph))
#define BOXES_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))
#define BOXES_IS_MINI_GRAPH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MINI_GRAPH))
#define BOXES_IS_MINI_GRAPH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MINI_GRAPH))
#define BOXES_MINI_GRAPH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MINI_GRAPH, BoxesMiniGraphClass))

typedef struct _BoxesMiniGraph BoxesMiniGraph;
typedef struct _BoxesMiniGraphClass BoxesMiniGraphClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

typedef enum  {
	BOXES_SIDEBAR_PAGE_COLLECTION,
	BOXES_SIDEBAR_PAGE_WIZARD,
	BOXES_SIDEBAR_PAGE_PROPERTIES
} BoxesSidebarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesSidebar {
	GtkRevealer parent_instance;
	BoxesSidebarPrivate * priv;
	GtkImage* screenshot;
	GtkListStore* props_listmodel;
	GtkTreeSelection* props_selection;
	GtkButton* shutdown_button;
	BoxesMiniGraph* cpu_graph;
	BoxesMiniGraph* io_graph;
	BoxesMiniGraph* net_graph;
};

struct _BoxesSidebarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesSidebarPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkNotebook* notebook;
	GtkBox* wizard_vbox;
	GtkLabel* wizard_intro_label;
	GtkLabel* wizard_source_label;
	GtkLabel* wizard_preparation_label;
	GtkLabel* wizard_setup_label;
	GtkLabel* wizard_review_label;
	GtkTreeModelFilter* props_model_filter;
};

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};


static gpointer boxes_sidebar_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_sidebar_boxes_ui_parent_iface = NULL;

GType boxes_sidebar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_mini_graph_get_type (void) G_GNUC_CONST;
#define BOXES_SIDEBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SIDEBAR, BoxesSidebarPrivate))
enum  {
	BOXES_SIDEBAR_DUMMY_PROPERTY,
	BOXES_SIDEBAR_PREVIOUS_UI_STATE,
	BOXES_SIDEBAR_UI_STATE
};
GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
void boxes_sidebar_set_wizard_page (BoxesSidebar* self, BoxesWizardPage wizard_page);
static void boxes_sidebar_ui_state_changed (BoxesSidebar* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void boxes_sidebar_setup_sidebar (BoxesSidebar* self);
static void boxes_sidebar_on_props_row_activated (BoxesSidebar* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
void boxes_properties_set_page (BoxesProperties* self, BoxesPropertiesPage value);
static void _boxes_sidebar_on_props_row_activated_gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self);
static void boxes_sidebar_on_shutdown_button_clicked (BoxesSidebar* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm);
static void _boxes_sidebar_on_shutdown_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesSidebar* boxes_sidebar_new (void);
BoxesSidebar* boxes_sidebar_construct (GType object_type);
static GObject * boxes_sidebar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_sidebar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_sidebar_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_sidebar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_sidebar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GType boxes_sidebar_page_get_type (void) {
	static volatile gsize boxes_sidebar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_sidebar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SIDEBAR_PAGE_COLLECTION, "BOXES_SIDEBAR_PAGE_COLLECTION", "collection"}, {BOXES_SIDEBAR_PAGE_WIZARD, "BOXES_SIDEBAR_PAGE_WIZARD", "wizard"}, {BOXES_SIDEBAR_PAGE_PROPERTIES, "BOXES_SIDEBAR_PAGE_PROPERTIES", "properties"}, {0, NULL, NULL}};
		GType boxes_sidebar_page_type_id;
		boxes_sidebar_page_type_id = g_enum_register_static ("BoxesSidebarPage", values);
		g_once_init_leave (&boxes_sidebar_page_type_id__volatile, boxes_sidebar_page_type_id);
	}
	return boxes_sidebar_page_type_id__volatile;
}


static gpointer _g_object_ref0 (gpointer self) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return self ? g_object_ref (self) : NULL;
#line 378 "sidebar.c"
}


void boxes_sidebar_set_wizard_page (BoxesSidebar* self, BoxesWizardPage wizard_page) {
	GtkBox* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GtkLabel* current_label = NULL;
	BoxesWizardPage _tmp4_ = 0;
	GtkLabel* _tmp15_ = NULL;
	GtkStyleContext* _tmp16_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->wizard_vbox;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = gtk_container_get_children ((GtkContainer*) _tmp0_);
#line 395 "sidebar.c"
	{
		GList* label_collection = NULL;
		GList* label_it = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		label_collection = _tmp1_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		for (label_it = label_collection; label_it != NULL; label_it = label_it->next) {
#line 403 "sidebar.c"
			GtkWidget* label = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			label = (GtkWidget*) label_it->data;
#line 407 "sidebar.c"
			{
				GtkWidget* _tmp2_ = NULL;
				GtkStyleContext* _tmp3_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp2_ = label;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp3_ = gtk_widget_get_style_context (_tmp2_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				gtk_style_context_remove_class (_tmp3_, "boxes-wizard-current-page-label");
#line 417 "sidebar.c"
			}
		}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_g_list_free0 (label_collection);
#line 422 "sidebar.c"
	}
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	current_label = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp4_ = wizard_page;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch ((gint) _tmp4_) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_WIZARD_PAGE_INTRODUCTION:
#line 432 "sidebar.c"
		{
			GtkLabel* _tmp5_ = NULL;
			GtkLabel* _tmp6_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp5_ = self->priv->wizard_intro_label;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp6_ = _g_object_ref0 (_tmp5_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_g_object_unref0 (current_label);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			current_label = _tmp6_;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 446 "sidebar.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_WIZARD_PAGE_SOURCE:
#line 450 "sidebar.c"
		{
			GtkLabel* _tmp7_ = NULL;
			GtkLabel* _tmp8_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp7_ = self->priv->wizard_source_label;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp8_ = _g_object_ref0 (_tmp7_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_g_object_unref0 (current_label);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			current_label = _tmp8_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 464 "sidebar.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_WIZARD_PAGE_PREPARATION:
#line 468 "sidebar.c"
		{
			GtkLabel* _tmp9_ = NULL;
			GtkLabel* _tmp10_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp9_ = self->priv->wizard_preparation_label;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp10_ = _g_object_ref0 (_tmp9_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_g_object_unref0 (current_label);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			current_label = _tmp10_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 482 "sidebar.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_WIZARD_PAGE_SETUP:
#line 486 "sidebar.c"
		{
			GtkLabel* _tmp11_ = NULL;
			GtkLabel* _tmp12_ = NULL;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp11_ = self->priv->wizard_setup_label;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp12_ = _g_object_ref0 (_tmp11_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_g_object_unref0 (current_label);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			current_label = _tmp12_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 500 "sidebar.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_WIZARD_PAGE_REVIEW:
#line 504 "sidebar.c"
		{
			GtkLabel* _tmp13_ = NULL;
			GtkLabel* _tmp14_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp13_ = self->priv->wizard_review_label;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp14_ = _g_object_ref0 (_tmp13_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_g_object_unref0 (current_label);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			current_label = _tmp14_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 518 "sidebar.c"
		}
		default:
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 523 "sidebar.c"
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp15_ = current_label;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp16_ = gtk_widget_get_style_context ((GtkWidget*) _tmp15_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_style_context_add_class (_tmp16_, "boxes-wizard-current-page-label");
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (current_label);
#line 533 "sidebar.c"
}


static void boxes_sidebar_ui_state_changed (BoxesSidebar* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = _tmp0_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (_tmp1_) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 552 "sidebar.c"
		{
			BoxesSidebarPage _tmp2_ = 0;
			BoxesUIState _tmp3_ = 0;
			BoxesUIState _tmp4_ = 0;
			GtkNotebook* _tmp5_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			gtk_revealer_set_reveal_child ((GtkRevealer*) self, TRUE);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp3_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp4_ = _tmp3_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			if (_tmp4_ == BOXES_UI_STATE_WIZARD) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp2_ = BOXES_SIDEBAR_PAGE_WIZARD;
#line 568 "sidebar.c"
			} else {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
				_tmp2_ = BOXES_SIDEBAR_PAGE_PROPERTIES;
#line 572 "sidebar.c"
			}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			_tmp5_ = self->priv->notebook;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			g_object_set (_tmp5_, "page", (gint) _tmp2_, NULL);
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 580 "sidebar.c"
		}
		default:
		{
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			gtk_revealer_set_reveal_child ((GtkRevealer*) self, FALSE);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
			break;
#line 588 "sidebar.c"
		}
	}
}


static void boxes_sidebar_setup_sidebar (BoxesSidebar* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->props_model_filter;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_tree_model_filter_set_visible_column (_tmp0_, 1);
#line 602 "sidebar.c"
}


static void boxes_sidebar_on_props_row_activated (BoxesSidebar* self, GtkTreeView* treeview, GtkTreePath* path, GtkTreeViewColumn* column) {
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	GtkTreeIter _tmp5_ = {0};
	BoxesAppWindow* _tmp6_ = NULL;
	BoxesProperties* _tmp7_ = NULL;
	GtkListStore* _tmp8_ = NULL;
	GtkTreeIter _tmp9_ = {0};
	GtkTreePath* _tmp10_ = NULL;
	GtkTreePath* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint* _tmp13_ = NULL;
	gint _tmp14_ = 0;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (treeview != NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (path != NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (column != NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->props_model_filter;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = path;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	filter_iter = _tmp2_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp3_ = self->priv->props_model_filter;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp4_ = filter_iter;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iter = _tmp5_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp6_ = boxes_app_window;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp7_ = _tmp6_->properties;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp8_ = self->props_listmodel;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp9_ = iter;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp10_ = gtk_tree_model_get_path ((GtkTreeModel*) _tmp8_, &_tmp9_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp11_ = _tmp10_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp13_ = gtk_tree_path_get_indices_with_depth (_tmp11_, &_tmp12_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp14_ = _tmp13_[0];
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_properties_set_page (_tmp7_, (BoxesPropertiesPage) _tmp14_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_gtk_tree_path_free0 (_tmp11_);
#line 668 "sidebar.c"
}


static void _boxes_sidebar_on_props_row_activated_gtk_tree_view_row_activated (GtkTreeView* _sender, GtkTreePath* path, GtkTreeViewColumn* column, gpointer self) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_on_props_row_activated ((BoxesSidebar*) self, _sender, path, column);
#line 675 "sidebar.c"
}


static void boxes_sidebar_on_shutdown_button_clicked (BoxesSidebar* self) {
	BoxesLibvirtMachine* machine = NULL;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	BoxesLibvirtMachine* _tmp3_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_return_if_fail (self != NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = boxes_app_app;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp1_ = _tmp0_->current_item;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp1_) : NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	machine = _tmp2_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp3_ = machine;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	if (_tmp3_ != NULL) {
#line 699 "sidebar.c"
		BoxesLibvirtMachine* _tmp4_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		_tmp4_ = machine;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		boxes_libvirt_machine_force_shutdown (_tmp4_, TRUE);
#line 705 "sidebar.c"
	}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (machine);
#line 709 "sidebar.c"
}


static void _boxes_sidebar_on_shutdown_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_on_shutdown_button_clicked ((BoxesSidebar*) self);
#line 716 "sidebar.c"
}


BoxesSidebar* boxes_sidebar_construct (GType object_type) {
	BoxesSidebar * self = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) g_object_new (object_type, NULL);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return self;
#line 726 "sidebar.c"
}


BoxesSidebar* boxes_sidebar_new (void) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return boxes_sidebar_construct (BOXES_TYPE_SIDEBAR);
#line 733 "sidebar.c"
}


static BoxesUIState boxes_sidebar_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 749 "sidebar.c"
}


static void boxes_sidebar_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = value;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 764 "sidebar.c"
}


static BoxesUIState boxes_sidebar_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = self->priv->_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	result = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return result;
#line 780 "sidebar.c"
}


static void boxes_sidebar_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesSidebar* self;
	BoxesUIState _tmp0_ = 0;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = (BoxesSidebar*) base;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_tmp0_ = value;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv->_ui_state = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 795 "sidebar.c"
}


static void _boxes_sidebar_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_ui_state_changed ((BoxesSidebar*) self);
#line 802 "sidebar.c"
}


static GObject * boxes_sidebar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSidebar * self;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	parent_class = G_OBJECT_CLASS (boxes_sidebar_parent_class);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_sidebar_ui_state_changed_g_object_notify, self, 0);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_setup_sidebar (self);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	return obj;
#line 822 "sidebar.c"
}


static void boxes_sidebar_class_init (BoxesSidebarClass * klass) {
	gint BoxesSidebar_private_offset;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSidebarPrivate));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_sidebar_get_property;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_sidebar_set_property;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_sidebar_constructor;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_sidebar_finalize;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SIDEBAR_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SIDEBAR_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	BoxesSidebar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/sidebar.ui");
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "notebook", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, notebook));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_vbox", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, wizard_vbox));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_intro_label", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, wizard_intro_label));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_source_label", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, wizard_source_label));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_preparation_label", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, wizard_preparation_label));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_setup_label", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, wizard_setup_label));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_review_label", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, wizard_review_label));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "screenshot", FALSE, G_STRUCT_OFFSET (BoxesSidebar, screenshot));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_listmodel", FALSE, G_STRUCT_OFFSET (BoxesSidebar, props_listmodel));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_model_filter", FALSE, BoxesSidebar_private_offset + G_STRUCT_OFFSET (BoxesSidebarPrivate, props_model_filter));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "props_selection", FALSE, G_STRUCT_OFFSET (BoxesSidebar, props_selection));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "shutdown_button", FALSE, G_STRUCT_OFFSET (BoxesSidebar, shutdown_button));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "cpu_graph", FALSE, G_STRUCT_OFFSET (BoxesSidebar, cpu_graph));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "io_graph", FALSE, G_STRUCT_OFFSET (BoxesSidebar, io_graph));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "net_graph", FALSE, G_STRUCT_OFFSET (BoxesSidebar, net_graph));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_props_row_activated", G_CALLBACK(_boxes_sidebar_on_props_row_activated_gtk_tree_view_row_activated));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_shutdown_button_clicked", G_CALLBACK(_boxes_sidebar_on_shutdown_button_clicked_gtk_button_clicked));
#line 882 "sidebar.c"
}


static void boxes_sidebar_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	boxes_sidebar_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->get_previous_ui_state = boxes_sidebar_real_get_previous_ui_state;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->set_previous_ui_state = boxes_sidebar_real_set_previous_ui_state;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->get_ui_state = boxes_sidebar_real_get_ui_state;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	iface->set_ui_state = boxes_sidebar_real_set_ui_state;
#line 897 "sidebar.c"
}


static void boxes_sidebar_instance_init (BoxesSidebar * self) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self->priv = BOXES_SIDEBAR_GET_PRIVATE (self);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	g_type_ensure (BOXES_TYPE_MINI_GRAPH);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 908 "sidebar.c"
}


static void boxes_sidebar_finalize (GObject* obj) {
	BoxesSidebar * self;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->notebook);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->wizard_vbox);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->wizard_intro_label);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->wizard_source_label);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->wizard_preparation_label);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->wizard_setup_label);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->wizard_review_label);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->screenshot);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->props_listmodel);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->priv->props_model_filter);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->props_selection);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->shutdown_button);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->cpu_graph);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->io_graph);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	_g_object_unref0 (self->net_graph);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	G_OBJECT_CLASS (boxes_sidebar_parent_class)->finalize (obj);
#line 948 "sidebar.c"
}


GType boxes_sidebar_get_type (void) {
	static volatile gsize boxes_sidebar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_sidebar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSidebarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_sidebar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSidebar), 0, (GInstanceInitFunc) boxes_sidebar_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_sidebar_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_sidebar_type_id;
		boxes_sidebar_type_id = g_type_register_static (GTK_TYPE_REVEALER, "BoxesSidebar", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_sidebar_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_sidebar_type_id__volatile, boxes_sidebar_type_id);
	}
	return boxes_sidebar_type_id__volatile;
}


static void _vala_boxes_sidebar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSidebar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (property_id) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_PREVIOUS_UI_STATE:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_UI_STATE:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 983 "sidebar.c"
		default:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 989 "sidebar.c"
	}
}


static void _vala_boxes_sidebar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSidebar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SIDEBAR, BoxesSidebar);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
	switch (property_id) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_PREVIOUS_UI_STATE:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		case BOXES_SIDEBAR_UI_STATE:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 1011 "sidebar.c"
		default:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/sidebar.vala"
		break;
#line 1017 "sidebar.c"
	}
}



