/* libvirt-machine.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from libvirt-machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <float.h>
#include <math.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;

#define BOXES_LIBVIRT_MACHINE_TYPE_MACHINE_STAT (boxes_libvirt_machine_machine_stat_get_type ())
typedef struct _BoxesLibvirtMachineMachineStat BoxesLibvirtMachineMachineStat;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesLibvirtMachineConnectDisplayData BoxesLibvirtMachineConnectDisplayData;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _Block20Data Block20Data;
typedef struct _Block21Data Block21Data;
#define __vala_GVirDomainDiskStats_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainDiskStats_free (var), NULL)))
typedef struct _BoxesLibvirtMachineUpdateIoStatData BoxesLibvirtMachineUpdateIoStatData;
typedef struct _Block22Data Block22Data;
typedef struct _Block23Data Block23Data;
#define __vala_GVirDomainInterfaceStats_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInterfaceStats_free (var), NULL)))
typedef struct _BoxesLibvirtMachineUpdateNetStatData BoxesLibvirtMachineUpdateNetStatData;
typedef struct _BoxesLibvirtMachineUpdateStatsData BoxesLibvirtMachineUpdateStatsData;
typedef struct _Block24Data Block24Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;

#define BOXES_TYPE_VNC_DISPLAY (boxes_vnc_display_get_type ())
#define BOXES_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay))
#define BOXES_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))
#define BOXES_IS_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_IS_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_VNC_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))

typedef struct _BoxesVncDisplay BoxesVncDisplay;
typedef struct _BoxesVncDisplayClass BoxesVncDisplayClass;
typedef struct _Block25Data Block25Data;
typedef struct _BoxesLibvirtMachineTakeScreenshotData BoxesLibvirtMachineTakeScreenshotData;
typedef struct _Block26Data Block26Data;
typedef struct _BoxesLibvirtMachineSaveRealData BoxesLibvirtMachineSaveRealData;
typedef struct _BoxesLibvirtMachineSuspendData BoxesLibvirtMachineSuspendData;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesLibvirtMachineStartData BoxesLibvirtMachineStartData;
typedef struct _Block27Data Block27Data;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_VM_IMPORTER (boxes_vm_importer_get_type ())
#define BOXES_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporter))
#define BOXES_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))
#define BOXES_IS_VM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_IMPORTER))
#define BOXES_IS_VM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_IMPORTER))
#define BOXES_VM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_IMPORTER, BoxesVMImporterClass))

typedef struct _BoxesVMImporter BoxesVMImporter;
typedef struct _BoxesVMImporterClass BoxesVMImporterClass;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesLibvirtMachineMachineStat {
	gint64 timestamp;
	gdouble cpu_time;
	gdouble cpu_time_abs;
	gdouble cpu_guest_percent;
	gdouble memory_percent;
	GVirDomainDiskStats* disk;
	gdouble disk_read;
	gdouble disk_write;
	GVirDomainInterfaceStats* net;
	gdouble net_read;
	gdouble net_write;
};

struct _BoxesLibvirtMachinePrivate {
	GVirDomain* _domain;
	GVirConfigDomain* _domain_config;
	GVirConnection* _connection;
	GVirStorageVol* _storage_volume;
	BoxesVMCreator* _vm_creator;
	BoxesLibvirtMachineProperties* properties;
	guint shutdown_timeout;
	guint stats_update_timeout;
	GCancellable* stats_cancellable;
	BoxesLibvirtMachineMachineStat* stats;
	gint stats_length1;
	gint _stats_size_;
	gboolean force_stopped;
};

struct _BoxesLibvirtMachineConnectDisplayData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	BoxesMachineConnectFlags flags;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	BoxesMachineConnectFlags _tmp2_;
	GCancellable* _tmp3_;
	GCancellable* _tmp4_;
	GCancellable* _tmp5_;
	GCancellable* _tmp6_;
	gboolean _tmp7_;
	GCancellable* _tmp8_;
	GCancellable* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	BoxesDisplay* _tmp12_;
	BoxesDisplay* _tmp13_;
	BoxesDisplay* _tmp14_;
	BoxesDisplay* _tmp15_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _Block20Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	BoxesLibvirtMachineMachineStat* stat;
	gpointer _async_data_;
};

struct _Block21Data {
	int _ref_count_;
	Block20Data * _data20_;
	GVirDomainDisk* disk;
};

struct _BoxesLibvirtMachineUpdateIoStatData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomainInfo* info;
	BoxesLibvirtMachineMachineStat* stat;
	Block20Data* _data20_;
	BoxesLibvirtMachineMachineStat* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainState _tmp2_;
	Block21Data* _data21_;
	GVirDomainDisk* _tmp3_;
	GVirDomainDisk* _tmp4_;
	BoxesLibvirtMachineMachineStat prev;
	BoxesLibvirtMachineMachineStat* _tmp5_;
	gint _tmp5__length1;
	BoxesLibvirtMachineMachineStat _tmp6_;
	BoxesLibvirtMachineMachineStat _tmp7_;
	BoxesLibvirtMachineMachineStat _tmp8_;
	GVirDomainDiskStats* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	GVirDomainDiskStats* _tmp11_;
	gint64 _tmp12_;
	BoxesLibvirtMachineMachineStat _tmp13_;
	GVirDomainDiskStats* _tmp14_;
	gint64 _tmp15_;
	BoxesLibvirtMachineMachineStat* _tmp16_;
	GVirDomainDiskStats* _tmp17_;
	gint64 _tmp18_;
	BoxesLibvirtMachineMachineStat _tmp19_;
	GVirDomainDiskStats* _tmp20_;
	gint64 _tmp21_;
	GError* err;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	GError * _inner_error_;
};

struct _Block22Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	BoxesLibvirtMachineMachineStat* stat;
	gpointer _async_data_;
};

struct _Block23Data {
	int _ref_count_;
	Block22Data * _data22_;
	GVirDomainInterface* net;
};

struct _BoxesLibvirtMachineUpdateNetStatData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomainInfo* info;
	BoxesLibvirtMachineMachineStat* stat;
	Block22Data* _data22_;
	BoxesLibvirtMachineMachineStat* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainState _tmp2_;
	Block23Data* _data23_;
	GVirDomainInterface* _tmp3_;
	GVirDomainInterface* _tmp4_;
	BoxesLibvirtMachineMachineStat prev;
	BoxesLibvirtMachineMachineStat* _tmp5_;
	gint _tmp5__length1;
	BoxesLibvirtMachineMachineStat _tmp6_;
	BoxesLibvirtMachineMachineStat _tmp7_;
	BoxesLibvirtMachineMachineStat _tmp8_;
	GVirDomainInterfaceStats* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	GVirDomainInterfaceStats* _tmp11_;
	gint64 _tmp12_;
	BoxesLibvirtMachineMachineStat _tmp13_;
	GVirDomainInterfaceStats* _tmp14_;
	gint64 _tmp15_;
	BoxesLibvirtMachineMachineStat* _tmp16_;
	GVirDomainInterfaceStats* _tmp17_;
	gint64 _tmp18_;
	BoxesLibvirtMachineMachineStat _tmp19_;
	GVirDomainInterfaceStats* _tmp20_;
	gint64 _tmp21_;
	GError* err;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineUpdateStatsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	gint64 now;
	gint64 _tmp0_;
	BoxesLibvirtMachineMachineStat stat;
	gint64 _tmp1_;
	BoxesLibvirtMachineMachineStat _tmp2_;
	GVirDomainInfo* info;
	GVirDomain* _tmp3_;
	GCancellable* _tmp4_;
	GVirDomainInfo* _tmp5_;
	GVirDomainInfo* _tmp6_;
	GVirDomainInfo* _tmp7_;
	GVirDomainInfo* _tmp8_;
	GVirDomainInfo* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	gint _tmp10__length1;
	BoxesLibvirtMachineMachineStat* _tmp11_;
	gint _tmp11__length1;
	BoxesLibvirtMachineMachineStat* _tmp12_;
	gint _tmp12__length1;
	BoxesLibvirtMachineMachineStat _tmp13_;
	BoxesLibvirtMachineMachineStat _tmp14_;
	GError* err;
	GError* _vala1_err;
	GError* _tmp15_;
	const gchar* _tmp16_;
	gdouble* _tmp17_;
	gdouble* _tmp18_;
	gdouble* _tmp19_;
	BoxesLibvirtMachineMachineStat* _tmp20_;
	gint _tmp20__length1;
	BoxesLibvirtMachineMachineStat* stat_collection;
	gint stat_collection_length1;
	gint _stat_collection_size_;
	gint stat_it;
	BoxesLibvirtMachineMachineStat _tmp21_;
	BoxesLibvirtMachineMachineStat _vala1_stat;
	gdouble* _tmp22_;
	gint _tmp22__length1;
	BoxesLibvirtMachineMachineStat _tmp23_;
	gdouble _tmp24_;
	gdouble* _tmp25_;
	gint _tmp25__length1;
	BoxesLibvirtMachineMachineStat _tmp26_;
	gdouble _tmp27_;
	BoxesLibvirtMachineMachineStat _tmp28_;
	gdouble _tmp29_;
	gdouble* _tmp30_;
	gint _tmp30__length1;
	BoxesLibvirtMachineMachineStat _tmp31_;
	gdouble _tmp32_;
	BoxesLibvirtMachineMachineStat _tmp33_;
	gdouble _tmp34_;
	GError * _inner_error_;
};

struct _Block24Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	gboolean stats_updating;
};

struct _Block25Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	GVirStream* stream;
	gpointer _async_data_;
};

struct _BoxesLibvirtMachineTakeScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GdkPixbuf* result;
	Block25Data* _data25_;
	GVirDomainState state;
	GVirDomainInfo* _tmp0_;
	GVirDomain* _tmp1_;
	GVirDomainInfo* _tmp2_;
	GVirDomainInfo* _tmp3_;
	GVirDomainInfo* _tmp4_;
	GVirDomainState _tmp5_;
	GError* _error_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	GVirDomainState _tmp10_;
	GVirDomainState _tmp11_;
	GVirDomainState _tmp12_;
	GVirConnection* _tmp13_;
	GVirStream* _tmp14_;
	GdkPixbufLoader* loader;
	GdkPixbufLoader* _tmp15_;
	GInputStream* input_stream;
	GVirStream* _tmp16_;
	GInputStream* _tmp17_;
	GInputStream* _tmp18_;
	guint8* buffer;
	guint8* _tmp19_;
	gint buffer_length1;
	gint _buffer_size_;
	gssize length;
	gboolean _tmp20_;
	gssize _tmp21_;
	gssize _tmp22_;
	GInputStream* _tmp23_;
	guint8* _tmp24_;
	gint _tmp24__length1;
	gssize _tmp25_;
	GdkPixbufLoader* _tmp26_;
	guint8* _tmp27_;
	gint _tmp27__length1;
	gssize _tmp28_;
	GdkPixbufLoader* _tmp29_;
	GdkPixbufLoader* _tmp30_;
	GdkPixbuf* _tmp31_;
	GdkPixbuf* _tmp32_;
	GError * _inner_error_;
};

struct _Block26Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	GVirDomain* domain;
};

struct _BoxesLibvirtMachineSaveRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomain* _tmp0_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineSuspendData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	gboolean _tmp0_;
	gboolean _tmp1_;
	GVirDomain* _tmp2_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineStartData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	BoxesMachineConnectFlags flags;
	GCancellable* cancellable;
	BoxesMachineMachineState _tmp0_;
	BoxesMachineMachineState _tmp1_;
	BoxesMachineMachineState _tmp2_;
	BoxesMachineMachineState _tmp3_;
	GVirDomain* _tmp4_;
	GCancellable* _tmp5_;
	BoxesMachineMachineState _tmp6_;
	BoxesMachineMachineState _tmp7_;
	GVirDomain* _tmp8_;
	GCancellable* _tmp9_;
	gboolean _tmp10_;
	GVirDomain* _tmp11_;
	gboolean _tmp12_;
	BoxesMachineConnectFlags _tmp13_;
	gboolean restore;
	gboolean _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	const gchar* _tmp21_;
	const gchar* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	GVirDomain* _tmp25_;
	BoxesMachineConnectFlags _tmp26_;
	GVirDomainStartFlags _tmp27_;
	GCancellable* _tmp28_;
	GError* _error_;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	GError* _vala1__error_;
	gboolean _tmp31_;
	GError* _tmp32_;
	GError* _tmp33_;
	GError* _tmp34_;
	GError * _inner_error_;
};

struct _Block27Data {
	int _ref_count_;
	BoxesLibvirtMachine* self;
	gulong state_id;
	GdNotification* notification;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef void (*BoxesNotificationCancelFunc) (void* user_data);

static gpointer boxes_libvirt_machine_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;

GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
static GType boxes_libvirt_machine_machine_stat_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static BoxesLibvirtMachineMachineStat* boxes_libvirt_machine_machine_stat_dup (const BoxesLibvirtMachineMachineStat* self);
static void boxes_libvirt_machine_machine_stat_free (BoxesLibvirtMachineMachineStat* self);
static void boxes_libvirt_machine_machine_stat_copy (const BoxesLibvirtMachineMachineStat* self, BoxesLibvirtMachineMachineStat* dest);
static void boxes_libvirt_machine_machine_stat_destroy (BoxesLibvirtMachineMachineStat* self);
#define BOXES_LIBVIRT_MACHINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachinePrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_DUMMY_PROPERTY,
	BOXES_LIBVIRT_MACHINE_DOMAIN,
	BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG,
	BOXES_LIBVIRT_MACHINE_CONNECTION,
	BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME,
	BOXES_LIBVIRT_MACHINE_VM_CREATOR,
	BOXES_LIBVIRT_MACHINE_IMPORTING,
	BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT
};
static void _vala_BoxesLibvirtMachineMachineStat_array_free (BoxesLibvirtMachineMachineStat* array, gint array_length);
#define BOXES_LIBVIRT_MACHINE_STATS_SIZE 20
static void boxes_libvirt_machine_real_disconnect_display (BoxesMachine* base);
void boxes_machine_disconnect_display (BoxesMachine* self);
static void boxes_libvirt_machine_real_connect_display_data_free (gpointer _data);
static void boxes_libvirt_machine_real_connect_display (BoxesMachine* base, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_connect_display_co (BoxesLibvirtMachineConnectDisplayData* _data_);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_connect_display_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_connect_it (BoxesDisplay* self, GError** error);
void boxes_machine_show_display (BoxesMachine* self);
void boxes_display_set_enable_audio (BoxesDisplay* self, gboolean enable);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_set_domain_config (BoxesLibvirtMachine* self, GVirConfigDomain* value);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain);
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value);
static void boxes_libvirt_machine_reconnect_display (BoxesLibvirtMachine* self);
void boxes_machine_connect_display (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_connect_display_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name);
void boxes_machine_create_display_config (BoxesMachine* self, const gchar* uuid);
void boxes_libvirt_machine_set_connection (BoxesLibvirtMachine* self, GVirConnection* value);
void boxes_libvirt_machine_set_domain (BoxesLibvirtMachine* self, GVirDomain* value);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
static void boxes_libvirt_machine_set_stats_enable (BoxesLibvirtMachine* self, gboolean enable);
static void __lambda141_ (BoxesLibvirtMachine* self);
static void ___lambda141__gvir_domain_started (GVirDomain* _sender, gpointer self);
static void __lambda142_ (BoxesLibvirtMachine* self);
static void ___lambda142__gvir_domain_suspended (GVirDomain* _sender, gpointer self);
static void __lambda143_ (BoxesLibvirtMachine* self);
static void ___lambda143__gvir_domain_resumed (GVirDomain* _sender, gpointer self);
static void __lambda144_ (BoxesLibvirtMachine* self);
static void ___lambda144__gvir_domain_stopped (GVirDomain* _sender, gpointer self);
static void __lambda145_ (BoxesLibvirtMachine* self);
static void ___lambda145__gvir_domain_pmsuspended (GVirDomain* _sender, gpointer self);
static void __lambda146_ (BoxesLibvirtMachine* self);
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void ___lambda146__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_libvirt_machine_update_domain_config_gvir_domain_updated (GVirDomain* _sender, gpointer self);
void boxes_machine_load_screenshot (BoxesMachine* self);
void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable);
static void boxes_libvirt_machine_update_cpu_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat);
static void boxes_libvirt_machine_update_mem_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat);
static void boxes_libvirt_machine_update_io_stat_data_free (gpointer _data);
static GVirDomainInfo* _vala_GVirDomainInfo_copy (GVirDomainInfo* self);
static void boxes_libvirt_machine_update_io_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_io_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_io_stat_co (BoxesLibvirtMachineUpdateIoStatData* _data_);
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
static Block21Data* block21_data_ref (Block21Data* _data21_);
static void block21_data_unref (void * _userdata_);
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
static void ___lambda62_ (Block21Data* _data21_, GError** error);
static void _vala_GVirDomainDiskStats_free (GVirDomainDiskStats* self);
static void ____lambda62__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_update_io_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
static void boxes_libvirt_machine_update_net_stat_data_free (gpointer _data);
static void boxes_libvirt_machine_update_net_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_net_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_net_stat_co (BoxesLibvirtMachineUpdateNetStatData* _data_);
static Block22Data* block22_data_ref (Block22Data* _data22_);
static void block22_data_unref (void * _userdata_);
static Block23Data* block23_data_ref (Block23Data* _data23_);
static void block23_data_unref (void * _userdata_);
static GVirDomainInterface* boxes_libvirt_machine_get_domain_network_interface (BoxesLibvirtMachine* self, GError** error);
static void ___lambda63_ (Block23Data* _data23_, GError** error);
static void _vala_GVirDomainInterfaceStats_free (GVirDomainInterfaceStats* self);
static void ____lambda63__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_update_net_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_update_stats_data_free (gpointer _data);
static void boxes_libvirt_machine_update_stats (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_stats_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_stats_co (BoxesLibvirtMachineUpdateStatsData* _data_);
static void boxes_libvirt_machine_update_stats_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static BoxesLibvirtMachineMachineStat* _vala_array_dup1 (BoxesLibvirtMachineMachineStat* self, int length);
static void _vala_array_add2 (BoxesLibvirtMachineMachineStat** array, int* length, int* size, const BoxesLibvirtMachineMachineStat* value);
static void _vala_array_add3 (gdouble** array, int* length, int* size, gdouble value);
static void _vala_array_add4 (gdouble** array, int* length, int* size, gdouble value);
static void _vala_array_add5 (gdouble** array, int* length, int* size, gdouble value);
static Block24Data* block24_data_ref (Block24Data* _data24_);
static void block24_data_unref (void * _userdata_);
static gboolean ___lambda61_ (Block24Data* _data24_);
static void __lambda64_ (Block24Data* _data24_);
static void ___lambda64__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ____lambda61__gsource_func (gpointer self);
static GList* boxes_libvirt_machine_real_get_properties (BoxesMachine* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
GList* boxes_iproperties_provider_get_properties (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static BoxesDisplay* boxes_libvirt_machine_create_display (BoxesLibvirtMachine* self, GError** error);
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port, gint tls_port, const gchar* host_subject);
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
BoxesVncDisplay* boxes_vnc_display_new (BoxesBoxConfig* config, const gchar* host, gint port);
BoxesVncDisplay* boxes_vnc_display_construct (GType object_type, BoxesBoxConfig* config, const gchar* host, gint port);
GType boxes_vnc_display_get_type (void) G_GNUC_CONST;
static void boxes_libvirt_machine_real_take_screenshot_data_free (gpointer _data);
static void boxes_libvirt_machine_real_take_screenshot (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_take_screenshot_co (BoxesLibvirtMachineTakeScreenshotData* _data_);
static Block25Data* block25_data_ref (Block25Data* _data25_);
static void block25_data_unref (void * _userdata_);
static void boxes_libvirt_machine_take_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void __lambda147_ (Block25Data* _data25_, GError** error);
static void ___lambda147__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_real_delete (BoxesMachine* base, gboolean by_user);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
static Block26Data* block26_data_ref (Block26Data* _data26_);
static void block26_data_unref (void * _userdata_);
static void ___lambda65_ (Block26Data* _data26_, GError** error);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void ____lambda65__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_real_save_real_data_free (gpointer _data);
static void boxes_libvirt_machine_real_save_real (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_save_real_co (BoxesLibvirtMachineSaveRealData* _data_);
static void boxes_libvirt_machine_save_real_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_suspend_data_free (gpointer _data);
void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_libvirt_machine_suspend_co (BoxesLibvirtMachineSuspendData* _data_);
gboolean boxes_libvirt_machine_get_save_on_quit (BoxesLibvirtMachine* self);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_suspend_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_try_shutdown (BoxesLibvirtMachine* self);
static GVirDomainStartFlags boxes_libvirt_machine_connect_flags_to_gvir (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags);
static void boxes_libvirt_machine_start_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_start_co (BoxesLibvirtMachineStartData* _data_);
static void boxes_libvirt_machine_start_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_machine_set_status (BoxesMachine* self, const gchar* value);
static void boxes_libvirt_machine_real_restart (BoxesMachine* base);
static Block27Data* block27_data_ref (Block27Data* _data27_);
static void block27_data_unref (void * _userdata_);
static void ___lambda148_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res);
void boxes_machine_restart (BoxesMachine* self);
static void ____lambda148__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void __lambda149_ (Block27Data* _data27_);
static void ___lambda150_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res);
static void ____lambda150__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda149__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda151_ (Block27Data* _data27_);
static void __lambda152_ (Block27Data* _data27_);
static void ___lambda152__boxes_notification_ok_func (gpointer self);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static gboolean ___lambda151__gsource_func (gpointer self);
BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self);
void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
void boxes_machine_set_can_delete (BoxesMachine* self, gboolean value);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
void boxes_machine_set_under_construction (BoxesMachine* self, gboolean value);
GType boxes_vm_importer_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_set_save_on_quit (BoxesLibvirtMachine* self, gboolean value);
static GObject * boxes_libvirt_machine_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
void boxes_machine_set_can_save (BoxesMachine* self, gboolean value);
static GVirDomainDiskStats* _vala_GVirDomainDiskStats_copy (GVirDomainDiskStats* self);
static GVirDomainInterfaceStats* _vala_GVirDomainInterfaceStats_copy (GVirDomainInterfaceStats* self);
static void boxes_libvirt_machine_finalize (GObject* obj);
static void _vala_boxes_libvirt_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_libvirt_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static void _vala_BoxesLibvirtMachineMachineStat_array_free (BoxesLibvirtMachineMachineStat* array, gint array_length) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array != NULL) {
#line 1014 "libvirt-machine.c"
		int i;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_destroy (&array[i]);
#line 1020 "libvirt-machine.c"
		}
	}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1025 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_disconnect_display (BoxesMachine* base) {
	BoxesLibvirtMachine * self;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachine*) self)->stay_on_display = FALSE;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (boxes_libvirt_machine_parent_class)->disconnect_display (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_MACHINE, BoxesMachine));
#line 1037 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display_data_free (gpointer _data) {
	BoxesLibvirtMachineConnectDisplayData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineConnectDisplayData, _data_);
#line 1048 "libvirt-machine.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 1055 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display (BoxesMachine* base, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineConnectDisplayData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesMachineConnectFlags _tmp1_ = 0;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineConnectDisplayData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_connect_display);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_connect_display_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = flags;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->flags = _tmp1_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_connect_display_co (_data_);
#line 1082 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineConnectDisplayData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1092 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1096 "libvirt-machine.c"
}


static void boxes_libvirt_machine_connect_display_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineConnectDisplayData* _data_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_connect_display_co (_data_);
#line 1110 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_connect_display_co (BoxesLibvirtMachineConnectDisplayData* _data_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 1119 "libvirt-machine.c"
		goto _state_0;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 1123 "libvirt-machine.c"
		goto _state_1;
		default:
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 1128 "libvirt-machine.c"
	}
	_state_0:
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_cancellable_reset (_data_->_tmp1_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->flags;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp4_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 1;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start (_data_->self, _data_->_tmp2_, _data_->_tmp4_, boxes_libvirt_machine_connect_display_ready, _data_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 1159 "libvirt-machine.c"
	_state_1:
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1173 "libvirt-machine.c"
		} else {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1177 "libvirt-machine.c"
		}
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1183 "libvirt-machine.c"
	}
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp5_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp5_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp6_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = FALSE;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = g_cancellable_is_cancelled (_data_->_tmp6_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp7_) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = boxes_machine_get_connecting_cancellable ((BoxesMachine*) _data_->self);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_cancellable_reset (_data_->_tmp9_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1213 "libvirt-machine.c"
		} else {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1217 "libvirt-machine.c"
		}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1223 "libvirt-machine.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp11_ = FALSE;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp11_ = boxes_libvirt_machine_update_display (_data_->self, &_data_->_inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = _data_->_tmp11_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1241 "libvirt-machine.c"
		} else {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1245 "libvirt-machine.c"
		}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 1251 "libvirt-machine.c"
	}
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp10_) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_display_connect_it (_data_->_tmp13_, &_data_->_inner_error_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1275 "libvirt-machine.c"
			} else {
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1279 "libvirt-machine.c"
			}
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 1285 "libvirt-machine.c"
		}
	} else {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_show_display ((BoxesMachine*) _data_->self);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp14_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp14_ = boxes_machine_get_display ((BoxesMachine*) _data_->self);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = _data_->_tmp14_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_display_set_enable_audio (_data_->_tmp15_, TRUE);
#line 1300 "libvirt-machine.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1306 "libvirt-machine.c"
	} else {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1310 "libvirt-machine.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 1316 "libvirt-machine.c"
}


void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self) {
	GError * _inner_error_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 1324 "libvirt-machine.c"
	{
		GVirConfigDomain* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirConfigDomain* _tmp2_ = NULL;
		GVirConnection* _tmp3_ = NULL;
		GVirDomain* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_config (_tmp1_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp2_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1341 "libvirt-machine.c"
			goto __catch13_g_error;
		}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_domain_config (self, _tmp0_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = self->priv->_connection;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = self->priv->_domain;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_get_storage_volume (_tmp3_, _tmp4_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_storage_volume (self, _tmp6_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_tmp6_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_tmp0_);
#line 1360 "libvirt-machine.c"
	}
	goto __finally13;
	__catch13_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = self->priv->_domain;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = gvir_domain_get_name (_tmp7_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _error_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = _tmp9_->message;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("libvirt-machine.vala:91: Failed to fetch configuration for domain '%s'" \
": %s", _tmp8_, _tmp10_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 1386 "libvirt-machine.c"
	}
	__finally13:
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1397 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_reconnect_display (BoxesLibvirtMachine* self) {
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp1_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == NULL) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1415 "libvirt-machine.c"
	}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_disconnect_display ((BoxesMachine*) self);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_connect_display ((BoxesMachine*) self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL);
#line 1421 "libvirt-machine.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1428 "libvirt-machine.c"
}


static void __lambda141_ (BoxesLibvirtMachine* self) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 1435 "libvirt-machine.c"
}


static void ___lambda141__gvir_domain_started (GVirDomain* _sender, gpointer self) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda141_ ((BoxesLibvirtMachine*) self);
#line 1442 "libvirt-machine.c"
}


static void __lambda142_ (BoxesLibvirtMachine* self) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_PAUSED);
#line 1449 "libvirt-machine.c"
}


static void ___lambda142__gvir_domain_suspended (GVirDomain* _sender, gpointer self) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda142_ ((BoxesLibvirtMachine*) self);
#line 1456 "libvirt-machine.c"
}


static void __lambda143_ (BoxesLibvirtMachine* self) {
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 1463 "libvirt-machine.c"
}


static void ___lambda143__gvir_domain_resumed (GVirDomain* _sender, gpointer self) {
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda143_ ((BoxesLibvirtMachine*) self);
#line 1470 "libvirt-machine.c"
}


static void __lambda144_ (BoxesLibvirtMachine* self) {
	GVirDomain* _tmp0_ = NULL;
	GSignalInvocationHint* _tmp1_ = NULL;
	GQuark _tmp2_ = 0U;
	GQuark _tmp3_ = 0U;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = g_signal_get_invocation_hint (_tmp0_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = (*_tmp1_).detail;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_quark_from_string ("saved");
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ == _tmp3_) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SAVED);
#line 1491 "libvirt-machine.c"
	} else {
		gboolean _tmp4_ = FALSE;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = self->priv->force_stopped;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp4_) {
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			self->priv->force_stopped = FALSE;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED);
#line 1502 "libvirt-machine.c"
		} else {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 1506 "libvirt-machine.c"
		}
	}
}


static void ___lambda144__gvir_domain_stopped (GVirDomain* _sender, gpointer self) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda144_ ((BoxesLibvirtMachine*) self);
#line 1515 "libvirt-machine.c"
}


static void __lambda145_ (BoxesLibvirtMachine* self) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SLEEPING);
#line 1522 "libvirt-machine.c"
}


static void ___lambda145__gvir_domain_pmsuspended (GVirDomain* _sender, gpointer self) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda145_ ((BoxesLibvirtMachine*) self);
#line 1529 "libvirt-machine.c"
}


static void __lambda146_ (BoxesLibvirtMachine* self) {
	BoxesMachineMachineState _tmp0_ = 0;
	BoxesMachineMachineState _tmp1_ = 0;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_reconnect_display (self);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_stats_enable (self, TRUE);
#line 1546 "libvirt-machine.c"
	} else {
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_stats_enable (self, FALSE);
#line 1550 "libvirt-machine.c"
	}
}


static void ___lambda146__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda146_ ((BoxesLibvirtMachine*) self);
#line 1558 "libvirt-machine.c"
}


static void _boxes_libvirt_machine_update_domain_config_gvir_domain_updated (GVirDomain* _sender, gpointer self) {
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config ((BoxesLibvirtMachine*) self);
#line 1565 "libvirt-machine.c"
}


BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
	BoxesLibvirtMachine * self = NULL;
	GVirConfigDomain* config = NULL;
	GVirDomain* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* item_name = NULL;
	gchar* _tmp7_ = NULL;
	BoxesCollectionSource* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	GVirDomain* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	GVirDomain* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	GVirConnection* _tmp16_ = NULL;
	GVirDomain* _tmp17_ = NULL;
	BoxesLibvirtMachineProperties* _tmp18_ = NULL;
	GVirDomain* _tmp29_ = NULL;
	GVirDomain* _tmp30_ = NULL;
	GVirDomain* _tmp31_ = NULL;
	GVirDomain* _tmp32_ = NULL;
	GVirDomain* _tmp33_ = NULL;
	GVirDomain* _tmp34_ = NULL;
	BoxesMachineMachineState _tmp35_ = 0;
	BoxesMachineMachineState _tmp36_ = 0;
	GError * _inner_error_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = domain;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_domain_get_config (_tmp0_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	config = _tmp1_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 1619 "libvirt-machine.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = config;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = gvir_config_domain_get_title (_tmp3_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp4_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ == NULL) {
#line 1629 "libvirt-machine.c"
		GVirDomain* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = domain;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = gvir_domain_get_name (_tmp5_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp6_;
#line 1638 "libvirt-machine.c"
	}
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = g_strdup (_tmp2_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	item_name = _tmp7_;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = source;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = item_name;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) boxes_machine_construct (object_type, _tmp8_, _tmp9_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = domain;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = gvir_domain_get_name (_tmp10_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = g_strconcat ("new libvirt machine: ", _tmp11_, NULL);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = _tmp12_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:111: %s", _tmp13_);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp13_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = domain;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = gvir_domain_get_uuid (_tmp14_);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_create_display_config ((BoxesMachine*) self, _tmp15_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = connection;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_connection (self, _tmp16_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = domain;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_domain (self, _tmp17_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = boxes_libvirt_machine_properties_new (self);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->properties);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->properties = _tmp18_;
#line 1682 "libvirt-machine.c"
	{
		GVirDomainInfo* _tmp19_ = NULL;
		GVirDomain* _tmp20_ = NULL;
		GVirDomainInfo* _tmp21_ = NULL;
		GVirDomainState s = 0;
		GVirDomainInfo* _tmp22_ = NULL;
		GVirDomainInfo* _tmp23_ = NULL;
		GVirDomainState _tmp24_ = 0;
		GVirDomainState _tmp25_ = 0;
		GVirDomainState _tmp26_ = 0;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp20_ = domain;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp21_ = gvir_domain_get_info (_tmp20_, &_inner_error_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = _tmp21_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1701 "libvirt-machine.c"
			goto __catch14_g_error;
		}
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp22_ = _tmp19_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp23_ = _tmp22_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp24_ = _tmp23_->state;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp25_ = _tmp24_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_tmp23_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		s = _tmp25_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp26_ = s;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (_tmp26_) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_RUNNING:
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_BLOCKED:
#line 1726 "libvirt-machine.c"
			{
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_libvirt_machine_set_stats_enable (self, TRUE);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1734 "libvirt-machine.c"
			}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_PAUSED:
#line 1738 "libvirt-machine.c"
			{
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_PAUSED);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1744 "libvirt-machine.c"
			}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_SHUTDOWN:
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_SHUTOFF:
#line 1750 "libvirt-machine.c"
			{
				GVirDomain* _tmp27_ = NULL;
				gboolean _tmp28_ = FALSE;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp27_ = domain;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp28_ = gvir_domain_get_saved (_tmp27_);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_tmp28_) {
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SAVED);
#line 1762 "libvirt-machine.c"
				} else {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 1766 "libvirt-machine.c"
				}
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1770 "libvirt-machine.c"
			}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_CRASHED:
#line 1774 "libvirt-machine.c"
			{
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1780 "libvirt-machine.c"
			}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_PMSUSPENDED:
#line 1784 "libvirt-machine.c"
			{
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_SLEEPING);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1790 "libvirt-machine.c"
			}
			default:
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_NONE:
#line 1795 "libvirt-machine.c"
			{
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_UNKNOWN);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1801 "libvirt-machine.c"
			}
		}
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_tmp19_);
#line 1806 "libvirt-machine.c"
	}
	goto __finally14;
	__catch14_g_error:
	{
		GError* _error_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_UNKNOWN);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 1820 "libvirt-machine.c"
	}
	__finally14:
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (item_name);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (config);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 1835 "libvirt-machine.c"
	}
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp29_ = domain;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp29_, "started", (GCallback) ___lambda141__gvir_domain_started, self, 0);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp30_ = domain;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp30_, "suspended", (GCallback) ___lambda142__gvir_domain_suspended, self, 0);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp31_ = domain;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp31_, "resumed", (GCallback) ___lambda143__gvir_domain_resumed, self, 0);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp32_ = domain;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp32_, "stopped", (GCallback) ___lambda144__gvir_domain_stopped, self, 0);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp33_ = domain;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp33_, "pmsuspended", (GCallback) ___lambda145__gvir_domain_pmsuspended, self, 0);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object ((GObject*) self, "notify::state", (GCallback) ___lambda146__g_object_notify, self, 0);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp34_ = domain;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp34_, "updated", (GCallback) _boxes_libvirt_machine_update_domain_config_gvir_domain_updated, self, 0);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp35_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp36_ = _tmp35_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp36_ != BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_load_screenshot ((BoxesMachine*) self);
#line 1873 "libvirt-machine.c"
	}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_screenshot_enable ((BoxesMachine*) self, TRUE);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (item_name);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (config);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self;
#line 1883 "libvirt-machine.c"
}


BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return boxes_libvirt_machine_construct (BOXES_TYPE_LIBVIRT_MACHINE, source, connection, domain, error);
#line 1890 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_cpu_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat) {
	BoxesLibvirtMachineMachineStat prev = {0};
	BoxesLibvirtMachineMachineStat* _tmp0_ = NULL;
	gint _tmp0__length1 = 0;
	BoxesLibvirtMachineMachineStat _tmp1_ = {0};
	BoxesLibvirtMachineMachineStat _tmp2_ = {0};
	gboolean _tmp3_ = FALSE;
	GVirDomainInfo* _tmp4_ = NULL;
	GVirDomainState _tmp5_ = 0;
	GVirDomainInfo* _tmp8_ = NULL;
	guint64 _tmp9_ = 0ULL;
	BoxesLibvirtMachineMachineStat _tmp10_ = {0};
	gdouble _tmp11_ = 0.0;
	GVirDomainInfo* _tmp12_ = NULL;
	guint64 _tmp13_ = 0ULL;
	gint64 dt = 0LL;
	BoxesLibvirtMachineMachineStat _tmp14_ = {0};
	gint64 _tmp15_ = 0LL;
	BoxesLibvirtMachineMachineStat _tmp16_ = {0};
	gint64 _tmp17_ = 0LL;
	gdouble percent = 0.0;
	BoxesLibvirtMachineMachineStat _tmp18_ = {0};
	gdouble _tmp19_ = 0.0;
	gint64 _tmp20_ = 0LL;
	gdouble _tmp21_ = 0.0;
	GVirDomainInfo* _tmp22_ = NULL;
	guint16 _tmp23_ = 0U;
	gdouble _tmp24_ = 0.0;
	gdouble _tmp25_ = 0.0;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (info != NULL);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (stat != NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->stats;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0__length1 = self->priv->stats_length1;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_copy (&_tmp1_, &_tmp2_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	prev = _tmp2_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = info;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->state;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ == GVIR_DOMAIN_STATE_CRASHED) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = TRUE;
#line 1947 "libvirt-machine.c"
	} else {
		GVirDomainInfo* _tmp6_ = NULL;
		GVirDomainState _tmp7_ = 0;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = info;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = _tmp6_->state;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp7_ == GVIR_DOMAIN_STATE_SHUTOFF;
#line 1957 "libvirt-machine.c"
	}
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp3_) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&prev);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1965 "libvirt-machine.c"
	}
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = info;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = _tmp8_->cpuTime;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = prev;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = _tmp10_.cpu_time_abs;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_time = _tmp9_ - _tmp11_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = info;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = _tmp12_->cpuTime;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_time_abs = (gdouble) _tmp13_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = *stat;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = _tmp14_.timestamp;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = prev;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = _tmp16_.timestamp;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	dt = (_tmp15_ - _tmp17_) * 10;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = *stat;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp19_ = _tmp18_.cpu_time;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp20_ = dt;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	percent = _tmp19_ / _tmp20_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp21_ = percent;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp22_ = info;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp23_ = _tmp22_->nrVirtCpu;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	percent = _tmp21_ / _tmp23_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = percent;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp25_ = CLAMP (_tmp24_, (gdouble) 0, (gdouble) 100);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_guest_percent = _tmp25_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_destroy (&prev);
#line 2017 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_mem_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat) {
	GVirDomainInfo* _tmp0_ = NULL;
	GVirDomainState _tmp1_ = 0;
	GVirDomainInfo* _tmp2_ = NULL;
	guint64 _tmp3_ = 0ULL;
	GVirDomainInfo* _tmp4_ = NULL;
	guint64 _tmp5_ = 0ULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (info != NULL);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (stat != NULL);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = info;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_->state;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2042 "libvirt-machine.c"
	}
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = info;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_->memory;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = info;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->maxMem;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*stat).memory_percent = (_tmp3_ * 100.0) / _tmp5_;
#line 2054 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateIoStatData, _data_);
#line 2067 "libvirt-machine.c"
}


static GVirDomainInfo* _vala_GVirDomainInfo_copy (GVirDomainInfo* self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_info_get_type (), self);
#line 2074 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainInfo_copy0 (gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainInfo_copy (self) : NULL;
#line 2081 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomainInfo* _tmp1_ = NULL;
	GVirDomainInfo* _tmp2_ = NULL;
	BoxesLibvirtMachineMachineStat* _tmp3_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateIoStatData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_io_stat);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_io_stat_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = info;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = __vala_GVirDomainInfo_copy0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->info = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = stat;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->stat = _tmp3_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_io_stat_co (_data_);
#line 2115 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2123 "libvirt-machine.c"
}


static Block20Data* block20_data_ref (Block20Data* _data20_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data20_->_ref_count_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data20_;
#line 2132 "libvirt-machine.c"
}


static void block20_data_unref (void * _userdata_) {
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
#line 2141 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data20_->self;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block20Data, _data20_);
#line 2149 "libvirt-machine.c"
	}
}


static Block21Data* block21_data_ref (Block21Data* _data21_) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data21_->_ref_count_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data21_;
#line 2159 "libvirt-machine.c"
}


static void block21_data_unref (void * _userdata_) {
	Block21Data* _data21_;
	_data21_ = (Block21Data*) _userdata_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data21_->_ref_count_)) {
#line 2168 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data21_->_data20_->self;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data21_->disk);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block20_data_unref (_data21_->_data20_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data21_->_data20_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block21Data, _data21_);
#line 2180 "libvirt-machine.c"
	}
}


static void _vala_GVirDomainDiskStats_free (GVirDomainDiskStats* self) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_disk_stats_get_type (), self);
#line 2188 "libvirt-machine.c"
}


static void ___lambda62_ (Block21Data* _data21_, GError** error) {
	Block20Data* _data20_;
	BoxesLibvirtMachine* self;
	GVirDomainDiskStats* _tmp0_ = NULL;
	GVirDomainDisk* _tmp1_ = NULL;
	GVirDomainDiskStats* _tmp2_ = NULL;
	GVirDomainDiskStats* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data20_ = _data21_->_data20_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data20_->self;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data21_->disk;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_disk_get_stats (_tmp1_, &_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _tmp2_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2216 "libvirt-machine.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp0_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*_data20_->stat).disk);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*_data20_->stat).disk = _tmp3_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 (_tmp0_);
#line 2228 "libvirt-machine.c"
}


static void ____lambda62__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda62_ (self, error);
#line 2235 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_io_stat_co (_data_);
#line 2249 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_io_stat_co (BoxesLibvirtMachineUpdateIoStatData* _data_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 2258 "libvirt-machine.c"
		goto _state_0;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2262 "libvirt-machine.c"
		goto _state_1;
		default:
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2267 "libvirt-machine.c"
	}
	_state_0:
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data20_ = g_slice_new0 (Block20Data);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data20_->_ref_count_ = 1;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data20_->self = g_object_ref (_data_->self);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->stat;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data20_->stat = _data_->_tmp0_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data20_->_async_data_ = _data_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->info;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_->state;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block20_data_unref (_data_->_data20_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data20_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2302 "libvirt-machine.c"
		} else {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2306 "libvirt-machine.c"
		}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2312 "libvirt-machine.c"
	}
	{
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data21_ = g_slice_new0 (Block21Data);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data21_->_ref_count_ = 1;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data21_->_data20_ = block20_data_ref (_data_->_data20_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = boxes_libvirt_machine_get_domain_disk (_data_->self, &_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data21_->disk = _data_->_tmp3_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block21_data_unref (_data_->_data21_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data21_ = NULL;
#line 2333 "libvirt-machine.c"
			goto __catch15_g_error;
		}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_data21_->disk;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp4_ == NULL) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block21_data_unref (_data_->_data21_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data21_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block20_data_unref (_data_->_data20_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data20_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2354 "libvirt-machine.c"
			} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2358 "libvirt-machine.c"
			}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 2364 "libvirt-machine.c"
		}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda62__boxes_run_in_thread_func, block21_data_ref (_data_->_data21_), block21_data_unref, boxes_libvirt_machine_update_io_stat_ready, _data_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2372 "libvirt-machine.c"
		_state_1:
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block21_data_unref (_data_->_data21_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data21_ = NULL;
#line 2382 "libvirt-machine.c"
			goto __catch15_g_error;
		}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = 0;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->priv->stats;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = _data_->self->priv->stats_length1;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp6_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp7_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp6_, &_data_->_tmp7_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->prev = _data_->_tmp7_;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp8_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->prev;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_.disk;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp9_ != NULL) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = _data_->_data20_->stat;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = (*_data_->_tmp10_).disk;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = 0LL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = _data_->_tmp11_->rd_bytes;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp13_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp13_ = _data_->prev;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->_tmp13_.disk;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = 0LL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = _data_->_tmp14_->rd_bytes;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data20_->stat).disk_read = (gdouble) (_data_->_tmp12_ - _data_->_tmp15_);
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = _data_->_data20_->stat;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = (*_data_->_tmp16_).disk;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = 0LL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = _data_->_tmp17_->wr_bytes;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp19_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = _data_->prev;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = _data_->_tmp19_.disk;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = 0LL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->_tmp20_->wr_bytes;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data20_->stat).disk_write = (gdouble) (_data_->_tmp18_ - _data_->_tmp21_);
#line 2465 "libvirt-machine.c"
		}
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->prev);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block21_data_unref (_data_->_data21_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data21_ = NULL;
#line 2473 "libvirt-machine.c"
	}
	goto __finally15;
	__catch15_g_error:
	{
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = _data_->err;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->_tmp24_->message;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:222: Failed to fetch I/O statistics for %s: %s", _data_->_tmp23_, _data_->_tmp25_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 2502 "libvirt-machine.c"
	}
	__finally15:
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block20_data_unref (_data_->_data20_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data20_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2517 "libvirt-machine.c"
	}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block20_data_unref (_data_->_data20_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data20_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2527 "libvirt-machine.c"
	} else {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2531 "libvirt-machine.c"
	}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 2537 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateNetStatData, _data_);
#line 2550 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomainInfo* _tmp1_ = NULL;
	GVirDomainInfo* _tmp2_ = NULL;
	BoxesLibvirtMachineMachineStat* _tmp3_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateNetStatData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_net_stat);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_net_stat_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = info;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = __vala_GVirDomainInfo_copy0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->info = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = stat;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->stat = _tmp3_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_net_stat_co (_data_);
#line 2584 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2592 "libvirt-machine.c"
}


static Block22Data* block22_data_ref (Block22Data* _data22_) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data22_->_ref_count_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data22_;
#line 2601 "libvirt-machine.c"
}


static void block22_data_unref (void * _userdata_) {
	Block22Data* _data22_;
	_data22_ = (Block22Data*) _userdata_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data22_->_ref_count_)) {
#line 2610 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data22_->self;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block22Data, _data22_);
#line 2618 "libvirt-machine.c"
	}
}


static Block23Data* block23_data_ref (Block23Data* _data23_) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data23_->_ref_count_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data23_;
#line 2628 "libvirt-machine.c"
}


static void block23_data_unref (void * _userdata_) {
	Block23Data* _data23_;
	_data23_ = (Block23Data*) _userdata_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data23_->_ref_count_)) {
#line 2637 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data23_->_data22_->self;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data23_->net);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block22_data_unref (_data23_->_data22_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data23_->_data22_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block23Data, _data23_);
#line 2649 "libvirt-machine.c"
	}
}


static void _vala_GVirDomainInterfaceStats_free (GVirDomainInterfaceStats* self) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_interface_stats_get_type (), self);
#line 2657 "libvirt-machine.c"
}


static void ___lambda63_ (Block23Data* _data23_, GError** error) {
	Block22Data* _data22_;
	BoxesLibvirtMachine* self;
	GVirDomainInterfaceStats* _tmp0_ = NULL;
	GVirDomainInterface* _tmp1_ = NULL;
	GVirDomainInterfaceStats* _tmp2_ = NULL;
	GVirDomainInterfaceStats* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data22_ = _data23_->_data22_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data22_->self;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data23_->net;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_interface_get_stats (_tmp1_, &_inner_error_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _tmp2_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2685 "libvirt-machine.c"
	}
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp0_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*_data22_->stat).net);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*_data22_->stat).net = _tmp3_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 (_tmp0_);
#line 2697 "libvirt-machine.c"
}


static void ____lambda63__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda63_ (self, error);
#line 2704 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_net_stat_co (_data_);
#line 2718 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_net_stat_co (BoxesLibvirtMachineUpdateNetStatData* _data_) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 2727 "libvirt-machine.c"
		goto _state_0;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2731 "libvirt-machine.c"
		goto _state_1;
		default:
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2736 "libvirt-machine.c"
	}
	_state_0:
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data22_ = g_slice_new0 (Block22Data);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data22_->_ref_count_ = 1;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data22_->self = g_object_ref (_data_->self);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->stat;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data22_->stat = _data_->_tmp0_;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data22_->_async_data_ = _data_;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->info;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_->state;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block22_data_unref (_data_->_data22_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data22_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2771 "libvirt-machine.c"
		} else {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2775 "libvirt-machine.c"
		}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2781 "libvirt-machine.c"
	}
	{
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data23_ = g_slice_new0 (Block23Data);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data23_->_ref_count_ = 1;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data23_->_data22_ = block22_data_ref (_data_->_data22_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = boxes_libvirt_machine_get_domain_network_interface (_data_->self, &_data_->_inner_error_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data23_->net = _data_->_tmp3_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block23_data_unref (_data_->_data23_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data23_ = NULL;
#line 2802 "libvirt-machine.c"
			goto __catch16_g_error;
		}
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_data23_->net;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp4_ == NULL) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block23_data_unref (_data_->_data23_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data23_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block22_data_unref (_data_->_data22_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data22_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2823 "libvirt-machine.c"
			} else {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2827 "libvirt-machine.c"
			}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 2833 "libvirt-machine.c"
		}
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda63__boxes_run_in_thread_func, block23_data_ref (_data_->_data23_), block23_data_unref, boxes_libvirt_machine_update_net_stat_ready, _data_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2841 "libvirt-machine.c"
		_state_1:
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block23_data_unref (_data_->_data23_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data23_ = NULL;
#line 2851 "libvirt-machine.c"
			goto __catch16_g_error;
		}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = 0;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->priv->stats;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = _data_->self->priv->stats_length1;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp6_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp7_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp6_, &_data_->_tmp7_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->prev = _data_->_tmp7_;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp8_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->prev;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_.net;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp9_ != NULL) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = _data_->_data22_->stat;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = (*_data_->_tmp10_).net;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = 0LL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = _data_->_tmp11_->rx_bytes;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp13_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp13_ = _data_->prev;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->_tmp13_.net;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = 0LL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = _data_->_tmp14_->rx_bytes;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data22_->stat).net_read = (gdouble) (_data_->_tmp12_ - _data_->_tmp15_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = _data_->_data22_->stat;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = (*_data_->_tmp16_).net;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = 0LL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = _data_->_tmp17_->tx_bytes;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp19_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = _data_->prev;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = _data_->_tmp19_.net;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = 0LL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->_tmp20_->tx_bytes;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_data22_->stat).net_write = (gdouble) (_data_->_tmp18_ - _data_->_tmp21_);
#line 2934 "libvirt-machine.c"
		}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->prev);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block23_data_unref (_data_->_data23_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data23_ = NULL;
#line 2942 "libvirt-machine.c"
	}
	goto __finally16;
	__catch16_g_error:
	{
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = NULL;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp22_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = NULL;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp23_ = _data_->_tmp22_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = NULL;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = _data_->err;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = NULL;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->_tmp24_->message;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:244: Failed to fetch network statistics for %s: %" \
"s", _data_->_tmp23_, _data_->_tmp25_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 2971 "libvirt-machine.c"
	}
	__finally16:
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block22_data_unref (_data_->_data22_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data22_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2986 "libvirt-machine.c"
	}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block22_data_unref (_data_->_data22_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data22_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2996 "libvirt-machine.c"
	} else {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3000 "libvirt-machine.c"
	}
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 3006 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateStatsData, _data_);
#line 3017 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateStatsData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_stats);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_stats_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats_co (_data_);
#line 3036 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3044 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats_co (_data_);
#line 3058 "libvirt-machine.c"
}


static BoxesLibvirtMachineMachineStat* _vala_array_dup1 (BoxesLibvirtMachineMachineStat* self, int length) {
	BoxesLibvirtMachineMachineStat* result;
	int i;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = g_new0 (BoxesLibvirtMachineMachineStat, length);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	for (i = 0; i < length; i++) {
#line 3069 "libvirt-machine.c"
		BoxesLibvirtMachineMachineStat _tmp0_ = {0};
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&self[i], &_tmp0_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		result[i] = _tmp0_;
#line 3075 "libvirt-machine.c"
	}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3079 "libvirt-machine.c"
}


static void _vala_array_add2 (BoxesLibvirtMachineMachineStat** array, int* length, int* size, const BoxesLibvirtMachineMachineStat* value) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (BoxesLibvirtMachineMachineStat, *array, *size);
#line 3090 "libvirt-machine.c"
	}
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = *value;
#line 3094 "libvirt-machine.c"
}


static void _vala_array_add3 (gdouble** array, int* length, int* size, gdouble value) {
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 3105 "libvirt-machine.c"
	}
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 3109 "libvirt-machine.c"
}


static void _vala_array_add4 (gdouble** array, int* length, int* size, gdouble value) {
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 3120 "libvirt-machine.c"
	}
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 3124 "libvirt-machine.c"
}


static void _vala_array_add5 (gdouble** array, int* length, int* size, gdouble value) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 3135 "libvirt-machine.c"
	}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 3139 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_stats_co (BoxesLibvirtMachineUpdateStatsData* _data_) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 3148 "libvirt-machine.c"
		goto _state_0;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 3152 "libvirt-machine.c"
		goto _state_1;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 3156 "libvirt-machine.c"
		goto _state_2;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 3160 "libvirt-machine.c"
		goto _state_3;
		default:
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 3165 "libvirt-machine.c"
	}
	_state_0:
	{
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = 0LL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = g_get_monotonic_time ();
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->now = _data_->_tmp0_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = 0LL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = _data_->now;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp2_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp2_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_.timestamp = _data_->_tmp1_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat = _data_->_tmp2_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->self->priv->_domain;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->self->priv->stats_cancellable;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_get_info_async (_data_->_tmp3_, _data_->_tmp4_, boxes_libvirt_machine_update_stats_ready, _data_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3201 "libvirt-machine.c"
		_state_1:
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = gvir_domain_get_info_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->info = _data_->_tmp5_;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_destroy (&_data_->stat);
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 3215 "libvirt-machine.c"
				goto __catch17_g_io_error_cancelled;
			}
			goto __catch17_g_error;
		}
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->info;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_cpu_stat (_data_->self, _data_->_tmp6_, &_data_->stat);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->info;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_mem_stat (_data_->self, _data_->_tmp7_, &_data_->stat);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = NULL;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->info;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 2;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_io_stat (_data_->self, _data_->_tmp8_, &_data_->stat, boxes_libvirt_machine_update_stats_ready, _data_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3242 "libvirt-machine.c"
		_state_2:
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_io_stat_finish (_data_->self, _data_->_res_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = NULL;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->info;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 3;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_net_stat (_data_->self, _data_->_tmp9_, &_data_->stat, boxes_libvirt_machine_update_stats_ready, _data_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3256 "libvirt-machine.c"
		_state_3:
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_net_stat_finish (_data_->self, _data_->_res_);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10__length1 = 0;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10_ = _data_->self->priv->stats;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10__length1 = _data_->self->priv->stats_length1;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = NULL;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11__length1 = 0;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = ((_data_->_tmp10_ + 1) != NULL) ? _vala_array_dup1 (_data_->_tmp10_ + 1, BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1) : ((gpointer) (_data_->_tmp10_ + 1));
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11__length1 = BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (_data_->self->priv->stats, _data_->self->priv->stats_length1), NULL);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats = _data_->_tmp11_;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats_length1 = _data_->_tmp11__length1;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->_stats_size_ = _data_->self->priv->stats_length1;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12__length1 = 0;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = _data_->self->priv->stats;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12__length1 = _data_->self->priv->stats_length1;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp13_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = _data_->stat;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp14_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp13_, &_data_->_tmp14_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_vala_array_add2 (&_data_->self->priv->stats, &_data_->self->priv->stats_length1, &_data_->self->priv->_stats_size_, &_data_->_tmp14_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->info);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->stat);
#line 3306 "libvirt-machine.c"
	}
	goto __finally17;
	__catch17_g_io_error_cancelled:
	{
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3321 "libvirt-machine.c"
		} else {
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3325 "libvirt-machine.c"
		}
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3331 "libvirt-machine.c"
	}
	goto __finally17;
	__catch17_g_error:
	{
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_vala1_err = _data_->_inner_error_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = _data_->_vala1_err;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp16_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp16_ = _data_->_tmp15_->message;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:270: %s", _data_->_tmp16_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->_vala1_err);
#line 3352 "libvirt-machine.c"
	}
	__finally17:
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 3363 "libvirt-machine.c"
	}
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = NULL;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = g_new0 (gdouble, 0);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats = (g_free (_data_->self->cpu_stats), NULL);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats = _data_->_tmp17_;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats_length1 = 0;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_cpu_stats_size_ = _data_->self->cpu_stats_length1;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = NULL;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = g_new0 (gdouble, 0);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats = (g_free (_data_->self->io_stats), NULL);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats = _data_->_tmp18_;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats_length1 = 0;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_io_stats_size_ = _data_->self->io_stats_length1;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = g_new0 (gdouble, 0);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats = (g_free (_data_->self->net_stats), NULL);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats = _data_->_tmp19_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats_length1 = 0;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_net_stats_size_ = _data_->self->net_stats_length1;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20_ = NULL;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20__length1 = 0;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20_ = _data_->self->priv->stats;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20__length1 = _data_->self->priv->stats_length1;
#line 3409 "libvirt-machine.c"
	{
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection_length1 = 0;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_stat_collection_size_ = 0;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection = _data_->_tmp20_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection_length1 = _data_->_tmp20__length1;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (_data_->stat_it = 0; _data_->stat_it < _data_->_tmp20__length1; _data_->stat_it = _data_->stat_it + 1) {
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp21_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_copy (&_data_->stat_collection[_data_->stat_it], &_data_->_tmp21_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_vala1_stat = _data_->_tmp21_;
#line 3427 "libvirt-machine.c"
			{
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22__length1 = 0;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = _data_->self->cpu_stats;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22__length1 = _data_->self->cpu_stats_length1;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp23_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = _data_->_vala1_stat;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = 0.0;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = _data_->_tmp23_.cpu_guest_percent;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add3 (&_data_->self->cpu_stats, &_data_->self->cpu_stats_length1, &_data_->self->_cpu_stats_size_, _data_->_tmp24_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = NULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25__length1 = 0;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = _data_->self->net_stats;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25__length1 = _data_->self->net_stats_length1;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp26_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = _data_->_vala1_stat;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = 0.0;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = _data_->_tmp26_.net_read;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp28_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = _data_->_vala1_stat;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = 0.0;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = _data_->_tmp28_.net_write;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add4 (&_data_->self->net_stats, &_data_->self->net_stats_length1, &_data_->self->_net_stats_size_, _data_->_tmp27_ + _data_->_tmp29_);
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30__length1 = 0;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = _data_->self->io_stats;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30__length1 = _data_->self->io_stats_length1;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp31_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = _data_->_vala1_stat;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp32_ = 0.0;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp32_ = _data_->_tmp31_.disk_read;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				memset (&_data_->_tmp33_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp33_ = _data_->_vala1_stat;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp34_ = 0.0;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp34_ = _data_->_tmp33_.disk_write;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add5 (&_data_->self->io_stats, &_data_->self->io_stats_length1, &_data_->self->_io_stats_size_, _data_->_tmp32_ + _data_->_tmp34_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_libvirt_machine_machine_stat_destroy (&_data_->_vala1_stat);
#line 3501 "libvirt-machine.c"
			}
		}
	}
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_emit_by_name (_data_->self, "stats-updated");
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3511 "libvirt-machine.c"
	} else {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3515 "libvirt-machine.c"
	}
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 3521 "libvirt-machine.c"
}


static Block24Data* block24_data_ref (Block24Data* _data24_) {
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data24_->_ref_count_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data24_;
#line 3530 "libvirt-machine.c"
}


static void block24_data_unref (void * _userdata_) {
	Block24Data* _data24_;
	_data24_ = (Block24Data*) _userdata_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data24_->_ref_count_)) {
#line 3539 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data24_->self;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block24Data, _data24_);
#line 3547 "libvirt-machine.c"
	}
}


static void __lambda64_ (Block24Data* _data24_) {
	BoxesLibvirtMachine* self;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data24_->self;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data24_->stats_updating = FALSE;
#line 3558 "libvirt-machine.c"
}


static void ___lambda64__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda64_ (self);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block24_data_unref (self);
#line 3567 "libvirt-machine.c"
}


static gboolean ___lambda61_ (Block24Data* _data24_) {
	BoxesLibvirtMachine* self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data24_->self;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _data24_->stats_updating;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 3581 "libvirt-machine.c"
		const gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:296: Fetching of stats for '%s' is taking too lon" \
"g. Probably a libvirt bug.", _tmp2_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		result = TRUE;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return result;
#line 3594 "libvirt-machine.c"
	}
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data24_->stats_updating = TRUE;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats (self, ___lambda64__gasync_ready_callback, block24_data_ref (_data24_));
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = TRUE;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3604 "libvirt-machine.c"
}


static gboolean ____lambda61__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda61_ (self);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3613 "libvirt-machine.c"
}


static void boxes_libvirt_machine_set_stats_enable (BoxesLibvirtMachine* self, gboolean enable) {
	gboolean _tmp0_ = FALSE;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = enable;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 3625 "libvirt-machine.c"
		Block24Data* _data24_;
		const gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		guint _tmp5_ = 0U;
		GCancellable* _tmp6_ = NULL;
		guint _tmp7_ = 0U;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data24_ = g_slice_new0 (Block24Data);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data24_->_ref_count_ = 1;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data24_->self = g_object_ref (self);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = g_strconcat ("enable statistics for ", _tmp2_, NULL);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:288: %s", _tmp4_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp4_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = self->priv->stats_update_timeout;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp5_ != ((guint) 0)) {
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			block24_data_unref (_data24_);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data24_ = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 3662 "libvirt-machine.c"
		}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->stats_cancellable;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_cancellable_reset (_tmp6_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data24_->stats_updating = FALSE;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, ____lambda61__gsource_func, block24_data_ref (_data24_), block24_data_unref);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->stats_update_timeout = _tmp7_;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block24_data_unref (_data24_);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data24_ = NULL;
#line 3678 "libvirt-machine.c"
	} else {
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		guint _tmp12_ = 0U;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _tmp8_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = g_strconcat ("disable statistics for ", _tmp9_, NULL);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = _tmp10_;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:307: %s", _tmp11_);
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp11_);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = self->priv->stats_update_timeout;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp12_ != ((guint) 0)) {
#line 3701 "libvirt-machine.c"
			GCancellable* _tmp13_ = NULL;
			guint _tmp14_ = 0U;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp13_ = self->priv->stats_cancellable;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_cancellable_cancel (_tmp13_);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp14_ = self->priv->stats_update_timeout;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_source_remove (_tmp14_);
#line 3712 "libvirt-machine.c"
		}
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->stats_update_timeout = (guint) 0;
#line 3716 "libvirt-machine.c"
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 3724 "libvirt-machine.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_list_free (self);
#line 3733 "libvirt-machine.c"
}


static GList* boxes_libvirt_machine_real_get_properties (BoxesMachine* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesLibvirtMachine * self;
	GList* result = NULL;
	GList* list = NULL;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesPropertiesPage _tmp1_ = 0;
	GList* _tmp2_ = NULL;
	BoxesDisplay* _tmp3_ = NULL;
	BoxesDisplay* _tmp4_ = NULL;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->properties;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = page;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_iproperties_provider_get_properties ((BoxesIPropertiesProvider*) _tmp0_, _tmp1_, flags);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	list = _tmp2_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = _tmp3_;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp4_ != NULL) {
#line 3762 "libvirt-machine.c"
		BoxesDisplay* _tmp5_ = NULL;
		BoxesDisplay* _tmp6_ = NULL;
		BoxesPropertiesPage _tmp7_ = 0;
		GList* _tmp8_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = page;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = boxes_display_get_properties (_tmp6_, _tmp7_, flags);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		list = g_list_concat (list, _tmp8_);
#line 3777 "libvirt-machine.c"
	}
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = list;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3783 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error) {
	gboolean result = FALSE;
	gboolean created_display = FALSE;
	BoxesDisplay* _tmp0_ = NULL;
	BoxesDisplay* _tmp1_ = NULL;
	BoxesDisplay* _tmp2_ = NULL;
	BoxesDisplay* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	created_display = _tmp1_ == NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp3_ == NULL) {
#line 3811 "libvirt-machine.c"
		BoxesDisplay* _tmp4_ = NULL;
		BoxesDisplay* _tmp5_ = NULL;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_libvirt_machine_create_display (self, &_inner_error_);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp5_;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 3824 "libvirt-machine.c"
		}
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_display ((BoxesMachine*) self, _tmp4_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_tmp4_);
#line 3830 "libvirt-machine.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = created_display;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3836 "libvirt-machine.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1314 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1315 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = self;
#line 1315 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 3848 "libvirt-machine.c"
}


static BoxesDisplay* boxes_libvirt_machine_create_display (BoxesLibvirtMachine* self, GError** error) {
	BoxesDisplay* result = NULL;
	gchar* type = NULL;
	gchar* port = NULL;
	gchar* socket = NULL;
	gchar* host = NULL;
	gchar* xmldoc = NULL;
	GVirConfigDomain* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	const gchar* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	const gchar* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	const gchar* _tmp34_ = NULL;
	const gchar* _tmp37_ = NULL;
	const gchar* _tmp38_ = NULL;
	GQuark _tmp40_ = 0U;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	static GQuark _tmp39_label0 = 0;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	static GQuark _tmp39_label1 = 0;
#line 3901 "libvirt-machine.c"
	GError * _inner_error_ = NULL;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain_config;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_config_object_to_xml ((GVirConfigObject*) _tmp0_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	xmldoc = _tmp1_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = xmldoc;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_extract_xpath (_tmp3_, "string(/domain/devices/graphics/@type)", TRUE, &_inner_error_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp4_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 3935 "libvirt-machine.c"
		} else {
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 3953 "libvirt-machine.c"
		}
	}
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp2_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (type);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	type = _tmp5_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = xmldoc;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = type;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = string_to_string (_tmp8_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp9_, "']/@port)", NULL);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = _tmp10_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = boxes_extract_xpath (_tmp7_, _tmp11_, FALSE, &_inner_error_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = _tmp12_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp11_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = _tmp13_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4002 "libvirt-machine.c"
		} else {
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4022 "libvirt-machine.c"
		}
	}
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = _tmp6_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (port);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	port = _tmp14_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = xmldoc;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = type;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = string_to_string (_tmp17_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp19_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp18_, "']/@socket)", NULL);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp20_ = _tmp19_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp21_ = boxes_extract_xpath (_tmp16_, _tmp20_, FALSE, &_inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp22_ = _tmp21_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp20_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = _tmp22_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4073 "libvirt-machine.c"
		} else {
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4095 "libvirt-machine.c"
		}
	}
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp23_ = _tmp15_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (socket);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	socket = _tmp23_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp25_ = xmldoc;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp26_ = type;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp27_ = string_to_string (_tmp26_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp28_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp27_, "']/@listen)", NULL);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp29_ = _tmp28_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp30_ = boxes_extract_xpath (_tmp25_, _tmp29_, FALSE, &_inner_error_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp31_ = _tmp30_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp29_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = _tmp31_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp15_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4148 "libvirt-machine.c"
		} else {
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp15_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp6_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp2_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (host);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (socket);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (port);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (type);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4172 "libvirt-machine.c"
		}
	}
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp32_ = _tmp24_;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = NULL;
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (host);
#line 342 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	host = _tmp32_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp34_ = host;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp34_ == NULL) {
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp33_ = TRUE;
#line 4189 "libvirt-machine.c"
	} else {
		const gchar* _tmp35_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp35_ = host;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp33_ = g_strcmp0 (_tmp35_, "") == 0;
#line 4196 "libvirt-machine.c"
	}
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp33_) {
#line 4200 "libvirt-machine.c"
		gchar* _tmp36_ = NULL;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp36_ = g_strdup ("localhost");
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (host);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		host = _tmp36_;
#line 4208 "libvirt-machine.c"
	}
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp37_ = type;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp38_ = _tmp37_;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp40_ = (NULL == _tmp38_) ? 0 : g_quark_from_string (_tmp38_);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp40_ == ((0 != _tmp39_label0) ? _tmp39_label0 : (_tmp39_label0 = g_quark_from_static_string ("spice")))) {
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 4220 "libvirt-machine.c"
			default:
			{
				BoxesBoxConfig* _tmp41_ = NULL;
				const gchar* _tmp42_ = NULL;
				const gchar* _tmp43_ = NULL;
				gint _tmp44_ = 0;
				BoxesSpiceDisplay* _tmp45_ = NULL;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp41_ = ((BoxesMachine*) self)->config;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp42_ = host;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp43_ = port;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp44_ = atoi (_tmp43_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp45_ = boxes_spice_display_new (_tmp41_, _tmp42_, _tmp44_, 0, NULL);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				result = (BoxesDisplay*) _tmp45_;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp24_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp15_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp6_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp2_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (xmldoc);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (host);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (socket);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (port);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (type);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return result;
#line 4260 "libvirt-machine.c"
			}
		}
	} else if (_tmp40_ == ((0 != _tmp39_label1) ? _tmp39_label1 : (_tmp39_label1 = g_quark_from_static_string ("vnc")))) {
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 4266 "libvirt-machine.c"
			default:
			{
				BoxesBoxConfig* _tmp46_ = NULL;
				const gchar* _tmp47_ = NULL;
				const gchar* _tmp48_ = NULL;
				gint _tmp49_ = 0;
				BoxesVncDisplay* _tmp50_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp46_ = ((BoxesMachine*) self)->config;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp47_ = host;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp48_ = port;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp49_ = atoi (_tmp48_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp50_ = boxes_vnc_display_new (_tmp46_, _tmp47_, _tmp49_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				result = (BoxesDisplay*) _tmp50_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp24_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp15_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp6_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp2_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (xmldoc);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (host);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (socket);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (port);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (type);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return result;
#line 4306 "libvirt-machine.c"
			}
		}
	} else {
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 4312 "libvirt-machine.c"
			default:
			{
				const gchar* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				gchar* _tmp53_ = NULL;
				GError* _tmp54_ = NULL;
				GError* _tmp55_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp51_ = type;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp52_ = g_strconcat ("unsupported display of type ", _tmp51_, NULL);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp53_ = _tmp52_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp54_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp53_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp55_ = _tmp54_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp53_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_inner_error_ = _tmp55_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_inner_error_->domain == BOXES_ERROR) {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_propagate_error (error, _inner_error_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp24_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp15_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp6_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp2_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (xmldoc);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (host);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (socket);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (port);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (type);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					return NULL;
#line 4358 "libvirt-machine.c"
				} else {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp24_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp15_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp6_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (_tmp2_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (xmldoc);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (host);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (socket);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (port);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (type);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_clear_error (&_inner_error_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					return NULL;
#line 4384 "libvirt-machine.c"
				}
			}
		}
	}
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp24_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp15_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp6_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp2_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (xmldoc);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (host);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (socket);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (port);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (type);
#line 4407 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_take_screenshot_data_free (gpointer _data) {
	BoxesLibvirtMachineTakeScreenshotData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineTakeScreenshotData, _data_);
#line 4420 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_take_screenshot (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineTakeScreenshotData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineTakeScreenshotData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_take_screenshot);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_take_screenshot_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_take_screenshot_co (_data_);
#line 4442 "libvirt-machine.c"
}


static GdkPixbuf* boxes_libvirt_machine_real_take_screenshot_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	GdkPixbuf* result;
	BoxesLibvirtMachineTakeScreenshotData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 4453 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4463 "libvirt-machine.c"
}


static Block25Data* block25_data_ref (Block25Data* _data25_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data25_->_ref_count_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data25_;
#line 4472 "libvirt-machine.c"
}


static void block25_data_unref (void * _userdata_) {
	Block25Data* _data25_;
	_data25_ = (Block25Data*) _userdata_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data25_->_ref_count_)) {
#line 4481 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data25_->self;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data25_->stream);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block25Data, _data25_);
#line 4491 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_take_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineTakeScreenshotData* _data_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_take_screenshot_co (_data_);
#line 4506 "libvirt-machine.c"
}


static void __lambda147_ (Block25Data* _data25_, GError** error) {
	BoxesLibvirtMachine* self;
	GVirDomain* _tmp0_ = NULL;
	GVirStream* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data25_->self;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data25_->stream;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_screenshot (_tmp0_, _tmp1_, (guint) 0, (guint) 0, &_inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp3_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4535 "libvirt-machine.c"
	}
}


static void ___lambda147__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda147_ (self, error);
#line 4543 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_take_screenshot_co (BoxesLibvirtMachineTakeScreenshotData* _data_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 4552 "libvirt-machine.c"
		goto _state_0;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 4556 "libvirt-machine.c"
		goto _state_1;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 4560 "libvirt-machine.c"
		goto _state_2;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 4564 "libvirt-machine.c"
		goto _state_3;
		default:
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 4569 "libvirt-machine.c"
	}
	_state_0:
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_ = g_slice_new0 (Block25Data);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_->_ref_count_ = 1;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_->self = g_object_ref (_data_->self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_->_async_data_ = _data_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->state = GVIR_DOMAIN_STATE_NONE;
#line 4582 "libvirt-machine.c"
	{
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = _data_->self->priv->_domain;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_get_info_async (_data_->_tmp1_, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4594 "libvirt-machine.c"
		_state_1:
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = gvir_domain_get_info_finish (_data_->_tmp1_, _data_->_res_, &_data_->_inner_error_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = _data_->_tmp2_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4604 "libvirt-machine.c"
			goto __catch18_g_error;
		}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->_tmp0_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = 0;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->_tmp4_->state;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->state = _data_->_tmp5_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->_tmp4_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->_tmp0_);
#line 4627 "libvirt-machine.c"
	}
	goto __finally18;
	__catch18_g_error:
	{
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:364: Failed to get information on '%s'", _data_->_tmp7_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->_error_);
#line 4648 "libvirt-machine.c"
	}
	__finally18:
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block25_data_unref (_data_->_data25_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data25_ = NULL;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4665 "libvirt-machine.c"
		} else {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4669 "libvirt-machine.c"
		}
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4675 "libvirt-machine.c"
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = 0;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = _data_->state;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp10_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = 0;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = _data_->state;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp11_ != GVIR_DOMAIN_STATE_PAUSED;
#line 4689 "libvirt-machine.c"
	} else {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = FALSE;
#line 4693 "libvirt-machine.c"
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp9_) {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = 0;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = _data_->state;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->_tmp12_ != GVIR_DOMAIN_STATE_PMSUSPENDED;
#line 4703 "libvirt-machine.c"
	} else {
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = FALSE;
#line 4707 "libvirt-machine.c"
	}
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp8_) {
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->result = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block25_data_unref (_data_->_data25_);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data25_ = NULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4721 "libvirt-machine.c"
		} else {
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4725 "libvirt-machine.c"
		}
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4731 "libvirt-machine.c"
	}
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp13_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp13_ = _data_->self->priv->_connection;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp14_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp14_ = gvir_connection_get_stream (_data_->_tmp13_, (guint) 0);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_->stream = _data_->_tmp14_;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 2;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread (___lambda147__boxes_run_in_thread_func, block25_data_ref (_data_->_data25_), block25_data_unref, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 4749 "libvirt-machine.c"
	_state_2:
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block25_data_unref (_data_->_data25_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data25_ = NULL;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4767 "libvirt-machine.c"
		} else {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4771 "libvirt-machine.c"
		}
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4777 "libvirt-machine.c"
	}
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = NULL;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = gdk_pixbuf_loader_new ();
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->loader = _data_->_tmp15_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = _data_->_data25_->stream;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = g_io_stream_get_input_stream ((GIOStream*) _data_->_tmp16_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = _g_object_ref0 (_data_->_tmp17_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->input_stream = _data_->_tmp18_;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = g_new0 (guint8, 65535);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer_length1 = 0;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_buffer_size_ = 0;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = _data_->_tmp19_;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer_length1 = 65535;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_buffer_size_ = _data_->buffer_length1;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->length = (gssize) 0;
#line 4815 "libvirt-machine.c"
	{
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp20_ = TRUE;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (TRUE) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (!_data_->_tmp20_) {
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = 0L;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = _data_->length;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (!(_data_->_tmp21_ > ((gssize) 0))) {
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					break;
#line 4831 "libvirt-machine.c"
				}
			}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = FALSE;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = _data_->input_stream;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24__length1 = 0;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24_ = _data_->buffer;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24__length1 = _data_->buffer_length1;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_state_ = 3;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_input_stream_read_async (_data_->_tmp23_, _data_->_tmp24_, (gsize) _data_->_tmp24__length1, G_PRIORITY_DEFAULT, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4854 "libvirt-machine.c"
			_state_3:
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp25_ = 0L;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp25_ = g_input_stream_read_finish (_data_->_tmp23_, _data_->_res_, &_data_->_inner_error_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp22_ = _data_->_tmp25_;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->buffer = (g_free (_data_->buffer), NULL);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->input_stream);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->loader);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				block25_data_unref (_data_->_data25_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_data25_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4882 "libvirt-machine.c"
				} else {
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 4886 "libvirt-machine.c"
				}
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 4892 "libvirt-machine.c"
			}
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->length = _data_->_tmp22_;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp26_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp26_ = _data_->loader;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27__length1 = 0;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27_ = _data_->buffer;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27__length1 = _data_->buffer_length1;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp28_ = 0L;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp28_ = _data_->length;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gdk_pixbuf_loader_write (_data_->_tmp26_, _data_->_tmp27_ + 0, (gsize) (((gint) _data_->_tmp28_) - 0), &_data_->_inner_error_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->buffer = (g_free (_data_->buffer), NULL);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->input_stream);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->loader);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				block25_data_unref (_data_->_data25_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_data25_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4934 "libvirt-machine.c"
				} else {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 4938 "libvirt-machine.c"
				}
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 4944 "libvirt-machine.c"
			}
		}
	}
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = _data_->loader;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gdk_pixbuf_loader_close (_data_->_tmp29_, &_data_->_inner_error_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->buffer = (g_free (_data_->buffer), NULL);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data_->input_stream);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data_->loader);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block25_data_unref (_data_->_data25_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data25_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4974 "libvirt-machine.c"
		} else {
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4978 "libvirt-machine.c"
		}
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4984 "libvirt-machine.c"
	}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp30_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp30_ = _data_->loader;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp31_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp31_ = gdk_pixbuf_loader_get_pixbuf (_data_->_tmp30_);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp32_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp32_ = _g_object_ref0 (_data_->_tmp31_);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = _data_->_tmp32_;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = (g_free (_data_->buffer), NULL);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->input_stream);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->loader);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block25_data_unref (_data_->_data25_);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5014 "libvirt-machine.c"
	} else {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5018 "libvirt-machine.c"
	}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = (g_free (_data_->buffer), NULL);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->input_stream);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->loader);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block25_data_unref (_data_->_data25_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data25_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5038 "libvirt-machine.c"
	} else {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5042 "libvirt-machine.c"
	}
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5048 "libvirt-machine.c"
}


static Block26Data* block26_data_ref (Block26Data* _data26_) {
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data26_->_ref_count_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data26_;
#line 5057 "libvirt-machine.c"
}


static void block26_data_unref (void * _userdata_) {
	Block26Data* _data26_;
	_data26_ = (Block26Data*) _userdata_;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data26_->_ref_count_)) {
#line 5066 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data26_->self;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data26_->domain);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block26Data, _data26_);
#line 5076 "libvirt-machine.c"
	}
}


static void ___lambda65_ (Block26Data* _data26_, GError** error) {
	BoxesLibvirtMachine* self;
	GVirStorageVol* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data26_->self;
#line 5087 "libvirt-machine.c"
	{
		GVirDomain* _tmp0_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _data26_->domain;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_delete (_tmp0_, (guint) GVIR_DOMAIN_DELETE_SAVED_STATE, &_inner_error_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5096 "libvirt-machine.c"
			goto __catch19_g_error;
		}
	}
	goto __finally19;
	__catch19_g_error:
	{
		GError* err = NULL;
		GError* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		err = _inner_error_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = err;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_->message;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:408: %s", _tmp2_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (err);
#line 5118 "libvirt-machine.c"
	}
	__finally19:
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5127 "libvirt-machine.c"
	}
	{
		GVirDomain* _tmp3_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _data26_->domain;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_stop (_tmp3_, (guint) 0, &_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5137 "libvirt-machine.c"
			goto __catch20_g_error;
		}
	}
	goto __finally20;
	__catch20_g_error:
	{
		GError* err = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		err = _inner_error_;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = err;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _tmp4_->message;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:415: %s", _tmp5_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (err);
#line 5159 "libvirt-machine.c"
	}
	__finally20:
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5168 "libvirt-machine.c"
	}
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = self->priv->_storage_volume;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp6_ != NULL) {
#line 5174 "libvirt-machine.c"
		{
			GVirStorageVol* _tmp7_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp7_ = self->priv->_storage_volume;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gvir_storage_vol_delete (_tmp7_, (guint) 0, &_inner_error_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5183 "libvirt-machine.c"
				goto __catch21_g_error;
			}
		}
		goto __finally21;
		__catch21_g_error:
		{
			GError* err = NULL;
			GError* _tmp8_ = NULL;
			const gchar* _tmp9_ = NULL;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			err = _inner_error_;
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_inner_error_ = NULL;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = err;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = _tmp8_->message;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_warning ("libvirt-machine.vala:423: %s", _tmp9_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_error_free0 (err);
#line 5205 "libvirt-machine.c"
		}
		__finally21:
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_propagate_error (error, _inner_error_);
#line 420 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 5214 "libvirt-machine.c"
		}
	}
}


static void ____lambda65__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda65_ (self, error);
#line 5223 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_delete (BoxesMachine* base, gboolean by_user) {
	BoxesLibvirtMachine * self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	guint _tmp5_ = 0U;
	gboolean _tmp7_ = FALSE;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = g_strconcat ("delete libvirt machine: ", _tmp1_, NULL);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:389: %s", _tmp3_);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp3_);
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = by_user;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (boxes_libvirt_machine_parent_class)->delete (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_MACHINE, BoxesMachine), _tmp4_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_stats_enable (self, FALSE);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = self->priv->shutdown_timeout;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ != ((guint) 0)) {
#line 5260 "libvirt-machine.c"
		guint _tmp6_ = 0U;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->shutdown_timeout;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_source_remove (_tmp6_);
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->shutdown_timeout = (guint) 0;
#line 5268 "libvirt-machine.c"
	}
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = by_user;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp7_) {
#line 5274 "libvirt-machine.c"
		Block26Data* _data26_;
		GVirDomain* _tmp8_ = NULL;
		GVirDomain* _tmp9_ = NULL;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data26_ = g_slice_new0 (Block26Data);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data26_->_ref_count_ = 1;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data26_->self = g_object_ref (self);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = self->priv->_domain;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _g_object_ref0 (_tmp8_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data26_->domain = _tmp9_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda65__boxes_run_in_thread_func, block26_data_ref (_data26_), block26_data_unref, NULL, NULL);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block26_data_unref (_data26_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data26_ = NULL;
#line 5296 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_real_save_real_data_free (gpointer _data) {
	BoxesLibvirtMachineSaveRealData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineSaveRealData, _data_);
#line 5308 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_save_real (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineSaveRealData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineSaveRealData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_save_real);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_save_real_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_save_real_co (_data_);
#line 5330 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_save_real_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineSaveRealData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5340 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5344 "libvirt-machine.c"
}


static void boxes_libvirt_machine_save_real_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineSaveRealData* _data_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_save_real_co (_data_);
#line 5358 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_save_real_co (BoxesLibvirtMachineSaveRealData* _data_) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 5367 "libvirt-machine.c"
		goto _state_0;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 5371 "libvirt-machine.c"
		goto _state_1;
		default:
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 5376 "libvirt-machine.c"
	}
	_state_0:
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = NULL;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->self->priv->_domain;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 1;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gvir_domain_save_async (_data_->_tmp0_, (guint) 0, NULL, boxes_libvirt_machine_save_real_ready, _data_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5389 "libvirt-machine.c"
	_state_1:
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gvir_domain_save_finish (_data_->_tmp0_, _data_->_res_, &_data_->_inner_error_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5403 "libvirt-machine.c"
		} else {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5407 "libvirt-machine.c"
		}
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5413 "libvirt-machine.c"
	}
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5419 "libvirt-machine.c"
	} else {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5423 "libvirt-machine.c"
	}
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5429 "libvirt-machine.c"
}


static void boxes_libvirt_machine_suspend_data_free (gpointer _data) {
	BoxesLibvirtMachineSuspendData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineSuspendData, _data_);
#line 5440 "libvirt-machine.c"
}


void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineSuspendData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineSuspendData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_suspend);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_suspend_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_suspend_co (_data_);
#line 5459 "libvirt-machine.c"
}


void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineSuspendData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5469 "libvirt-machine.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5473 "libvirt-machine.c"
}


static void boxes_libvirt_machine_suspend_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineSuspendData* _data_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_suspend_co (_data_);
#line 5487 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_suspend_co (BoxesLibvirtMachineSuspendData* _data_) {
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 5496 "libvirt-machine.c"
		goto _state_0;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 5500 "libvirt-machine.c"
		goto _state_1;
		default:
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 5505 "libvirt-machine.c"
	}
	_state_0:
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = FALSE;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = boxes_libvirt_machine_get_save_on_quit (_data_->self);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = FALSE;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp1_) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_save ((BoxesMachine*) _data_->self, boxes_libvirt_machine_suspend_ready, _data_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5524 "libvirt-machine.c"
		_state_1:
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_save_finish ((BoxesMachine*) _data_->self, _data_->_res_, &_data_->_inner_error_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5538 "libvirt-machine.c"
			} else {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 5542 "libvirt-machine.c"
			}
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 5548 "libvirt-machine.c"
		}
	} else {
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = _data_->self->priv->_domain;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_suspend (_data_->_tmp2_, &_data_->_inner_error_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5567 "libvirt-machine.c"
			} else {
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 5571 "libvirt-machine.c"
			}
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 5577 "libvirt-machine.c"
		}
	}
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5584 "libvirt-machine.c"
	} else {
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5588 "libvirt-machine.c"
	}
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5594 "libvirt-machine.c"
}


void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm) {
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp11_ = NULL;
	const gchar* _tmp12_ = NULL;
	GError * _inner_error_ = NULL;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = confirm;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 5609 "libvirt-machine.c"
		GtkMessageDialog* dialog = NULL;
		BoxesAppWindow* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GtkMessageDialog* _tmp3_ = NULL;
		GtkMessageDialog* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gint response = 0;
		GtkMessageDialog* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		GtkMessageDialog* _tmp9_ = NULL;
		gint _tmp10_ = 0;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_app_window;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _ ("When you force shutdown, the box may lose data.");
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) _tmp1_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, _tmp2_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_ref_sink (_tmp3_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		dialog = _tmp3_;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = dialog;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _ ("_Cancel");
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _ ("_Shutdown");
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gtk_dialog_add_buttons ((GtkDialog*) _tmp4_, _tmp5_, GTK_RESPONSE_CANCEL, _tmp6_, GTK_RESPONSE_OK, NULL);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = dialog;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = gtk_dialog_run ((GtkDialog*) _tmp7_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		response = _tmp8_;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = dialog;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp9_);
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = response;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp10_ != ((gint) GTK_RESPONSE_OK)) {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_object_unref0 (dialog);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 5658 "libvirt-machine.c"
		}
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (dialog);
#line 5662 "libvirt-machine.c"
	}
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = _tmp11_;
#line 456 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:456: Force shutdown '%s'..", _tmp12_);
#line 5670 "libvirt-machine.c"
	{
		GVirDomain* _tmp13_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self->priv->force_stopped = TRUE;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp13_ = self->priv->_domain;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_stop (_tmp13_, (guint) 0, &_inner_error_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5681 "libvirt-machine.c"
			goto __catch22_g_error;
		}
	}
	goto __finally22;
	__catch22_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp14_ = self->priv->_domain;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = gvir_domain_get_name (_tmp14_);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp16_ = _error_;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp17_ = _tmp16_->message;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:461: Failed to shutdown '%s': %s", _tmp15_, _tmp17_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5709 "libvirt-machine.c"
	}
	__finally22:
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5720 "libvirt-machine.c"
	}
}


void boxes_libvirt_machine_try_shutdown (BoxesLibvirtMachine* self) {
	GError * _inner_error_ = NULL;
#line 465 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 5729 "libvirt-machine.c"
	{
		GVirDomain* _tmp0_ = NULL;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = self->priv->_domain;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_shutdown (_tmp0_, (guint) 0, &_inner_error_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5738 "libvirt-machine.c"
			goto __catch23_g_error;
		}
	}
	goto __finally23;
	__catch23_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _error_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->message;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:469: Failed to reboot '%s': %s", _tmp2_, _tmp4_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5766 "libvirt-machine.c"
	}
	__finally23:
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5777 "libvirt-machine.c"
	}
}


GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error) {
	GVirDomainDisk* result = NULL;
	GVirDomainDisk* disk = NULL;
	gpointer _tmp0_ = NULL;
	GVirDomainDisk* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gvir_domain_disk_get_type ()) ? ((GVirDomainDisk*) _tmp0_) : NULL);
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	disk = _tmp1_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = self->priv->_domain_config;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = gvir_config_domain_get_devices (_tmp2_);
#line 5802 "libvirt-machine.c"
	{
		GList* device_config_collection = NULL;
		GList* device_config_it = NULL;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		device_config_collection = _tmp3_;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 5810 "libvirt-machine.c"
			GVirConfigDomainDevice* _tmp4_ = NULL;
			GVirConfigDomainDevice* device_config = NULL;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp4_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			device_config = _tmp4_;
#line 5817 "libvirt-machine.c"
			{
				GVirConfigDomainDevice* _tmp5_ = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp5_ = device_config;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_disk_get_type ())) {
#line 5824 "libvirt-machine.c"
					GVirConfigDomainDisk* disk_config = NULL;
					GVirConfigDomainDevice* _tmp6_ = NULL;
					GVirConfigDomainDisk* _tmp7_ = NULL;
					GVirConfigDomainDiskGuestDeviceType disk_type = 0;
					GVirConfigDomainDisk* _tmp8_ = NULL;
					GVirConfigDomainDiskGuestDeviceType _tmp9_ = 0;
					const gchar* _tmp10_ = NULL;
					GVirStorageVol* _tmp11_ = NULL;
					gchar* storage_volume_path = NULL;
					gchar* _tmp14_ = NULL;
					gboolean _tmp15_ = FALSE;
					GVirConfigDomainDiskGuestDeviceType _tmp16_ = 0;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp6_ = device_config;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp6_) : NULL);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					disk_config = _tmp7_;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp8_ = disk_config;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp9_ = gvir_config_domain_disk_get_guest_device_type (_tmp8_);
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					disk_type = _tmp9_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp11_ = self->priv->_storage_volume;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp11_ != NULL) {
#line 5853 "libvirt-machine.c"
						GVirStorageVol* _tmp12_ = NULL;
						const gchar* _tmp13_ = NULL;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp12_ = self->priv->_storage_volume;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp13_ = gvir_storage_vol_get_path (_tmp12_, &_inner_error_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp10_ = _tmp13_;
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							g_propagate_error (error, _inner_error_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (disk_config);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (device_config);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							__g_list_free__g_object_unref0_0 (device_config_collection);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (disk);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							return NULL;
#line 5876 "libvirt-machine.c"
						}
					} else {
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp10_ = NULL;
#line 5881 "libvirt-machine.c"
					}
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp14_ = g_strdup (_tmp10_);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					storage_volume_path = _tmp14_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp16_ = disk_type;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp16_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_DISK) {
#line 5891 "libvirt-machine.c"
						GVirConfigDomainDisk* _tmp17_ = NULL;
						const gchar* _tmp18_ = NULL;
						const gchar* _tmp19_ = NULL;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp17_ = disk_config;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp18_ = gvir_config_domain_disk_get_source (_tmp17_);
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp19_ = storage_volume_path;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp15_ = g_strcmp0 (_tmp18_, _tmp19_) == 0;
#line 5903 "libvirt-machine.c"
					} else {
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp15_ = FALSE;
#line 5907 "libvirt-machine.c"
					}
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp15_) {
#line 5911 "libvirt-machine.c"
						GVirDomain* _tmp20_ = NULL;
						GVirConfigDomainDevice* _tmp21_ = NULL;
						GObject* _tmp22_ = NULL;
						GObject* _tmp23_ = NULL;
						GVirDomainDisk* _tmp24_ = NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp20_ = self->priv->_domain;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp21_ = device_config;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp22_ = g_object_new (gvir_domain_disk_get_type (), "domain", _tmp20_, "config", _tmp21_, NULL);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp23_ = G_IS_INITIALLY_UNOWNED (_tmp22_) ? g_object_ref_sink (_tmp22_) : _tmp22_;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, gvir_domain_disk_get_type ()) ? ((GVirDomainDisk*) _tmp23_) : NULL;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						if (_tmp24_ == NULL) {
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
							_g_object_unref0 (_tmp23_);
#line 5931 "libvirt-machine.c"
						}
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (disk);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						disk = _tmp24_;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_free0 (storage_volume_path);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (disk_config);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (device_config);
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						break;
#line 5945 "libvirt-machine.c"
					}
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_free0 (storage_volume_path);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (disk_config);
#line 5951 "libvirt-machine.c"
				}
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (device_config);
#line 5955 "libvirt-machine.c"
			}
		}
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__g_list_free__g_object_unref0_0 (device_config_collection);
#line 5960 "libvirt-machine.c"
	}
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = disk;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5966 "libvirt-machine.c"
}


static GVirDomainInterface* boxes_libvirt_machine_get_domain_network_interface (BoxesLibvirtMachine* self, GError** error) {
	GVirDomainInterface* result = NULL;
	GVirDomainInterface* net = NULL;
	gpointer _tmp0_ = NULL;
	GVirDomainInterface* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = NULL;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gvir_domain_interface_get_type ()) ? ((GVirDomainInterface*) _tmp0_) : NULL);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	net = _tmp1_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = self->priv->_domain_config;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = gvir_config_domain_get_devices (_tmp2_);
#line 5989 "libvirt-machine.c"
	{
		GList* device_config_collection = NULL;
		GList* device_config_it = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		device_config_collection = _tmp3_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 5997 "libvirt-machine.c"
			GVirConfigDomainDevice* _tmp4_ = NULL;
			GVirConfigDomainDevice* device_config = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp4_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			device_config = _tmp4_;
#line 6004 "libvirt-machine.c"
			{
				GVirConfigDomainDevice* _tmp5_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_tmp5_ = device_config;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_interface_get_type ())) {
#line 6011 "libvirt-machine.c"
					GVirDomain* _tmp6_ = NULL;
					GVirConfigDomainDevice* _tmp7_ = NULL;
					GObject* _tmp8_ = NULL;
					GObject* _tmp9_ = NULL;
					GVirDomainInterface* _tmp10_ = NULL;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp6_ = self->priv->_domain;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp7_ = device_config;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp8_ = g_object_new (gvir_domain_interface_get_type (), "domain", _tmp6_, "config", _tmp7_, NULL);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp9_ = G_IS_INITIALLY_UNOWNED (_tmp8_) ? g_object_ref_sink (_tmp8_) : _tmp8_;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gvir_domain_interface_get_type ()) ? ((GVirDomainInterface*) _tmp9_) : NULL;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp10_ == NULL) {
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (_tmp9_);
#line 6031 "libvirt-machine.c"
					}
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (net);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					net = _tmp10_;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (device_config);
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					break;
#line 6041 "libvirt-machine.c"
				}
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (device_config);
#line 6045 "libvirt-machine.c"
			}
		}
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		__g_list_free__g_object_unref0_0 (device_config_collection);
#line 6050 "libvirt-machine.c"
	}
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = net;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6056 "libvirt-machine.c"
}


static GVirDomainStartFlags boxes_libvirt_machine_connect_flags_to_gvir (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags) {
	GVirDomainStartFlags result = 0;
	GVirDomainStartFlags gvir_flags = 0;
	BoxesMachineConnectFlags _tmp0_ = 0;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	gvir_flags = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = flags;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((_tmp0_ & BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) == BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) {
#line 6072 "libvirt-machine.c"
		GVirDomainStartFlags _tmp1_ = 0;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = gvir_flags;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_flags = _tmp1_ | GVIR_DOMAIN_START_FORCE_BOOT;
#line 6078 "libvirt-machine.c"
	}
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = gvir_flags;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6084 "libvirt-machine.c"
}


static void boxes_libvirt_machine_start_data_free (gpointer _data) {
	BoxesLibvirtMachineStartData* _data_;
	_data_ = _data;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineStartData, _data_);
#line 6097 "libvirt-machine.c"
}


void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineStartData* _data_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesMachineConnectFlags _tmp1_ = 0;
	GCancellable* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineStartData);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_start);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_start_data_free);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = flags;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->flags = _tmp1_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = cancellable;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp3_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start_co (_data_);
#line 6131 "libvirt-machine.c"
}


void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineStartData* _data_;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6141 "libvirt-machine.c"
	}
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6145 "libvirt-machine.c"
}


static void boxes_libvirt_machine_start_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineStartData* _data_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_start_co (_data_);
#line 6159 "libvirt-machine.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? g_error_copy (self) : NULL;
#line 6166 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_start_co (BoxesLibvirtMachineStartData* _data_) {
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 6175 "libvirt-machine.c"
		goto _state_0;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 6179 "libvirt-machine.c"
		goto _state_1;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 6183 "libvirt-machine.c"
		goto _state_2;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 6187 "libvirt-machine.c"
		goto _state_3;
		default:
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 6192 "libvirt-machine.c"
	}
	_state_0:
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = 0;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = boxes_machine_get_state ((BoxesMachine*) _data_->self);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = 0;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp1_ == BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6209 "libvirt-machine.c"
		} else {
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 6213 "libvirt-machine.c"
		}
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 6219 "libvirt-machine.c"
	}
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = 0;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = boxes_machine_get_state ((BoxesMachine*) _data_->self);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = 0;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp3_ == BOXES_MACHINE_MACHINE_STATE_PAUSED) {
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->self->priv->_domain;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->cancellable;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_resume_async (_data_->_tmp4_, _data_->_tmp5_, boxes_libvirt_machine_start_ready, _data_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 6245 "libvirt-machine.c"
		_state_1:
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_resume_finish (_data_->_tmp4_, _data_->_res_, &_data_->_inner_error_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6259 "libvirt-machine.c"
			} else {
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 6263 "libvirt-machine.c"
			}
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 6269 "libvirt-machine.c"
		}
	} else {
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = 0;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = boxes_machine_get_state ((BoxesMachine*) _data_->self);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = 0;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp7_ == BOXES_MACHINE_MACHINE_STATE_SLEEPING) {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp8_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp8_ = _data_->self->priv->_domain;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp9_ = NULL;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp9_ = _data_->cancellable;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_state_ = 2;
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gvir_domain_wakeup_async (_data_->_tmp8_, (guint) 0, _data_->_tmp9_, boxes_libvirt_machine_start_ready, _data_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 6296 "libvirt-machine.c"
			_state_2:
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gvir_domain_wakeup_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6310 "libvirt-machine.c"
				} else {
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 6314 "libvirt-machine.c"
				}
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 527 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 6320 "libvirt-machine.c"
			}
		} else {
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = NULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = _data_->self->priv->_domain;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = FALSE;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = gvir_domain_get_saved (_data_->_tmp11_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_tmp12_) {
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp13_ = 0;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp13_ = _data_->flags;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp10_ = !((_data_->_tmp13_ & BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE) == BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE);
#line 6339 "libvirt-machine.c"
			} else {
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp10_ = FALSE;
#line 6343 "libvirt-machine.c"
			}
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->restore = _data_->_tmp10_;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = FALSE;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->restore;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_tmp14_) {
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp15_ = NULL;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp15_ = _ ("Restoring %s from disk");
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp16_ = NULL;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp16_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp17_ = NULL;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp18_ = NULL;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp18_ = g_strdup_printf (_data_->_tmp15_, _data_->_tmp17_);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp19_ = NULL;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp19_ = _data_->_tmp18_;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_status ((BoxesMachine*) _data_->self, _data_->_tmp19_);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_data_->_tmp19_);
#line 6377 "libvirt-machine.c"
			} else {
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp20_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp20_ = _ ("Starting %s");
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp21_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = _data_->_tmp21_;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = g_strdup_printf (_data_->_tmp20_, _data_->_tmp22_);
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = NULL;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = _data_->_tmp23_;
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_status ((BoxesMachine*) _data_->self, _data_->_tmp24_);
#line 536 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_data_->_tmp24_);
#line 6403 "libvirt-machine.c"
			}
			{
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = NULL;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = _data_->self->priv->_domain;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = 0;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = _data_->flags;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = 0;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = boxes_libvirt_machine_connect_flags_to_gvir (_data_->self, _data_->_tmp26_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = NULL;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = _data_->cancellable;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_state_ = 3;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_start_async (_data_->_tmp25_, (guint) _data_->_tmp27_, _data_->_tmp28_, boxes_libvirt_machine_start_ready, _data_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 6428 "libvirt-machine.c"
				_state_3:
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_start_finish (_data_->_tmp25_, _data_->_res_, &_data_->_inner_error_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 6436 "libvirt-machine.c"
						goto __catch24_g_io_error_cancelled;
					}
					goto __catch24_g_error;
				}
			}
			goto __finally24;
			__catch24_g_io_error_cancelled:
			{
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_error_ = _data_->_inner_error_;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_inner_error_ = NULL;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = NULL;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = NULL;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_debug ("libvirt-machine.vala:540: starting of %s was cancelled", _data_->_tmp30_);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_error_free0 (_data_->_error_);
#line 6461 "libvirt-machine.c"
			}
			goto __finally24;
			__catch24_g_error:
			{
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_inner_error_ = NULL;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = FALSE;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = _data_->restore;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_tmp31_) {
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp32_ = NULL;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp32_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_RESTORE_FAILED, "Restore failed");
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_inner_error_ = _data_->_tmp32_;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_error_free0 (_data_->_vala1__error_);
#line 6484 "libvirt-machine.c"
					goto __finally24;
				} else {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp33_ = NULL;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp33_ = _data_->_vala1__error_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp34_ = NULL;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_tmp34_ = _g_error_copy0 (_data_->_tmp33_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_data_->_inner_error_ = _data_->_tmp34_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					_g_error_free0 (_data_->_vala1__error_);
#line 6499 "libvirt-machine.c"
					goto __finally24;
				}
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 6504 "libvirt-machine.c"
			}
			__finally24:
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6517 "libvirt-machine.c"
				} else {
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 6521 "libvirt-machine.c"
				}
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 6527 "libvirt-machine.c"
			}
		}
	}
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6535 "libvirt-machine.c"
	} else {
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6539 "libvirt-machine.c"
	}
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 6545 "libvirt-machine.c"
}


static Block27Data* block27_data_ref (Block27Data* _data27_) {
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data27_->_ref_count_);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return _data27_;
#line 6554 "libvirt-machine.c"
}


static void block27_data_unref (void * _userdata_) {
	Block27Data* _data27_;
	_data27_ = (Block27Data*) _userdata_;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data27_->_ref_count_)) {
#line 6563 "libvirt-machine.c"
		BoxesLibvirtMachine* self;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		self = _data27_->self;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data27_->notification);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block27Data, _data27_);
#line 6573 "libvirt-machine.c"
	}
}


static void ___lambda148_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (res != NULL);
#line 6582 "libvirt-machine.c"
	{
		GAsyncResult* _tmp0_ = NULL;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = res;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start_finish (self, _tmp0_, &_inner_error_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6591 "libvirt-machine.c"
			goto __catch25_g_error;
		}
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_restart ((BoxesMachine*) self);
#line 6596 "libvirt-machine.c"
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _error_;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->message;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:558: Failed to start '%s': %s", _tmp2_, _tmp4_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 6622 "libvirt-machine.c"
	}
	__finally25:
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6633 "libvirt-machine.c"
	}
}


static void ____lambda148__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda148_ ((BoxesLibvirtMachine*) self, source_object, res);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (self);
#line 6643 "libvirt-machine.c"
}


static void ___lambda150_ (BoxesLibvirtMachine* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (res != NULL);
#line 6651 "libvirt-machine.c"
	{
		GAsyncResult* _tmp0_ = NULL;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = res;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start_finish (self, _tmp0_, &_inner_error_);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6660 "libvirt-machine.c"
			goto __catch26_g_error;
		}
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = self->priv->_domain;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _error_;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->message;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:578: Failed to start '%s': %s", _tmp2_, _tmp4_);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 6688 "libvirt-machine.c"
	}
	__finally26:
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6699 "libvirt-machine.c"
	}
}


static void ____lambda150__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	___lambda150_ ((BoxesLibvirtMachine*) self, source_object, res);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (self);
#line 6709 "libvirt-machine.c"
}


static void __lambda149_ (Block27Data* _data27_) {
	BoxesLibvirtMachine* self;
	gboolean _tmp0_ = FALSE;
	BoxesMachineMachineState _tmp1_ = 0;
	BoxesMachineMachineState _tmp2_ = 0;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data27_->self;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ == BOXES_MACHINE_MACHINE_STATE_STOPPED) {
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = TRUE;
#line 6728 "libvirt-machine.c"
	} else {
		BoxesMachineMachineState _tmp3_ = 0;
		BoxesMachineMachineState _tmp4_ = 0;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = _tmp4_ == BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 6738 "libvirt-machine.c"
	}
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 6742 "libvirt-machine.c"
		const gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gulong _tmp7_ = 0UL;
		guint _tmp8_ = 0U;
		GdNotification* _tmp10_ = NULL;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:573: '%s' stopped.", _tmp6_);
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start (self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, ____lambda150__gasync_ready_callback, g_object_ref (self));
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = _data27_->state_id;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_signal_handler_disconnect ((GObject*) self, _tmp7_);
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = self->priv->shutdown_timeout;
#line 583 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp8_ != ((guint) 0)) {
#line 6764 "libvirt-machine.c"
			guint _tmp9_ = 0U;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = self->priv->shutdown_timeout;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			g_source_remove (_tmp9_);
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			self->priv->shutdown_timeout = (guint) 0;
#line 6772 "libvirt-machine.c"
		}
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = _data27_->notification;
#line 587 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp10_ != NULL) {
#line 6778 "libvirt-machine.c"
			GdNotification* _tmp11_ = NULL;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_tmp11_ = _data27_->notification;
#line 588 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			gd_notification_dismiss (_tmp11_);
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_g_object_unref0 (_data27_->notification);
#line 589 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			_data27_->notification = NULL;
#line 6788 "libvirt-machine.c"
		}
	}
}


static void ___lambda149__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda149_ (self);
#line 6797 "libvirt-machine.c"
}


static void __lambda152_ (Block27Data* _data27_) {
	BoxesLibvirtMachine* self;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data27_->self;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data27_->notification);
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->notification = NULL;
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_force_shutdown (self, FALSE);
#line 6811 "libvirt-machine.c"
}


static void ___lambda152__boxes_notification_ok_func (gpointer self) {
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__lambda152_ (self);
#line 6818 "libvirt-machine.c"
}


static gboolean __lambda151_ (Block27Data* _data27_) {
	BoxesLibvirtMachine* self;
	gboolean result = FALSE;
	BoxesNotificationOKFunc really_force_shutdown = NULL;
	void* really_force_shutdown_target = NULL;
	GDestroyNotify really_force_shutdown_target_destroy_notify = NULL;
	gchar* message = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	BoxesNotificationbar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	BoxesNotificationOKFunc _tmp7_ = NULL;
	void* _tmp7__target = NULL;
	GDestroyNotify _tmp7__target_destroy_notify = NULL;
	GdNotification* _tmp8_ = NULL;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = _data27_->self;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown = ___lambda152__boxes_notification_ok_func;
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target = block27_data_ref (_data27_);
#line 596 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target_destroy_notify = block27_data_unref;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _ ("Restart of '%s' is taking too long. Force it to shutdown?");
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp2_);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	message = _tmp3_;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_app_window;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->notificationbar;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = _ ("_Shutdown");
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = really_force_shutdown;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7__target = really_force_shutdown_target;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7__target_destroy_notify = really_force_shutdown_target_destroy_notify;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target_destroy_notify = NULL;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = boxes_notificationbar_display_for_action (_tmp5_, message, _tmp6_, _tmp7_, _tmp7__target, _tmp7__target_destroy_notify, NULL, NULL, NULL, -1);
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data27_->notification);
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->notification = _tmp8_;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->shutdown_timeout = (guint) 0;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = FALSE;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (message);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(really_force_shutdown_target_destroy_notify == NULL) ? NULL : (really_force_shutdown_target_destroy_notify (really_force_shutdown_target), NULL);
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown = NULL;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target = NULL;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	really_force_shutdown_target_destroy_notify = NULL;
#line 609 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6894 "libvirt-machine.c"
}


static gboolean ___lambda151__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda151_ (self);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6903 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_restart (BoxesMachine* base) {
	BoxesLibvirtMachine * self;
	Block27Data* _data27_;
	BoxesMachineMachineState _tmp0_ = 0;
	BoxesMachineMachineState _tmp1_ = 0;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
	guint _tmp7_ = 0U;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_ = g_slice_new0 (Block27Data);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->_ref_count_ = 1;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->self = g_object_ref (self);
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 6930 "libvirt-machine.c"
		const gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp2_;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:552: '%s' is in saved state. Resuming it..", _tmp3_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_start (self, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, ____lambda148__gasync_ready_callback, g_object_ref (self));
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		block27_data_unref (_data27_);
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_data27_ = NULL;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6947 "libvirt-machine.c"
	}
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachine*) self)->stay_on_display = TRUE;
#line 566 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->state_id = (gulong) 0;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->notification = NULL;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:568: Rebooting '%s'..", _tmp5_);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = g_signal_connect_data ((GObject*) self, "notify::state", (GCallback) ___lambda149__g_object_notify, block27_data_ref (_data27_), (GClosureNotify) block27_data_unref, 0);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_->state_id = _tmp6_;
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 5, ___lambda151__gsource_func, block27_data_ref (_data27_), block27_data_unref);
#line 594 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->shutdown_timeout = _tmp7_;
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_try_shutdown (self);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	block27_data_unref (_data27_);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_data27_ = NULL;
#line 6975 "libvirt-machine.c"
}


GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self) {
	GVirDomain* result;
	GVirDomain* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 6990 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_domain (BoxesLibvirtMachine* self, GVirDomain* value) {
	GVirDomain* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_domain = _tmp1_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "domain");
#line 7009 "libvirt-machine.c"
}


GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self) {
	GVirConfigDomain* result;
	GVirConfigDomain* _tmp0_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_domain_config;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7024 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_domain_config (BoxesLibvirtMachine* self, GVirConfigDomain* value) {
	GVirConfigDomain* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain_config);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_domain_config = _tmp1_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "domain-config");
#line 7043 "libvirt-machine.c"
}


GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self) {
	GVirConnection* result;
	GVirConnection* _tmp0_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_connection;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7058 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_connection (BoxesLibvirtMachine* self, GVirConnection* value) {
	GVirConnection* _tmp0_ = NULL;
	GVirConnection* _tmp1_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_connection);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_connection = _tmp1_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "connection");
#line 7077 "libvirt-machine.c"
}


GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self) {
	GVirStorageVol* result;
	GVirStorageVol* _tmp0_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_storage_volume;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7092 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value) {
	GVirStorageVol* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_storage_volume);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_storage_volume = _tmp1_;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "storage-volume");
#line 7111 "libvirt-machine.c"
}


BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self) {
	BoxesVMCreator* result;
	BoxesVMCreator* _tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->_vm_creator;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7126 "libvirt-machine.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 7133 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value) {
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesVMCreator* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	BoxesVMCreator* _tmp5_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _boxes_vm_creator_ref0 (_tmp0_);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_boxes_vm_creator_unref0 (self->priv->_vm_creator);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_vm_creator = _tmp1_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_libvirt_machine_get_importing (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_can_delete ((BoxesMachine*) self, !_tmp3_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = value;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ != NULL) {
#line 7164 "libvirt-machine.c"
		GVirConfigDomain* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->_domain_config;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = boxes_vm_configurator_is_live_config (_tmp6_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = !_tmp7_;
#line 7173 "libvirt-machine.c"
	} else {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = FALSE;
#line 7177 "libvirt-machine.c"
	}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_under_construction ((BoxesMachine*) self, _tmp4_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "vm-creator");
#line 7183 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	BoxesVMCreator* _tmp1_ = NULL;
	BoxesVMCreator* _tmp2_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_libvirt_machine_get_vm_creator (self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp2_ != NULL) {
#line 7200 "libvirt-machine.c"
		BoxesVMCreator* _tmp3_ = NULL;
		BoxesVMCreator* _tmp4_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_libvirt_machine_get_vm_creator (self);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_VM_IMPORTER);
#line 7209 "libvirt-machine.c"
	} else {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = FALSE;
#line 7213 "libvirt-machine.c"
	}
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp0_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7219 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_get_save_on_quit (BoxesLibvirtMachine* self) {
	gboolean result;
	BoxesCollectionSource* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_iconfig_get_boolean ((BoxesIConfig*) _tmp0_, "source", "save-on-quit", FALSE);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp1_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 7237 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_save_on_quit (BoxesLibvirtMachine* self, gboolean value) {
	BoxesCollectionSource* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = value;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_iconfig_set_boolean ((BoxesIConfig*) _tmp0_, "source", "save-on-quit", _tmp1_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "save-on-quit");
#line 7254 "libvirt-machine.c"
}


static GObject * boxes_libvirt_machine_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineMachineStat* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	parent_class = G_OBJECT_CLASS (boxes_libvirt_machine_parent_class);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = g_new0 (BoxesLibvirtMachineMachineStat, BOXES_LIBVIRT_MACHINE_STATS_SIZE);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (self->priv->stats, self->priv->stats_length1), NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = _tmp0_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats_length1 = BOXES_LIBVIRT_MACHINE_STATS_SIZE;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_stats_size_ = self->priv->stats_length1;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = g_cancellable_new ();
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->stats_cancellable);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats_cancellable = _tmp1_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_can_save ((BoxesMachine*) self, TRUE);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return obj;
#line 7290 "libvirt-machine.c"
}


static GVirDomainDiskStats* _vala_GVirDomainDiskStats_copy (GVirDomainDiskStats* self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_disk_stats_get_type (), self);
#line 7297 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainDiskStats_copy0 (gpointer self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainDiskStats_copy (self) : NULL;
#line 7304 "libvirt-machine.c"
}


static GVirDomainInterfaceStats* _vala_GVirDomainInterfaceStats_copy (GVirDomainInterfaceStats* self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_interface_stats_get_type (), self);
#line 7311 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainInterfaceStats_copy0 (gpointer self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainInterfaceStats_copy (self) : NULL;
#line 7318 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_copy (const BoxesLibvirtMachineMachineStat* self, BoxesLibvirtMachineMachineStat* dest) {
	gint64 _tmp0_ = 0LL;
	gdouble _tmp1_ = 0.0;
	gdouble _tmp2_ = 0.0;
	gdouble _tmp3_ = 0.0;
	gdouble _tmp4_ = 0.0;
	GVirDomainDiskStats* _tmp5_ = NULL;
	GVirDomainDiskStats* _tmp6_ = NULL;
	gdouble _tmp7_ = 0.0;
	gdouble _tmp8_ = 0.0;
	GVirDomainInterfaceStats* _tmp9_ = NULL;
	GVirDomainInterfaceStats* _tmp10_ = NULL;
	gdouble _tmp11_ = 0.0;
	gdouble _tmp12_ = 0.0;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = (*self).timestamp;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).timestamp = _tmp0_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = (*self).cpu_time;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_time = _tmp1_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = (*self).cpu_time_abs;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_time_abs = _tmp2_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = (*self).cpu_guest_percent;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_guest_percent = _tmp3_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = (*self).memory_percent;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).memory_percent = _tmp4_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = (*self).disk;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = __vala_GVirDomainDiskStats_copy0 (_tmp5_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*dest).disk);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk = _tmp6_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = (*self).disk_read;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk_read = _tmp7_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = (*self).disk_write;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk_write = _tmp8_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = (*self).net;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = __vala_GVirDomainInterfaceStats_copy0 (_tmp9_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*dest).net);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net = _tmp10_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = (*self).net_read;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net_read = _tmp11_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = (*self).net_write;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net_write = _tmp12_;
#line 7388 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_destroy (BoxesLibvirtMachineMachineStat* self) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*self).disk);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*self).net);
#line 7397 "libvirt-machine.c"
}


static BoxesLibvirtMachineMachineStat* boxes_libvirt_machine_machine_stat_dup (const BoxesLibvirtMachineMachineStat* self) {
	BoxesLibvirtMachineMachineStat* dup;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	dup = g_new0 (BoxesLibvirtMachineMachineStat, 1);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_copy (self, dup);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return dup;
#line 7409 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_free (BoxesLibvirtMachineMachineStat* self) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_destroy (self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (self);
#line 7418 "libvirt-machine.c"
}


static GType boxes_libvirt_machine_machine_stat_get_type (void) {
	static volatile gsize boxes_libvirt_machine_machine_stat_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_machine_stat_type_id__volatile)) {
		GType boxes_libvirt_machine_machine_stat_type_id;
		boxes_libvirt_machine_machine_stat_type_id = g_boxed_type_register_static ("BoxesLibvirtMachineMachineStat", (GBoxedCopyFunc) boxes_libvirt_machine_machine_stat_dup, (GBoxedFreeFunc) boxes_libvirt_machine_machine_stat_free);
		g_once_init_leave (&boxes_libvirt_machine_machine_stat_type_id__volatile, boxes_libvirt_machine_machine_stat_type_id);
	}
	return boxes_libvirt_machine_machine_stat_type_id__volatile;
}


static void boxes_libvirt_machine_class_init (BoxesLibvirtMachineClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->disconnect_display = boxes_libvirt_machine_real_disconnect_display;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->connect_display = boxes_libvirt_machine_real_connect_display;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->connect_display_finish = boxes_libvirt_machine_real_connect_display_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_properties = boxes_libvirt_machine_real_get_properties;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot = boxes_libvirt_machine_real_take_screenshot;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot_finish = boxes_libvirt_machine_real_take_screenshot_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->delete = boxes_libvirt_machine_real_delete;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->save_real = boxes_libvirt_machine_real_save_real;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->save_real_finish = boxes_libvirt_machine_real_save_real_finish;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->restart = boxes_libvirt_machine_real_restart;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_libvirt_machine_get_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_libvirt_machine_set_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_libvirt_machine_constructor;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_DOMAIN, g_param_spec_object ("domain", "domain", "domain", gvir_domain_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG, g_param_spec_object ("domain-config", "domain-config", "domain-config", gvir_config_domain_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_CONNECTION, g_param_spec_object ("connection", "connection", "connection", gvir_connection_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME, g_param_spec_object ("storage-volume", "storage-volume", "storage-volume", gvir_storage_vol_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_VM_CREATOR, boxes_param_spec_vm_creator ("vm-creator", "vm-creator", "vm-creator", BOXES_TYPE_VM_CREATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_IMPORTING, g_param_spec_boolean ("importing", "importing", "importing", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT, g_param_spec_boolean ("save-on-quit", "save-on-quit", "save-on-quit", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_signal_new ("stats_updated", BOXES_TYPE_LIBVIRT_MACHINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 7482 "libvirt-machine.c"
}


static void boxes_libvirt_machine_instance_init (BoxesLibvirtMachine * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_GET_PRIVATE (self);
#line 7489 "libvirt-machine.c"
}


static void boxes_libvirt_machine_finalize (GObject* obj) {
	BoxesLibvirtMachine * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_domain_config);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_connection);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->_storage_volume);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_boxes_vm_creator_unref0 (self->priv->_vm_creator);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->properties);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->stats_cancellable);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (self->priv->stats, self->priv->stats_length1), NULL);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->cpu_stats = (g_free (self->cpu_stats), NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->io_stats = (g_free (self->io_stats), NULL);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	self->net_stats = (g_free (self->net_stats), NULL);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_parent_class)->finalize (obj);
#line 7521 "libvirt-machine.c"
}


GType boxes_libvirt_machine_get_type (void) {
	static volatile gsize boxes_libvirt_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachine), 0, (GInstanceInitFunc) boxes_libvirt_machine_instance_init, NULL };
		GType boxes_libvirt_machine_type_id;
		boxes_libvirt_machine_type_id = g_type_register_static (BOXES_TYPE_MACHINE, "BoxesLibvirtMachine", &g_define_type_info, 0);
		g_once_init_leave (&boxes_libvirt_machine_type_id__volatile, boxes_libvirt_machine_type_id);
	}
	return boxes_libvirt_machine_type_id__volatile;
}


static void _vala_boxes_libvirt_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesLibvirtMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_domain (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_domain_config (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_CONNECTION:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_connection (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_object (value, boxes_libvirt_machine_get_storage_volume (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_VM_CREATOR:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_value_set_vm_creator (value, boxes_libvirt_machine_get_vm_creator (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_IMPORTING:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_libvirt_machine_get_importing (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_libvirt_machine_get_save_on_quit (self));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 7584 "libvirt-machine.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 7590 "libvirt-machine.c"
	}
}


static void _vala_boxes_libvirt_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesLibvirtMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	switch (property_id) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_domain (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_DOMAIN_CONFIG:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_domain_config (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_CONNECTION:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_connection (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_STORAGE_VOLUME:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_storage_volume (self, g_value_get_object (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_VM_CREATOR:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_vm_creator (self, boxes_value_get_vm_creator (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_save_on_quit (self, g_value_get_boolean (value));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 7636 "libvirt-machine.c"
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 7642 "libvirt-machine.c"
	}
}



