/* vm-creator.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from vm-creator.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <libgd/gd.h>
#include <libcommon.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib/gstdio.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
typedef struct _BoxesVMCreatorPrivate BoxesVMCreatorPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))
typedef struct _Block60Data Block60Data;
typedef struct _Block61Data Block61Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;
typedef struct _BoxesVmCreatorCreateVmData BoxesVmCreatorCreateVmData;
typedef struct _Block62Data Block62Data;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _Block63Data Block63Data;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _BoxesVmCreatorContinueInstallationData BoxesVmCreatorContinueInstallationData;
typedef struct _Block64Data Block64Data;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _BoxesVmCreatorGetStoragePoolData BoxesVmCreatorGetStoragePoolData;
typedef struct _BoxesVmCreatorCreateDomainConfigData BoxesVmCreatorCreateDomainConfigData;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _Block65Data Block65Data;
typedef struct _Block66Data Block66Data;
typedef struct _BoxesVmCreatorUpdateInstallProgressData BoxesVmCreatorUpdateInstallProgressData;
typedef struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData BoxesVmCreatorCreateDomainNameAndTitleFromMediaData;
typedef struct _BoxesVmCreatorCreateTargetVolumeData BoxesVmCreatorCreateTargetVolumeData;
typedef struct _BoxesParamSpecVMCreator BoxesParamSpecVMCreator;

struct _BoxesVMCreator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesVMCreatorPrivate * priv;
};

struct _BoxesVMCreatorClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesVMCreator *self);
	void (*launch_vm) (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
	void (*continue_installation) (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*continue_installation_finish) (BoxesVMCreator* self, GAsyncResult* _res_);
	void (*update_machine_info) (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
	void (*create_domain_config) (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GVirConfigDomain* (*create_domain_config_finish) (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
	void (*create_domain_base_name_and_title) (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
};

struct _BoxesVMCreatorPrivate {
	BoxesInstallerMedia* _install_media;
	gulong state_changed_id;
	guint _num_reboots;
	gint prev_progress;
	gboolean updating_install_progress;
};

struct _Block60Data {
	int _ref_count_;
	BoxesVMCreator* self;
	gpointer _async_data_;
};

struct _Block61Data {
	int _ref_count_;
	Block60Data * _data60_;
	gulong handler;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesVmCreatorCreateVmData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GCancellable* cancellable;
	BoxesLibvirtMachine* result;
	Block60Data* _data60_;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	gboolean _tmp3_;
	Block61Data* _data61_;
	BoxesApp* _tmp4_;
	gulong _tmp5_;
	gchar* title;
	gchar* name;
	gchar* _tmp6_;
	gchar* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	const gchar* _tmp9_;
	GCancellable* _tmp10_;
	GError* _error_;
	gchar* msg;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	BoxesAppWindow* _tmp13_;
	BoxesNotificationbar* _tmp14_;
	const gchar* _tmp15_;
	GdNotification* _tmp16_;
	GdNotification* _tmp17_;
	GError* _tmp18_;
	const gchar* _tmp19_;
	GVirStorageVol* volume;
	const gchar* _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	OsinfoResources* _tmp22_;
	gint64 _tmp23_;
	gint64 _tmp24_;
	GVirStorageVol* _tmp25_;
	GVirConfigDomain* config;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	GVirStorageVol* _tmp28_;
	GCancellable* _tmp29_;
	GVirConfigDomain* _tmp30_;
	GVirDomain* domain;
	GVirConnection* _tmp31_;
	GVirConnection* _tmp32_;
	GVirConnection* _tmp33_;
	GVirConfigDomain* _tmp34_;
	GVirDomain* _tmp35_;
	GVirDomain* _tmp36_;
	BoxesLibvirtMachine* machine;
	BoxesLibvirtBroker* _tmp37_;
	BoxesLibvirtBroker* _tmp38_;
	BoxesApp* _tmp39_;
	BoxesCollectionSource* _tmp40_;
	BoxesCollectionSource* _tmp41_;
	BoxesApp* _tmp42_;
	GVirConnection* _tmp43_;
	GVirConnection* _tmp44_;
	GVirConnection* _tmp45_;
	GVirDomain* _tmp46_;
	BoxesLibvirtMachine* _tmp47_;
	BoxesLibvirtMachine* _tmp48_;
	BoxesLibvirtMachine* _tmp49_;
	GError * _inner_error_;
};

struct _Block62Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _Block63Data {
	int _ref_count_;
	Block62Data * _data62_;
	gulong signal_id;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesVmCreatorContinueInstallationData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	BoxesMediaManager* _tmp0_;
	BoxesMediaManager* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GVirConfigDomain* _tmp3_;
	GVirConfigDomain* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomain* _tmp9_;
	guint _tmp10_;
	gchar* name;
	BoxesLibvirtMachine* _tmp11_;
	GVirDomain* _tmp12_;
	GVirDomain* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesLibvirtMachine* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	const gchar* _tmp19_;
	gboolean _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	const gchar* _tmp22_;
	BoxesLibvirtMachine* _tmp23_;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	BoxesApp* _tmp26_;
	BoxesLibvirtMachine* _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	const gchar* _tmp29_;
	BoxesLibvirtMachine* _tmp30_;
	gulong _tmp31_;
	BoxesLibvirtMachine* _tmp32_;
	BoxesLibvirtMachine* _tmp33_;
	BoxesLibvirtMachine* _tmp34_;
	gboolean _tmp35_;
	BoxesLibvirtMachine* _tmp36_;
	BoxesMachineMachineState _tmp37_;
	BoxesMachineMachineState _tmp38_;
	BoxesLibvirtMachine* _tmp39_;
	GVirConfigDomain* _tmp40_;
	GVirConfigDomain* _tmp41_;
	gboolean _tmp42_;
	BoxesLibvirtMachine* _tmp43_;
	GVirDomain* _tmp44_;
	GVirDomain* _tmp45_;
	GError* e;
	BoxesLibvirtMachine* _tmp46_;
	const gchar* _tmp47_;
	const gchar* _tmp48_;
	GError* _tmp49_;
	const gchar* _tmp50_;
	GError * _inner_error_;
};

struct _Block64Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);
struct _BoxesVmCreatorGetStoragePoolData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	GVirStoragePool* result;
	GVirStoragePool* pool;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GVirStoragePool* _tmp3_;
	GVirStoragePool* _tmp4_;
	GVirStoragePool* _tmp5_;
	GVirConfigStoragePool* config;
	GVirConfigStoragePool* _tmp6_;
	GVirStoragePool* _tmp7_;
	GVirConnection* _tmp8_;
	GVirConnection* _tmp9_;
	GVirConnection* _tmp10_;
	GVirConfigStoragePool* _tmp11_;
	GVirStoragePool* _tmp12_;
	GVirStoragePool* _tmp13_;
	GVirStoragePool* _tmp14_;
	GVirStoragePool* _tmp15_;
	GVirStoragePool* _tmp16_;
	GVirStoragePool* _tmp17_;
	GVirStoragePoolInfo* _tmp18_;
	GVirStoragePool* _tmp19_;
	GVirStoragePoolInfo* _tmp20_;
	GVirStoragePoolInfo* _tmp21_;
	GVirStoragePoolInfo* _tmp22_;
	GVirStoragePoolState _tmp23_;
	gboolean _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	GVirStoragePool* _tmp29_;
	GVirStoragePool* _tmp30_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_VM_CONFIGURATOR_ERROR_NO_GUEST_CAPS
} BoxesVMConfiguratorError;
#define BOXES_VM_CONFIGURATOR_ERROR boxes_vm_configurator_error_quark ()
struct _BoxesVmCreatorCreateDomainConfigData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	GVirStorageVol* volume;
	GCancellable* cancellable;
	GVirConfigDomain* result;
	GVirConfigCapabilities* caps;
	GVirConnection* _tmp0_;
	GVirConnection* _tmp1_;
	GVirConnection* _tmp2_;
	GCancellable* _tmp3_;
	GVirConfigCapabilities* _tmp4_;
	GVirConfigCapabilities* _tmp5_;
	const gchar* _tmp6_;
	GVirStorageVol* _tmp7_;
	const gchar* _tmp8_;
	GVirConfigDomain* config;
	BoxesInstallerMedia* _tmp9_;
	GVirConfigCapabilities* _tmp10_;
	GVirConfigDomain* _tmp11_;
	GVirConfigDomain* _tmp12_;
	const gchar* _tmp13_;
	GVirConfigDomain* _tmp14_;
	const gchar* _tmp15_;
	GError * _inner_error_;
};

struct _Block65Data {
	int _ref_count_;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
};

struct _Block66Data {
	int _ref_count_;
	BoxesVMCreator* self;
	gint progress;
	BoxesLibvirtMachine* machine;
	gpointer _async_data_;
};

struct _BoxesVmCreatorUpdateInstallProgressData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	BoxesLibvirtMachine* machine;
	Block66Data* _data66_;
	BoxesLibvirtMachine* _tmp0_;
	GError* _error_;
	BoxesLibvirtMachine* _tmp1_;
	GVirStorageVol* _tmp2_;
	GVirStorageVol* _tmp3_;
	const gchar* _tmp4_;
	GError* _tmp5_;
	const gchar* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateDomainNameAndTitleFromMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gchar* title;
	gchar* base_name;
	gchar* base_title;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp4_;
	gint i;
	gboolean _tmp5_;
	gint _tmp6_;
	gboolean _tmp7_;
	gboolean _tmp8_;
	GVirConnection* _tmp9_;
	GVirConnection* _tmp10_;
	GVirConnection* _tmp11_;
	const gchar* _tmp12_;
	GVirDomain* _tmp13_;
	GVirDomain* _tmp14_;
	gboolean _tmp15_;
	GVirConnection* _tmp16_;
	GVirConnection* _tmp17_;
	GVirConnection* _tmp18_;
	const gchar* _tmp19_;
	GVirDomain* _tmp20_;
	GVirDomain* _tmp21_;
	const gchar* _tmp22_;
	GVirStorageVol* _tmp23_;
	GVirStorageVol* _tmp24_;
	gchar* _tmp25_;
	gchar* _tmp26_;
	gint _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gint _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	GError * _inner_error_;
};

struct _BoxesVmCreatorCreateTargetVolumeData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesVMCreator* self;
	gchar* name;
	gint64 storage;
	GVirStorageVol* result;
	GVirStoragePool* pool;
	GVirStoragePool* _tmp0_;
	GVirConfigStorageVol* config;
	const gchar* _tmp1_;
	gint64 _tmp2_;
	GVirConfigStorageVol* _tmp3_;
	const gchar* _tmp4_;
	GVirStorageVol* volume;
	GVirStoragePool* _tmp5_;
	GVirConfigStorageVol* _tmp6_;
	GVirStorageVol* _tmp7_;
	const gchar* _tmp8_;
	GError * _inner_error_;
};

struct _BoxesParamSpecVMCreator {
	GParamSpec parent_instance;
};


static gpointer boxes_vm_creator_parent_class = NULL;
extern BoxesApp* boxes_app_app;
extern BoxesAppWindow* boxes_app_window;

gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_VM_CREATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorPrivate))
enum  {
	BOXES_VM_CREATOR_DUMMY_PROPERTY
};
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up (BoxesInstallerMedia* self);
#define BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT 99
BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media);
BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media);
void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value);
BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine);
BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine);
void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static void boxes_vm_creator_create_vm_data_free (gpointer _data);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_);
static Block60Data* block60_data_ref (Block60Data* _data60_);
static void block60_data_unref (void * _userdata_);
static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self);
static Block61Data* block61_data_ref (Block61Data* _data61_);
static void block61_data_unref (void * _userdata_);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void ___lambda66_ (Block61Data* _data61_);
static void ____lambda66__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error);
static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_for_installation_finish (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
void boxes_vm_creator_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirConfigDomain* boxes_vm_creator_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
GType boxes_broker_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
BoxesLibvirtMachine* boxes_libvirt_broker_add_domain (BoxesLibvirtBroker* self, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_libvirt_machine_set_vm_creator (BoxesLibvirtMachine* self, BoxesVMCreator* value);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
static void boxes_vm_creator_real_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
static Block62Data* block62_data_ref (Block62Data* _data62_);
static void block62_data_unref (void * _userdata_);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
static Block63Data* block63_data_ref (Block63Data* _data63_);
static void block63_data_unref (void * _userdata_);
static void ___lambda67_ (Block63Data* _data63_);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
static void ____lambda67__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec);
static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_vm_creator_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_real_continue_installation_data_free (gpointer _data);
static void boxes_vm_creator_real_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_vm_creator_real_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_);
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint boxes_vm_configurator_get_num_reboots (GVirConfigDomain* domain);
static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value);
void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_installer_media_prepare_to_continue_installation (BoxesInstallerMedia* self, const gchar* vm_name);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
static Block64Data* block64_data_ref (Block64Data* _data64_);
static void block64_data_unref (void * _userdata_);
gboolean boxes_machine_is_on (BoxesMachine* self);
static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
static gboolean boxes_vm_creator_install_trackable (BoxesVMCreator* self);
void boxes_machine_set_info (BoxesMachine* self, const gchar* value);
static void ____lambda54_ (Block64Data* _data64_);
static void _____lambda54__boxes_app_undo_notify_callback (gpointer self);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_vm_creator_real_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
static void boxes_vm_creator_track_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine);
void boxes_vm_configurator_post_install_setup (GVirConfigDomain* domain, BoxesInstallerMedia* install_media);
static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data);
void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
GVirConfigStoragePool* boxes_vm_configurator_get_pool_config (GError** error);
static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
static void boxes_vm_creator_real_create_domain_config_data_free (gpointer _data);
static void boxes_vm_creator_real_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_vm_creator_real_create_domain_config_co (BoxesVmCreatorCreateDomainConfigData* _data_);
static void boxes_vm_creator_create_domain_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GQuark boxes_vm_configurator_error_quark (void);
GVirConfigDomain* boxes_vm_configurator_create_domain_config (BoxesInstallerMedia* install_media, const gchar* target_path, GVirConfigCapabilities* caps, GError** error);
void boxes_vm_creator_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
static void boxes_vm_creator_real_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title);
static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self);
void boxes_vm_configurator_set_num_reboots (GVirConfigDomain* domain, BoxesInstallerMedia* install_media, guint num_reboots);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static gint boxes_vm_creator_get_progress (BoxesVMCreator* self, GVirStorageVol* volume, GError** error);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static Block65Data* block65_data_ref (Block65Data* _data65_);
static void block65_data_unref (void * _userdata_);
static gboolean __lambda57_ (Block65Data* _data65_);
static void boxes_vm_creator_update_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_vm_creator_update_install_progress_finish (BoxesVMCreator* self, GAsyncResult* _res_);
static gboolean ___lambda57__gsource_func (gpointer self);
static void boxes_vm_creator_update_install_progress_data_free (gpointer _data);
static gboolean boxes_vm_creator_update_install_progress_co (BoxesVmCreatorUpdateInstallProgressData* _data_);
static Block66Data* block66_data_ref (Block66Data* _data66_);
static void block66_data_unref (void * _userdata_);
static void ___lambda58_ (Block66Data* _data66_, GError** error);
static void ____lambda58__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_vm_creator_update_install_progress_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
guint64 boxes_installer_media_get_installed_size (BoxesInstallerMedia* self);
static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_);
static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_vm_creator_create_target_volume_data_free (gpointer _data);
static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_);
static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GVirConfigStorageVol* boxes_vm_configurator_create_volume_config (const gchar* name, gint64 storage, GError** error);
static void boxes_vm_creator_finalize (BoxesVMCreator* obj);


BoxesVMCreator* boxes_vm_creator_construct (GType object_type, BoxesInstallerMedia* install_media) {
	BoxesVMCreator* self = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (install_media != NULL, NULL);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = install_media;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (self, _tmp0_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 1026 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new (BoxesInstallerMedia* install_media) {
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct (BOXES_TYPE_VM_CREATOR, install_media);
#line 1033 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_construct_for_install_completion (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesVMCreator* self = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = (BoxesVMCreator*) g_type_create_instance (object_type);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_continue_installation (self, _tmp0_, NULL, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self;
#line 1050 "vm-creator.c"
}


BoxesVMCreator* boxes_vm_creator_new_for_install_completion (BoxesLibvirtMachine* machine) {
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return boxes_vm_creator_construct_for_install_completion (BOXES_TYPE_VM_CREATOR, machine);
#line 1057 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_data_free (gpointer _data) {
	BoxesVmCreatorCreateVmData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateVmData, _data_);
#line 1072 "vm-creator.c"
}


static gpointer _boxes_vm_creator_ref0 (gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? boxes_vm_creator_ref (self) : NULL;
#line 1079 "vm-creator.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return self ? g_object_ref (self) : NULL;
#line 1086 "vm-creator.c"
}


void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateVmData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_vm);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_vm_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1115 "vm-creator.c"
}


BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachine* result;
	BoxesVmCreatorCreateVmData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 1126 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 1136 "vm-creator.c"
}


static Block60Data* block60_data_ref (Block60Data* _data60_) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data60_->_ref_count_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data60_;
#line 1145 "vm-creator.c"
}


static void block60_data_unref (void * _userdata_) {
	Block60Data* _data60_;
	_data60_ = (Block60Data*) _userdata_;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data60_->_ref_count_)) {
#line 1154 "vm-creator.c"
		BoxesVMCreator* self;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data60_->self;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block60Data, _data60_);
#line 1162 "vm-creator.c"
	}
}


static Block61Data* block61_data_ref (Block61Data* _data61_) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data61_->_ref_count_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data61_;
#line 1172 "vm-creator.c"
}


static void block61_data_unref (void * _userdata_) {
	Block61Data* _data61_;
	_data61_ = (Block61Data*) _userdata_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data61_->_ref_count_)) {
#line 1181 "vm-creator.c"
		BoxesVMCreator* self;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data61_->_data60_->self;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data61_->_data60_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data61_->_data60_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block61Data, _data61_);
#line 1191 "vm-creator.c"
	}
}


static void ___lambda66_ (Block61Data* _data61_) {
	Block60Data* _data60_;
	BoxesVMCreator* self;
	BoxesApp* _tmp0_ = NULL;
	gulong _tmp1_ = 0UL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data60_ = _data61_->_data60_;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data60_->self;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data60_->_async_data_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data61_->handler;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 1213 "vm-creator.c"
}


static void ____lambda66__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda66_ (self);
#line 1220 "vm-creator.c"
}


static void boxes_vm_creator_create_vm_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateVmData* _data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_vm_co (_data_);
#line 1234 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_vm_co (BoxesVmCreatorCreateVmData* _data_) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 1243 "vm-creator.c"
		goto _state_0;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 1247 "vm-creator.c"
		goto _state_1;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 1251 "vm-creator.c"
		goto _state_2;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 1255 "vm-creator.c"
		goto _state_3;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 1259 "vm-creator.c"
		goto _state_4;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 1263 "vm-creator.c"
		goto _state_5;
		default:
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 1268 "vm-creator.c"
	}
	_state_0:
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data60_ = g_slice_new0 (Block60Data);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data60_->_ref_count_ = 1;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data60_->self = boxes_vm_creator_ref (_data_->self);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data60_->_async_data_ = _data_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = FALSE;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->_tmp2_ == NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp3_) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data61_ = g_slice_new0 (Block61Data);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data61_->_ref_count_ = 1;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data61_->_data60_ = block60_data_ref (_data_->_data60_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data61_->handler = (gulong) 0;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = boxes_app_app;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = 0UL;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = g_signal_connect_data ((GObject*) _data_->_tmp4_, "notify::default-connection", (GCallback) ____lambda66__g_object_notify, block61_data_ref (_data_->_data61_), (GClosureNotify) block61_data_unref, 0);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data61_->handler = _data_->_tmp5_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1321 "vm-creator.c"
		_state_1:
		;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block61_data_unref (_data_->_data61_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data61_ = NULL;
#line 1328 "vm-creator.c"
	}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 2;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media (_data_->self, boxes_vm_creator_create_vm_ready, _data_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1340 "vm-creator.c"
	_state_2:
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_finish (_data_->self, _data_->_res_, &_data_->_tmp6_, &_data_->_tmp7_, &_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp6_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp7_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data_->_data60_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data60_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1370 "vm-creator.c"
		} else {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1374 "vm-creator.c"
		}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1380 "vm-creator.c"
	}
	{
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = _data_->self->priv->_install_media;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->name;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->cancellable;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_prepare_for_installation (_data_->_tmp8_, _data_->_tmp9_, _data_->_tmp10_, boxes_vm_creator_create_vm_ready, _data_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1401 "vm-creator.c"
		_state_3:
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_prepare_for_installation_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1407 "vm-creator.c"
			goto __catch96_g_error;
		}
	}
	goto __finally96;
	__catch96_g_error:
	{
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _ ("An error occurred during installation preparation. Express Install dis" \
"abled.");
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->msg = _data_->_tmp12_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = boxes_app_window;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = _data_->_tmp13_->notificationbar;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = _data_->msg;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = boxes_notificationbar_display_error (_data_->_tmp14_, _data_->_tmp15_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->_tmp16_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp17_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = _data_->_error_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = _data_->_tmp18_->message;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:50: Disabling unattended installation: %s", _data_->_tmp19_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->msg);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 1464 "vm-creator.c"
	}
	__finally96:
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data_->_data60_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data60_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1485 "vm-creator.c"
		} else {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1489 "vm-creator.c"
		}
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1495 "vm-creator.c"
	}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = _data_->name;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp21_ = _data_->self->priv->_install_media;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp22_ = _data_->_tmp21_->resources;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = 0LL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp23_ = osinfo_resources_get_storage (_data_->_tmp22_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = 0LL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp24_ = _data_->_tmp23_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 4;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume (_data_->self, _data_->_tmp20_, _data_->_tmp24_, boxes_vm_creator_create_vm_ready, _data_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1523 "vm-creator.c"
	_state_4:
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp25_ = boxes_vm_creator_create_target_volume_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp25_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data_->_data60_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data60_ = NULL;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1549 "vm-creator.c"
		} else {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1553 "vm-creator.c"
		}
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1559 "vm-creator.c"
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp26_ = _data_->name;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp27_ = _data_->title;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->volume;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->cancellable;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 5;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_config (_data_->self, _data_->_tmp26_, _data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_, boxes_vm_creator_create_vm_ready, _data_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1583 "vm-creator.c"
	_state_5:
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = boxes_vm_creator_create_domain_config_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp30_;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data_->_data60_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data60_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1611 "vm-creator.c"
		} else {
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1615 "vm-creator.c"
		}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1621 "vm-creator.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = boxes_vm_creator_get_connection (_data_->self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = _data_->_tmp32_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = _data_->config;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp35_ = gvir_connection_create_domain (_data_->_tmp33_, _data_->_tmp34_, &_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->_tmp35_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp33_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->domain = _data_->_tmp36_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data_->_data60_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data60_ = NULL;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1673 "vm-creator.c"
		} else {
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1677 "vm-creator.c"
		}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1683 "vm-creator.c"
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = boxes_libvirt_broker_get_default ();
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp39_ = boxes_app_app;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp40_ = boxes_app_get_default_source (_data_->_tmp39_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp41_ = _data_->_tmp40_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp42_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp42_ = boxes_app_app;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp43_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp43_ = boxes_app_get_default_connection (_data_->_tmp42_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp44_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp44_ = _data_->_tmp43_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp45_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp45_ = _data_->_tmp44_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp46_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp46_ = _data_->domain;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp47_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp47_ = boxes_libvirt_broker_add_domain (_data_->_tmp38_, _data_->_tmp41_, _data_->_tmp45_, _data_->_tmp46_, &_data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp48_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp48_ = _data_->_tmp47_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp45_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp38_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _data_->_tmp48_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->domain);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->volume);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block60_data_unref (_data_->_data60_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data60_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1763 "vm-creator.c"
		} else {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1767 "vm-creator.c"
		}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 1773 "vm-creator.c"
	}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp49_ = NULL;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp49_ = _data_->machine;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp49_, _data_->self);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->machine;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block60_data_unref (_data_->_data60_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data60_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1801 "vm-creator.c"
	} else {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1805 "vm-creator.c"
	}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->domain);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block60_data_unref (_data_->_data60_);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data60_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1831 "vm-creator.c"
	} else {
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1835 "vm-creator.c"
	}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 1841 "vm-creator.c"
}


static Block62Data* block62_data_ref (Block62Data* _data62_) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data62_->_ref_count_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data62_;
#line 1850 "vm-creator.c"
}


static void block62_data_unref (void * _userdata_) {
	Block62Data* _data62_;
	_data62_ = (Block62Data*) _userdata_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data62_->_ref_count_)) {
#line 1859 "vm-creator.c"
		BoxesVMCreator* self;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data62_->self;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data62_->machine);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block62Data, _data62_);
#line 1869 "vm-creator.c"
	}
}


static Block63Data* block63_data_ref (Block63Data* _data63_) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data63_->_ref_count_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data63_;
#line 1879 "vm-creator.c"
}


static void block63_data_unref (void * _userdata_) {
	Block63Data* _data63_;
	_data63_ = (Block63Data*) _userdata_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data63_->_ref_count_)) {
#line 1888 "vm-creator.c"
		BoxesVMCreator* self;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data63_->_data62_->self;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block62_data_unref (_data63_->_data62_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_->_data62_ = NULL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block63Data, _data63_);
#line 1898 "vm-creator.c"
	}
}


static void ___lambda67_ (Block63Data* _data63_) {
	Block62Data* _data62_;
	BoxesVMCreator* self;
	BoxesApp* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesApp* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesApp* _tmp5_ = NULL;
	gulong _tmp6_ = 0UL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data62_ = _data63_->_data62_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data62_->self;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_ != BOXES_UI_STATE_COLLECTION) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 1927 "vm-creator.c"
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_app_app;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data62_->machine;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_app_select_item (_tmp3_, (BoxesCollectionItem*) _tmp4_);
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = boxes_app_app;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _data63_->signal_id;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_signal_handler_disconnect ((GObject*) _tmp5_, _tmp6_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return;
#line 1943 "vm-creator.c"
}


static void ____lambda67__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda67_ (self);
#line 1950 "vm-creator.c"
}


static void _boxes_vm_creator_on_machine_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed ((BoxesVMCreator*) self, _sender, pspec);
#line 1957 "vm-creator.c"
}


static void boxes_vm_creator_real_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error) {
	Block62Data* _data62_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesInstallerMedia* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	BoxesLibvirtMachine* _tmp15_ = NULL;
	BoxesBoxConfig* _tmp16_ = NULL;
	gint64 _tmp17_ = 0LL;
	BoxesLibvirtMachine* _tmp18_ = NULL;
	GError * _inner_error_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data62_ = g_slice_new0 (Block62Data);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data62_->_ref_count_ = 1;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data62_->self = boxes_vm_creator_ref (self);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data62_->machine);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data62_->machine = _tmp1_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = TRUE;
#line 1996 "vm-creator.c"
	} else {
		BoxesInstallerMedia* _tmp4_ = NULL;
		BoxesUnattendedSetupBox* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = self->priv->_install_media;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp4_) : NULL)->setup_box;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = boxes_unattended_setup_box_get_express_install (_tmp5_);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = _tmp6_;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = !_tmp7_;
#line 2012 "vm-creator.c"
	}
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp2_) {
#line 2016 "vm-creator.c"
		Block63Data* _data63_;
		BoxesApp* _tmp8_ = NULL;
		gulong _tmp9_ = 0UL;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_ = g_slice_new0 (Block63Data);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_->_ref_count_ = 1;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_->_data62_ = block62_data_ref (_data62_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_->signal_id = (gulong) 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = boxes_app_app;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_signal_connect_data ((GObject*) _tmp8_, "notify::ui-state", (GCallback) ____lambda67__g_object_notify, block63_data_ref (_data63_), (GClosureNotify) block63_data_unref, 0);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_->signal_id = _tmp9_;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block63_data_unref (_data63_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data63_ = NULL;
#line 2038 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp10_ = NULL;
		GVirDomain* _tmp11_ = NULL;
		GVirDomain* _tmp12_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data62_->machine;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain (_tmp10_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _tmp11_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_start (_tmp12_, (guint) 0, &_inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_propagate_error (error, _inner_error_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block62_data_unref (_data62_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data62_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2061 "vm-creator.c"
		}
	}
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp13_ = _data62_->machine;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp14_ = g_signal_connect ((GObject*) _tmp13_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->state_changed_id = _tmp14_;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = _data62_->machine;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = ((BoxesMachine*) _tmp15_)->config;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp17_ = g_get_real_time ();
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_box_config_set_access_last_time (_tmp16_, _tmp17_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp18_ = _data62_->machine;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_machine_info (self, _tmp18_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block62_data_unref (_data62_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data62_ = NULL;
#line 2086 "vm-creator.c"
}


void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->launch_vm (self, machine, error);
#line 2095 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation_data_free (gpointer _data) {
	BoxesVmCreatorContinueInstallationData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorContinueInstallationData, _data_);
#line 2108 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorContinueInstallationData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_real_continue_installation);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_real_continue_installation_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_continue_installation_co (_data_);
#line 2137 "vm-creator.c"
}


static void boxes_vm_creator_real_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2145 "vm-creator.c"
}


static void boxes_vm_creator_continue_installation_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorContinueInstallationData* _data_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_continue_installation_co (_data_);
#line 2159 "vm-creator.c"
}


static gboolean boxes_vm_creator_real_continue_installation_co (BoxesVmCreatorContinueInstallationData* _data_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 2168 "vm-creator.c"
		goto _state_0;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 2172 "vm-creator.c"
		goto _state_1;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 2176 "vm-creator.c"
		goto _state_2;
		default:
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 2181 "vm-creator.c"
	}
	_state_0:
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_media_manager_get_instance ();
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->machine;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp2_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_media_manager_create_installer_media_from_config (_data_->_tmp1_, _data_->_tmp4_, boxes_vm_creator_continue_installation_ready, _data_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2210 "vm-creator.c"
	_state_1:
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = boxes_media_manager_create_installer_media_from_config_finish (_data_->_tmp1_, _data_->_res_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_install_media (_data_->self, _data_->_tmp6_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp1_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->machine;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp7_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->_tmp8_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = 0U;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = boxes_vm_configurator_get_num_reboots (_data_->_tmp9_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (_data_->self, _data_->_tmp10_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = _data_->machine;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = boxes_libvirt_machine_get_domain (_data_->_tmp11_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = gvir_domain_get_name (_data_->_tmp13_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = g_strdup (_data_->_tmp14_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp15_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp16_ = _data_->self->priv->_install_media;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp16_ == NULL) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:94: Could not find needed install media to continue in" \
"stallation, give up on automatic installation");
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->machine;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (_data_->self, _data_->_tmp17_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2286 "vm-creator.c"
		} else {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2290 "vm-creator.c"
		}
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2296 "vm-creator.c"
	}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp18_ = _data_->self->priv->_install_media;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp19_ = _data_->_tmp18_->device_file;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = FALSE;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp20_ = g_file_test (_data_->_tmp19_, G_FILE_TEST_EXISTS);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_data_->_tmp20_) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->self->priv->_install_media;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = _data_->_tmp21_->device_file;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = _data_->machine;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp23_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:100: Source installer media '%s' no longer exists. Del" \
"eting machine '%s'..", _data_->_tmp22_, _data_->_tmp25_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp26_ = boxes_app_app;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp27_ = _data_->machine;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_app_delete_machine (_data_->_tmp26_, (BoxesMachine*) _data_->_tmp27_, TRUE);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2350 "vm-creator.c"
		} else {
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2354 "vm-creator.c"
		}
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 2360 "vm-creator.c"
	}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp28_ = _data_->self->priv->_install_media;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp29_ = _data_->name;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_installer_media_prepare_to_continue_installation (_data_->_tmp28_, _data_->_tmp29_);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp30_ = _data_->machine;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = 0UL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp31_ = g_signal_connect ((GObject*) _data_->_tmp30_, "notify::state", (GCallback) _boxes_vm_creator_on_machine_state_changed_g_object_notify, _data_->self);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->state_changed_id = _data_->_tmp31_;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp32_ = _data_->machine;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_libvirt_machine_set_vm_creator (_data_->_tmp32_, _data_->self);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp33_ = _data_->machine;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_machine_info (_data_->self, _data_->_tmp33_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp34_ = _data_->machine;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_on_machine_state_changed (_data_->self, (GObject*) _data_->_tmp34_, NULL);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp36_ = _data_->machine;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = 0;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp37_ = boxes_machine_get_state ((BoxesMachine*) _data_->_tmp36_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = 0;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp38_ = _data_->_tmp37_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp38_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp39_ = _data_->machine;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp40_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp39_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp42_ = FALSE;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp42_ = boxes_vm_configurator_is_install_config (_data_->_tmp41_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp35_ = _data_->_tmp42_;
#line 2432 "vm-creator.c"
	} else {
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp35_ = FALSE;
#line 2436 "vm-creator.c"
	}
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp35_) {
#line 2440 "vm-creator.c"
		{
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp43_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp43_ = _data_->machine;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp44_ = boxes_libvirt_machine_get_domain (_data_->_tmp43_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp45_ = _data_->_tmp44_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 2;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_async (_data_->_tmp45_, (guint) 0, NULL, boxes_vm_creator_continue_installation_ready, _data_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2460 "vm-creator.c"
			_state_2:
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start_finish (_data_->_tmp45_, _data_->_res_, &_data_->_inner_error_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2466 "vm-creator.c"
				goto __catch97_g_error;
			}
		}
		goto __finally97;
		__catch97_g_error:
		{
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->e = _data_->_inner_error_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_inner_error_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp46_ = _data_->machine;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp47_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp46_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp48_ = _data_->_tmp47_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp49_ = _data_->e;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp50_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp50_ = _data_->_tmp49_->message;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:119: Failed to start '%s': %s", _data_->_tmp48_, _data_->_tmp50_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_data_->e);
#line 2501 "vm-creator.c"
		}
		__finally97:
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->name);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_data_->_inner_error_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 2514 "vm-creator.c"
		}
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2523 "vm-creator.c"
	} else {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2527 "vm-creator.c"
	}
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 2533 "vm-creator.c"
}


void boxes_vm_creator_continue_installation (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->continue_installation (self, machine, _callback_, _user_data_);
#line 2540 "vm-creator.c"
}


void boxes_vm_creator_continue_installation_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->continue_installation_finish (self, _res_);
#line 2547 "vm-creator.c"
}


static Block64Data* block64_data_ref (Block64Data* _data64_) {
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data64_->_ref_count_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data64_;
#line 2556 "vm-creator.c"
}


static void block64_data_unref (void * _userdata_) {
	Block64Data* _data64_;
	_data64_ = (Block64Data*) _userdata_;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data64_->_ref_count_)) {
#line 2565 "vm-creator.c"
		BoxesVMCreator* self;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data64_->self;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data64_->machine);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block64Data, _data64_);
#line 2575 "vm-creator.c"
	}
}


static void ____lambda54_ (Block64Data* _data64_) {
	BoxesVMCreator* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data64_->self;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:169: Live box deletion cancelled. Invoking post instal" \
"lation setup...");
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _data64_->machine;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_post_install_config (self, _tmp0_);
#line 2591 "vm-creator.c"
}


static void _____lambda54__boxes_app_undo_notify_callback (gpointer self) {
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	____lambda54_ (self);
#line 2598 "vm-creator.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 2605 "vm-creator.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_list_free (self);
#line 2614 "vm-creator.c"
}


static void boxes_vm_creator_on_machine_state_changed (BoxesVMCreator* self, GObject* object, GParamSpec* pspec) {
	Block64Data* _data64_;
	GObject* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	GVirDomain* domain = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	GVirDomain* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	BoxesLibvirtMachine* _tmp8_ = NULL;
	gboolean _tmp9_ = FALSE;
	BoxesLibvirtMachine* _tmp15_ = NULL;
	BoxesMachineMachineState _tmp16_ = 0;
	BoxesMachineMachineState _tmp17_ = 0;
	BoxesLibvirtMachine* _tmp21_ = NULL;
	BoxesLibvirtMachine* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	GError * _inner_error_ = NULL;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (object != NULL);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data64_ = g_slice_new0 (Block64Data);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data64_->_ref_count_ = 1;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data64_->self = boxes_vm_creator_ref (self);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = object;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data64_->machine = _tmp1_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _data64_->machine;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_machine_is_on ((BoxesMachine*) _tmp2_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp3_) {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block64_data_unref (_data64_);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data64_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2666 "vm-creator.c"
	}
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _data64_->machine;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = boxes_libvirt_machine_get_domain (_tmp4_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _tmp5_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	domain = _tmp7_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = _data64_->machine;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp9_ = ((BoxesMachine*) _tmp8_)->deleted;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp9_) {
#line 2684 "vm-creator.c"
		BoxesLibvirtMachine* _tmp10_ = NULL;
		gulong _tmp11_ = 0UL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _data64_->machine;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = self->priv->state_changed_id;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = _data64_->machine;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:133: '%s' was deleted, no need for post-installation s" \
"etup on it", _tmp14_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block64_data_unref (_data64_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data64_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2712 "vm-creator.c"
	}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp15_ = _data64_->machine;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp16_ = boxes_machine_get_state ((BoxesMachine*) _tmp15_);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp17_ = _tmp16_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp17_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 2722 "vm-creator.c"
		BoxesLibvirtMachine* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp18_ = _data64_->machine;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp18_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp20_ = _tmp19_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:140: '%s' has saved state, no need for post-installati" \
"on setup on it", _tmp20_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (domain);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block64_data_unref (_data64_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data64_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 2742 "vm-creator.c"
	}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp21_ = _data64_->machine;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_increment_num_reboots (self, _tmp21_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp22_ = _data64_->machine;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp23_ = boxes_vm_creator_guest_installed_os (self, _tmp22_);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp23_) {
#line 2754 "vm-creator.c"
		BoxesLibvirtMachine* _tmp24_ = NULL;
		BoxesInstallerMedia* _tmp25_ = NULL;
		BoxesLibvirtMachine* _tmp31_ = NULL;
		gulong _tmp32_ = 0UL;
		gboolean _tmp33_ = FALSE;
		BoxesLibvirtMachine* _tmp34_ = NULL;
		GVirConfigDomain* _tmp35_ = NULL;
		GVirConfigDomain* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
		BoxesLibvirtMachine* _tmp40_ = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp24_ = _data64_->machine;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_set_post_install_config (self, _tmp24_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp25_ = self->priv->_install_media;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp25_);
#line 2773 "vm-creator.c"
		{
			GVirDomain* _tmp26_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp26_ = domain;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_domain_start (_tmp26_, (guint) 0, &_inner_error_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2782 "vm-creator.c"
				goto __catch98_g_error;
			}
		}
		goto __finally98;
		__catch98_g_error:
		{
			GError* _error_ = NULL;
			GVirDomain* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			GError* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_error_ = _inner_error_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_inner_error_ = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp27_ = domain;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp28_ = gvir_domain_get_name (_tmp27_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp29_ = _error_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp30_ = _tmp29_->message;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_warning ("vm-creator.vala:153: Failed to start domain '%s': %s", _tmp28_, _tmp30_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_error_free0 (_error_);
#line 2810 "vm-creator.c"
		}
		__finally98:
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (domain);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			block64_data_unref (_data64_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data64_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_clear_error (&_inner_error_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return;
#line 2827 "vm-creator.c"
		}
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp31_ = _data64_->machine;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp32_ = self->priv->state_changed_id;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_signal_handler_disconnect ((GObject*) _tmp31_, _tmp32_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp34_ = _data64_->machine;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp35_ = boxes_libvirt_machine_get_domain_config (_tmp34_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp36_ = _tmp35_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp37_ = boxes_vm_configurator_is_live_config (_tmp36_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp37_) {
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp33_ = TRUE;
#line 2847 "vm-creator.c"
		} else {
			gboolean _tmp38_ = FALSE;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp38_ = boxes_vm_creator_install_trackable (self);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp33_ = !_tmp38_;
#line 2854 "vm-creator.c"
		}
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp33_) {
#line 2858 "vm-creator.c"
			BoxesLibvirtMachine* _tmp39_ = NULL;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp39_ = _data64_->machine;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_machine_set_info ((BoxesMachine*) _tmp39_, NULL);
#line 2864 "vm-creator.c"
		}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp40_ = _data64_->machine;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_libvirt_machine_set_vm_creator (_tmp40_, NULL);
#line 2870 "vm-creator.c"
	} else {
		gboolean _tmp41_ = FALSE;
		BoxesLibvirtMachine* _tmp42_ = NULL;
		GVirConfigDomain* _tmp43_ = NULL;
		GVirConfigDomain* _tmp44_ = NULL;
		gboolean _tmp45_ = FALSE;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp42_ = _data64_->machine;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp43_ = boxes_libvirt_machine_get_domain_config (_tmp42_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp44_ = _tmp43_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp45_ = boxes_vm_configurator_is_live_config (_tmp44_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp45_) {
#line 2887 "vm-creator.c"
			BoxesLibvirtMachine* _tmp46_ = NULL;
			BoxesMachineMachineState _tmp47_ = 0;
			BoxesMachineMachineState _tmp48_ = 0;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp46_ = _data64_->machine;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp47_ = boxes_machine_get_state ((BoxesMachine*) _tmp46_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp48_ = _tmp47_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp41_ = _tmp48_ != BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED;
#line 2899 "vm-creator.c"
		} else {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp41_ = FALSE;
#line 2903 "vm-creator.c"
		}
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp41_) {
#line 2907 "vm-creator.c"
			BoxesLibvirtMachine* _tmp49_ = NULL;
			gulong _tmp50_ = 0UL;
			BoxesInstallerMedia* _tmp51_ = NULL;
			GList* items = NULL;
			BoxesLibvirtMachine* _tmp52_ = NULL;
			BoxesCollectionItem* _tmp53_ = NULL;
			BoxesAppUndoNotifyCallback undo_notify_callback = NULL;
			void* undo_notify_callback_target = NULL;
			GDestroyNotify undo_notify_callback_target_destroy_notify = NULL;
			gchar* msg = NULL;
			const gchar* _tmp54_ = NULL;
			BoxesLibvirtMachine* _tmp55_ = NULL;
			const gchar* _tmp56_ = NULL;
			const gchar* _tmp57_ = NULL;
			gchar* _tmp58_ = NULL;
			BoxesApp* _tmp59_ = NULL;
			GList* _tmp60_ = NULL;
			const gchar* _tmp61_ = NULL;
			BoxesAppUndoNotifyCallback _tmp62_ = NULL;
			void* _tmp62__target = NULL;
			GDestroyNotify _tmp62__target_destroy_notify = NULL;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp49_ = _data64_->machine;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp50_ = self->priv->state_changed_id;
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_signal_handler_disconnect ((GObject*) _tmp49_, _tmp50_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp51_ = self->priv->_install_media;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_installer_media_clean_up (_tmp51_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp52_ = _data64_->machine;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp53_ = _g_object_ref0 ((BoxesCollectionItem*) _tmp52_);
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = g_list_append (items, _tmp53_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback = _____lambda54__boxes_app_undo_notify_callback;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target = block64_data_ref (_data64_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = block64_data_unref;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp54_ = _ ("Live box '%s' has been deleted automatically.");
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp55_ = _data64_->machine;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp56_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp55_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp57_ = _tmp56_;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp58_ = g_strdup_printf (_tmp54_, _tmp57_);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			msg = _tmp58_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp59_ = boxes_app_app;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp60_ = items;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			items = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp61_ = msg;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62_ = undo_notify_callback;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62__target = undo_notify_callback_target;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp62__target_destroy_notify = undo_notify_callback_target_destroy_notify;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			boxes_app_delete_machines_undoable (_tmp59_, _tmp60_, _tmp61_, _tmp62_, _tmp62__target, _tmp62__target_destroy_notify);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (msg);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			(undo_notify_callback_target_destroy_notify == NULL) ? NULL : (undo_notify_callback_target_destroy_notify (undo_notify_callback_target), NULL);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			undo_notify_callback_target_destroy_notify = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			__g_list_free__g_object_unref0_0 (items);
#line 2995 "vm-creator.c"
		} else {
			{
				GVirDomain* _tmp63_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp63_ = domain;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				gvir_domain_start (_tmp63_, (guint) 0, &_inner_error_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3005 "vm-creator.c"
					goto __catch99_g_error;
				}
			}
			goto __finally99;
			__catch99_g_error:
			{
				GError* _error_ = NULL;
				GVirDomain* _tmp64_ = NULL;
				const gchar* _tmp65_ = NULL;
				GError* _tmp66_ = NULL;
				const gchar* _tmp67_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_error_ = _inner_error_;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_inner_error_ = NULL;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp64_ = domain;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp65_ = gvir_domain_get_name (_tmp64_);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp66_ = _error_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp67_ = _tmp66_->message;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_warning ("vm-creator.vala:179: Failed to start domain '%s': %s", _tmp65_, _tmp67_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_error_free0 (_error_);
#line 3033 "vm-creator.c"
			}
			__finally99:
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (domain);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				block64_data_unref (_data64_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data64_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_clear_error (&_inner_error_);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return;
#line 3050 "vm-creator.c"
			}
		}
	}
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (domain);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block64_data_unref (_data64_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data64_ = NULL;
#line 3060 "vm-creator.c"
}


static void boxes_vm_creator_real_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain_config (_tmp0_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = boxes_vm_configurator_is_install_config (_tmp2_);
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp3_) {
#line 3081 "vm-creator.c"
		BoxesLibvirtMachine* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		BoxesLibvirtMachine* _tmp6_ = NULL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = machine;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _ ("Installing...");
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp4_, _tmp5_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = machine;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_track_install_progress (self, _tmp6_);
#line 3095 "vm-creator.c"
	} else {
		BoxesLibvirtMachine* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = machine;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _ ("Live");
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp7_, _tmp8_);
#line 3105 "vm-creator.c"
	}
}


void boxes_vm_creator_update_machine_info (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->update_machine_info (self, machine);
#line 3115 "vm-creator.c"
}


void boxes_vm_creator_set_post_install_config (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:194: Setting post-installation configuration on '%s'", _tmp2_);
#line 3136 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp3_ = NULL;
		GVirDomain* _tmp4_ = NULL;
		GVirDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		GVirConfigDomain* _tmp7_ = NULL;
		BoxesInstallerMedia* _tmp8_ = NULL;
		BoxesLibvirtMachine* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirDomain* _tmp11_ = NULL;
		GVirConfigDomain* _tmp12_ = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = machine;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_libvirt_machine_get_domain (_tmp3_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = _tmp4_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = gvir_domain_get_config (_tmp5_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp6_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3161 "vm-creator.c"
			goto __catch100_g_error;
		}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = config;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = self->priv->_install_media;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_post_install_setup (_tmp7_, _tmp8_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = machine;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = boxes_libvirt_machine_get_domain (_tmp9_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = config;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp11_, _tmp12_, &_inner_error_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 3184 "vm-creator.c"
			goto __catch100_g_error;
		}
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 3189 "vm-creator.c"
	}
	goto __finally100;
	__catch100_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		GError* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = machine;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp13_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _tmp14_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _error_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp17_ = _tmp16_->message;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:200: Failed to set post-install configuration on '%s':" \
" %s", _tmp15_, _tmp17_);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 3218 "vm-creator.c"
	}
	__finally100:
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 3229 "vm-creator.c"
	}
}


static void boxes_vm_creator_get_storage_pool_data_free (gpointer _data) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorGetStoragePoolData, _data_);
#line 3243 "vm-creator.c"
}


void boxes_vm_creator_get_storage_pool (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorGetStoragePoolData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_get_storage_pool);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_get_storage_pool_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 3262 "vm-creator.c"
}


GVirStoragePool* boxes_vm_creator_get_storage_pool_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStoragePool* result;
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 3273 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3283 "vm-creator.c"
}


static void boxes_vm_creator_get_storage_pool_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorGetStoragePoolData* _data_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool_co (_data_);
#line 3297 "vm-creator.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 3304 "vm-creator.c"
}


static gboolean boxes_vm_creator_get_storage_pool_co (BoxesVmCreatorGetStoragePoolData* _data_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3313 "vm-creator.c"
		goto _state_0;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3317 "vm-creator.c"
		goto _state_1;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 2:
#line 3321 "vm-creator.c"
		goto _state_2;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 3:
#line 3325 "vm-creator.c"
		goto _state_3;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 4:
#line 3329 "vm-creator.c"
		goto _state_4;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 5:
#line 3333 "vm-creator.c"
		goto _state_5;
		default:
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3338 "vm-creator.c"
	}
	_state_0:
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_get_storage_pool (_data_->_tmp2_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp4_;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->pool;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_tmp5_ == NULL) {
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:207: Creating storage pool..");
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = boxes_vm_configurator_get_pool_config (&_data_->_inner_error_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->config = _data_->_tmp6_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3391 "vm-creator.c"
			} else {
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3395 "vm-creator.c"
			}
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3401 "vm-creator.c"
		}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp8_ = boxes_vm_creator_get_connection (_data_->self);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp9_ = _data_->_tmp8_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp11_ = _data_->config;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp12_ = gvir_connection_create_storage_pool (_data_->_tmp10_, _data_->_tmp11_, (guint) 0, &_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp10_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = _data_->_tmp13_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3445 "vm-creator.c"
			} else {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3449 "vm-creator.c"
			}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3455 "vm-creator.c"
		}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp14_ = _data_->_tmp7_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp7_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->pool = _data_->_tmp14_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp15_ = _data_->pool;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_async (_data_->_tmp15_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3477 "vm-creator.c"
		_state_1:
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_build_finish (_data_->_tmp15_, _data_->_res_, &_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3497 "vm-creator.c"
			} else {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3501 "vm-creator.c"
			}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3507 "vm-creator.c"
		}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp16_ = _data_->pool;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 2;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_async (_data_->_tmp16_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3519 "vm-creator.c"
		_state_2:
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_start_finish (_data_->_tmp16_, _data_->_res_, &_data_->_inner_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3539 "vm-creator.c"
			} else {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3543 "vm-creator.c"
			}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3549 "vm-creator.c"
		}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp17_ = _data_->pool;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 3;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_async (_data_->_tmp17_, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3561 "vm-creator.c"
		_state_3:
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_storage_pool_refresh_finish (_data_->_tmp17_, _data_->_res_, &_data_->_inner_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->_tmp7_);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->config);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3581 "vm-creator.c"
			} else {
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3585 "vm-creator.c"
			}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3591 "vm-creator.c"
		}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_debug ("vm-creator.vala:213: Created storage pool.");
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->_tmp7_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 3599 "vm-creator.c"
	} else {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp19_ = _data_->pool;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp20_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp20_ = gvir_storage_pool_get_info (_data_->_tmp19_, &_data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = _data_->_tmp20_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_error_free (_data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (_data_->pool);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_data_->_state_ == 0) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3623 "vm-creator.c"
			} else {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3627 "vm-creator.c"
			}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_object_unref (_data_->_async_result);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3633 "vm-creator.c"
		}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp21_ = _data_->_tmp18_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp18_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp22_ = _data_->_tmp21_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = 0;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp23_ = _data_->_tmp22_->state;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = FALSE;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp24_ = _data_->_tmp23_ == GVIR_STORAGE_POOL_STATE_INACTIVE;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		__vala_GVirStoragePoolInfo_free0 (_data_->_tmp22_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_tmp24_) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp25_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp25_ = boxes_get_user_pkgdata (NULL);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp26_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp26_ = _data_->_tmp25_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp27_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp27_ = g_build_filename (_data_->_tmp26_, "images", NULL, NULL);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp28_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp28_ = _data_->_tmp27_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_mkdir_with_parents (_data_->_tmp28_, 0775);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->_tmp28_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_data_->_tmp26_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp29_ = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp29_ = _data_->pool;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 4;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_start_async (_data_->_tmp29_, (guint) 0, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3689 "vm-creator.c"
			_state_4:
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_start_finish (_data_->_tmp29_, _data_->_res_, &_data_->_inner_error_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_error_free (_data_->_inner_error_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStoragePoolInfo_free0 (_data_->_tmp18_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->pool);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_state_ == 0) {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3707 "vm-creator.c"
				} else {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 3711 "vm-creator.c"
				}
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_unref (_data_->_async_result);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return FALSE;
#line 3717 "vm-creator.c"
			}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp30_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp30_ = _data_->pool;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_state_ = 5;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_refresh_async (_data_->_tmp30_, NULL, boxes_vm_creator_get_storage_pool_ready, _data_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return FALSE;
#line 3729 "vm-creator.c"
			_state_5:
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			gvir_storage_pool_refresh_finish (_data_->_tmp30_, _data_->_res_, &_data_->_inner_error_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_error_free (_data_->_inner_error_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStoragePoolInfo_free0 (_data_->_tmp18_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->pool);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_state_ == 0) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3747 "vm-creator.c"
				} else {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 3751 "vm-creator.c"
				}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_unref (_data_->_async_result);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return FALSE;
#line 3757 "vm-creator.c"
			}
		}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		__vala_GVirStoragePoolInfo_free0 (_data_->_tmp18_);
#line 3762 "vm-creator.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->pool;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3770 "vm-creator.c"
	} else {
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3774 "vm-creator.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3786 "vm-creator.c"
	} else {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3790 "vm-creator.c"
	}
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3796 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_config_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainConfigData, _data_);
#line 3817 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GVirStorageVol* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
	GCancellable* _tmp8_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainConfigData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_real_create_domain_config);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_real_create_domain_config_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = title;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _tmp4_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = volume;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _tmp6_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = cancellable;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->cancellable);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->cancellable = _tmp8_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_create_domain_config_co (_data_);
#line 3876 "vm-creator.c"
}


static GVirConfigDomain* boxes_vm_creator_real_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirConfigDomain* result;
	BoxesVmCreatorCreateDomainConfigData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 3887 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 3897 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainConfigData* _data_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_real_create_domain_config_co (_data_);
#line 3911 "vm-creator.c"
}


static gboolean boxes_vm_creator_real_create_domain_config_co (BoxesVmCreatorCreateDomainConfigData* _data_) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 3920 "vm-creator.c"
		goto _state_0;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 3924 "vm-creator.c"
		goto _state_1;
		default:
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 3929 "vm-creator.c"
	}
	_state_0:
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_connection (_data_->self);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = _data_->cancellable;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_connection_get_capabilities_async (_data_->_tmp2_, _data_->_tmp3_, boxes_vm_creator_create_domain_config_ready, _data_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 3954 "vm-creator.c"
	_state_1:
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = gvir_connection_get_capabilities_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_tmp2_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->caps = _data_->_tmp5_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3978 "vm-creator.c"
		} else {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3982 "vm-creator.c"
		}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 3988 "vm-creator.c"
	}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->volume;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = gvir_storage_vol_get_path (_data_->_tmp7_, &_data_->_inner_error_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->_tmp8_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4012 "vm-creator.c"
		} else {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4016 "vm-creator.c"
		}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4022 "vm-creator.c"
	}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = _data_->self->priv->_install_media;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->caps;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp11_ = boxes_vm_configurator_create_domain_config (_data_->_tmp9_, _data_->_tmp6_, _data_->_tmp10_, &_data_->_inner_error_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp11_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->caps);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4050 "vm-creator.c"
		} else {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4054 "vm-creator.c"
		}
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 4060 "vm-creator.c"
	}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp12_ = _data_->config;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp13_ = _data_->name;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_name (_data_->_tmp12_, _data_->_tmp13_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp14_ = _data_->config;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp15_ = _data_->title;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	gvir_config_domain_set_title (_data_->_tmp14_, _data_->_tmp15_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->config;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4090 "vm-creator.c"
	} else {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4094 "vm-creator.c"
	}
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->caps);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4108 "vm-creator.c"
	} else {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4112 "vm-creator.c"
	}
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4118 "vm-creator.c"
}


void boxes_vm_creator_create_domain_config (BoxesVMCreator* self, const gchar* name, const gchar* title, GVirStorageVol* volume, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_config (self, name, title, volume, cancellable, _callback_, _user_data_);
#line 4125 "vm-creator.c"
}


GVirConfigDomain* boxes_vm_creator_create_domain_config_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_config_finish (self, _res_, error);
#line 4132 "vm-creator.c"
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1230 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1231 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1231 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1231 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1232 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1232 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 4165 "vm-creator.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1233 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1233 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1233 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 4174 "vm-creator.c"
	}
#line 1235 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1235 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 4180 "vm-creator.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1236 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1236 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1236 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 4189 "vm-creator.c"
	}
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 4195 "vm-creator.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 4204 "vm-creator.c"
	} else {
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 4208 "vm-creator.c"
	}
#line 1238 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 4216 "vm-creator.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 4225 "vm-creator.c"
	} else {
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 4229 "vm-creator.c"
	}
#line 1239 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1240 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1240 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1240 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1241 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 4251 "vm-creator.c"
}


static void boxes_vm_creator_real_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title) {
	gchar* _vala_base_name = NULL;
	gchar* _vala_base_title = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	OsinfoOs* _tmp4_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _tmp0_->label;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_vala_base_title);
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_vala_base_title = _tmp2_;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = _tmp3_->os;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp4_ != NULL) {
#line 4279 "vm-creator.c"
		BoxesInstallerMedia* _tmp5_ = NULL;
		OsinfoOs* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		BoxesInstallerMedia* _tmp10_ = NULL;
		OsinfoMedia* _tmp11_ = NULL;
		const gchar* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		gint _tmp28_ = 0;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = self->priv->_install_media;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = _tmp5_->os;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp6_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = _tmp7_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = g_strdup (_tmp8_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_vala_base_name = _tmp9_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = self->priv->_install_media;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = _tmp10_->os_media;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp11_ != NULL) {
#line 4310 "vm-creator.c"
			OsinfoOsVariantList* variants = NULL;
			BoxesInstallerMedia* _tmp12_ = NULL;
			OsinfoMedia* _tmp13_ = NULL;
			OsinfoOsVariantList* _tmp14_ = NULL;
			OsinfoOsVariantList* _tmp15_ = NULL;
			gint _tmp16_ = 0;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp12_ = self->priv->_install_media;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp13_ = _tmp12_->os_media;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp14_ = osinfo_media_get_os_variants (_tmp13_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			variants = _tmp14_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp15_ = variants;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp16_ = osinfo_list_get_length ((OsinfoList*) _tmp15_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp16_ > 0) {
#line 4331 "vm-creator.c"
				const gchar* _tmp17_ = NULL;
				OsinfoOsVariantList* _tmp18_ = NULL;
				OsinfoEntity* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				gchar* _tmp24_ = NULL;
				gchar* _tmp25_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp17_ = _vala_base_name;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp18_ = variants;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp19_ = osinfo_list_get_nth ((OsinfoList*) _tmp18_, 0);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_get (_tmp19_, "id", &_tmp20_, NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp21_ = _tmp20_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp22_ = _tmp21_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp23_ = g_strconcat ("-", _tmp22_, NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp24_ = _tmp23_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp25_ = g_strconcat (_tmp17_, _tmp24_, NULL);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_vala_base_name);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_vala_base_name = _tmp25_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_tmp24_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_tmp22_);
#line 4367 "vm-creator.c"
			}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (variants);
#line 4371 "vm-creator.c"
		}
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = _vala_base_name;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = strlen (_tmp26_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp28_ = _tmp27_;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp28_ > 12) {
#line 4381 "vm-creator.c"
			const gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp29_ = _vala_base_name;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp30_ = string_slice (_tmp29_, (glong) 0, (glong) 12);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_free0 (_vala_base_name);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_vala_base_name = _tmp30_;
#line 4392 "vm-creator.c"
		}
	} else {
		gchar* _tmp31_ = NULL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp31_ = g_strdup ("boxes-unknown");
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_vala_base_name = _tmp31_;
#line 4402 "vm-creator.c"
	}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (base_name) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*base_name = _vala_base_name;
#line 4408 "vm-creator.c"
	} else {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_name);
#line 4412 "vm-creator.c"
	}
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (base_title) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*base_title = _vala_base_title;
#line 4418 "vm-creator.c"
	} else {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_vala_base_title);
#line 4422 "vm-creator.c"
	}
}


void boxes_vm_creator_create_domain_base_name_and_title (BoxesVMCreator* self, gchar** base_name, gchar** base_title) {
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_GET_CLASS (self)->create_domain_base_name_and_title (self, base_name, base_title);
#line 4432 "vm-creator.c"
}


static void boxes_vm_creator_increment_num_reboots (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	guint _tmp0_ = 0U;
	GError * _inner_error_ = NULL;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_set_num_reboots (self, _tmp0_ + 1);
#line 4447 "vm-creator.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		BoxesInstallerMedia* _tmp6_ = NULL;
		guint _tmp7_ = 0U;
		BoxesLibvirtMachine* _tmp8_ = NULL;
		GVirDomain* _tmp9_ = NULL;
		GVirDomain* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = machine;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _tmp2_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		config = _tmp4_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4473 "vm-creator.c"
			goto __catch101_g_error;
		}
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp5_ = config;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp6_ = self->priv->_install_media;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp7_ = self->priv->_num_reboots;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_configurator_set_num_reboots (_tmp5_, _tmp6_, _tmp7_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp8_ = machine;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp9_ = boxes_libvirt_machine_get_domain (_tmp8_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp10_ = _tmp9_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp11_ = config;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		gvir_domain_set_config (_tmp10_, _tmp11_, &_inner_error_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (config);
#line 4498 "vm-creator.c"
			goto __catch101_g_error;
		}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (config);
#line 4503 "vm-creator.c"
	}
	goto __finally101;
	__catch101_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GError* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp12_ = machine;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp13_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp12_);
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp14_ = _tmp13_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp15_ = _error_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp16_ = _tmp15_->message;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:265: Failed to update configuration on '%s': %s", _tmp14_, _tmp16_);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 4532 "vm-creator.c"
	}
	__finally101:
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_inner_error_);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 4543 "vm-creator.c"
	}
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 4551 "vm-creator.c"
}


static gboolean boxes_vm_creator_guest_installed_os (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	gboolean result = FALSE;
	GVirStorageVol* volume = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVol* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (machine != NULL, FALSE);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume = _tmp3_;
#line 4577 "vm-creator.c"
	{
		gboolean _tmp4_ = FALSE;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp4_ = boxes_vm_creator_install_trackable (self);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_tmp4_) {
#line 4584 "vm-creator.c"
			gint _tmp5_ = 0;
			GVirStorageVol* _tmp6_ = NULL;
			gint _tmp7_ = 0;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp6_ = volume;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp7_ = boxes_vm_creator_get_progress (self, _tmp6_, &_inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp5_ = _tmp7_;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4596 "vm-creator.c"
				goto __catch102_g_error;
			}
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			result = _tmp5_ == BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_g_object_unref0 (volume);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return result;
#line 4605 "vm-creator.c"
		} else {
			gboolean _tmp8_ = FALSE;
			BoxesInstallerMedia* _tmp9_ = NULL;
			OsinfoMedia* _tmp10_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp9_ = self->priv->_install_media;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_tmp10_ = _tmp9_->os_media;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp10_ != NULL) {
#line 4616 "vm-creator.c"
				BoxesLibvirtMachine* _tmp11_ = NULL;
				GVirConfigDomain* _tmp12_ = NULL;
				GVirConfigDomain* _tmp13_ = NULL;
				gboolean _tmp14_ = FALSE;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp11_ = machine;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp12_ = boxes_libvirt_machine_get_domain_config (_tmp11_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp13_ = _tmp12_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp14_ = boxes_vm_configurator_is_install_config (_tmp13_);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp8_ = _tmp14_;
#line 4631 "vm-creator.c"
			} else {
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp8_ = FALSE;
#line 4635 "vm-creator.c"
			}
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			if (_tmp8_) {
#line 4639 "vm-creator.c"
				guint _tmp15_ = 0U;
				BoxesInstallerMedia* _tmp16_ = NULL;
				OsinfoMedia* _tmp17_ = NULL;
				gint _tmp18_ = 0;
				gint _tmp19_ = 0;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp15_ = self->priv->_num_reboots;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp16_ = self->priv->_install_media;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp17_ = _tmp16_->os_media;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				g_object_get (_tmp17_, "installer-reboots", &_tmp18_, NULL);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp19_ = _tmp18_;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				result = _tmp15_ == ((guint) _tmp19_);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (volume);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return result;
#line 4661 "vm-creator.c"
			} else {
				GVirStorageVolInfo* info = NULL;
				GVirStorageVol* _tmp20_ = NULL;
				GVirStorageVolInfo* _tmp21_ = NULL;
				GVirStorageVolInfo* _tmp22_ = NULL;
				guint64 _tmp23_ = 0ULL;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp20_ = volume;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp21_ = gvir_storage_vol_get_info (_tmp20_, &_inner_error_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				info = _tmp21_;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4676 "vm-creator.c"
					goto __catch102_g_error;
				}
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp22_ = info;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_tmp23_ = _tmp22_->allocation;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				result = _tmp23_ >= ((guint64) OSINFO_MEBIBYTES);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				__vala_GVirStorageVolInfo_free0 (info);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (volume);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				return result;
#line 4691 "vm-creator.c"
			}
		}
	}
	goto __finally102;
	__catch102_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		GError* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_error_ = _inner_error_;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_inner_error_ = NULL;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp24_ = volume;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp25_ = gvir_storage_vol_get_name (_tmp24_);
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp26_ = _error_;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp27_ = _tmp26_->message;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:285: Failed to get information from volume '%s': %s", _tmp25_, _tmp27_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_error_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (volume);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 4725 "vm-creator.c"
	}
	__finally102:
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (volume);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_clear_error (&_inner_error_);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 4736 "vm-creator.c"
}


static Block65Data* block65_data_ref (Block65Data* _data65_) {
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data65_->_ref_count_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data65_;
#line 4745 "vm-creator.c"
}


static void block65_data_unref (void * _userdata_) {
	Block65Data* _data65_;
	_data65_ = (Block65Data*) _userdata_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data65_->_ref_count_)) {
#line 4754 "vm-creator.c"
		BoxesVMCreator* self;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data65_->self;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data65_->machine);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block65Data, _data65_);
#line 4764 "vm-creator.c"
	}
}


static gboolean __lambda57_ (Block65Data* _data65_) {
	BoxesVMCreator* self;
	gboolean result = FALSE;
	gint _tmp0_ = 0;
	gboolean _tmp2_ = FALSE;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data65_->self;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->prev_progress;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ == 100) {
#line 4780 "vm-creator.c"
		BoxesLibvirtMachine* _tmp1_ = NULL;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = _data65_->machine;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_machine_set_info ((BoxesMachine*) _tmp1_, NULL);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		result = FALSE;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return result;
#line 4790 "vm-creator.c"
	}
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = self->priv->updating_install_progress;
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp2_) {
#line 4796 "vm-creator.c"
		BoxesLibvirtMachine* _tmp3_ = NULL;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp3_ = _data65_->machine;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_update_install_progress (self, _tmp3_, NULL, NULL);
#line 4802 "vm-creator.c"
	}
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = TRUE;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4808 "vm-creator.c"
}


static gboolean ___lambda57__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda57_ (self);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 4817 "vm-creator.c"
}


static void boxes_vm_creator_track_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine) {
	Block65Data* _data65_;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesLibvirtMachine* _tmp3_ = NULL;
	GVirStorageVol* _tmp4_ = NULL;
	GVirStorageVol* _tmp5_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (machine != NULL);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data65_ = g_slice_new0 (Block65Data);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data65_->_ref_count_ = 1;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data65_->self = boxes_vm_creator_ref (self);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = machine;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data65_->machine);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data65_->machine = _tmp1_;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_vm_creator_install_trackable (self);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!_tmp2_) {
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block65_data_unref (_data65_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data65_ = NULL;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 4857 "vm-creator.c"
	}
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _data65_->machine;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_libvirt_machine_get_storage_volume (_tmp3_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 6, ___lambda57__gsource_func, block65_data_ref (_data65_), block65_data_unref);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block65_data_unref (_data65_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data65_ = NULL;
#line 4873 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_data_free (gpointer _data) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorUpdateInstallProgressData, _data_);
#line 4884 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorUpdateInstallProgressData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_update_install_progress);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_update_install_progress_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = machine;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->machine);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->machine = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_install_progress_co (_data_);
#line 4913 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_finish (BoxesVMCreator* self, GAsyncResult* _res_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4921 "vm-creator.c"
}


static Block66Data* block66_data_ref (Block66Data* _data66_) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&_data66_->_ref_count_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return _data66_;
#line 4930 "vm-creator.c"
}


static void block66_data_unref (void * _userdata_) {
	Block66Data* _data66_;
	_data66_ = (Block66Data*) _userdata_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&_data66_->_ref_count_)) {
#line 4939 "vm-creator.c"
		BoxesVMCreator* self;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		self = _data66_->self;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data66_->machine);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_boxes_vm_creator_unref0 (self);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_slice_free (Block66Data, _data66_);
#line 4949 "vm-creator.c"
	}
}


static void ___lambda58_ (Block66Data* _data66_, GError** error) {
	BoxesVMCreator* self;
	gint _tmp0_ = 0;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVol* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	GError * _inner_error_ = NULL;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = _data66_->self;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _data66_->machine;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = boxes_libvirt_machine_get_storage_volume (_tmp1_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = _tmp2_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_vm_creator_get_progress (self, _tmp3_, &_inner_error_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _tmp4_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_propagate_error (error, _inner_error_);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 4980 "vm-creator.c"
	}
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data66_->progress = _tmp0_;
#line 4984 "vm-creator.c"
}


static void ____lambda58__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	___lambda58_ (self, error);
#line 4991 "vm-creator.c"
}


static void boxes_vm_creator_update_install_progress_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorUpdateInstallProgressData* _data_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_update_install_progress_co (_data_);
#line 5005 "vm-creator.c"
}


static gboolean boxes_vm_creator_update_install_progress_co (BoxesVmCreatorUpdateInstallProgressData* _data_) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 5014 "vm-creator.c"
		goto _state_0;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 5018 "vm-creator.c"
		goto _state_1;
		default:
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 5023 "vm-creator.c"
	}
	_state_0:
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_ = g_slice_new0 (Block66Data);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_->_ref_count_ = 1;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_->self = boxes_vm_creator_ref (_data_->self);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = _data_->machine;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->_data66_->machine);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_->machine = _data_->_tmp0_;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_->_async_data_ = _data_;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->updating_install_progress = TRUE;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_->progress = 0;
#line 5046 "vm-creator.c"
	{
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_state_ = 1;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_run_in_thread (____lambda58__boxes_run_in_thread_func, block66_data_ref (_data_->_data66_), block66_data_unref, boxes_vm_creator_update_install_progress_ready, _data_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5054 "vm-creator.c"
		_state_1:
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 5060 "vm-creator.c"
			goto __catch103_g_error;
		}
	}
	goto __finally103;
	__catch103_g_error:
	{
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_inner_error_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp1_ = _data_->_data66_->machine;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp2_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp1_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp4_ = gvir_storage_vol_get_name (_data_->_tmp3_);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp5_ = _data_->_error_;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = NULL;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_tmp6_ = _data_->_tmp5_->message;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_warning ("vm-creator.vala:321: Failed to get information from volume '%s': %s", _data_->_tmp4_, _data_->_tmp6_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_error_free0 (_data_->_error_);
#line 5099 "vm-creator.c"
	}
	__finally103:
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block66_data_unref (_data_->_data66_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_ = NULL;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_clear_error (&_data_->_inner_error_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5114 "vm-creator.c"
	}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_data66_->progress < 0) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		block66_data_unref (_data_->_data66_);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->_data66_ = NULL;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5126 "vm-creator.c"
		} else {
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5130 "vm-creator.c"
		}
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5136 "vm-creator.c"
	}
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = _data_->_data66_->machine;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = ngettext ("%d%% Installed", "%d%% Installed", (gulong) _data_->_data66_->progress);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp9_ = g_strdup_printf (_data_->_tmp8_, _data_->_data66_->progress);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_machine_set_info ((BoxesMachine*) _data_->_tmp7_, _data_->_tmp10_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->_tmp10_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->prev_progress = _data_->_data66_->progress;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self->priv->updating_install_progress = FALSE;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	block66_data_unref (_data_->_data66_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_data66_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5170 "vm-creator.c"
	} else {
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5174 "vm-creator.c"
	}
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5180 "vm-creator.c"
}


static gboolean boxes_vm_creator_install_trackable (BoxesVMCreator* self) {
	gboolean result = FALSE;
	BoxesInstallerMedia* _tmp0_ = NULL;
	guint64 _tmp1_ = 0ULL;
	guint64 _tmp2_ = 0ULL;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_installer_media_get_installed_size (_tmp0_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_ > ((guint64) 0);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5201 "vm-creator.c"
}


static gint boxes_vm_creator_get_progress (BoxesVMCreator* self, GVirStorageVol* volume, GError** error) {
	gint result = 0;
	GVirStorageVolInfo* volume_info = NULL;
	GVirStorageVol* _tmp0_ = NULL;
	GVirStorageVolInfo* _tmp1_ = NULL;
	gint percent = 0;
	guint64 _tmp2_ = 0ULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	guint64 _tmp4_ = 0ULL;
	guint64 _tmp5_ = 0ULL;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	gint _tmp8_ = 0;
	GError * _inner_error_ = NULL;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (volume != NULL, 0);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = volume;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = gvir_storage_vol_get_info (_tmp0_, &_inner_error_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	volume_info = _tmp1_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_propagate_error (error, _inner_error_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return 0;
#line 5235 "vm-creator.c"
	}
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = volume_info->allocation;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = self->priv->_install_media;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp4_ = boxes_installer_media_get_installed_size (_tmp3_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp5_ = _tmp4_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	percent = (gint) ((_tmp2_ * 100) / _tmp5_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp6_ = percent;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp7_ = CLAMP (_tmp6_, 0, BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	percent = _tmp7_;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp8_ = percent;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp8_ == BOXES_VM_CREATOR_INSTALL_COMPLETE_PERCENT) {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		percent = 100;
#line 5259 "vm-creator.c"
	}
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = percent;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5267 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_data_free (gpointer _data) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData, _data_);
#line 5278 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media (BoxesVMCreator* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_domain_name_and_title_from_media);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_domain_name_and_title_from_media_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 5297 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_finish (BoxesVMCreator* self, GAsyncResult* _res_, gchar** name, gchar** title, GError** error) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return;
#line 5307 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (name) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*name = _data_->name;
#line 5315 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->name);
#line 5319 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (title) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*title = _data_->title;
#line 5327 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->title);
#line 5331 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = NULL;
#line 5335 "vm-creator.c"
}


static void boxes_vm_creator_create_domain_name_and_title_from_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_name_and_title_from_media_co (_data_);
#line 5349 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_domain_name_and_title_from_media_co (BoxesVmCreatorCreateDomainNameAndTitleFromMediaData* _data_) {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 5358 "vm-creator.c"
		goto _state_0;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 5362 "vm-creator.c"
		goto _state_1;
		default:
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 5367 "vm-creator.c"
	}
	_state_0:
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_domain_base_name_and_title (_data_->self, &_data_->_tmp0_, &_data_->_tmp1_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_name = _data_->_tmp0_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->base_title = _data_->_tmp1_;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = NULL;
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = g_strdup (_data_->base_name);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 358 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _data_->_tmp2_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = g_strdup (_data_->base_title);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->title);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->title = _data_->_tmp3_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_domain_name_and_title_from_media_ready, _data_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5406 "vm-creator.c"
	_state_1:
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp4_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_title);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_free0 (_data_->base_name);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5428 "vm-creator.c"
		} else {
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5432 "vm-creator.c"
		}
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5438 "vm-creator.c"
	}
	{
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_data_->i = 2;
#line 5443 "vm-creator.c"
		{
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			_data_->_tmp5_ = TRUE;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			while (TRUE) {
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp5_) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp6_ = 0;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp6_ = _data_->i;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->i = _data_->_tmp6_ + 1;
#line 5457 "vm-creator.c"
				}
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp5_ = FALSE;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp9_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp9_ = boxes_vm_creator_get_connection (_data_->self);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp10_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp10_ = _data_->_tmp9_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp11_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp11_ = _data_->_tmp10_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp12_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp12_ = _data_->name;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp13_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp13_ = gvir_connection_find_domain_by_name (_data_->_tmp11_, _data_->_tmp12_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp14_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp14_ = _data_->_tmp13_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp15_ = FALSE;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp15_ = _data_->_tmp14_ != NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp14_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_object_unref0 (_data_->_tmp11_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp15_) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp8_ = TRUE;
#line 5497 "vm-creator.c"
				} else {
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp16_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp16_ = boxes_vm_creator_get_connection (_data_->self);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp17_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp17_ = _data_->_tmp16_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp18_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp18_ = _data_->_tmp17_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp19_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp19_ = _data_->title;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp20_ = gvir_connection_find_domain_by_name (_data_->_tmp18_, _data_->_tmp19_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp21_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp21_ = _data_->_tmp20_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp8_ = _data_->_tmp21_ != NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp21_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp18_);
#line 5529 "vm-creator.c"
				}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (_data_->_tmp8_) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp7_ = TRUE;
#line 5535 "vm-creator.c"
				} else {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp22_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp22_ = _data_->name;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp23_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp23_ = gvir_storage_pool_get_volume (_data_->pool, _data_->_tmp22_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp24_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp24_ = _data_->_tmp23_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_data_->_tmp7_ = _data_->_tmp24_ != NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					_g_object_unref0 (_data_->_tmp24_);
#line 5553 "vm-creator.c"
				}
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				if (!_data_->_tmp7_) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
					break;
#line 5559 "vm-creator.c"
				}
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp25_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp25_ = g_strconcat (_data_->base_name, "-", NULL);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp26_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp26_ = _data_->_tmp25_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp27_ = 0;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp27_ = _data_->i;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp28_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp28_ = g_strdup_printf ("%i", _data_->_tmp27_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp29_ = _data_->_tmp28_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = NULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp30_ = g_strconcat (_data_->_tmp26_, _data_->_tmp29_, NULL);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->name);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->name = _data_->_tmp30_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp29_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp26_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp31_ = g_strconcat (_data_->base_title, " ", NULL);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp32_ = _data_->_tmp31_;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = 0;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp33_ = _data_->i;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp34_ = g_strdup_printf ("%i", _data_->_tmp33_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp35_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp35_ = _data_->_tmp34_;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp36_ = NULL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->_tmp36_ = g_strconcat (_data_->_tmp32_, _data_->_tmp35_, NULL);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->title);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_data_->title = _data_->_tmp36_;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp35_);
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
				_g_free0 (_data_->_tmp32_);
#line 5625 "vm-creator.c"
			}
		}
	}
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_title);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->base_name);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5639 "vm-creator.c"
	} else {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5643 "vm-creator.c"
	}
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5649 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_data_free (gpointer _data) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	_data_ = _data;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->result);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_boxes_vm_creator_unref0 (_data_->self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_slice_free (BoxesVmCreatorCreateTargetVolumeData, _data_);
#line 5664 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume (BoxesVMCreator* self, const gchar* name, gint64 storage, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
	BoxesVMCreator* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gint64 _tmp3_ = 0LL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_slice_new0 (BoxesVmCreatorCreateTargetVolumeData);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_vm_creator_create_target_volume);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_vm_creator_create_target_volume_data_free);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = _boxes_vm_creator_ref0 (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->self = _tmp0_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = name;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_free0 (_data_->name);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->name = _tmp2_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp3_ = storage;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->storage = _tmp3_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 5698 "vm-creator.c"
}


static GVirStorageVol* boxes_vm_creator_create_target_volume_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error) {
	GVirStorageVol* result;
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return NULL;
#line 5709 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _data_->result;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5719 "vm-creator.c"
}


static void boxes_vm_creator_create_target_volume_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesVmCreatorCreateTargetVolumeData* _data_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_ = _user_data_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_source_object_ = source_object;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_res_ = _res_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_create_target_volume_co (_data_);
#line 5733 "vm-creator.c"
}


static gboolean boxes_vm_creator_create_target_volume_co (BoxesVmCreatorCreateTargetVolumeData* _data_) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	switch (_data_->_state_) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 0:
#line 5742 "vm-creator.c"
		goto _state_0;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		case 1:
#line 5746 "vm-creator.c"
		goto _state_1;
		default:
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_assert_not_reached ();
#line 5751 "vm-creator.c"
	}
	_state_0:
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_state_ = 1;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_get_storage_pool (_data_->self, boxes_vm_creator_create_target_volume_ready, _data_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5760 "vm-creator.c"
	_state_1:
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = NULL;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp0_ = boxes_vm_creator_get_storage_pool_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->pool = _data_->_tmp0_;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5778 "vm-creator.c"
		} else {
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5782 "vm-creator.c"
		}
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5788 "vm-creator.c"
	}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp1_ = _data_->name;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = 0LL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp2_ = _data_->storage;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp3_ = boxes_vm_configurator_create_volume_config (_data_->_tmp1_, _data_->_tmp2_, &_data_->_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->config = _data_->_tmp3_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5816 "vm-creator.c"
		} else {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5820 "vm-creator.c"
		}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5826 "vm-creator.c"
	}
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = NULL;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp4_ = _data_->name;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:375: Creating volume '%s'..", _data_->_tmp4_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp5_ = _data_->pool;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp6_ = _data_->config;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp7_ = gvir_storage_pool_create_volume (_data_->_tmp5_, _data_->_tmp6_, &_data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->volume = _data_->_tmp7_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_error_free (_data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->config);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_g_object_unref0 (_data_->pool);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (_data_->_state_ == 0) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5862 "vm-creator.c"
		} else {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 5866 "vm-creator.c"
		}
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_object_unref (_data_->_async_result);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return FALSE;
#line 5872 "vm-creator.c"
	}
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->_tmp8_ = _data_->name;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_debug ("vm-creator.vala:377: Created volume '%s'.", _data_->_tmp8_);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_data_->result = _data_->volume;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5890 "vm-creator.c"
	} else {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5894 "vm-creator.c"
	}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->volume);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->config);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (_data_->pool);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_data_->_state_ == 0) {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5910 "vm-creator.c"
	} else {
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5914 "vm-creator.c"
	}
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_object_unref (_data_->_async_result);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return FALSE;
#line 5920 "vm-creator.c"
}


BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5935 "vm-creator.c"
}


void boxes_vm_creator_set_install_media (BoxesVMCreator* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_install_media = _tmp1_;
#line 5952 "vm-creator.c"
}


static GVirConnection* boxes_vm_creator_get_connection (BoxesVMCreator* self) {
	GVirConnection* result;
	BoxesApp* _tmp0_ = NULL;
	GVirConnection* _tmp1_ = NULL;
	GVirConnection* _tmp2_ = NULL;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = boxes_app_app;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp1_ = boxes_app_get_default_connection (_tmp0_);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp2_ = _tmp1_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp2_;
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5973 "vm-creator.c"
}


static guint boxes_vm_creator_get_num_reboots (BoxesVMCreator* self) {
	guint result;
	guint _tmp0_ = 0U;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_num_reboots;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	result = _tmp0_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return result;
#line 5988 "vm-creator.c"
}


static void boxes_vm_creator_set_num_reboots (BoxesVMCreator* self, guint value) {
	guint _tmp0_ = 0U;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (self != NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = value;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->_num_reboots = _tmp0_;
#line 6000 "vm-creator.c"
}


static void boxes_value_vm_creator_init (GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	value->data[0].v_pointer = NULL;
#line 6007 "vm-creator.c"
}


static void boxes_value_vm_creator_free_value (GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (value->data[0].v_pointer);
#line 6016 "vm-creator.c"
	}
}


static void boxes_value_vm_creator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (src_value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = boxes_vm_creator_ref (src_value->data[0].v_pointer);
#line 6026 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6030 "vm-creator.c"
	}
}


static gpointer boxes_value_vm_creator_peek_pointer (const GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 6038 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (collect_values[0].v_pointer) {
#line 6045 "vm-creator.c"
		BoxesVMCreator* object;
		object = collect_values[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		if (object->parent_instance.g_class == NULL) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6052 "vm-creator.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6056 "vm-creator.c"
		}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = boxes_vm_creator_ref (object);
#line 6060 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 6064 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 6068 "vm-creator.c"
}


static gchar* boxes_value_vm_creator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesVMCreator** object_p;
	object_p = collect_values[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!object_p) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6079 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (!value->data[0].v_pointer) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = NULL;
#line 6085 "vm-creator.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = value->data[0].v_pointer;
#line 6089 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		*object_p = boxes_vm_creator_ref (value->data[0].v_pointer);
#line 6093 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return NULL;
#line 6097 "vm-creator.c"
}


GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecVMCreator* spec;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return G_PARAM_SPEC (spec);
#line 6111 "vm-creator.c"
}


gpointer boxes_value_get_vm_creator (const GValue* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR), NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return value->data[0].v_pointer;
#line 6120 "vm-creator.c"
}


void boxes_value_set_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_ref (value->data[0].v_pointer);
#line 6140 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 6144 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 6150 "vm-creator.c"
	}
}


void boxes_value_take_vm_creator (GValue* value, gpointer v_object) {
	BoxesVMCreator* old;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	old = value->data[0].v_pointer;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (v_object) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_VM_CREATOR));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = v_object;
#line 6169 "vm-creator.c"
	} else {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		value->data[0].v_pointer = NULL;
#line 6173 "vm-creator.c"
	}
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (old) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_vm_creator_unref (old);
#line 6179 "vm-creator.c"
	}
}


static void boxes_vm_creator_class_init (BoxesVMCreatorClass * klass) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	boxes_vm_creator_parent_class = g_type_class_peek_parent (klass);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->finalize = boxes_vm_creator_finalize;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_type_class_add_private (klass, sizeof (BoxesVMCreatorPrivate));
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->launch_vm = boxes_vm_creator_real_launch_vm;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->continue_installation = boxes_vm_creator_real_continue_installation;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->continue_installation_finish = boxes_vm_creator_real_continue_installation_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->update_machine_info = boxes_vm_creator_real_update_machine_info;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->create_domain_config = boxes_vm_creator_real_create_domain_config;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->create_domain_config_finish = boxes_vm_creator_real_create_domain_config_finish;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	BOXES_VM_CREATOR_CLASS (klass)->create_domain_base_name_and_title = boxes_vm_creator_real_create_domain_base_name_and_title;
#line 6205 "vm-creator.c"
}


static void boxes_vm_creator_instance_init (BoxesVMCreator * self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv = BOXES_VM_CREATOR_GET_PRIVATE (self);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->priv->prev_progress = 0;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self->ref_count = 1;
#line 6216 "vm-creator.c"
}


static void boxes_vm_creator_finalize (BoxesVMCreator* obj) {
	BoxesVMCreator * self;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_VM_CREATOR, BoxesVMCreator);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_tmp0_ = self->priv->_install_media;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (_tmp0_ != NULL) {
#line 6229 "vm-creator.c"
		BoxesInstallerMedia* _tmp1_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		_tmp1_ = self->priv->_install_media;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		boxes_installer_media_clean_up (_tmp1_);
#line 6235 "vm-creator.c"
	}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 6239 "vm-creator.c"
}


GType boxes_vm_creator_get_type (void) {
	static volatile gsize boxes_vm_creator_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_vm_creator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_vm_creator_init, boxes_value_vm_creator_free_value, boxes_value_vm_creator_copy_value, boxes_value_vm_creator_peek_pointer, "p", boxes_value_vm_creator_collect_value, "p", boxes_value_vm_creator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesVMCreatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_vm_creator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesVMCreator), 0, (GInstanceInitFunc) boxes_vm_creator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_vm_creator_type_id;
		boxes_vm_creator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesVMCreator", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_vm_creator_type_id__volatile, boxes_vm_creator_type_id);
	}
	return boxes_vm_creator_type_id__volatile;
}


gpointer boxes_vm_creator_ref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	g_atomic_int_inc (&self->ref_count);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	return instance;
#line 6264 "vm-creator.c"
}


void boxes_vm_creator_unref (gpointer instance) {
	BoxesVMCreator* self;
	self = instance;
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		BOXES_VM_CREATOR_GET_CLASS (self)->finalize (self);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/vm-creator.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6277 "vm-creator.c"
	}
}



