/* wizard.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from wizard.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libcommon.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <libxml/uri.h>
#include <libgd/gd.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <pango/pango.h>


#define BOXES_TYPE_WIZARD_PAGE (boxes_wizard_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;
typedef struct _BoxesWizardPrivate BoxesWizardPrivate;

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;

#define BOXES_TYPE_WIZARD_SUMMARY (boxes_wizard_summary_get_type ())
#define BOXES_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary))
#define BOXES_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryClass))
#define BOXES_IS_WIZARD_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SUMMARY))
#define BOXES_IS_WIZARD_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SUMMARY))
#define BOXES_WIZARD_SUMMARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryClass))

typedef struct _BoxesWizardSummary BoxesWizardSummary;
typedef struct _BoxesWizardSummaryClass BoxesWizardSummaryClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block70Data Block70Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER (boxes_libvirt_system_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporter))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))

typedef struct _BoxesLibvirtSystemImporter BoxesLibvirtSystemImporter;
typedef struct _BoxesLibvirtSystemImporterClass BoxesLibvirtSystemImporterClass;
typedef struct _BoxesWizardCreateData BoxesWizardCreateData;
#define _xmlFreeURI0(var) ((var == NULL) ? NULL : (var = (xmlFreeURI (var), NULL)))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _Block71Data Block71Data;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesWizardPrepareMediaData BoxesWizardPrepareMediaData;
typedef struct _BoxesWizardReviewData BoxesWizardReviewData;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
#define _boxes_pair_unref0(var) ((var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL)))
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))
typedef struct _Block72Data Block72Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
typedef struct _BoxesWizardDoReviewCancellableData BoxesWizardDoReviewCancellableData;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;

#define BOXES_TYPE_WIZARD_TOOLBAR (boxes_wizard_toolbar_get_type ())
#define BOXES_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbar))
#define BOXES_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))
#define BOXES_IS_WIZARD_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_IS_WIZARD_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_TOOLBAR))
#define BOXES_WIZARD_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_TOOLBAR, BoxesWizardToolbarClass))

typedef struct _BoxesWizardToolbar BoxesWizardToolbar;
typedef struct _BoxesWizardToolbarClass BoxesWizardToolbarClass;
typedef struct _BoxesWizardToolbarPrivate BoxesWizardToolbarPrivate;
typedef struct _BoxesWizardSummaryPrivate BoxesWizardSummaryPrivate;
typedef struct _Block73Data Block73Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

typedef enum  {
	BOXES_WIZARD_PAGE_INTRODUCTION,
	BOXES_WIZARD_PAGE_SOURCE,
	BOXES_WIZARD_PAGE_PREPARATION,
	BOXES_WIZARD_PAGE_SETUP,
	BOXES_WIZARD_PAGE_REVIEW,
	BOXES_WIZARD_PAGE_LAST
} BoxesWizardPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesWizard {
	GtkStack parent_instance;
	BoxesWizardPrivate * priv;
};

struct _BoxesWizardClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	GtkButton* cancel_button;
	GtkButton* back_button;
	GtkButton* next_button;
	GtkButton* continue_button;
	GtkButton* create_button;
	BoxesCollectionSource* source;
	BoxesWizardSource* wizard_source;
	BoxesWizardSummary* summary;
	GtkProgressBar* prep_progress;
	GtkLabel* prep_media_label;
	GtkLabel* prep_status_label;
	GtkBox* setup_box;
	GtkLabel* review_label;
	GtkInfoBar* nokvm_infobar;
	GtkImage* installer_image;
	BoxesMediaManager* media_manager;
	BoxesVMCreator* vm_creator;
	BoxesMachine* _machine;
	BoxesWizardPage _page;
	GCancellable* review_cancellable;
	gboolean skip_review_for_live;
};

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

struct _Block70Data {
	int _ref_count_;
	BoxesWizard* self;
	gpointer _async_data_;
};

struct _BoxesWizardSource {
	GtkStack parent_instance;
	BoxesWizardSourcePrivate * priv;
	gboolean libvirt_sys_import;
	GtkEntry* url_entry;
	BoxesMediaManager* media_manager;
};

struct _BoxesWizardSourceClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardCreateData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	Block70Data* _data70_;
	BoxesVMCreator* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	GCancellable* _tmp3_;
	gulong wait;
	gulong _tmp4_;
	gulong _tmp5_;
	BoxesLibvirtMachine* _tmp6_;
	BoxesLibvirtMachine* _tmp7_;
	GtkButton* _tmp8_;
	BoxesVMCreator* _tmp9_;
	BoxesLibvirtMachine* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	GError* _error_;
	GError* _tmp12_;
	const gchar* _tmp13_;
	BoxesVMCreator* _tmp14_;
	BoxesInstallerMedia* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesWizardSource* _tmp17_;
	BoxesWizardSource* _tmp18_;
	BoxesCollectionSource* _tmp19_;
	BoxesCollectionSource* _tmp20_;
	BoxesApp* _tmp21_;
	BoxesCollectionSource* _tmp22_;
	BoxesWizardSource* _tmp23_;
	gboolean _tmp24_;
	BoxesWizardSource* _tmp25_;
	BoxesLibvirtSystemImporter* _tmp26_;
	BoxesLibvirtSystemImporter* _tmp27_;
	GError * _inner_error_;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

struct _Block71Data {
	int _ref_count_;
	BoxesWizard* self;
	BoxesActivityProgress* progress;
	gpointer _async_data_;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardPrepareMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	BoxesInstallerMedia* install_media;
	Block71Data* _data71_;
	BoxesInstallerMedia* _tmp0_;
	OsinfoOs* _tmp1_;
	GtkLabel* _tmp2_;
	BoxesInstallerMedia* _tmp3_;
	OsinfoOs* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GtkImage* _tmp7_;
	BoxesInstallerMedia* _tmp8_;
	OsinfoOs* _tmp9_;
	BoxesActivityProgress* _tmp10_;
	GtkLabel* _tmp11_;
	BoxesInstallerMedia* _tmp12_;
	BoxesInstallerMedia* _tmp13_;
	BoxesVMCreator* _tmp14_;
	GtkProgressBar* _tmp15_;
};

struct _BoxesWizardReviewData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	gboolean _result_;
	gboolean _tmp2_;
};

struct _Block72Data {
	int _ref_count_;
	BoxesWizard* self;
	GVirConfigDomain* config;
};

typedef void (*BoxesWizardSummaryCustomizeFunc) (void* user_data);
struct _BoxesWizardDoReviewCancellableData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizard* self;
	gboolean result;
	GCancellable* _tmp0_;
	GtkInfoBar* _tmp1_;
	BoxesWizardSummary* _tmp2_;
	BoxesCollectionSource* _tmp3_;
	BoxesRemoteMachine* _tmp4_;
	BoxesCollectionSource* _tmp5_;
	BoxesRemoteMachine* _tmp6_;
	GError* _error_;
	GError* _tmp7_;
	const gchar* _tmp8_;
	gboolean _tmp9_;
	BoxesVMCreator* _tmp10_;
	BoxesLibvirtMachine* _tmp11_;
	BoxesLibvirtMachine* _tmp12_;
	BoxesLibvirtMachine* _tmp13_;
	BoxesVMCreator* _tmp14_;
	GCancellable* _tmp15_;
	BoxesLibvirtMachine* _tmp16_;
	GError* cancel_error;
	GError* _vala1__error_;
	BoxesAppWindow* _tmp17_;
	BoxesNotificationbar* _tmp18_;
	const gchar* _tmp19_;
	GdNotification* _tmp20_;
	GdNotification* _tmp21_;
	GError* _tmp22_;
	const gchar* _tmp23_;
	BoxesLibvirtMachine* _tmp24_;
	BoxesLibvirtMachine* _tmp25_;
	GCancellable* _tmp26_;
	gboolean _tmp27_;
	GtkLabel* _tmp28_;
	const gchar* _tmp29_;
	BoxesCollectionSource* _tmp30_;
	xmlURI* uri;
	BoxesCollectionSource* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	xmlURI* _tmp35_;
	xmlURI* _tmp36_;
	BoxesWizardSummary* _tmp37_;
	const gchar* _tmp38_;
	BoxesCollectionSource* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	gchar* _tmp42_;
	gboolean _tmp43_;
	xmlURI* _tmp44_;
	xmlURI* _tmp45_;
	const gchar* _tmp46_;
	BoxesWizardSummary* _tmp47_;
	const gchar* _tmp48_;
	xmlURI* _tmp49_;
	const gchar* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	BoxesWizardSummary* _tmp53_;
	const gchar* _tmp54_;
	BoxesCollectionSource* _tmp55_;
	gchar* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	gchar* _tmp60_;
	xmlURI* _tmp61_;
	const gchar* _tmp62_;
	const gchar* _tmp63_;
	GQuark _tmp65_;
	gint port;
	gint tls_port;
	BoxesCollectionSource* _tmp66_;
	gchar* _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gint* _tmp70_;
	gint* _tmp71_;
	gint* _tmp72_;
	gint* _tmp73_;
	gint _tmp74_;
	BoxesWizardSummary* _tmp75_;
	const gchar* _tmp76_;
	gint _tmp77_;
	gchar* _tmp78_;
	gchar* _tmp79_;
	gint _tmp80_;
	BoxesWizardSummary* _tmp81_;
	const gchar* _tmp82_;
	gint _tmp83_;
	gchar* _tmp84_;
	gchar* _tmp85_;
	GError* _vala2__error_;
	GError* _tmp86_;
	const gchar* _tmp87_;
	xmlURI* _tmp88_;
	gint _tmp89_;
	BoxesWizardSummary* _tmp90_;
	const gchar* _tmp91_;
	xmlURI* _tmp92_;
	gint _tmp93_;
	gchar* _tmp94_;
	gchar* _tmp95_;
	BoxesApp* _tmp96_;
	BoxesCollectionSource* _tmp97_;
	gchar* _tmp98_;
	gchar* _tmp99_;
	gchar* _tmp100_;
	gboolean _tmp101_;
	gboolean _tmp102_;
	GtkLabel* _tmp103_;
	const gchar* _tmp104_;
	BoxesLibvirtMachine* _tmp105_;
	BoxesLibvirtMachine* _tmp106_;
	BoxesVMCreator* _tmp107_;
	BoxesInstallerMedia* _tmp108_;
	BoxesInstallerMedia* _tmp109_;
	GList* _tmp110_;
	GList* property_collection;
	GList* property_it;
	BoxesPair* _tmp111_;
	BoxesPair* property;
	BoxesWizardSummary* _tmp112_;
	BoxesPair* _tmp113_;
	gconstpointer _tmp114_;
	BoxesPair* _tmp115_;
	gconstpointer _tmp116_;
	Block72Data* _data72_;
	gpointer _tmp117_;
	GVirConfigDomain* _tmp118_;
	gchar* memory;
	GVirConfigDomain* _tmp119_;
	guint64 _tmp120_;
	guint64 _tmp121_;
	gchar* _tmp122_;
	BoxesWizardSummary* _tmp123_;
	const gchar* _tmp124_;
	const gchar* _tmp125_;
	GError* _vala3__error_;
	BoxesLibvirtMachine* _tmp126_;
	BoxesLibvirtMachine* _tmp127_;
	const gchar* _tmp128_;
	const gchar* _tmp129_;
	GError* _tmp130_;
	const gchar* _tmp131_;
	gboolean _tmp132_;
	BoxesLibvirtMachine* _tmp133_;
	BoxesLibvirtMachine* _tmp134_;
	gboolean _tmp135_;
	gboolean _tmp136_;
	BoxesLibvirtMachine* _tmp137_;
	BoxesLibvirtMachine* _tmp138_;
	GVirStorageVol* _tmp139_;
	GVirStorageVol* _tmp140_;
	GVirStorageVolInfo* volume_info;
	BoxesLibvirtMachine* _tmp141_;
	BoxesLibvirtMachine* _tmp142_;
	GVirStorageVol* _tmp143_;
	GVirStorageVol* _tmp144_;
	GVirStorageVolInfo* _tmp145_;
	gchar* capacity;
	GVirStorageVolInfo* _tmp146_;
	guint64 _tmp147_;
	gchar* _tmp148_;
	BoxesWizardSummary* _tmp149_;
	const gchar* _tmp150_;
	const gchar* _tmp151_;
	gchar* _tmp152_;
	gchar* _tmp153_;
	const gchar* _tmp154_;
	GError* _vala4__error_;
	BoxesLibvirtMachine* _tmp155_;
	BoxesLibvirtMachine* _tmp156_;
	GVirStorageVol* _tmp157_;
	GVirStorageVol* _tmp158_;
	const gchar* _tmp159_;
	GError* _tmp160_;
	const gchar* _tmp161_;
	GtkInfoBar* _tmp162_;
	BoxesLibvirtMachine* _tmp163_;
	BoxesLibvirtMachine* _tmp164_;
	GVirConfigDomain* _tmp165_;
	GVirConfigDomain* _tmp166_;
	GVirConfigDomainVirtType _tmp167_;
	BoxesWizardSource* _tmp168_;
	gboolean _tmp169_;
	GtkLabel* _tmp170_;
	BoxesWizardSource* _tmp171_;
	BoxesLibvirtSystemImporter* _tmp172_;
	BoxesLibvirtSystemImporter* _tmp173_;
	gchar* _tmp174_;
	gchar* _tmp175_;
	gchar* _tmp176_;
	BoxesMachine* _tmp177_;
	BoxesWizardSummary* _tmp178_;
	GError * _inner_error_;
};

struct _BoxesTopbar {
	GtkStack parent_instance;
	BoxesTopbarPrivate * priv;
	BoxesWizardToolbar* wizard_toolbar;
	gchar* _status;
};

struct _BoxesTopbarClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardToolbar {
	GtkHeaderBar parent_instance;
	BoxesWizardToolbarPrivate * priv;
	GtkButton* cancel_btn;
	GtkButton* back_btn;
	GtkButton* continue_btn;
	GtkButton* create_btn;
};

struct _BoxesWizardToolbarClass {
	GtkHeaderBarClass parent_class;
};

struct _BoxesWizardSummary {
	GtkGrid parent_instance;
	BoxesWizardSummaryPrivate * priv;
};

struct _BoxesWizardSummaryClass {
	GtkGridClass parent_class;
};

struct _BoxesWizardSummaryPrivate {
	gint current_row;
};

struct _Block73Data {
	int _ref_count_;
	BoxesWizardSummary* self;
	BoxesWizardSummaryCustomizeFunc customize_func;
	gpointer customize_func_target;
};


static gpointer boxes_wizard_parent_class = NULL;
extern BoxesApp* boxes_app_app;
extern BoxesAppWindow* boxes_app_window;
static BoxesUIIface* boxes_wizard_boxes_ui_parent_iface = NULL;
static gpointer boxes_wizard_summary_parent_class = NULL;

GType boxes_wizard_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_wizard_summary_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD, BoxesWizardPrivate))
enum  {
	BOXES_WIZARD_DUMMY_PROPERTY,
	BOXES_WIZARD_PREVIOUS_UI_STATE,
	BOXES_WIZARD_UI_STATE,
	BOXES_WIZARD_MACHINE,
	BOXES_WIZARD_PAGE
};
static void boxes_wizard_wizard_source_update_next (BoxesWizard* self);
BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self);
GType boxes_source_page_get_type (void) G_GNUC_CONST;
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, GError** error);
GType boxes_app_get_type (void) G_GNUC_CONST;
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_wizard_destroy_machine (BoxesWizard* self);
void boxes_wizard_source_cleanup (BoxesWizardSource* self);
static void boxes_wizard_create_data_free (gpointer _data);
static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_);
static Block70Data* block70_data_ref (Block70Data* _data70_);
static void block70_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self);
static void ____lambda119_ (Block70Data* _data70_);
static void _____lambda119__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_vm_creator_launch_vm (BoxesVMCreator* self, BoxesLibvirtMachine* machine, GError** error);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
void boxes_installer_media_clean_up_preparation_cache (BoxesInstallerMedia* self);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
GType boxes_libvirt_system_importer_get_type (void) G_GNUC_CONST;
BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self);
void boxes_libvirt_system_importer_import (BoxesLibvirtSystemImporter* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_system_importer_import_finish (BoxesLibvirtSystemImporter* self, GAsyncResult* _res_);
void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value);
static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, GError** error);
static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error);
void spice_validate_uri (const gchar* uri_as_text, gint** port, gint** tls_port, GError** error);
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GObject* source_object, GAsyncResult* _result_);
static void _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value);
static void boxes_wizard_prepare_media_data_free (gpointer _data);
static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_);
static Block71Data* block71_data_ref (Block71Data* _data71_);
static void block71_data_unref (void * _userdata_);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static void __lambda92_ (Block71Data* _data71_);
static void ___lambda92__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_installer_media_prepare (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_installer_media_prepare_finish (BoxesInstallerMedia* self, GAsyncResult* _res_);
static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
BoxesVMCreator* boxes_installer_media_get_vm_creator (BoxesInstallerMedia* self);
static gboolean boxes_wizard_prepare (BoxesWizard* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
static gboolean boxes_wizard_setup (BoxesWizard* self);
void boxes_installer_media_populate_setup_box (BoxesInstallerMedia* self, GtkBox* setup_box);
static void __lambda93_ (BoxesWizard* self);
gboolean boxes_installer_media_get_ready_to_create (BoxesInstallerMedia* self);
static void ___lambda93__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self);
static void boxes_wizard_review_data_free (gpointer _data);
static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_);
static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_);
static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_);
static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_do_review_cancellable_data_free (gpointer _data);
static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_);
void boxes_wizard_summary_clear (BoxesWizardSummary* self);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_vm_creator_create_vm (BoxesVMCreator* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtMachine* boxes_vm_creator_create_vm_finish (BoxesVMCreator* self, GAsyncResult* _res_, GError** error);
static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void boxes_wizard_summary_add_property (BoxesWizardSummary* self, const gchar* name, const gchar* value);
GList* boxes_installer_media_get_vm_properties (BoxesInstallerMedia* self);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
static Block72Data* block72_data_ref (Block72Data* _data72_);
static void block72_data_unref (void * _userdata_);
static void _____lambda116_ (Block72Data* _data72_, GError** error);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void ______lambda116__boxes_run_in_thread_func (gpointer self, GError** error);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
gchar* boxes_libvirt_system_importer_get_wizard_review_label (BoxesLibvirtSystemImporter* self);
BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self);
void boxes_wizard_summary_append_customize_button (BoxesWizardSummary* self, BoxesWizardSummaryCustomizeFunc customize_func, void* customize_func_target);
static void ___lambda117_ (BoxesWizard* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
static void ____lambda117__boxes_wizard_summary_customize_func (gpointer self);
static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page);
gboolean boxes_installer_media_get_need_user_input_for_vm_creation (BoxesInstallerMedia* self);
gboolean boxes_installer_media_get_live (BoxesInstallerMedia* self);
void boxes_wizard_setup_ui (BoxesWizard* self);
GType boxes_wizard_toolbar_get_type (void) G_GNUC_CONST;
static void __lambda121_ (BoxesWizard* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static void ___lambda121__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda122_ (BoxesWizard* self);
static void ___lambda122__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda123_ (BoxesWizard* self);
static void ___lambda123__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda124_ (BoxesWizard* self);
static void ___lambda124__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
static void boxes_wizard_ui_state_changed (BoxesWizard* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
BoxesWizard* boxes_wizard_new (void);
BoxesWizard* boxes_wizard_construct (GType object_type);
static void _boxes_wizard_page_____lambda118_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda118__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _boxes_wizard_page_____lambda120_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_);
static void __boxes_wizard_page_____lambda120__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_sidebar_set_wizard_page (BoxesSidebar* self, BoxesWizardPage wizard_page);
static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
BoxesMediaManager* boxes_media_manager_get_instance (void);
static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void _boxes_wizard_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _boxes_wizard___lambda125_ (BoxesWizard* self);
static void __boxes_wizard___lambda125__boxes_wizard_source_activated (BoxesWizardSource* _sender, gpointer self);
static void boxes_wizard_finalize (GObject* obj);
static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define BOXES_WIZARD_SUMMARY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummaryPrivate))
enum  {
	BOXES_WIZARD_SUMMARY_DUMMY_PROPERTY
};
static Block73Data* block73_data_ref (Block73Data* _data73_);
static void block73_data_unref (void * _userdata_);
static void __lambda91_ (Block73Data* _data73_);
static void ___lambda91__gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesWizardSummary* boxes_wizard_summary_new (void);
BoxesWizardSummary* boxes_wizard_summary_construct (GType object_type);
static GObject * boxes_wizard_summary_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void boxes_wizard_summary_finalize (GObject* obj);

static const gchar* BOXES_WIZARD_page_names[5] = {"introduction", "source", "preparation", "setup", "review"};

GType boxes_wizard_page_get_type (void) {
	static volatile gsize boxes_wizard_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_WIZARD_PAGE_INTRODUCTION, "BOXES_WIZARD_PAGE_INTRODUCTION", "introduction"}, {BOXES_WIZARD_PAGE_SOURCE, "BOXES_WIZARD_PAGE_SOURCE", "source"}, {BOXES_WIZARD_PAGE_PREPARATION, "BOXES_WIZARD_PAGE_PREPARATION", "preparation"}, {BOXES_WIZARD_PAGE_SETUP, "BOXES_WIZARD_PAGE_SETUP", "setup"}, {BOXES_WIZARD_PAGE_REVIEW, "BOXES_WIZARD_PAGE_REVIEW", "review"}, {BOXES_WIZARD_PAGE_LAST, "BOXES_WIZARD_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_wizard_page_type_id;
		boxes_wizard_page_type_id = g_enum_register_static ("BoxesWizardPage", values);
		g_once_init_leave (&boxes_wizard_page_type_id__volatile, boxes_wizard_page_type_id);
	}
	return boxes_wizard_page_type_id__volatile;
}


static void boxes_wizard_wizard_source_update_next (BoxesWizard* self) {
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
	GtkButton* _tmp2_ = NULL;
	BoxesWizardSource* _tmp3_ = NULL;
	BoxesSourcePage _tmp4_ = 0;
	BoxesSourcePage _tmp5_ = 0;
	GError * _inner_error_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != BOXES_WIZARD_PAGE_SOURCE) {
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 989 "wizard.c"
	}
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->next_button;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp2_, FALSE);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = boxes_wizard_source_get_page (_tmp3_);
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = _tmp4_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 1005 "wizard.c"
		{
			GtkButton* _tmp6_ = NULL;
			BoxesWizardSource* _tmp7_ = NULL;
			GtkWidget* _tmp8_ = NULL;
			GtkWidget* _tmp9_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->next_button;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->wizard_source;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = boxes_wizard_source_get_selected (_tmp7_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _tmp8_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, _tmp9_ != NULL);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->source);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			self->priv->source = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1027 "wizard.c"
		}
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 1031 "wizard.c"
		{
			GtkButton* _tmp10_ = NULL;
			BoxesWizardSource* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			gint _tmp14_ = 0;
			gint _tmp15_ = 0;
			gchar* text = NULL;
			const gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* icon = NULL;
			gchar* _tmp18_ = NULL;
			BoxesWizardSource* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			const gchar* _tmp37_ = NULL;
			const gchar* _tmp38_ = NULL;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->next_button;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->wizard_source;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = boxes_wizard_source_get_uri (_tmp11_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = _tmp12_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = strlen (_tmp13_);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, _tmp15_ != 0);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp16_ = _ ("Please enter desktop or collection URI");
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = g_strdup (_tmp16_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			text = _tmp17_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp18_ = g_strdup ("preferences-desktop-remote-desktop");
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			icon = _tmp18_;
#line 1072 "wizard.c"
			{
				BoxesWizardSource* _tmp19_ = NULL;
				const gchar* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				gboolean _tmp22_ = FALSE;
				BoxesCollectionSource* _tmp23_ = NULL;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = self->priv->wizard_source;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp20_ = boxes_wizard_source_get_uri (_tmp19_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = _tmp20_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_prepare_for_location (self, _tmp21_, TRUE, &_inner_error_);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1089 "wizard.c"
					goto __catch111_g_error;
				}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp23_ = self->priv->source;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp23_ != NULL) {
#line 1096 "wizard.c"
					BoxesApp* _tmp24_ = NULL;
					BoxesCollectionSource* _tmp25_ = NULL;
					gchar* _tmp26_ = NULL;
					gchar* _tmp27_ = NULL;
					gchar* _tmp28_ = NULL;
					gboolean _tmp29_ = FALSE;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp24_ = boxes_app_app;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp25_ = self->priv->source;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp26_ = boxes_collection_source_get_source_type (_tmp25_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp27_ = _tmp26_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp28_ = _tmp27_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp29_ = boxes_app_has_broker_for_source_type (_tmp24_, _tmp28_);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp22_ = _tmp29_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp28_);
#line 1119 "wizard.c"
				} else {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp22_ = FALSE;
#line 1123 "wizard.c"
				}
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp22_) {
#line 1127 "wizard.c"
					const gchar* _tmp30_ = NULL;
					gchar* _tmp31_ = NULL;
					gchar* _tmp32_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp30_ = _ ("Will add boxes for all systems available from this account.");
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp31_ = g_strdup (_tmp30_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					text = _tmp31_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp32_ = g_strdup ("network-workgroup");
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (icon);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					icon = _tmp32_;
#line 1145 "wizard.c"
				} else {
					const gchar* _tmp33_ = NULL;
					gchar* _tmp34_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp33_ = _ ("Will add a single box.");
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp34_ = g_strdup (_tmp33_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (text);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					text = _tmp34_;
#line 1157 "wizard.c"
				}
			}
			goto __finally111;
			__catch111_g_error:
			{
				GError* _error_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_error_ = _inner_error_;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_inner_error_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_error_);
#line 1170 "wizard.c"
			}
			__finally111:
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (icon);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (text);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1185 "wizard.c"
			}
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = self->priv->wizard_source;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp36_ = _ ("Desktop Access");
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = text;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp38_ = icon;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_update_url_page (_tmp35_, _tmp36_, _tmp37_, _tmp38_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (icon);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (text);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1203 "wizard.c"
		}
		default:
		{
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warn_if_reached ();
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 1211 "wizard.c"
		}
	}
}


void boxes_wizard_cleanup (BoxesWizard* self) {
	BoxesWizardSource* _tmp0_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_destroy_machine (self);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->vm_creator = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->source = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_cleanup (_tmp0_);
#line 1235 "wizard.c"
}


static void boxes_wizard_create_data_free (gpointer _data) {
	BoxesWizardCreateData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardCreateData, _data_);
#line 1246 "wizard.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self ? g_object_ref (self) : NULL;
#line 1253 "wizard.c"
}


static void boxes_wizard_create (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardCreateData* _data_;
	BoxesWizard* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardCreateData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_create);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_create_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data_);
#line 1272 "wizard.c"
}


static gboolean boxes_wizard_create_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardCreateData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 1285 "wizard.c"
}


static Block70Data* block70_data_ref (Block70Data* _data70_) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data70_->_ref_count_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data70_;
#line 1294 "wizard.c"
}


static void block70_data_unref (void * _userdata_) {
	Block70Data* _data70_;
	_data70_ = (Block70Data*) _userdata_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data70_->_ref_count_)) {
#line 1303 "wizard.c"
		BoxesWizard* self;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data70_->self;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block70Data, _data70_);
#line 1311 "wizard.c"
	}
}


static void ____lambda119_ (Block70Data* _data70_) {
	BoxesWizard* self;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data70_->self;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_create_co (_data70_->_async_data_);
#line 1322 "wizard.c"
}


static void _____lambda119__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	____lambda119_ (self);
#line 1329 "wizard.c"
}


static gboolean boxes_wizard_create_co (BoxesWizardCreateData* _data_) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 1338 "wizard.c"
		goto _state_0;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 1342 "wizard.c"
		goto _state_1;
		default:
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 1347 "wizard.c"
	}
	_state_0:
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data70_ = g_slice_new0 (Block70Data);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data70_->_ref_count_ = 1;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data70_->self = g_object_ref (_data_->self);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data70_->_async_data_ = _data_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->vm_creator;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp0_ != NULL) {
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp1_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp1_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp2_ == NULL) {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp3_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp3_ = _data_->self->priv->review_cancellable;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_return_val_if_fail (_data_->_tmp3_ != NULL, FALSE);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = 0UL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = g_signal_connect_data ((GObject*) _data_->self, "notify::machine", (GCallback) _____lambda119__g_object_notify, block70_data_ref (_data_->_data70_), (GClosureNotify) block70_data_unref, 0);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->wait = _data_->_tmp4_;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_state_ = 1;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1390 "wizard.c"
			_state_1:
			;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = 0UL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->wait;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp5_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_tmp6_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp7_ == NULL) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				block70_data_unref (_data_->_data70_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data70_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ == 0) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1419 "wizard.c"
				} else {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 1423 "wizard.c"
				}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 1429 "wizard.c"
			}
		}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->self->priv->next_button;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp8_, FALSE);
#line 1438 "wizard.c"
		{
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->self->priv->vm_creator;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp10_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = _data_->_tmp10_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_vm_creator_launch_vm (_data_->_tmp9_, _data_->_tmp11_, &_data_->_inner_error_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1456 "wizard.c"
				goto __catch112_g_error;
			}
		}
		goto __finally112;
		__catch112_g_error:
		{
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_error_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp13_ = _data_->_tmp12_->message;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:216: %s", _data_->_tmp13_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->result = FALSE;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			block70_data_unref (_data_->_data70_);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_data70_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_state_ == 0) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1489 "wizard.c"
			} else {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1493 "wizard.c"
			}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_object_unref (_data_->_async_result);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1499 "wizard.c"
		}
		__finally112:
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			block70_data_unref (_data_->_data70_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_data70_ = NULL;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 1514 "wizard.c"
		}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp14_ = _data_->self->priv->vm_creator;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp15_ = boxes_vm_creator_get_install_media (_data_->_tmp14_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = NULL;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp16_ = _data_->_tmp15_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_installer_media_clean_up_preparation_cache (_data_->_tmp16_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->self->priv->vm_creator = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = NULL;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp17_ = _data_->self->priv->wizard_source;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_source_set_uri (_data_->_tmp17_, "");
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_ = _data_->self->priv->wizard_source;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp18_->libvirt_sys_import = FALSE;
#line 1546 "wizard.c"
	} else {
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = NULL;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp19_ = _data_->self->priv->source;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp19_ != NULL) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp20_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp20_ = _data_->self->priv->source;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_iconfig_save ((BoxesIConfig*) _data_->_tmp20_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp21_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp21_ = boxes_app_app;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp22_ = NULL;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp22_ = _data_->self->priv->source;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_app_add_collection_source (_data_->_tmp21_, _data_->_tmp22_, NULL, NULL);
#line 1570 "wizard.c"
		} else {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp23_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp23_ = _data_->self->priv->wizard_source;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = FALSE;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = _data_->_tmp23_->libvirt_sys_import;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp24_) {
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp25_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp25_ = _data_->self->priv->wizard_source;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp26_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp26_ = boxes_wizard_source_get_libvirt_sys_importer (_data_->_tmp25_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp27_ = NULL;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp27_ = _data_->_tmp26_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_libvirt_system_importer_import (_data_->_tmp27_, NULL, NULL);
#line 1596 "wizard.c"
			} else {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_return_val_if_reached (FALSE);
#line 1600 "wizard.c"
			}
		}
	}
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_machine (_data_->self, NULL);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block70_data_unref (_data_->_data70_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data70_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1616 "wizard.c"
	} else {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1620 "wizard.c"
	}
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block70_data_unref (_data_->_data70_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data70_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1634 "wizard.c"
	} else {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1638 "wizard.c"
	}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 1644 "wizard.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1278 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1278 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1279 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1664 "wizard.c"
}


static void boxes_wizard_prepare_for_location (BoxesWizard* self, const gchar* location, gboolean probing, GError** error) {
	const gchar* _tmp0_ = NULL;
	GFile* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GFile* file = NULL;
	GFile* _tmp9_ = NULL;
	gchar* path = NULL;
	GFile* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_ = NULL;
	GError * _inner_error_ = NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (location != NULL);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = location;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp0_, "") == 0) {
#line 1689 "wizard.c"
		GError* _tmp1_ = NULL;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "empty location");
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp1_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 1699 "wizard.c"
	}
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = location;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = string_contains (_tmp3_, "://");
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 1707 "wizard.c"
		const gchar* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = location;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = g_file_new_for_uri (_tmp5_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp2_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp6_;
#line 1718 "wizard.c"
	} else {
		const gchar* _tmp7_ = NULL;
		GFile* _tmp8_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = location;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = g_file_new_for_path (_tmp7_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp2_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp8_;
#line 1730 "wizard.c"
	}
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = _g_object_ref0 (_tmp2_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	file = _tmp9_;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = file;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = g_file_get_path (_tmp10_);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	path = _tmp11_;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = path;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp13_ != NULL) {
#line 1746 "wizard.c"
		gboolean _tmp14_ = FALSE;
		GFile* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = file;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp16_ = g_file_has_uri_scheme (_tmp15_, "file");
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp16_) {
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = TRUE;
#line 1758 "wizard.c"
		} else {
			GFile* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = file;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp18_ = g_file_has_uri_scheme (_tmp17_, "smb");
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = _tmp18_;
#line 1768 "wizard.c"
		}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp14_;
#line 1772 "wizard.c"
	} else {
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = FALSE;
#line 1776 "wizard.c"
	}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp12_) {
#line 1780 "wizard.c"
		gboolean _tmp19_ = FALSE;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp19_ = probing;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (!_tmp19_) {
#line 1786 "wizard.c"
			const gchar* _tmp20_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = path;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_installer (self, _tmp20_, &_inner_error_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp2_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1804 "wizard.c"
			}
		}
	} else {
		gboolean uncertain = FALSE;
		gchar* uri = NULL;
		GFile* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* mimetype = NULL;
		const gchar* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		gchar* _tmp25_ = NULL;
		gboolean _tmp26_ = FALSE;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp21_ = file;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp22_ = g_file_get_uri (_tmp21_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		uri = _tmp22_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp23_ = uri;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp25_ = g_content_type_guess (_tmp23_, NULL, (gsize) 0, &_tmp24_);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		uncertain = _tmp24_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		mimetype = _tmp25_;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp26_ = uncertain;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp26_) {
#line 1835 "wizard.c"
			const gchar* _tmp27_ = NULL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp27_ = uri;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_prepare_for_uri (self, _tmp27_, &_inner_error_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (mimetype);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (uri);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (path);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (file);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp2_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 1857 "wizard.c"
			}
		} else {
			const gchar* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			gchar* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
			GError* _tmp33_ = NULL;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp28_ = uri;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp29_ = mimetype;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp30_ = g_content_type_get_mime_type (_tmp29_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp31_ = _tmp30_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_debug ("wizard.vala:258: Can't handle remote location '%s' (mime type: '%s')", _tmp28_, _tmp31_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_tmp31_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp32_ = _ ("Invalid URI");
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp33_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp32_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_inner_error_ = _tmp33_;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (mimetype);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (uri);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (path);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (file);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_tmp2_);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 1898 "wizard.c"
		}
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (mimetype);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (uri);
#line 1904 "wizard.c"
	}
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_free0 (path);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (file);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp2_);
#line 1912 "wizard.c"
}


static void boxes_wizard_prepare_for_uri (BoxesWizard* self, const gchar* uri_as_text, GError** error) {
	xmlURI* uri = NULL;
	const gchar* _tmp0_ = NULL;
	xmlURI* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	xmlURI* _tmp3_ = NULL;
	const gchar* _tmp8_ = NULL;
	xmlURI* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	xmlURI* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	BoxesCollectionSource* _tmp15_ = NULL;
	xmlURI* _tmp16_ = NULL;
	const gchar* _tmp17_ = NULL;
	GError * _inner_error_ = NULL;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri_as_text != NULL);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = uri_as_text;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = xmlParseURI (_tmp0_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	uri = _tmp1_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = uri;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp3_ == NULL) {
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = TRUE;
#line 1948 "wizard.c"
	} else {
		xmlURI* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = uri;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_->scheme;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = _tmp5_ == NULL;
#line 1958 "wizard.c"
	}
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp2_) {
#line 1962 "wizard.c"
		const gchar* _tmp6_ = NULL;
		GError* _tmp7_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _ ("Invalid URI");
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp6_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = _tmp7_;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_propagate_error (error, _inner_error_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 1979 "wizard.c"
		} else {
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_xmlFreeURI0 (uri);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_inner_error_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return;
#line 1989 "wizard.c"
		}
	}
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = uri;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = _tmp9_->server;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = _tmp10_;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp8_ == NULL) {
#line 2000 "wizard.c"
		const gchar* _tmp11_ = NULL;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = uri_as_text;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = _tmp11_;
#line 2006 "wizard.c"
	}
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = uri;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = _tmp12_->scheme;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = uri_as_text;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = boxes_collection_source_new (_tmp8_, _tmp13_, _tmp14_);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->source = _tmp15_;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = uri;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = _tmp16_->scheme;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_strcmp0 (_tmp17_, "spice") == 0) {
#line 2026 "wizard.c"
		const gchar* _tmp18_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp18_ = uri_as_text;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		spice_validate_uri (_tmp18_, NULL, NULL, &_inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_propagate_error (error, _inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2042 "wizard.c"
			} else {
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_xmlFreeURI0 (uri);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 2052 "wizard.c"
			}
		}
	} else {
		xmlURI* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp19_ = uri;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp20_ = _tmp19_->scheme;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (g_strcmp0 (_tmp20_, "vnc") == 0) {
#line 2064 "wizard.c"
		} else {
			xmlURI* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp21_ = uri;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp22_ = _tmp21_->scheme;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp23_ = g_str_has_prefix (_tmp22_, "qemu");
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp23_) {
#line 2077 "wizard.c"
				BoxesCollectionSource* _tmp24_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = self->priv->source;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_collection_source_set_source_type (_tmp24_, "libvirt");
#line 2083 "wizard.c"
			} else {
				BoxesApp* _tmp25_ = NULL;
				xmlURI* _tmp26_ = NULL;
				const gchar* _tmp27_ = NULL;
				gboolean _tmp28_ = FALSE;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp25_ = boxes_app_app;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp26_ = uri;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp27_ = _tmp26_->scheme;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp28_ = boxes_app_has_broker_for_source_type (_tmp25_, _tmp27_);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp28_) {
#line 2099 "wizard.c"
					BoxesCollectionSource* _tmp29_ = NULL;
					xmlURI* _tmp30_ = NULL;
					const gchar* _tmp31_ = NULL;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp29_ = self->priv->source;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp30_ = uri;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp31_ = _tmp30_->scheme;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					boxes_collection_source_set_source_type (_tmp29_, _tmp31_);
#line 2111 "wizard.c"
				} else {
					const gchar* _tmp32_ = NULL;
					xmlURI* _tmp33_ = NULL;
					const gchar* _tmp34_ = NULL;
					gchar* _tmp35_ = NULL;
					gchar* _tmp36_ = NULL;
					GError* _tmp37_ = NULL;
					GError* _tmp38_ = NULL;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp32_ = _ ("Unsupported protocol '%s'");
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp33_ = uri;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp34_ = _tmp33_->scheme;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp35_ = g_strdup_printf (_tmp32_, _tmp34_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp36_ = _tmp35_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp37_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp36_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp38_ = _tmp37_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_tmp36_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_inner_error_ = _tmp38_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_inner_error_->domain == BOXES_ERROR) {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_propagate_error (error, _inner_error_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						return;
#line 2146 "wizard.c"
					} else {
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (uri);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_clear_error (&_inner_error_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						return;
#line 2156 "wizard.c"
					}
				}
			}
		}
	}
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_xmlFreeURI0 (uri);
#line 2164 "wizard.c"
}


static void _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_on_installer_media_instantiated ((BoxesWizard*) self, source_object, res);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 2173 "wizard.c"
}


static void boxes_wizard_prepare_for_installer (BoxesWizard* self, const gchar* path, GError** error) {
	GtkButton* _tmp0_ = NULL;
	GtkLabel* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	BoxesMediaManager* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (path != NULL);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->prep_media_label;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _ ("Unknown installer media");
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp1_, _tmp2_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->prep_status_label;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _ ("Analyzing...");
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_label (_tmp3_, _tmp4_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->media_manager;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = path;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_media_manager_create_installer_media_for_path (_tmp5_, _tmp6_, NULL, _boxes_wizard_on_installer_media_instantiated_gasync_ready_callback, g_object_ref (self));
#line 2211 "wizard.c"
}


static void boxes_wizard_on_installer_media_instantiated (BoxesWizard* self, GObject* source_object, GAsyncResult* _result_) {
	GError * _inner_error_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 2221 "wizard.c"
	{
		BoxesInstallerMedia* install_media = NULL;
		BoxesMediaManager* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_ = NULL;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = self->priv->media_manager;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = _result_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_media_manager_create_installer_media_for_path_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		install_media = _tmp2_;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2240 "wizard.c"
				goto __catch113_g_io_error_cancelled;
			}
			goto __catch113_g_error;
		}
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = install_media;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp3_, NULL, NULL);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (install_media);
#line 2251 "wizard.c"
	}
	goto __finally113;
	__catch113_g_io_error_cancelled:
	{
		GError* cancel_error = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		cancel_error = _inner_error_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (cancel_error);
#line 2263 "wizard.c"
	}
	goto __finally113;
	__catch113_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* msg = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		BoxesAppWindow* _tmp8_ = NULL;
		BoxesNotificationbar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		GdNotification* _tmp11_ = NULL;
		GdNotification* _tmp12_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_error_ = _inner_error_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_inner_error_ = NULL;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _error_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_->message;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_debug ("wizard.vala:302: Failed to analyze installer image: %s", _tmp5_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _ ("Failed to analyze installer media. Corrupted or incomplete media?");
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = g_strdup (_tmp6_);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		msg = _tmp7_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = boxes_app_window;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = _tmp8_->notificationbar;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = msg;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = boxes_notificationbar_display_error (_tmp9_, _tmp10_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp11_;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp12_);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (msg);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_error_free0 (_error_);
#line 2313 "wizard.c"
	}
	__finally113:
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_clear_error (&_inner_error_);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 2324 "wizard.c"
	}
}


static void boxes_wizard_prepare_media_data_free (gpointer _data) {
	BoxesWizardPrepareMediaData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardPrepareMediaData, _data_);
#line 2338 "wizard.c"
}


static void boxes_wizard_prepare_media (BoxesWizard* self, BoxesInstallerMedia* install_media, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
	BoxesWizard* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardPrepareMediaData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_prepare_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_prepare_media_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = install_media;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->install_media);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->install_media = _tmp2_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2367 "wizard.c"
}


static void boxes_wizard_prepare_media_finish (BoxesWizard* self, GAsyncResult* _res_) {
	BoxesWizardPrepareMediaData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2375 "wizard.c"
}


static Block71Data* block71_data_ref (Block71Data* _data71_) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data71_->_ref_count_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data71_;
#line 2384 "wizard.c"
}


static void block71_data_unref (void * _userdata_) {
	Block71Data* _data71_;
	_data71_ = (Block71Data*) _userdata_;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data71_->_ref_count_)) {
#line 2393 "wizard.c"
		BoxesWizard* self;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data71_->self;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data71_->progress);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block71Data, _data71_);
#line 2403 "wizard.c"
	}
}


static void __lambda92_ (Block71Data* _data71_) {
	BoxesWizard* self;
	gdouble _tmp0_ = 0.0;
	gdouble _tmp1_ = 0.0;
	GtkProgressBar* _tmp2_ = NULL;
	gdouble _tmp3_ = 0.0;
	gdouble _tmp4_ = 0.0;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data71_->self;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_activity_progress_get_progress (_data71_->progress);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->prep_progress;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = gtk_progress_bar_get_fraction (_tmp2_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if ((_tmp1_ - _tmp4_) >= 0.01) {
#line 2429 "wizard.c"
		GtkProgressBar* _tmp5_ = NULL;
		gdouble _tmp6_ = 0.0;
		gdouble _tmp7_ = 0.0;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = self->priv->prep_progress;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_activity_progress_get_progress (_data71_->progress);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_progress_bar_set_fraction (_tmp5_, _tmp7_);
#line 2441 "wizard.c"
	}
}


static void ___lambda92__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda92_ (self);
#line 2449 "wizard.c"
}


static void boxes_wizard_prepare_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardPrepareMediaData* _data_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_prepare_media_co (_data_);
#line 2463 "wizard.c"
}


static gboolean boxes_wizard_prepare_media_co (BoxesWizardPrepareMediaData* _data_) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 2472 "wizard.c"
		goto _state_0;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 2476 "wizard.c"
		goto _state_1;
		default:
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2481 "wizard.c"
	}
	_state_0:
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data71_ = g_slice_new0 (Block71Data);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data71_->_ref_count_ = 1;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data71_->self = g_object_ref (_data_->self);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data71_->_async_data_ = _data_;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->install_media;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->_tmp0_->os;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp1_ != NULL) {
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp2_ = _data_->self->priv->prep_media_label;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp3_ = _data_->install_media;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp4_ = _data_->_tmp3_->os;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp5_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp4_);
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_data_->_tmp2_, _data_->_tmp6_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp7_ = _data_->self->priv->installer_image;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp8_ = _data_->install_media;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = NULL;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp9_ = _data_->_tmp8_->os;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_downloader_fetch_os_logo (_data_->_tmp7_, _data_->_tmp9_, 128, NULL, NULL);
#line 2538 "wizard.c"
	}
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp10_ = NULL;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp10_ = boxes_activity_progress_new ();
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data71_->progress = _data_->_tmp10_;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data ((GObject*) _data_->_data71_->progress, "notify::progress", (GCallback) ___lambda92__g_object_notify, block71_data_ref (_data_->_data71_), (GClosureNotify) block71_data_unref, 0);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp11_ = NULL;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp11_ = _data_->self->priv->prep_status_label;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_data71_->progress, "info", (GObject*) _data_->_tmp11_, "label", G_BINDING_DEFAULT, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp12_ = NULL;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp12_ = _data_->install_media;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare (_data_->_tmp12_, _data_->_data71_->progress, NULL, boxes_wizard_prepare_media_ready, _data_);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2564 "wizard.c"
	_state_1:
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_prepare_finish (_data_->_tmp12_, _data_->_res_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp13_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp13_ = _data_->install_media;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp14_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp14_ = boxes_installer_media_get_vm_creator (_data_->_tmp13_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (_data_->self->priv->vm_creator);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->vm_creator = _data_->_tmp14_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp15_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp15_ = _data_->self->priv->prep_progress;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_progress_bar_set_fraction (_data_->_tmp15_, 1.0);
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (_data_->self, BOXES_WIZARD_PAGE_SETUP);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block71_data_unref (_data_->_data71_);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_data71_ = NULL;
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2596 "wizard.c"
	} else {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2600 "wizard.c"
	}
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2606 "wizard.c"
}


static gboolean boxes_wizard_prepare (BoxesWizard* self) {
	gboolean result = FALSE;
	GtkImage* _tmp0_ = NULL;
	BoxesWizardSource* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->installer_image;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_image_set_from_icon_name (_tmp0_, "media-optical", 0);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = boxes_wizard_source_get_install_media (_tmp1_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp3_ != NULL) {
#line 2631 "wizard.c"
		GtkLabel* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GtkLabel* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		BoxesWizardSource* _tmp8_ = NULL;
		BoxesInstallerMedia* _tmp9_ = NULL;
		BoxesInstallerMedia* _tmp10_ = NULL;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->prep_media_label;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _ ("Unknown installer media");
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp4_, _tmp5_);
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = self->priv->prep_status_label;
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _ ("Analyzing...");
#line 334 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		gtk_label_set_label (_tmp6_, _tmp7_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp8_ = self->priv->wizard_source;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = boxes_wizard_source_get_install_media (_tmp8_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp10_ = _tmp9_;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_prepare_media (self, _tmp10_, NULL, NULL);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 2663 "wizard.c"
	} else {
		BoxesWizardSource* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp11_ = self->priv->wizard_source;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp11_->libvirt_sys_import;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp12_) {
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			result = TRUE;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return result;
#line 2677 "wizard.c"
		} else {
			{
				BoxesWizardSource* _tmp13_ = NULL;
				const gchar* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp13_ = self->priv->wizard_source;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp14_ = boxes_wizard_source_get_uri (_tmp13_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp15_ = _tmp14_;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_prepare_for_location (self, _tmp15_, FALSE, &_inner_error_);
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2693 "wizard.c"
					goto __catch114_g_error;
				}
			}
			goto __finally114;
			__catch114_g_error:
			{
				GError* _error_ = NULL;
				BoxesAppWindow* _tmp16_ = NULL;
				BoxesNotificationbar* _tmp17_ = NULL;
				GError* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				GdNotification* _tmp20_ = NULL;
				GdNotification* _tmp21_ = NULL;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_error_ = _inner_error_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_inner_error_ = NULL;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp16_ = boxes_app_window;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp17_ = _tmp16_->notificationbar;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp18_ = _error_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = _tmp18_->message;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp20_ = boxes_notificationbar_display_error (_tmp17_, _tmp19_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = _tmp20_;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_tmp21_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				result = FALSE;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_error_);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return result;
#line 2731 "wizard.c"
			}
			__finally114:
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_inner_error_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 2742 "wizard.c"
			}
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			result = TRUE;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return result;
#line 2748 "wizard.c"
		}
	}
}


static void __lambda93_ (BoxesWizard* self) {
	BoxesVMCreator* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->vm_creator;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_vm_creator_get_install_media (_tmp0_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_installer_media_get_ready_to_create (_tmp2_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 2772 "wizard.c"
		BoxesWizardPage _tmp5_ = 0;
		BoxesWizardPage _tmp6_ = 0;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = boxes_wizard_get_page (self);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = _tmp5_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp6_ + 1);
#line 2781 "wizard.c"
	}
}


static void ___lambda93__boxes_installer_media_user_wants_to_create (BoxesInstallerMedia* _sender, gpointer self) {
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda93_ ((BoxesWizard*) self);
#line 2789 "wizard.c"
}


static gboolean boxes_wizard_setup (BoxesWizard* self) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesVMCreator* _tmp4_ = NULL;
	BoxesVMCreator* _tmp5_ = NULL;
	BoxesInstallerMedia* _tmp6_ = NULL;
	BoxesInstallerMedia* _tmp7_ = NULL;
	GtkButton* _tmp8_ = NULL;
	BoxesVMCreator* _tmp9_ = NULL;
	BoxesInstallerMedia* _tmp10_ = NULL;
	BoxesInstallerMedia* _tmp11_ = NULL;
	GtkBox* _tmp12_ = NULL;
	BoxesVMCreator* _tmp13_ = NULL;
	BoxesInstallerMedia* _tmp14_ = NULL;
	BoxesInstallerMedia* _tmp15_ = NULL;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->source;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ != NULL) {
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = TRUE;
#line 2817 "wizard.c"
	} else {
		BoxesWizardSource* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = self->priv->wizard_source;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = _tmp2_->libvirt_sys_import;
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp0_ = _tmp3_;
#line 2827 "wizard.c"
	}
#line 354 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_) {
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 2835 "wizard.c"
	}
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = self->priv->vm_creator;
#line 357 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_tmp4_ != NULL);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->vm_creator;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = boxes_vm_creator_get_install_media (_tmp5_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = self->priv->continue_button;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_bind_property_with_closures ((GObject*) _tmp7_, "ready-to-create", (GObject*) _tmp8_, "sensitive", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = self->priv->vm_creator;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = boxes_vm_creator_get_install_media (_tmp9_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = _tmp10_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = self->priv->setup_box;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_installer_media_populate_setup_box (_tmp11_, _tmp12_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = self->priv->vm_creator;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = boxes_vm_creator_get_install_media (_tmp13_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = _tmp14_;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp15_, "user-wants-to-create", (GCallback) ___lambda93__boxes_installer_media_user_wants_to_create, self, 0);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = TRUE;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 2873 "wizard.c"
}


static void boxes_wizard_review_data_free (gpointer _data) {
	BoxesWizardReviewData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardReviewData, _data_);
#line 2884 "wizard.c"
}


static void boxes_wizard_review (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
	BoxesWizard* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardReviewData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_review);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_review_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 2903 "wizard.c"
}


static gboolean boxes_wizard_review_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardReviewData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 2916 "wizard.c"
}


static void boxes_wizard_review_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardReviewData* _data_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_review_co (_data_);
#line 2930 "wizard.c"
}


static gboolean boxes_wizard_review_co (BoxesWizardReviewData* _data_) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 2939 "wizard.c"
		goto _state_0;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 2943 "wizard.c"
		goto _state_1;
		default:
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 2948 "wizard.c"
	}
	_state_0:
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_data_->_tmp0_ == NULL);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = g_cancellable_new ();
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = _data_->_tmp1_;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_state_ = 1;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable (_data_->self, boxes_wizard_review_ready, _data_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 2971 "wizard.c"
	_state_1:
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = FALSE;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = boxes_wizard_do_review_cancellable_finish (_data_->self, _data_->_res_);
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_result_ = _data_->_tmp2_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self->priv->review_cancellable);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->review_cancellable = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self->priv->skip_review_for_live = FALSE;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = _data_->_result_;
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2991 "wizard.c"
	} else {
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2995 "wizard.c"
	}
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 382 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3005 "wizard.c"
	} else {
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3009 "wizard.c"
	}
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 3015 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_data_free (gpointer _data) {
	BoxesWizardDoReviewCancellableData* _data_;
	_data_ = _data;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_slice_free (BoxesWizardDoReviewCancellableData, _data_);
#line 3026 "wizard.c"
}


static void boxes_wizard_do_review_cancellable (BoxesWizard* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
	BoxesWizard* _tmp0_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_slice_new0 (BoxesWizardDoReviewCancellableData);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_do_review_cancellable);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_do_review_cancellable_data_free);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->self = _tmp0_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 3045 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_finish (BoxesWizard* self, GAsyncResult* _res_) {
	gboolean result;
	BoxesWizardDoReviewCancellableData* _data_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _data_->result;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 3058 "wizard.c"
}


static void boxes_wizard_do_review_cancellable_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardDoReviewCancellableData* _data_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_ = _user_data_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_source_object_ = source_object;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_res_ = _res_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_do_review_cancellable_co (_data_);
#line 3072 "wizard.c"
}


static gpointer _boxes_pair_ref0 (gpointer self) {
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self ? boxes_pair_ref (self) : NULL;
#line 3079 "wizard.c"
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 3086 "wizard.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_list_free (self);
#line 3095 "wizard.c"
}


static Block72Data* block72_data_ref (Block72Data* _data72_) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data72_->_ref_count_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data72_;
#line 3104 "wizard.c"
}


static void block72_data_unref (void * _userdata_) {
	Block72Data* _data72_;
	_data72_ = (Block72Data*) _userdata_;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data72_->_ref_count_)) {
#line 3113 "wizard.c"
		BoxesWizard* self;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data72_->self;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_data72_->config);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block72Data, _data72_);
#line 3123 "wizard.c"
	}
}


static void _____lambda116_ (Block72Data* _data72_, GError** error) {
	BoxesWizard* self;
	GVirConfigDomain* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	GVirDomain* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	GVirConfigDomain* _tmp5_ = NULL;
	GVirConfigDomain* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data72_->self;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_libvirt_machine (self);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gvir_domain_get_config (_tmp4_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _tmp5_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_propagate_error (error, _inner_error_);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 3158 "wizard.c"
	}
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = _tmp0_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = NULL;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_data72_->config);
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data72_->config = _tmp6_;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (_tmp0_);
#line 3170 "wizard.c"
}


static void ______lambda116__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_____lambda116_ (self, error);
#line 3177 "wizard.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 3184 "wizard.c"
}


static void ___lambda117_ (BoxesWizard* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_app_app;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->_machine;
#line 489 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_app_select_item (_tmp0_, (BoxesCollectionItem*) _tmp1_);
#line 3197 "wizard.c"
}


static void ____lambda117__boxes_wizard_summary_customize_func (gpointer self) {
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	___lambda117_ ((BoxesWizard*) self);
#line 3204 "wizard.c"
}


static gboolean boxes_wizard_do_review_cancellable_co (BoxesWizardDoReviewCancellableData* _data_) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_data_->_state_) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 0:
#line 3213 "wizard.c"
		goto _state_0;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 1:
#line 3217 "wizard.c"
		goto _state_1;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case 2:
#line 3221 "wizard.c"
		goto _state_2;
		default:
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_assert_not_reached ();
#line 3226 "wizard.c"
	}
	_state_0:
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = NULL;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp0_ = _data_->self->priv->review_cancellable;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_data_->_tmp0_ != NULL);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = NULL;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp1_ = _data_->self->priv->nokvm_infobar;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_hide ((GtkWidget*) _data_->_tmp1_);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = NULL;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp2_ = _data_->self->priv->summary;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_summary_clear (_data_->_tmp2_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp3_ = _data_->self->priv->source;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp3_ != NULL) {
#line 3253 "wizard.c"
		{
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp5_ = _data_->self->priv->source;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp6_ = boxes_remote_machine_new (_data_->_tmp5_, &_data_->_inner_error_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp4_ = _data_->_tmp6_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3269 "wizard.c"
					goto __catch115_boxes_error;
				}
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3278 "wizard.c"
			}
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp4_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (_data_->_tmp4_);
#line 3284 "wizard.c"
		}
		goto __finally115;
		__catch115_boxes_error:
		{
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_inner_error_ = NULL;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = NULL;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp7_ = _data_->_error_;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = NULL;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp8_ = _data_->_tmp7_->message;
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_warning ("wizard.vala:395: %s", _data_->_tmp8_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_error_free0 (_data_->_error_);
#line 3305 "wizard.c"
		}
		__finally115:
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_clear_error (&_data_->_inner_error_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			return FALSE;
#line 3316 "wizard.c"
		}
	} else {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = NULL;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp10_ = _data_->self->priv->vm_creator;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp10_ != NULL) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = NULL;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp11_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = NULL;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp12_ = _data_->_tmp11_;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = _data_->_tmp12_ == NULL;
#line 3335 "wizard.c"
		} else {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp9_ = FALSE;
#line 3339 "wizard.c"
		}
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp9_) {
#line 3343 "wizard.c"
			{
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp14_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp14_ = _data_->self->priv->vm_creator;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp15_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp15_ = _data_->self->priv->review_cancellable;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 1;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_vm_creator_create_vm (_data_->_tmp14_, _data_->_tmp15_, boxes_wizard_do_review_cancellable_ready, _data_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3359 "wizard.c"
				_state_1:
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp16_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp16_ = boxes_vm_creator_create_vm_finish (_data_->_tmp14_, _data_->_res_, &_data_->_inner_error_);
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp13_ = _data_->_tmp16_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 3371 "wizard.c"
						goto __catch116_g_io_error_cancelled;
					}
					goto __catch116_g_error;
				}
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_set_machine (_data_->self, (BoxesMachine*) _data_->_tmp13_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp13_);
#line 3380 "wizard.c"
			}
			goto __finally116;
			__catch116_g_io_error_cancelled:
			{
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->cancel_error = _data_->_inner_error_;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->cancel_error);
#line 3391 "wizard.c"
			}
			goto __finally116;
			__catch116_g_error:
			{
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp17_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp17_ = boxes_app_window;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp18_ = _data_->_tmp17_->notificationbar;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp19_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp19_ = _ ("Box setup failed");
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp20_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp20_ = boxes_notificationbar_display_error (_data_->_tmp18_, _data_->_tmp19_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp21_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp21_ = _data_->_tmp20_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (_data_->_tmp21_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp22_ = _data_->_vala1__error_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = NULL;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp23_ = _data_->_tmp22_->message;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:403: %s", _data_->_tmp23_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 3434 "wizard.c"
			}
			__finally116:
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3445 "wizard.c"
			}
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp24_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp25_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp25_ = _data_->_tmp24_;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp25_ == NULL) {
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_notify ((GObject*) _data_->self, "machine");
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->result = FALSE;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_data_->_state_ == 0) {
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3465 "wizard.c"
				} else {
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 3469 "wizard.c"
				}
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_object_unref (_data_->_async_result);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 3475 "wizard.c"
			}
		}
	}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp26_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp26_ = _data_->self->priv->review_cancellable;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp27_ = FALSE;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp27_ = g_cancellable_is_cancelled (_data_->_tmp26_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp27_) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->result = FALSE;
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_state_ == 0) {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3495 "wizard.c"
		} else {
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3499 "wizard.c"
		}
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_object_unref (_data_->_async_result);
#line 414 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return FALSE;
#line 3505 "wizard.c"
	}
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp28_ = NULL;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp28_ = _data_->self->priv->review_label;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp29_ = NULL;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp29_ = _ ("Boxes will create a new box with the following properties:");
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_text (_data_->_tmp28_, _data_->_tmp29_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp30_ = NULL;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp30_ = _data_->self->priv->source;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp30_ != NULL) {
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		static GQuark _tmp64_label0 = 0;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		static GQuark _tmp64_label1 = 0;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp31_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp31_ = _data_->self->priv->source;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp32_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp32_ = boxes_collection_source_get_uri (_data_->_tmp31_);
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp33_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp34_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp34_ = _data_->_tmp33_;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp35_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp35_ = xmlParseURI (_data_->_tmp34_);
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp36_ = NULL;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp34_);
#line 419 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->uri = _data_->_tmp36_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp37_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp37_ = _data_->self->priv->summary;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp38_ = _ ("Type");
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp39_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp39_ = _data_->self->priv->source;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp40_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp40_ = boxes_collection_source_get_source_type (_data_->_tmp39_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp41_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp41_ = _data_->_tmp40_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp42_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp42_ = _data_->_tmp41_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_summary_add_property (_data_->_tmp37_, _data_->_tmp38_, _data_->_tmp42_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp42_);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp44_ = NULL;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp44_ = _data_->uri;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp44_ != NULL) {
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp45_ = NULL;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp45_ = _data_->uri;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = NULL;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp46_ = _data_->_tmp45_->server;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp43_ = _data_->_tmp46_ != NULL;
#line 3599 "wizard.c"
		} else {
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp43_ = FALSE;
#line 3603 "wizard.c"
		}
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp43_) {
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp47_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp47_ = _data_->self->priv->summary;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp48_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp48_ = _ ("Host");
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp49_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp49_ = _data_->uri;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp50_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp50_ = _data_->_tmp49_->server;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp51_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp51_ = g_utf8_strdown (_data_->_tmp50_, (gssize) (-1));
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = NULL;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp52_ = _data_->_tmp51_;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_summary_add_property (_data_->_tmp47_, _data_->_tmp48_, _data_->_tmp52_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp52_);
#line 3635 "wizard.c"
		} else {
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp53_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp53_ = _data_->self->priv->summary;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp54_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp54_ = _ ("URI");
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp55_ = _data_->self->priv->source;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp56_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp56_ = boxes_collection_source_get_uri (_data_->_tmp55_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp57_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp57_ = _data_->_tmp56_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp58_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp58_ = _data_->_tmp57_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp59_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp59_ = g_utf8_strdown (_data_->_tmp58_, (gssize) (-1));
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp60_ = NULL;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp60_ = _data_->_tmp59_;
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_summary_add_property (_data_->_tmp53_, _data_->_tmp54_, _data_->_tmp60_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp60_);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_free0 (_data_->_tmp58_);
#line 3675 "wizard.c"
		}
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp61_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp61_ = _data_->uri;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp62_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp62_ = _data_->_tmp61_->scheme;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp63_ = NULL;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp65_ = 0U;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp63_ = _data_->_tmp62_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp65_ = (NULL == _data_->_tmp63_) ? 0 : g_quark_from_string (_data_->_tmp63_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp65_ == ((0 != _tmp64_label0) ? _tmp64_label0 : (_tmp64_label0 = g_quark_from_static_string ("spice")))) {
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 3697 "wizard.c"
				default:
				{
					{
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->port = 0;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->tls_port = 0;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp66_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp66_ = _data_->self->priv->source;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp67_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp67_ = boxes_collection_source_get_uri (_data_->_tmp66_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp68_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp68_ = _data_->_tmp67_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp69_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp69_ = _data_->_tmp68_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp70_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp71_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						spice_validate_uri (_data_->_tmp69_, &_data_->_tmp70_, &_data_->_tmp71_, &_data_->_inner_error_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp72_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp72_ = _data_->_tmp70_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->port = *_data_->_tmp72_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp73_ = NULL;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp73_ = _data_->_tmp71_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->tls_port = *_data_->_tmp73_;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp73_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp72_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp69_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3749 "wizard.c"
								goto __catch117_boxes_error;
							}
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_xmlFreeURI0 (_data_->uri);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							g_clear_error (&_data_->_inner_error_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							return FALSE;
#line 3760 "wizard.c"
						}
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp74_ = 0;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp74_ = _data_->port;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp74_ > 0) {
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp75_ = NULL;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp75_ = _data_->self->priv->summary;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp76_ = NULL;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp76_ = _ ("Port");
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp77_ = 0;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp77_ = _data_->port;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp78_ = NULL;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp78_ = g_strdup_printf ("%i", _data_->_tmp77_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp79_ = NULL;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp79_ = _data_->_tmp78_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							boxes_wizard_summary_add_property (_data_->_tmp75_, _data_->_tmp76_, _data_->_tmp79_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp79_);
#line 3792 "wizard.c"
						}
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp80_ = 0;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp80_ = _data_->tls_port;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						if (_data_->_tmp80_ > 0) {
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp81_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp81_ = _data_->self->priv->summary;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp82_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp82_ = _ ("TLS Port");
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp83_ = 0;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp83_ = _data_->tls_port;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp84_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp84_ = g_strdup_printf ("%i", _data_->_tmp83_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp85_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_data_->_tmp85_ = _data_->_tmp84_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							boxes_wizard_summary_add_property (_data_->_tmp81_, _data_->_tmp82_, _data_->_tmp85_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
							_g_free0 (_data_->_tmp85_);
#line 3824 "wizard.c"
						}
					}
					goto __finally117;
					__catch117_boxes_error:
					{
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_vala2__error_ = _data_->_inner_error_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_inner_error_ = NULL;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp86_ = NULL;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp86_ = _data_->_vala2__error_;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp87_ = NULL;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp87_ = _data_->_tmp86_->message;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("wizard.vala:440: %s", _data_->_tmp87_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_error_free0 (_data_->_vala2__error_);
#line 3846 "wizard.c"
					}
					__finally117:
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_xmlFreeURI0 (_data_->uri);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						g_clear_error (&_data_->_inner_error_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						return FALSE;
#line 3859 "wizard.c"
					}
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 3863 "wizard.c"
				}
			}
		} else if (_data_->_tmp65_ == ((0 != _tmp64_label1) ? _tmp64_label1 : (_tmp64_label1 = g_quark_from_static_string ("vnc")))) {
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			switch (0) {
#line 3869 "wizard.c"
				default:
				{
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp88_ = NULL;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp88_ = _data_->uri;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp89_ = 0;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp89_ = _data_->_tmp88_->port;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_data_->_tmp89_ > 0) {
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp90_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp90_ = _data_->self->priv->summary;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp91_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp91_ = _ ("Port");
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp92_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp92_ = _data_->uri;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp93_ = 0;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp93_ = _data_->_tmp92_->port;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp94_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp94_ = g_strdup_printf ("%i", _data_->_tmp93_);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp95_ = _data_->_tmp94_;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						boxes_wizard_summary_add_property (_data_->_tmp90_, _data_->_tmp91_, _data_->_tmp95_);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_g_free0 (_data_->_tmp95_);
#line 3910 "wizard.c"
					}
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					break;
#line 3914 "wizard.c"
				}
			}
		}
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp96_ = NULL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp96_ = boxes_app_app;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp97_ = NULL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp97_ = _data_->self->priv->source;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp98_ = NULL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp98_ = boxes_collection_source_get_source_type (_data_->_tmp97_);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp99_ = NULL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp99_ = _data_->_tmp98_;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp100_ = NULL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp100_ = _data_->_tmp99_;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp101_ = FALSE;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp101_ = boxes_app_has_broker_for_source_type (_data_->_tmp96_, _data_->_tmp100_);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp102_ = FALSE;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp102_ = _data_->_tmp101_;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_free0 (_data_->_tmp100_);
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp102_) {
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp103_ = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp103_ = _data_->self->priv->review_label;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp104_ = NULL;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp104_ = _ ("Will add boxes for all systems available from this account:");
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_label_set_text (_data_->_tmp103_, _data_->_tmp104_);
#line 3960 "wizard.c"
		}
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_xmlFreeURI0 (_data_->uri);
#line 3964 "wizard.c"
	} else {
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp105_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp105_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp106_ = NULL;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp106_ = _data_->_tmp105_;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_data_->_tmp106_ != NULL) {
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp107_ = _data_->self->priv->vm_creator;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp108_ = boxes_vm_creator_get_install_media (_data_->_tmp107_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp109_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp109_ = _data_->_tmp108_;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp110_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp110_ = boxes_installer_media_get_vm_properties (_data_->_tmp109_);
#line 3992 "wizard.c"
			{
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->property_collection = _data_->_tmp110_;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				for (_data_->property_it = _data_->property_collection; _data_->property_it != NULL; _data_->property_it = _data_->property_it->next) {
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp111_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp111_ = _boxes_pair_ref0 ((BoxesPair*) _data_->property_it->data);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->property = _data_->_tmp111_;
#line 4004 "wizard.c"
					{
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp112_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp112_ = _data_->self->priv->summary;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp113_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp113_ = _data_->property;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp114_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp114_ = _data_->_tmp113_->first;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp115_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp115_ = _data_->property;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp116_ = NULL;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_data_->_tmp116_ = _data_->_tmp115_->second;
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						boxes_wizard_summary_add_property (_data_->_tmp112_, (const gchar*) _data_->_tmp114_, (const gchar*) _data_->_tmp116_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_boxes_pair_unref0 (_data_->property);
#line 4030 "wizard.c"
					}
				}
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				__g_list_free__boxes_pair_unref0_0 (_data_->property_collection);
#line 4035 "wizard.c"
			}
			{
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data72_ = g_slice_new0 (Block72Data);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data72_->_ref_count_ = 1;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data72_->self = g_object_ref (_data_->self);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp117_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp117_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp118_ = NULL;
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp118_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp117_, gvir_config_domain_get_type ()) ? ((GVirConfigDomain*) _data_->_tmp117_) : NULL);
#line 458 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data72_->config = _data_->_tmp118_;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_state_ = 2;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_run_in_thread (______lambda116__boxes_run_in_thread_func, block72_data_ref (_data_->_data72_), block72_data_unref, boxes_wizard_do_review_cancellable_ready, _data_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4060 "wizard.c"
				_state_2:
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					block72_data_unref (_data_->_data72_);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_data72_ = NULL;
#line 4070 "wizard.c"
					goto __catch118_g_error;
				}
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp119_ = NULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp119_ = _data_->_data72_->config;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp120_ = 0ULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp120_ = gvir_config_domain_get_memory (_data_->_tmp119_);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp121_ = 0ULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp121_ = _data_->_tmp120_;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp122_ = NULL;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp122_ = g_format_size_full (_data_->_tmp121_ * OSINFO_KIBIBYTES, G_FORMAT_SIZE_IEC_UNITS);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->memory = _data_->_tmp122_;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp123_ = NULL;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp123_ = _data_->self->priv->summary;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp124_ = NULL;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp124_ = _ ("Memory");
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = NULL;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp125_ = _data_->memory;
#line 464 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_summary_add_property (_data_->_tmp123_, _data_->_tmp124_, _data_->_tmp125_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->memory);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				block72_data_unref (_data_->_data72_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_data72_ = NULL;
#line 4111 "wizard.c"
			}
			goto __finally118;
			__catch118_g_error:
			{
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_vala3__error_ = _data_->_inner_error_;
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_inner_error_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp126_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp126_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp127_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp127_ = _data_->_tmp126_;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp128_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp128_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->_tmp127_);
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp129_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp129_ = _data_->_tmp128_;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp130_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp130_ = _data_->_vala3__error_;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp131_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp131_ = _data_->_tmp130_->message;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_warning ("wizard.vala:466: Failed to get configuration for machine '%s': %s", _data_->_tmp129_, _data_->_tmp131_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_error_free0 (_data_->_vala3__error_);
#line 4148 "wizard.c"
			}
			__finally118:
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				g_clear_error (&_data_->_inner_error_);
#line 457 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return FALSE;
#line 4159 "wizard.c"
			}
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp133_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp133_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp134_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp134_ = _data_->_tmp133_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp135_ = FALSE;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp135_ = boxes_libvirt_machine_get_importing (_data_->_tmp134_);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp136_ = FALSE;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp136_ = _data_->_tmp135_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (!_data_->_tmp136_) {
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp137_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp137_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp138_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp138_ = _data_->_tmp137_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp139_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp139_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp138_);
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp140_ = NULL;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp140_ = _data_->_tmp139_;
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp132_ = _data_->_tmp140_ != NULL;
#line 4197 "wizard.c"
			} else {
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp132_ = FALSE;
#line 4201 "wizard.c"
			}
#line 469 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp132_) {
#line 4205 "wizard.c"
				{
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp141_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp141_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp142_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp142_ = _data_->_tmp141_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp143_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp143_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp142_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp144_ = _data_->_tmp143_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp145_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp145_ = gvir_storage_vol_get_info (_data_->_tmp144_, &_data_->_inner_error_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->volume_info = _data_->_tmp145_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4231 "wizard.c"
						goto __catch119_g_error;
					}
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp146_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp146_ = _data_->volume_info;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = 0ULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp147_ = _data_->_tmp146_->capacity;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp148_ = NULL;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp148_ = g_format_size_full (_data_->_tmp147_, G_FORMAT_SIZE_DEFAULT);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->capacity = _data_->_tmp148_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp149_ = _data_->self->priv->summary;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp150_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp150_ = _ ("Disk");
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp151_ = _data_->capacity;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp152_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp152_ = g_strdup_printf ("%s maximum", _data_->_tmp151_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp153_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp153_ = _data_->_tmp152_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp154_ = NULL;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp154_ = _ (_data_->_tmp153_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					boxes_wizard_summary_add_property (_data_->_tmp149_, _data_->_tmp150_, _data_->_tmp154_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->_tmp153_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_free0 (_data_->capacity);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					__vala_GVirStorageVolInfo_free0 (_data_->volume_info);
#line 4280 "wizard.c"
				}
				goto __finally119;
				__catch119_g_error:
				{
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_vala4__error_ = _data_->_inner_error_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_inner_error_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp155_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp155_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp156_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp156_ = _data_->_tmp155_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp157_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp157_ = boxes_libvirt_machine_get_storage_volume (_data_->_tmp156_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp158_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp158_ = _data_->_tmp157_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp159_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp159_ = gvir_storage_vol_get_name (_data_->_tmp158_);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp160_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp160_ = _data_->_vala4__error_;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp161_ = NULL;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_data_->_tmp161_ = _data_->_tmp160_->message;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_warning ("wizard.vala:475: Failed to get information on volume '%s': %s", _data_->_tmp159_, _data_->_tmp161_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_g_error_free0 (_data_->_vala4__error_);
#line 4321 "wizard.c"
				}
				__finally119:
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					g_clear_error (&_data_->_inner_error_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					return FALSE;
#line 4332 "wizard.c"
				}
			}
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp162_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp162_ = _data_->self->priv->nokvm_infobar;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp163_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp163_ = boxes_wizard_get_libvirt_machine (_data_->self);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp164_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp164_ = _data_->_tmp163_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp165_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp165_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp164_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp166_ = NULL;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp166_ = _data_->_tmp165_;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp167_ = 0;
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp167_ = gvir_config_domain_get_virt_type (_data_->_tmp166_);
#line 481 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _data_->_tmp162_, _data_->_tmp167_ != GVIR_CONFIG_DOMAIN_VIRT_KVM);
#line 4361 "wizard.c"
		} else {
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp168_ = NULL;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp168_ = _data_->self->priv->wizard_source;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp169_ = FALSE;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_data_->_tmp169_ = _data_->_tmp168_->libvirt_sys_import;
#line 482 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_data_->_tmp169_) {
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp170_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp170_ = _data_->self->priv->review_label;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp171_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp171_ = _data_->self->priv->wizard_source;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp172_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp172_ = boxes_wizard_source_get_libvirt_sys_importer (_data_->_tmp171_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp173_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp173_ = _data_->_tmp172_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp174_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp174_ = boxes_libvirt_system_importer_get_wizard_review_label (_data_->_tmp173_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp175_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp175_ = _data_->_tmp174_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp176_ = NULL;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_data_->_tmp176_ = _data_->_tmp175_;
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_label_set_text (_data_->_tmp170_, _data_->_tmp176_);
#line 483 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_free0 (_data_->_tmp176_);
#line 4405 "wizard.c"
			}
		}
	}
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp177_ = NULL;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->_tmp177_ = _data_->self->priv->_machine;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_tmp177_ != NULL) {
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp178_ = NULL;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data_->_tmp178_ = _data_->self->priv->summary;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_summary_append_customize_button (_data_->_tmp178_, ____lambda117__boxes_wizard_summary_customize_func, _data_->self);
#line 4421 "wizard.c"
	}
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data_->result = TRUE;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4429 "wizard.c"
	} else {
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4433 "wizard.c"
	}
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_data_->_state_ == 0) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4443 "wizard.c"
	} else {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4447 "wizard.c"
	}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (_data_->_async_result);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return FALSE;
#line 4453 "wizard.c"
}


static gboolean boxes_wizard_skip_page (BoxesWizard* self, BoxesWizardPage page) {
	gboolean result = FALSE;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage skip_to = 0;
	BoxesWizardPage _tmp3_ = 0;
	gboolean _tmp4_ = FALSE;
	BoxesCollectionSource* _tmp5_ = NULL;
	gboolean _tmp12_ = FALSE;
	gboolean _tmp13_ = FALSE;
	BoxesVMCreator* _tmp16_ = NULL;
	BoxesWizardPage _tmp52_ = 0;
	BoxesWizardPage _tmp53_ = 0;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = page;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_get_page (self);
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_;
#line 498 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	forwards = _tmp0_ > _tmp2_;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = page;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	skip_to = _tmp3_;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->source;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp5_ != NULL) {
#line 4490 "wizard.c"
		BoxesWizardPage _tmp6_ = 0;
		BoxesWizardPage _tmp7_ = 0;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = page;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = (BOXES_WIZARD_PAGE_SOURCE < _tmp7_) && (_tmp7_ < BOXES_WIZARD_PAGE_REVIEW);
#line 4499 "wizard.c"
	} else {
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = FALSE;
#line 4503 "wizard.c"
	}
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp4_) {
#line 4507 "wizard.c"
		BoxesWizardPage _tmp8_ = 0;
		gboolean _tmp9_ = FALSE;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp9_ = forwards;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp9_) {
#line 4514 "wizard.c"
			BoxesWizardPage _tmp10_ = 0;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = page;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = _tmp10_ + 1;
#line 4520 "wizard.c"
		} else {
			BoxesWizardPage _tmp11_ = 0;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = page;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = _tmp11_ - 1;
#line 4527 "wizard.c"
		}
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		skip_to = _tmp8_;
#line 4531 "wizard.c"
	}
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = forwards;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (!_tmp13_) {
#line 4537 "wizard.c"
		BoxesWizardPage _tmp14_ = 0;
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp14_ = page;
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = _tmp14_ == BOXES_WIZARD_PAGE_PREPARATION;
#line 4543 "wizard.c"
	} else {
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp12_ = FALSE;
#line 4547 "wizard.c"
	}
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp12_) {
#line 4551 "wizard.c"
		BoxesWizardPage _tmp15_ = 0;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp15_ = page;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		skip_to = _tmp15_ - 1;
#line 4557 "wizard.c"
	}
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = self->priv->vm_creator;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp16_ != NULL) {
#line 4563 "wizard.c"
		gboolean _tmp17_ = FALSE;
		BoxesWizardPage _tmp18_ = 0;
		gboolean _tmp28_ = FALSE;
		gboolean _tmp29_ = FALSE;
		gboolean _tmp30_ = FALSE;
		BoxesWizardPage _tmp31_ = 0;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp18_ = page;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp18_ == BOXES_WIZARD_PAGE_SETUP) {
#line 4574 "wizard.c"
			BoxesVMCreator* _tmp19_ = NULL;
			BoxesInstallerMedia* _tmp20_ = NULL;
			BoxesInstallerMedia* _tmp21_ = NULL;
			gboolean _tmp22_ = FALSE;
			gboolean _tmp23_ = FALSE;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp19_ = self->priv->vm_creator;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp20_ = boxes_vm_creator_get_install_media (_tmp19_);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp21_ = _tmp20_;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp22_ = boxes_installer_media_get_need_user_input_for_vm_creation (_tmp21_);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp23_ = _tmp22_;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = !_tmp23_;
#line 4592 "wizard.c"
		} else {
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp17_ = FALSE;
#line 4596 "wizard.c"
		}
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp17_) {
#line 4600 "wizard.c"
			BoxesWizardPage _tmp24_ = 0;
			gboolean _tmp25_ = FALSE;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp25_ = forwards;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp25_) {
#line 4607 "wizard.c"
				BoxesWizardPage _tmp26_ = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp26_ = page;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = _tmp26_ + 1;
#line 4613 "wizard.c"
			} else {
				BoxesWizardPage _tmp27_ = 0;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp27_ = page;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = _tmp27_ - 1;
#line 4620 "wizard.c"
			}
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			skip_to = _tmp24_;
#line 4624 "wizard.c"
		}
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp31_ = page;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp31_ == BOXES_WIZARD_PAGE_REVIEW) {
#line 4630 "wizard.c"
			gboolean _tmp32_ = FALSE;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp32_ = forwards;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp30_ = _tmp32_;
#line 4636 "wizard.c"
		} else {
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp30_ = FALSE;
#line 4640 "wizard.c"
		}
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp30_) {
#line 4644 "wizard.c"
			BoxesVMCreator* _tmp33_ = NULL;
			BoxesInstallerMedia* _tmp34_ = NULL;
			BoxesInstallerMedia* _tmp35_ = NULL;
			gboolean _tmp36_ = FALSE;
			gboolean _tmp37_ = FALSE;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp33_ = self->priv->vm_creator;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp34_ = boxes_vm_creator_get_install_media (_tmp33_);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp35_ = _tmp34_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp36_ = boxes_installer_media_get_live (_tmp35_);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp37_ = _tmp36_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp29_ = _tmp37_;
#line 4662 "wizard.c"
		} else {
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp29_ = FALSE;
#line 4666 "wizard.c"
		}
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp29_) {
#line 4670 "wizard.c"
			gboolean _tmp38_ = FALSE;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp38_ = self->priv->skip_review_for_live;
#line 520 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp28_ = _tmp38_;
#line 4676 "wizard.c"
		} else {
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp28_ = FALSE;
#line 4680 "wizard.c"
		}
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp28_) {
#line 4684 "wizard.c"
			BoxesWizardPage _tmp39_ = 0;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp39_ = skip_to;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			skip_to = _tmp39_ + 1;
#line 4690 "wizard.c"
		}
	} else {
		BoxesWizardSource* _tmp40_ = NULL;
		gboolean _tmp41_ = FALSE;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp40_ = self->priv->wizard_source;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp41_ = _tmp40_->libvirt_sys_import;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp41_) {
#line 4701 "wizard.c"
			BoxesWizardPage _tmp42_ = 0;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp42_ = page;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			if (_tmp42_ == BOXES_WIZARD_PAGE_PREPARATION) {
#line 4707 "wizard.c"
				BoxesWizardPage _tmp43_ = 0;
				gboolean _tmp44_ = FALSE;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp44_ = forwards;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp44_) {
#line 4714 "wizard.c"
					BoxesWizardPage _tmp45_ = 0;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp45_ = page;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp45_ + 2;
#line 4720 "wizard.c"
				} else {
					BoxesWizardPage _tmp46_ = 0;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp46_ = page;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp43_ = _tmp46_ - 1;
#line 4727 "wizard.c"
				}
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				skip_to = _tmp43_;
#line 4731 "wizard.c"
			} else {
				BoxesWizardPage _tmp47_ = 0;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp47_ = page;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (_tmp47_ == BOXES_WIZARD_PAGE_SETUP) {
#line 4738 "wizard.c"
					BoxesWizardPage _tmp48_ = 0;
					gboolean _tmp49_ = FALSE;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					_tmp49_ = forwards;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					if (_tmp49_) {
#line 4745 "wizard.c"
						BoxesWizardPage _tmp50_ = 0;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp50_ = page;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp48_ = _tmp50_ + 1;
#line 4751 "wizard.c"
					} else {
						BoxesWizardPage _tmp51_ = 0;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp51_ = page;
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
						_tmp48_ = _tmp51_ - 2;
#line 4758 "wizard.c"
					}
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					skip_to = _tmp48_;
#line 4762 "wizard.c"
				}
			}
		}
	}
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp52_ = skip_to;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp53_ = page;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp52_ != _tmp53_) {
#line 4773 "wizard.c"
		BoxesWizardPage _tmp54_ = 0;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp54_ = skip_to;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp54_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		result = TRUE;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return result;
#line 4783 "wizard.c"
	}
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = FALSE;
#line 534 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 4789 "wizard.c"
}


static void __lambda121_ (BoxesWizard* self) {
	BoxesWizardSource* _tmp0_ = NULL;
	BoxesApp* _tmp1_ = NULL;
#line 540 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_cleanup (self);
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->wizard_source;
#line 541 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp0_, BOXES_SOURCE_PAGE_MAIN);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_app_app;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp1_, BOXES_UI_STATE_COLLECTION);
#line 4806 "wizard.c"
}


static void ___lambda121__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda121_ ((BoxesWizard*) self);
#line 4813 "wizard.c"
}


static void __lambda122_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 546 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ - 1);
#line 4826 "wizard.c"
}


static void ___lambda122__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda122_ ((BoxesWizard*) self);
#line 4833 "wizard.c"
}


static void __lambda123_ (BoxesWizard* self) {
	BoxesWizardPage _tmp0_ = 0;
	BoxesWizardPage _tmp1_ = 0;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_wizard_get_page (self);
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 550 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, _tmp1_ + 1);
#line 4846 "wizard.c"
}


static void ___lambda123__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda123_ ((BoxesWizard*) self);
#line 4853 "wizard.c"
}


static void __lambda124_ (BoxesWizard* self) {
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_LAST);
#line 4860 "wizard.c"
}


static void ___lambda124__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda124_ ((BoxesWizard*) self);
#line 4867 "wizard.c"
}


void boxes_wizard_setup_ui (BoxesWizard* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesTopbar* _tmp1_ = NULL;
	BoxesWizardToolbar* _tmp2_ = NULL;
	GtkButton* _tmp3_ = NULL;
	GtkButton* _tmp4_ = NULL;
	GtkButton* _tmp5_ = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	BoxesTopbar* _tmp7_ = NULL;
	BoxesWizardToolbar* _tmp8_ = NULL;
	GtkButton* _tmp9_ = NULL;
	GtkButton* _tmp10_ = NULL;
	GtkButton* _tmp11_ = NULL;
	BoxesAppWindow* _tmp12_ = NULL;
	BoxesTopbar* _tmp13_ = NULL;
	BoxesWizardToolbar* _tmp14_ = NULL;
	GtkButton* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	BoxesAppWindow* _tmp18_ = NULL;
	BoxesTopbar* _tmp19_ = NULL;
	BoxesWizardToolbar* _tmp20_ = NULL;
	GtkButton* _tmp21_ = NULL;
	GtkButton* _tmp22_ = NULL;
	GtkButton* _tmp23_ = NULL;
#line 537 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_app_window;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_->topbar;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _tmp1_->wizard_toolbar;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = _tmp2_->cancel_btn;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->cancel_button = _tmp4_;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->cancel_button;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp5_, "clicked", (GCallback) ___lambda121__gtk_button_clicked, self, 0);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = boxes_app_window;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = _tmp6_->topbar;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = _tmp7_->wizard_toolbar;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = _tmp8_->back_btn;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->back_button = _tmp10_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = self->priv->back_button;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp11_, "clicked", (GCallback) ___lambda122__gtk_button_clicked, self, 0);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = boxes_app_window;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = _tmp12_->topbar;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = _tmp13_->wizard_toolbar;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = _tmp14_->continue_btn;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->continue_button = _tmp16_;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = self->priv->continue_button;
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp17_, "clicked", (GCallback) ___lambda123__gtk_button_clicked, self, 0);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp18_ = boxes_app_window;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp19_ = _tmp18_->topbar;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp20_ = _tmp19_->wizard_toolbar;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp21_ = _tmp20_->create_btn;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp22_ = _g_object_ref0 (_tmp21_);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->create_button = _tmp22_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp23_ = self->priv->create_button;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp23_, "clicked", (GCallback) ___lambda124__gtk_button_clicked, self, 0);
#line 4970 "wizard.c"
}


void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live) {
	BoxesApp* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesWizardSource* _tmp2_ = NULL;
	BoxesWizardSource* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 558 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (uri != NULL);
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_app_app;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = skip_review_for_live;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->skip_review_for_live = _tmp1_;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_SOURCE);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_page (_tmp2_, BOXES_SOURCE_PAGE_URL);
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = uri;
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_source_set_uri (_tmp3_, _tmp4_);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 5006 "wizard.c"
}


static void boxes_wizard_ui_state_changed (BoxesWizard* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _tmp0_;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ == BOXES_UI_STATE_WIZARD) {
#line 5021 "wizard.c"
		BoxesUIState _tmp2_ = 0;
		BoxesUIState _tmp3_ = 0;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_ui_get_previous_ui_state ((BoxesUI*) self);
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = _tmp2_;
#line 570 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		if (_tmp3_ == BOXES_UI_STATE_PROPERTIES) {
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_review (self, NULL, NULL);
#line 5032 "wizard.c"
		} else {
			BoxesWizardSource* _tmp4_ = NULL;
			BoxesWizardSource* _tmp5_ = NULL;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp4_ = self->priv->wizard_source;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_uri (_tmp4_, "");
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp5_ = self->priv->wizard_source;
#line 574 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp5_->libvirt_sys_import = FALSE;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_INTRODUCTION);
#line 5046 "wizard.c"
		}
	}
}


static void boxes_wizard_destroy_machine (BoxesWizard* self) {
	GCancellable* _tmp0_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
#line 580 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->review_cancellable;
#line 581 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ != NULL) {
#line 5061 "wizard.c"
		GCancellable* _tmp1_ = NULL;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp1_ = self->priv->review_cancellable;
#line 582 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_cancellable_cancel (_tmp1_);
#line 5067 "wizard.c"
	}
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->_machine;
#line 584 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp2_ != NULL) {
#line 5073 "wizard.c"
		BoxesApp* _tmp3_ = NULL;
		BoxesMachine* _tmp4_ = NULL;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_app_app;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = self->priv->_machine;
#line 585 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_app_delete_machine (_tmp3_, _tmp4_, TRUE);
#line 586 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, NULL);
#line 5084 "wizard.c"
	}
}


BoxesWizard* boxes_wizard_construct (GType object_type) {
	BoxesWizard * self = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) g_object_new (object_type, NULL);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self;
#line 5095 "wizard.c"
}


BoxesWizard* boxes_wizard_new (void) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return boxes_wizard_construct (BOXES_TYPE_WIZARD);
#line 5102 "wizard.c"
}


static BoxesUIState boxes_wizard_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5118 "wizard.c"
}


static void boxes_wizard_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 5133 "wizard.c"
}


static BoxesUIState boxes_wizard_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_ui_state;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5149 "wizard.c"
}


static void boxes_wizard_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesWizard* self;
	BoxesUIState _tmp0_ = 0;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizard*) base;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_ui_state = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 5164 "wizard.c"
}


BoxesMachine* boxes_wizard_get_machine (BoxesWizard* self) {
	BoxesMachine* result;
	BoxesMachine* _tmp0_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5179 "wizard.c"
}


void boxes_wizard_set_machine (BoxesWizard* self, BoxesMachine* value) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_machine = _tmp1_;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "machine");
#line 5198 "wizard.c"
}


static BoxesLibvirtMachine* boxes_wizard_get_libvirt_machine (BoxesWizard* self) {
	BoxesLibvirtMachine* result;
	BoxesMachine* _tmp0_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_machine;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp0_) : NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5213 "wizard.c"
}


BoxesWizardPage boxes_wizard_get_page (BoxesWizard* self) {
	BoxesWizardPage result;
	BoxesWizardPage _tmp0_ = 0;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->_page;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	result = _tmp0_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return result;
#line 5228 "wizard.c"
}


static void _boxes_wizard_page_____lambda118_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GtkButton* _tmp0_ = NULL;
	GtkButton* _tmp1_ = NULL;
	GAsyncResult* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->next_button;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, TRUE);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->create_button;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _result_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_review_finish (self, _tmp2_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (!_tmp3_) {
#line 5253 "wizard.c"
		BoxesWizardPage _tmp4_ = 0;
		BoxesWizardPage _tmp5_ = 0;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = boxes_wizard_get_page (self);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _tmp4_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, _tmp5_ - 1);
#line 5262 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda118__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda118_ ((BoxesWizard*) self, source_object, res);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 5272 "wizard.c"
}


static void _boxes_wizard_page_____lambda120_ (BoxesWizard* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (_result_ != NULL);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _result_;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = boxes_wizard_create_finish (self, _tmp0_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_) {
#line 5287 "wizard.c"
		BoxesApp* _tmp2_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp2_ = boxes_app_app;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp2_, BOXES_UI_STATE_COLLECTION);
#line 5293 "wizard.c"
	} else {
		BoxesAppWindow* _tmp3_ = NULL;
		BoxesNotificationbar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GdNotification* _tmp6_ = NULL;
		GdNotification* _tmp7_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp3_ = boxes_app_window;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp4_ = _tmp3_->notificationbar;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp5_ = _ ("Box creation failed");
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp6_ = boxes_notificationbar_display_error (_tmp4_, _tmp5_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp7_ = _tmp6_;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (_tmp7_);
#line 5312 "wizard.c"
	}
}


static void __boxes_wizard_page_____lambda120__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard_page_____lambda120_ ((BoxesWizard*) self, source_object, res);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_unref (self);
#line 5322 "wizard.c"
}


static void boxes_wizard_set_page (BoxesWizard* self, BoxesWizardPage value) {
	GtkButton* _tmp0_ = NULL;
	BoxesWizardPage _tmp1_ = 0;
	gboolean forwards = FALSE;
	BoxesWizardPage _tmp2_ = 0;
	BoxesWizardPage _tmp3_ = 0;
	BoxesWizardPage _tmp4_ = 0;
	BoxesWizardPage _tmp5_ = 0;
	gboolean _tmp16_ = FALSE;
	BoxesWizardPage _tmp32_ = 0;
	gboolean _tmp33_ = FALSE;
	BoxesWizardPage _tmp34_ = 0;
	BoxesAppWindow* _tmp35_ = NULL;
	BoxesSidebar* _tmp36_ = NULL;
	BoxesWizardPage _tmp37_ = 0;
	BoxesWizardPage _tmp38_ = 0;
	const gchar* _tmp39_ = NULL;
	BoxesWizardPage _tmp40_ = 0;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = self->priv->back_button;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = value;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp1_ != BOXES_WIZARD_PAGE_INTRODUCTION);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = value;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = boxes_wizard_get_page (self);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	forwards = _tmp2_ > _tmp4_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = value;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (_tmp5_) {
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_INTRODUCTION:
#line 5366 "wizard.c"
		{
			GtkButton* _tmp6_ = NULL;
			GtkButton* _tmp7_ = NULL;
			GtkButton* _tmp8_ = NULL;
			GtkButton* _tmp9_ = NULL;
			GtkButton* _tmp10_ = NULL;
			GtkButton* _tmp11_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp6_ = self->priv->create_button;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp6_, FALSE);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp7_ = self->priv->continue_button;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_visible ((GtkWidget*) _tmp7_, TRUE);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp8_ = self->priv->continue_button;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp9_ = _g_object_ref0 (_tmp8_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_g_object_unref0 (self->priv->next_button);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			self->priv->next_button = _tmp9_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp10_ = self->priv->next_button;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, TRUE);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp11_ = self->priv->next_button;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp11_);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5400 "wizard.c"
		}
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE_SOURCE:
#line 5404 "wizard.c"
		{
			BoxesWizardSource* _tmp12_ = NULL;
			BoxesWizardSource* _tmp13_ = NULL;
			BoxesSourcePage _tmp14_ = 0;
			BoxesSourcePage _tmp15_ = 0;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp12_ = self->priv->wizard_source;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp13_ = self->priv->wizard_source;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp14_ = boxes_wizard_source_get_page (_tmp13_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			_tmp15_ = _tmp14_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_source_set_page (_tmp12_, _tmp15_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			boxes_wizard_cleanup (self);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5424 "wizard.c"
		}
		default:
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 5429 "wizard.c"
	}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = forwards;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp16_) {
#line 5435 "wizard.c"
		BoxesWizardPage _tmp17_ = 0;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp17_ = value;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		switch (_tmp17_) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SOURCE:
#line 5443 "wizard.c"
			{
				BoxesWizardSource* _tmp18_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp18_ = self->priv->wizard_source;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_source_set_page (_tmp18_, BOXES_SOURCE_PAGE_MAIN);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5452 "wizard.c"
			}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_PREPARATION:
#line 5456 "wizard.c"
			{
				gboolean _tmp19_ = FALSE;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp19_ = boxes_wizard_prepare (self);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!_tmp19_) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					return;
#line 5465 "wizard.c"
				}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5469 "wizard.c"
			}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_SETUP:
#line 5473 "wizard.c"
			{
				gboolean _tmp20_ = FALSE;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp20_ = boxes_wizard_setup (self);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				if (!_tmp20_) {
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
					return;
#line 5482 "wizard.c"
				}
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5486 "wizard.c"
			}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 5490 "wizard.c"
			{
				GtkButton* _tmp21_ = NULL;
				GtkButton* _tmp22_ = NULL;
				GtkButton* _tmp23_ = NULL;
				GtkButton* _tmp24_ = NULL;
				GtkButton* _tmp25_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp21_ = self->priv->continue_button;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp21_, FALSE);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp22_ = self->priv->create_button;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp22_, TRUE);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp23_ = self->priv->create_button;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp24_ = _g_object_ref0 (_tmp23_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp24_;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp25_ = self->priv->next_button;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_sensitive ((GtkWidget*) _tmp25_, FALSE);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_review (self, __boxes_wizard_page_____lambda118__gasync_ready_callback, g_object_ref (self));
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5521 "wizard.c"
			}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_LAST:
#line 5525 "wizard.c"
			{
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_create (self, __boxes_wizard_page_____lambda120__gasync_ready_callback, g_object_ref (self));
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				return;
#line 5531 "wizard.c"
			}
			default:
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5536 "wizard.c"
		}
	} else {
		BoxesWizardPage _tmp26_ = 0;
		BoxesWizardPage _tmp27_ = 0;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp26_ = boxes_wizard_get_page (self);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_tmp27_ = _tmp26_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		switch (_tmp27_) {
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			case BOXES_WIZARD_PAGE_REVIEW:
#line 5549 "wizard.c"
			{
				GtkButton* _tmp28_ = NULL;
				GtkButton* _tmp29_ = NULL;
				GtkButton* _tmp30_ = NULL;
				GtkButton* _tmp31_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp28_ = self->priv->create_button;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp28_, FALSE);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp29_ = self->priv->continue_button;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_widget_set_visible ((GtkWidget*) _tmp29_, TRUE);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp30_ = self->priv->continue_button;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp31_ = _g_object_ref0 (_tmp30_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_g_object_unref0 (self->priv->next_button);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				self->priv->next_button = _tmp31_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				boxes_wizard_destroy_machine (self);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				break;
#line 5575 "wizard.c"
			}
			default:
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			break;
#line 5580 "wizard.c"
		}
	}
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp32_ = value;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp33_ = boxes_wizard_skip_page (self, _tmp32_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp33_) {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 5591 "wizard.c"
	}
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp34_ = value;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->_page = _tmp34_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp35_ = boxes_app_window;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp36_ = _tmp35_->sidebar;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp37_ = value;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_sidebar_set_wizard_page (_tmp36_, _tmp37_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp38_ = value;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp39_ = BOXES_WIZARD_page_names[_tmp38_];
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp39_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp40_ = value;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp40_ == BOXES_WIZARD_PAGE_SOURCE) {
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_wizard_source_update_next (self);
#line 5617 "wizard.c"
	}
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_notify ((GObject *) self, "page");
#line 5621 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next ((BoxesWizard*) self);
#line 5628 "wizard.c"
}


static void _boxes_wizard_wizard_source_update_next_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_wizard_source_update_next ((BoxesWizard*) self);
#line 5635 "wizard.c"
}


static void _boxes_wizard_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_ui_state_changed ((BoxesWizard*) self);
#line 5642 "wizard.c"
}


static void _boxes_wizard___lambda125_ (BoxesWizard* self) {
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_set_page (self, BOXES_WIZARD_PAGE_PREPARATION);
#line 5649 "wizard.c"
}


static void __boxes_wizard___lambda125__boxes_wizard_source_activated (BoxesWizardSource* _sender, gpointer self) {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_wizard___lambda125_ ((BoxesWizard*) self);
#line 5656 "wizard.c"
}


static GObject * boxes_wizard_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizard * self;
	BoxesMediaManager* _tmp0_ = NULL;
	BoxesWizardSource* _tmp1_ = NULL;
	BoxesWizardSource* _tmp2_ = NULL;
	BoxesWizardSource* _tmp3_ = NULL;
	GtkEntry* _tmp4_ = NULL;
	BoxesWizardSource* _tmp5_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_parent_class);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = boxes_media_manager_get_instance ();
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->media_manager = _tmp0_;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->wizard_source;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::page", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = self->priv->wizard_source;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) _tmp2_, "notify::selected", (GCallback) _boxes_wizard_wizard_source_update_next_g_object_notify, self, 0);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = self->priv->wizard_source;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = _tmp3_->url_entry;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GtkEditable*) _tmp4_, "changed", (GCallback) _boxes_wizard_wizard_source_update_next_gtk_editable_changed, self, 0);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_wizard_ui_state_changed_g_object_notify, self, 0);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = self->priv->wizard_source;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_object (_tmp5_, "activated", (GCallback) __boxes_wizard___lambda125__boxes_wizard_source_activated, self, 0);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return obj;
#line 5706 "wizard.c"
}


static void boxes_wizard_class_init (BoxesWizardClass * klass) {
	gint BoxesWizard_private_offset;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_parent_class = g_type_class_peek_parent (klass);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardPrivate));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_get_property;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_set_property;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_constructor;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_finalize;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_MACHINE, g_param_spec_object ("machine", "machine", "machine", BOXES_TYPE_MACHINE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_WIZARD_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	BoxesWizard_private_offset = g_type_class_get_instance_private_offset (klass);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard.ui");
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "wizard_source", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, wizard_source));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "summary", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, summary));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_progress", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_progress));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_media_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_media_label));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "prep_status_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, prep_status_label));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "setup_box", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, setup_box));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "review_label", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, review_label));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "nokvm_infobar", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, nokvm_infobar));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "installer_image", FALSE, BoxesWizard_private_offset + G_STRUCT_OFFSET (BoxesWizardPrivate, installer_image));
#line 5754 "wizard.c"
}


static void boxes_wizard_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->get_previous_ui_state = boxes_wizard_real_get_previous_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->set_previous_ui_state = boxes_wizard_real_set_previous_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->get_ui_state = boxes_wizard_real_get_ui_state;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	iface->set_ui_state = boxes_wizard_real_set_ui_state;
#line 5769 "wizard.c"
}


static void boxes_wizard_instance_init (BoxesWizard * self) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_GET_PRIVATE (self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SUMMARY);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SOURCE);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 5782 "wizard.c"
}


static void boxes_wizard_finalize (GObject* obj) {
	BoxesWizard * self;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD, BoxesWizard);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 21 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->back_button);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->next_button);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->continue_button);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->create_button);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->source);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->wizard_source);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->summary);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_progress);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_media_label);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->prep_status_label);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->setup_box);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_label);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->nokvm_infobar);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->installer_image);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->media_manager);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_boxes_vm_creator_unref0 (self->priv->vm_creator);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->_machine);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (self->priv->review_cancellable);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_parent_class)->finalize (obj);
#line 5830 "wizard.c"
}


GType boxes_wizard_get_type (void) {
	static volatile gsize boxes_wizard_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizard), 0, (GInstanceInitFunc) boxes_wizard_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_wizard_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_wizard_type_id;
		boxes_wizard_type_id = g_type_register_static (GTK_TYPE_STACK, "BoxesWizard", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_wizard_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_wizard_type_id__volatile, boxes_wizard_type_id);
	}
	return boxes_wizard_type_id__volatile;
}


static void _vala_boxes_wizard_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PREVIOUS_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_object (value, boxes_wizard_get_machine (self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_value_set_enum (value, boxes_wizard_get_page (self));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 5877 "wizard.c"
		default:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 5883 "wizard.c"
	}
}


static void _vala_boxes_wizard_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizard * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD, BoxesWizard);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	switch (property_id) {
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PREVIOUS_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_UI_STATE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_MACHINE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_machine (self, g_value_get_object (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		case BOXES_WIZARD_PAGE:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		boxes_wizard_set_page (self, g_value_get_enum (value));
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 5917 "wizard.c"
		default:
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		break;
#line 5923 "wizard.c"
	}
}


void boxes_wizard_summary_add_property (BoxesWizardSummary* self, const gchar* name, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	GtkLabel* label_name = NULL;
	const gchar* _tmp1_ = NULL;
	GtkLabel* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	GtkStyleContext* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	GtkLabel* label_value = NULL;
	const gchar* _tmp8_ = NULL;
	GtkLabel* _tmp9_ = NULL;
	GtkLabel* _tmp10_ = NULL;
	GtkStyleContext* _tmp11_ = NULL;
	GtkLabel* _tmp12_ = NULL;
	GtkLabel* _tmp13_ = NULL;
	GtkLabel* _tmp14_ = NULL;
	GtkLabel* _tmp15_ = NULL;
	gint _tmp16_ = 0;
	gint _tmp17_ = 0;
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (name != NULL);
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = value;
#line 602 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp0_ == NULL) {
#line 603 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 5959 "wizard.c"
	}
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = name;
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = (GtkLabel*) gtk_label_new (_tmp1_);
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp2_);
#line 605 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	label_name = _tmp2_;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = label_name;
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) _tmp3_);
#line 606 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp4_, "boxes-wizard-summary-prop-name-label");
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = label_name;
#line 607 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp5_, "xalign", 1.0f, NULL);
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = label_name;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->current_row;
#line 608 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp6_, 0, _tmp7_, 1, 1);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = value;
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = (GtkLabel*) gtk_label_new (_tmp8_);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp9_);
#line 610 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	label_value = _tmp9_;
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp10_ = label_value;
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) _tmp10_);
#line 611 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp11_, "boxes-wizard-summary-prop-value-label");
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp12_ = label_value;
#line 612 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_ellipsize (_tmp12_, PANGO_ELLIPSIZE_END);
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp13_ = label_value;
#line 613 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_label_set_max_width_chars (_tmp13_, 32);
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp14_ = label_value;
#line 614 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_set ((GtkMisc*) _tmp14_, "xalign", 0.0f, NULL);
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp15_ = label_value;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp16_ = self->priv->current_row;
#line 615 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp15_, 1, _tmp16_, 1, 1);
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp17_ = self->priv->current_row;
#line 617 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = _tmp17_ + 1;
#line 618 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_value);
#line 601 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (label_name);
#line 6027 "wizard.c"
}


static Block73Data* block73_data_ref (Block73Data* _data73_) {
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_atomic_int_inc (&_data73_->_ref_count_);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return _data73_;
#line 6036 "wizard.c"
}


static void block73_data_unref (void * _userdata_) {
	Block73Data* _data73_;
	_data73_ = (Block73Data*) _userdata_;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (g_atomic_int_dec_and_test (&_data73_->_ref_count_)) {
#line 6045 "wizard.c"
		BoxesWizardSummary* self;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		self = _data73_->self;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_object_unref0 (self);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		g_slice_free (Block73Data, _data73_);
#line 6053 "wizard.c"
	}
}


static void __lambda91_ (Block73Data* _data73_) {
	BoxesWizardSummary* self;
	BoxesWizardSummaryCustomizeFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = _data73_->self;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = _data73_->customize_func;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0__target = _data73_->customize_func_target;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ (_tmp0__target);
#line 6070 "wizard.c"
}


static void ___lambda91__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	__lambda91_ (self);
#line 6077 "wizard.c"
}


void boxes_wizard_summary_append_customize_button (BoxesWizardSummary* self, BoxesWizardSummaryCustomizeFunc customize_func, void* customize_func_target) {
	Block73Data* _data73_;
	BoxesWizardSummaryCustomizeFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gint _tmp1_ = 0;
	GtkButton* button = NULL;
	const gchar* _tmp2_ = NULL;
	GtkButton* _tmp3_ = NULL;
	GtkButton* _tmp4_ = NULL;
	GtkStyleContext* _tmp5_ = NULL;
	GtkButton* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	GtkButton* _tmp8_ = NULL;
	GtkButton* _tmp9_ = NULL;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data73_ = g_slice_new0 (Block73Data);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data73_->_ref_count_ = 1;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data73_->self = g_object_ref (self);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = customize_func;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0__target = customize_func_target;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data73_->customize_func = _tmp0_;
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data73_->customize_func_target = _tmp0__target;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp1_ = self->priv->current_row;
#line 623 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	if (_tmp1_ == 0) {
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		block73_data_unref (_data73_);
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_data73_ = NULL;
#line 624 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		return;
#line 6121 "wizard.c"
	}
#line 626 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp2_ = _ ("C_ustomize...");
#line 626 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp3_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp2_);
#line 626 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_object_ref_sink (_tmp3_);
#line 626 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	button = _tmp3_;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp4_ = button;
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) _tmp4_);
#line 627 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_style_context_add_class (_tmp5_, "boxes-wizard-summary-customize-button");
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp6_ = button;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp7_ = self->priv->current_row;
#line 628 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_grid_attach ((GtkGrid*) self, (GtkWidget*) _tmp6_, 2, _tmp7_ - 1, 1, 1);
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp8_ = button;
#line 629 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_show ((GtkWidget*) _tmp8_);
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp9_ = button;
#line 631 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_signal_connect_data (_tmp9_, "clicked", (GCallback) ___lambda91__gtk_button_clicked, block73_data_ref (_data73_), (GClosureNotify) block73_data_unref, 0);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_g_object_unref0 (button);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	block73_data_unref (_data73_);
#line 621 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_data73_ = NULL;
#line 6157 "wizard.c"
}


void boxes_wizard_summary_clear (BoxesWizardSummary* self) {
	GList* _tmp0_ = NULL;
#line 634 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_return_if_fail (self != NULL);
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	_tmp0_ = gtk_container_get_children ((GtkContainer*) self);
#line 6167 "wizard.c"
	{
		GList* child_collection = NULL;
		GList* child_it = NULL;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		child_collection = _tmp0_;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		for (child_it = child_collection; child_it != NULL; child_it = child_it->next) {
#line 6175 "wizard.c"
			GtkWidget* child = NULL;
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
			child = (GtkWidget*) child_it->data;
#line 6179 "wizard.c"
			{
				GtkWidget* _tmp1_ = NULL;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				_tmp1_ = child;
#line 636 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
				gtk_container_remove ((GtkContainer*) self, _tmp1_);
#line 6186 "wizard.c"
			}
		}
#line 635 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
		_g_list_free0 (child_collection);
#line 6191 "wizard.c"
	}
#line 639 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 6195 "wizard.c"
}


BoxesWizardSummary* boxes_wizard_summary_construct (GType object_type) {
	BoxesWizardSummary * self = NULL;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = (BoxesWizardSummary*) g_object_new (object_type, NULL);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return self;
#line 6205 "wizard.c"
}


BoxesWizardSummary* boxes_wizard_summary_new (void) {
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return boxes_wizard_summary_construct (BOXES_TYPE_WIZARD_SUMMARY);
#line 6212 "wizard.c"
}


static GObject * boxes_wizard_summary_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardSummary * self;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_summary_parent_class);
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary);
#line 598 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv->current_row = 0;
#line 597 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	return obj;
#line 6230 "wizard.c"
}


static void boxes_wizard_summary_class_init (BoxesWizardSummaryClass * klass) {
	gint BoxesWizardSummary_private_offset;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	boxes_wizard_summary_parent_class = g_type_class_peek_parent (klass);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSummaryPrivate));
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_summary_constructor;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_summary_finalize;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	BoxesWizardSummary_private_offset = g_type_class_get_instance_private_offset (klass);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-summary.ui");
#line 6248 "wizard.c"
}


static void boxes_wizard_summary_instance_init (BoxesWizardSummary * self) {
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self->priv = BOXES_WIZARD_SUMMARY_GET_PRIVATE (self);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 6257 "wizard.c"
}


static void boxes_wizard_summary_finalize (GObject* obj) {
	BoxesWizardSummary * self;
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SUMMARY, BoxesWizardSummary);
#line 592 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard.vala"
	G_OBJECT_CLASS (boxes_wizard_summary_parent_class)->finalize (obj);
#line 6267 "wizard.c"
}


GType boxes_wizard_summary_get_type (void) {
	static volatile gsize boxes_wizard_summary_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_summary_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSummary), 0, (GInstanceInitFunc) boxes_wizard_summary_instance_init, NULL };
		GType boxes_wizard_summary_type_id;
		boxes_wizard_summary_type_id = g_type_register_static (GTK_TYPE_GRID, "BoxesWizardSummary", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_summary_type_id__volatile, boxes_wizard_summary_type_id);
	}
	return boxes_wizard_summary_type_id__volatile;
}



