/* libvirt-machine-properties.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from libvirt-machine-properties.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libcommon.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <config.h>
#include <pango/pango.h>
#include <osinfo/osinfo.h>


#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;

#define BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES (boxes_libvirt_machine_properties_get_type ())
#define BOXES_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_IS_LIBVIRT_MACHINE_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES))
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesClass))

typedef struct _BoxesLibvirtMachineProperties BoxesLibvirtMachineProperties;
typedef struct _BoxesLibvirtMachinePropertiesClass BoxesLibvirtMachinePropertiesClass;
typedef struct _BoxesLibvirtMachinePropertiesPrivate BoxesLibvirtMachinePropertiesPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))
#define __vala_GVirNodeInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirNodeInfo_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))

#define BOXES_TYPE_STRING_PROPERTY (boxes_string_property_get_type ())
#define BOXES_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringProperty))
#define BOXES_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))
#define BOXES_IS_STRING_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_IS_STRING_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_STRING_PROPERTY))
#define BOXES_STRING_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_STRING_PROPERTY, BoxesStringPropertyClass))

typedef struct _BoxesStringProperty BoxesStringProperty;
typedef struct _BoxesStringPropertyClass BoxesStringPropertyClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_SIZE_PROPERTY (boxes_size_property_get_type ())
#define BOXES_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizeProperty))
#define BOXES_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))
#define BOXES_IS_SIZE_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_IS_SIZE_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIZE_PROPERTY))
#define BOXES_SIZE_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIZE_PROPERTY, BoxesSizePropertyClass))

typedef struct _BoxesSizeProperty BoxesSizeProperty;
typedef struct _BoxesSizePropertyClass BoxesSizePropertyClass;
typedef struct _Block28Data Block28Data;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
typedef struct _Block29Data Block29Data;
typedef struct _Block30Data Block30Data;
typedef struct _Block31Data Block31Data;
typedef struct _Block32Data Block32Data;
typedef struct _Block33Data Block33Data;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
typedef struct _Block34Data Block34Data;
typedef struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesLibvirtMachinePropertiesGetOsForMachineData BoxesLibvirtMachinePropertiesGetOsForMachineData;
typedef struct _Block35Data Block35Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _Block36Data Block36Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _Block37Data Block37Data;
typedef struct _Block38Data Block38Data;

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

struct _BoxesLibvirtMachineProperties {
	GObject parent_instance;
	BoxesLibvirtMachinePropertiesPrivate * priv;
};

struct _BoxesLibvirtMachinePropertiesClass {
	GObjectClass parent_class;
};

struct _BoxesLibvirtMachinePropertiesPrivate {
	BoxesLibvirtMachine* machine;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block28Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	gchar* log;
	GtkDialog* dialog;
};

struct _Block29Data {
	int _ref_count_;
	Block28Data * _data28_;
	GtkFileChooserDialog* chooser;
};

struct _Block30Data {
	int _ref_count_;
	Block29Data * _data29_;
	GtkMessageDialog* m;
};

struct _Block31Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
};

struct _Block32Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
};

struct _Block33Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	GtkLabel* label;
	gboolean empty;
	GtkLabel* button_label;
	GVirConfigDomainDisk* disk_config;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _Block34Data {
	int _ref_count_;
	Block33Data * _data33_;
	GtkFileChooserDialog* dialog;
};

struct _BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* ram_property;
	BoxesSizeProperty* storage_property;
	gboolean _tmp0_;
	BoxesSizeProperty* _tmp1_;
	BoxesSizeProperty* _tmp2_;
	OsinfoOs* os;
	BoxesLibvirtMachine* _tmp3_;
	OsinfoOs* _tmp4_;
	OsinfoOs* _tmp5_;
	gchar* architecture;
	BoxesLibvirtMachine* _tmp6_;
	GVirConfigDomain* _tmp7_;
	GVirConfigDomain* _tmp8_;
	GVirConfigDomainOs* _tmp9_;
	GVirConfigDomainOs* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	OsinfoResources* resources;
	OsinfoOs* _tmp14_;
	const gchar* _tmp15_;
	OsinfoResources* _tmp16_;
	OsinfoResources* _tmp17_;
	BoxesSizeProperty* _tmp18_;
	BoxesSizeProperty* _tmp19_;
	OsinfoResources* _tmp20_;
	gint64 _tmp21_;
	gint64 _tmp22_;
	BoxesSizeProperty* _tmp23_;
	BoxesSizeProperty* _tmp24_;
	OsinfoResources* _tmp25_;
	gint64 _tmp26_;
	gint64 _tmp27_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_DB_LOADING_FAILED,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesLibvirtMachinePropertiesGetOsForMachineData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* machine;
	OsinfoOs* result;
	gchar* os_id;
	BoxesLibvirtMachine* _tmp0_;
	GVirConfigDomain* _tmp1_;
	GVirConfigDomain* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	BoxesOSDatabase* os_db;
	BoxesMediaManager* _tmp5_;
	BoxesMediaManager* _tmp6_;
	BoxesOSDatabase* _tmp7_;
	BoxesOSDatabase* _tmp8_;
	BoxesOSDatabase* _tmp9_;
	BoxesOSDatabase* _tmp10_;
	OsinfoOs* _tmp11_;
	BoxesOSDatabase* _tmp12_;
	const gchar* _tmp13_;
	OsinfoOs* _tmp14_;
	OsinfoOs* _tmp15_;
	GError* _error_;
	const gchar* _tmp16_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	GError * _inner_error_;
};

struct _Block35Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesSizeProperty* property;
};

struct _Block36Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	BoxesProperty* property;
	guint64 value;
};

struct _Block37Data {
	int _ref_count_;
	BoxesLibvirtMachineProperties* self;
	guint64 value;
};

struct _Block38Data {
	int _ref_count_;
	Block37Data * _data37_;
	guint64 size;
	GVirStoragePool* pool;
};


static gpointer boxes_libvirt_machine_properties_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;
extern BoxesApp* boxes_app_app;
static BoxesIPropertiesProviderIface* boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = NULL;

GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_properties_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachinePropertiesPrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_PROPERTIES_DUMMY_PROPERTY
};
#define BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES ((guint64) (1000 * 1000))
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine);
BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine);
static gboolean boxes_libvirt_machine_properties_try_change_name (BoxesLibvirtMachineProperties* self, const gchar* name);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
void boxes_collection_item_set_name (BoxesCollectionItem* self, const gchar* value);
static void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_remove_usb_controllers (GVirConfigDomain* domain, GError** error);
void boxes_vm_configurator_add_usb_support (GVirConfigDomain* domain);
static void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error);
void boxes_vm_configurator_add_smartcard_support (GVirConfigDomain* domain);
static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self);
GVirConnection* boxes_libvirt_machine_get_connection (BoxesLibvirtMachine* self);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
static void _vala_GVirNodeInfo_free (GVirNodeInfo* self);
const gchar* gvir_domain_state_to_string (GVirDomainState self);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
void boxes_display_collect_logs (BoxesDisplay* self, GString* builder);
static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags);
gboolean boxes_machine_is_on (BoxesMachine* self);
gboolean boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self, GError** error);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
GType boxes_string_property_get_type (void) G_GNUC_CONST;
BoxesStringProperty* boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_string_property_set_editable (BoxesStringProperty* self, gboolean value);
static gboolean ___lambda128_ (BoxesLibvirtMachineProperties* self, BoxesStringProperty* property, const gchar* name);
static gboolean ____lambda128__boxes_string_property_changed (BoxesStringProperty* _sender, const gchar* value, gpointer self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
gchar* boxes_display_get_uri (BoxesDisplay* self);
GType boxes_size_property_get_type (void) G_GNUC_CONST;
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list);
static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list);
static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
BoxesProperty* boxes_iproperties_provider_add_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, GtkWidget* widget, GtkWidget* extra_widget);
static void ___lambda133_ (BoxesLibvirtMachineProperties* self);
static Block28Data* block28_data_ref (Block28Data* _data28_);
static void block28_data_unref (void * _userdata_);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
static void __lambda134_ (Block28Data* _data28_, gint response_id);
static Block29Data* block29_data_ref (Block29Data* _data29_);
static void block29_data_unref (void * _userdata_);
static void ___lambda135_ (Block29Data* _data29_, gint response_id);
static Block30Data* block30_data_ref (Block30Data* _data30_);
static void block30_data_unref (void * _userdata_);
static void ____lambda136_ (Block30Data* _data30_);
static void _____lambda136__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ____lambda135__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ___lambda134__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ____lambda133__gtk_button_clicked (GtkButton* _sender, gpointer self);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
GVirConfigDomain* boxes_libvirt_machine_get_domain_config (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list);
static Block31Data* block31_data_ref (Block31Data* _data31_);
static void block31_data_unref (void * _userdata_);
static void ____lambda139_ (Block31Data* _data31_);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
void boxes_property_set_reboot_required (BoxesProperty* self, gboolean value);
static void _____lambda139__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block32Data* block32_data_ref (Block32Data* _data32_);
static void block32_data_unref (void * _userdata_);
static void ____lambda140_ (Block32Data* _data32_);
static void _____lambda140__gtk_button_clicked (GtkButton* _sender, gpointer self);
static Block33Data* block33_data_ref (Block33Data* _data33_);
static void block33_data_unref (void * _userdata_);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
BoxesVMCreator* boxes_libvirt_machine_get_vm_creator (BoxesLibvirtMachine* self);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
BoxesInstallerMedia* boxes_vm_creator_get_install_media (BoxesVMCreator* self);
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
gboolean boxes_unattended_setup_box_get_express_install (BoxesUnattendedSetupBox* self);
static void __lambda137_ (Block33Data* _data33_);
static Block34Data* block34_data_ref (Block34Data* _data34_);
static void block34_data_unref (void * _userdata_);
static void ___lambda138_ (Block34Data* _data34_, gint response);
static void ____lambda138__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void ___lambda137__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property);
static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_);
static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_);
static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_);
static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
OsinfoResources* boxes_os_database_get_recommended_resources_for_os (OsinfoOs* os, const gchar* architecture);
void boxes_size_property_set_recommended (BoxesSizeProperty* self, guint64 value);
static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data);
static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
GType boxes_os_database_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
BoxesMediaManager* boxes_media_manager_get_instance (void);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static Block35Data* block35_data_ref (Block35Data* _data35_);
static void block35_data_unref (void * _userdata_);
BoxesSizeProperty* boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 step, GFormatSizeFlags format_flags);
gboolean boxes_vm_configurator_is_install_config (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_live_config (GVirConfigDomain* domain);
GType boxes_app_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
void boxes_property_set_sensitive (BoxesProperty* self, gboolean value);
static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static void ___lambda130_ (Block35Data* _data35_);
static void ____lambda130__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static Block36Data* block36_data_ref (Block36Data* _data36_);
static void block36_data_unref (void * _userdata_);
static gboolean __lambda129_ (Block36Data* _data36_);
static gboolean ___lambda129__gsource_func (gpointer self);
void boxes_property_set_deferred_change (BoxesProperty* self, GSourceFunc value, gpointer value_target, GDestroyNotify value_target_destroy_notify);
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_libvirt_machine_get_storage_volume (BoxesLibvirtMachine* self);
GVirStoragePool* boxes_get_storage_pool (GVirConnection* connection);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
void boxes_property_set_defer_interval (BoxesProperty* self, guint value);
static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value);
static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self);
static Block37Data* block37_data_ref (Block37Data* _data37_);
static void block37_data_unref (void * _userdata_);
static gboolean __lambda131_ (Block37Data* _data37_);
gboolean boxes_machine_is_running (BoxesMachine* self);
GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
static Block38Data* block38_data_ref (Block38Data* _data38_);
static void block38_data_unref (void * _userdata_);
static void _____lambda132_ (Block38Data* _data38_, GObject* obj, GAsyncResult* res);
static void ______lambda132__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error);
static gboolean ___lambda131__gsource_func (gpointer self);
OsinfoResources* boxes_os_database_get_minimum_resources_for_os (OsinfoOs* os, const gchar* architecture);
OsinfoResources* boxes_os_database_get_default_resources (void);
void boxes_libvirt_machine_set_storage_volume (BoxesLibvirtMachine* self, GVirStorageVol* value);
static void boxes_libvirt_machine_properties_finalize (GObject* obj);


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_construct (GType object_type, BoxesLibvirtMachine* machine) {
	BoxesLibvirtMachineProperties * self = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) g_object_new (object_type, NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = machine;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv->machine = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self;
#line 709 "libvirt-machine-properties.c"
}


BoxesLibvirtMachineProperties* boxes_libvirt_machine_properties_new (BoxesLibvirtMachine* machine) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return boxes_libvirt_machine_properties_construct (BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, machine);
#line 716 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_try_change_name (BoxesLibvirtMachineProperties* self, const gchar* name) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 727 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		BoxesLibvirtMachine* _tmp6_ = NULL;
		GVirDomain* _tmp7_ = NULL;
		GVirDomain* _tmp8_ = NULL;
		GVirConfigDomain* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 754 "libvirt-machine-properties.c"
			goto __catch27_g_error;
		}
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = config;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = name;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_title (_tmp4_, _tmp5_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = self->priv->machine;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = config;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 777 "libvirt-machine-properties.c"
			goto __catch27_g_error;
		}
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = self->priv->machine;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = name;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_collection_item_set_name ((BoxesCollectionItem*) _tmp10_, _tmp11_);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = TRUE;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 792 "libvirt-machine-properties.c"
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		GVirDomain* _tmp13_ = NULL;
		GVirDomain* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		GError* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = gvir_domain_get_name (_tmp14_);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = name;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _error_;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _tmp17_->message;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:25: Failed to change title of box '%s'" \
" to '%s': %s", _tmp15_, _tmp16_, _tmp18_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 831 "libvirt-machine-properties.c"
	}
	__finally27:
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 840 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_try_enable_usb_redir (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_ = NULL;
	GVirConfigDomain* _tmp5_ = NULL;
	BoxesLibvirtMachine* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	GVirDomain* _tmp8_ = NULL;
	GVirConfigDomain* _tmp9_ = NULL;
	GError * _inner_error_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 875 "libvirt-machine-properties.c"
	}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_remove_usb_controllers (_tmp4_, &_inner_error_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 889 "libvirt-machine-properties.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = config;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_usb_support (_tmp5_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = self->priv->machine;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = boxes_libvirt_machine_get_domain (_tmp6_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _tmp7_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = config;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 913 "libvirt-machine-properties.c"
	}
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 917 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_try_enable_smartcard (BoxesLibvirtMachineProperties* self, GError** error) {
	GVirConfigDomain* config = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirDomain* _tmp1_ = NULL;
	GVirDomain* _tmp2_ = NULL;
	GVirConfigDomain* _tmp3_ = NULL;
	GVirConfigDomain* _tmp4_ = NULL;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	GVirDomain* _tmp6_ = NULL;
	GVirDomain* _tmp7_ = NULL;
	GVirConfigDomain* _tmp8_ = NULL;
	GError * _inner_error_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	config = _tmp3_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 951 "libvirt-machine-properties.c"
	}
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = config;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_vm_configurator_add_smartcard_support (_tmp4_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = config;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gvir_domain_set_config (_tmp7_, _tmp8_, &_inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 975 "libvirt-machine-properties.c"
	}
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (config);
#line 979 "libvirt-machine-properties.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 986 "libvirt-machine-properties.c"
}


static void _vala_GVirNodeInfo_free (GVirNodeInfo* self) {
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_node_info_get_type (), self);
#line 993 "libvirt-machine-properties.c"
}


static gchar* boxes_libvirt_machine_properties_collect_logs (BoxesLibvirtMachineProperties* self) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_ = NULL;
	GString* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
	GVirDomain* _tmp3_ = NULL;
	GVirDomain* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GString* _tmp6_ = NULL;
	BoxesLibvirtMachine* _tmp7_ = NULL;
	GVirDomain* _tmp8_ = NULL;
	GVirDomain* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	BoxesLibvirtMachine* _tmp12_ = NULL;
	GVirDomain* _tmp13_ = NULL;
	GVirDomain* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	GString* _tmp16_ = NULL;
	BoxesLibvirtMachine* _tmp43_ = NULL;
	BoxesDisplay* _tmp44_ = NULL;
	BoxesDisplay* _tmp45_ = NULL;
	GString* _tmp74_ = NULL;
	const gchar* _tmp75_ = NULL;
	gchar* _tmp76_ = NULL;
	GError * _inner_error_ = NULL;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = g_string_new ("");
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	builder = _tmp0_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = builder;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = self->priv->machine;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = boxes_libvirt_machine_get_domain (_tmp2_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _tmp3_;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp1_, "Domain: %s\n", _tmp5_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = builder;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = self->priv->machine;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = boxes_libvirt_machine_get_domain (_tmp7_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _tmp8_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_domain_get_uuid (_tmp9_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp6_, "UUID: %s\n", _tmp10_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = self->priv->machine;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = gvir_domain_get_persistent (_tmp14_);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = "yes";
#line 1066 "libvirt-machine-properties.c"
	} else {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = "no";
#line 1070 "libvirt-machine-properties.c"
	}
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp16_ = builder;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_string_append_printf (_tmp16_, "Persistent: %s\n", _tmp11_);
#line 1076 "libvirt-machine-properties.c"
	{
		GVirDomainInfo* info = NULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		GVirDomain* _tmp19_ = NULL;
		GVirDomainInfo* _tmp20_ = NULL;
		GString* _tmp21_ = NULL;
		GVirDomainInfo* _tmp22_ = NULL;
		guint64 _tmp23_ = 0ULL;
		GString* _tmp24_ = NULL;
		GVirDomainInfo* _tmp25_ = NULL;
		guint64 _tmp26_ = 0ULL;
		GVirNodeInfo* _tmp27_ = NULL;
		BoxesLibvirtMachine* _tmp28_ = NULL;
		GVirConnection* _tmp29_ = NULL;
		GVirConnection* _tmp30_ = NULL;
		GVirNodeInfo* _tmp31_ = NULL;
		GString* _tmp32_ = NULL;
		GVirNodeInfo* _tmp33_ = NULL;
		GVirNodeInfo* _tmp34_ = NULL;
		gulong _tmp35_ = 0UL;
		GString* _tmp36_ = NULL;
		GVirDomainInfo* _tmp37_ = NULL;
		guint16 _tmp38_ = 0U;
		GString* _tmp39_ = NULL;
		GVirDomainInfo* _tmp40_ = NULL;
		GVirDomainState _tmp41_ = 0;
		GEnumValue* _tmp42_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_info (_tmp19_, &_inner_error_);
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		info = _tmp20_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1117 "libvirt-machine-properties.c"
			goto __catch28_g_error;
		}
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = builder;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = info;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->cpuTime;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp21_, "Cpu time: %" G_GINT64_MODIFIER "d\n", _tmp23_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = builder;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = info;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _tmp25_->memory;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp24_, "Memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp26_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = boxes_libvirt_machine_get_connection (_tmp28_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = _tmp29_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = gvir_connection_get_node_info (_tmp30_, &_inner_error_);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = _tmp31_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirDomainInfo_free0 (info);
#line 1150 "libvirt-machine-properties.c"
			goto __catch28_g_error;
		}
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = builder;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _tmp27_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _tmp33_;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _tmp34_->memory;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp32_, "Max memory: %" G_GINT64_MODIFIER "d KiB\n", _tmp35_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp34_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = builder;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = info;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = _tmp37_->nrVirtCpu;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp36_, "CPUs: %d\n", (gint) _tmp38_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = builder;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = info;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = _tmp40_->state;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = g_enum_get_value (g_type_class_ref (gvir_domain_state_get_type ()), _tmp41_);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp39_, "State: %s\n", (_tmp42_ != NULL) ? _tmp42_->value_name : NULL);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp27_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirDomainInfo_free0 (info);
#line 1189 "libvirt-machine-properties.c"
	}
	goto __finally28;
	__catch28_g_error:
	{
		GError* e = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1201 "libvirt-machine-properties.c"
	}
	__finally28:
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1214 "libvirt-machine-properties.c"
	}
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp43_ = self->priv->machine;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp44_ = boxes_machine_get_display ((BoxesMachine*) _tmp43_);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp45_ = _tmp44_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp45_ != NULL) {
#line 1224 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp46_ = NULL;
		BoxesDisplay* _tmp47_ = NULL;
		BoxesDisplay* _tmp48_ = NULL;
		GString* _tmp49_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = self->priv->machine;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp47_ = boxes_machine_get_display ((BoxesMachine*) _tmp46_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp48_ = _tmp47_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp49_ = builder;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_display_collect_logs (_tmp48_, _tmp49_);
#line 1239 "libvirt-machine-properties.c"
	}
	{
		GVirConfigDomain* conf = NULL;
		BoxesLibvirtMachine* _tmp50_ = NULL;
		GVirDomain* _tmp51_ = NULL;
		GVirDomain* _tmp52_ = NULL;
		GVirConfigDomain* _tmp53_ = NULL;
		GString* _tmp54_ = NULL;
		GString* _tmp55_ = NULL;
		GString* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GString* _tmp59_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp50_ = self->priv->machine;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp51_ = boxes_libvirt_machine_get_domain (_tmp50_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp52_ = _tmp51_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp53_ = gvir_domain_get_config (_tmp52_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		conf = _tmp53_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1265 "libvirt-machine-properties.c"
			goto __catch29_g_error;
		}
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp54_ = builder;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp54_, "\nDomain config:\n");
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp55_ = builder;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp55_, "------------------------------------------------------------\n");
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp56_ = builder;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp57_ = gvir_config_object_to_xml ((GVirConfigObject*) conf);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _tmp57_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp56_, _tmp58_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp58_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = builder;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp59_, "%s", "\n" "------------------------------------------------------------\n");
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (conf);
#line 1292 "libvirt-machine-properties.c"
	}
	goto __finally29;
	__catch29_g_error:
	{
		GError* _error_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 1304 "libvirt-machine-properties.c"
	}
	__finally29:
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1317 "libvirt-machine-properties.c"
	}
	{
		gchar* logfile = NULL;
		const gchar* _tmp60_ = NULL;
		BoxesLibvirtMachine* _tmp61_ = NULL;
		GVirDomain* _tmp62_ = NULL;
		GVirDomain* _tmp63_ = NULL;
		const gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		gchar* data = NULL;
		gchar* _tmp69_ = NULL;
		GString* _tmp70_ = NULL;
		GString* _tmp71_ = NULL;
		GString* _tmp72_ = NULL;
		GString* _tmp73_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = g_get_user_cache_dir ();
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = self->priv->machine;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp62_ = boxes_libvirt_machine_get_domain (_tmp61_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp63_ = _tmp62_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp64_ = gvir_domain_get_name (_tmp63_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp65_ = g_strconcat (_tmp64_, ".log", NULL);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp66_ = _tmp65_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp67_ = g_build_filename (_tmp60_, "libvirt/qemu/log", _tmp66_, NULL);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp68_ = _tmp67_;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp66_);
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		logfile = _tmp68_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_file_get_contents (logfile, &_tmp69_, NULL, &_inner_error_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		data = _tmp69_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (data);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (logfile);
#line 1370 "libvirt-machine-properties.c"
			goto __catch30_g_error;
		}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp70_ = builder;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp70_, "\nQEMU log:\n");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp71_ = builder;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp71_, "------------------------------------------------------------\n");
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp72_ = builder;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append (_tmp72_, data);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp73_ = builder;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_string_append_printf (_tmp73_, "------------------------------------------------------------\n");
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (data);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (logfile);
#line 1393 "libvirt-machine-properties.c"
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* e = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 1405 "libvirt-machine-properties.c"
	}
	__finally30:
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_string_free0 (builder);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return NULL;
#line 1418 "libvirt-machine-properties.c"
	}
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp74_ = builder;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp75_ = _tmp74_->str;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp76_ = g_strdup (_tmp75_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp76_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_string_free0 (builder);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1432 "libvirt-machine-properties.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1439 "libvirt-machine-properties.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_list_free (self);
#line 1448 "libvirt-machine-properties.c"
}


static gboolean ___lambda128_ (BoxesLibvirtMachineProperties* self, BoxesStringProperty* property, const gchar* name) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (property != NULL, FALSE);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (name != NULL, FALSE);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = name;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_properties_try_change_name (self, _tmp0_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _tmp1_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1468 "libvirt-machine-properties.c"
}


static gboolean ____lambda128__boxes_string_property_changed (BoxesStringProperty* _sender, const gchar* value, gpointer self) {
	gboolean result;
	result = ___lambda128_ ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 1477 "libvirt-machine-properties.c"
}


static Block28Data* block28_data_ref (Block28Data* _data28_) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data28_->_ref_count_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data28_;
#line 1486 "libvirt-machine-properties.c"
}


static void block28_data_unref (void * _userdata_) {
	Block28Data* _data28_;
	_data28_ = (Block28Data*) _userdata_;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data28_->_ref_count_)) {
#line 1495 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data28_->self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data28_->dialog);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data28_->log);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block28Data, _data28_);
#line 1507 "libvirt-machine-properties.c"
	}
}


static Block29Data* block29_data_ref (Block29Data* _data29_) {
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data29_->_ref_count_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data29_;
#line 1517 "libvirt-machine-properties.c"
}


static void block29_data_unref (void * _userdata_) {
	Block29Data* _data29_;
	_data29_ = (Block29Data*) _userdata_;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data29_->_ref_count_)) {
#line 1526 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data29_->_data28_->self;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data29_->chooser);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block28_data_unref (_data29_->_data28_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->_data28_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block29Data, _data29_);
#line 1538 "libvirt-machine-properties.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 1546 "libvirt-machine-properties.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1300 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1301 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1301 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1301 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1302 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 1590 "libvirt-machine-properties.c"
	}
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1303 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1596 "libvirt-machine-properties.c"
}


static Block30Data* block30_data_ref (Block30Data* _data30_) {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data30_->_ref_count_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data30_;
#line 1605 "libvirt-machine-properties.c"
}


static void block30_data_unref (void * _userdata_) {
	Block30Data* _data30_;
	_data30_ = (Block30Data*) _userdata_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data30_->_ref_count_)) {
#line 1614 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data30_->_data29_->_data28_->self;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data30_->m);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block29_data_unref (_data30_->_data29_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data30_->_data29_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block30Data, _data30_);
#line 1626 "libvirt-machine-properties.c"
	}
}


static void ____lambda136_ (Block30Data* _data30_) {
	Block29Data* _data29_;
	Block28Data* _data28_;
	BoxesLibvirtMachineProperties* self;
	GtkMessageDialog* _tmp0_ = NULL;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data29_ = _data30_->_data29_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = _data29_->_data28_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data28_->self;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data30_->m;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp0_);
#line 1646 "libvirt-machine-properties.c"
}


static void _____lambda136__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda136_ (self);
#line 1653 "libvirt-machine-properties.c"
}


static void ___lambda135_ (Block29Data* _data29_, gint response_id) {
	Block28Data* _data28_;
	BoxesLibvirtMachineProperties* self;
	gint _tmp0_ = 0;
	GError * _inner_error_ = NULL;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = _data29_->_data28_;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data28_->self;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response_id;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 1670 "libvirt-machine-properties.c"
		GFile* file = NULL;
		GtkFileChooserDialog* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_ = NULL;
		GtkFileChooserDialog* _tmp17_ = NULL;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data29_->chooser;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = gtk_file_chooser_get_file ((GtkFileChooser*) _tmp1_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		file = _tmp3_;
#line 1684 "libvirt-machine-properties.c"
		{
			GFile* _tmp4_ = NULL;
			guint8* _tmp5_ = NULL;
			gint _tmp5__length1 = 0;
			guint8* _tmp6_ = NULL;
			gint _tmp6__length1 = 0;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp4_ = file;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = string_get_data (_data28_->log, &_tmp5__length1);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = _tmp5_;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6__length1 = _tmp5__length1;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_file_replace_contents (_tmp4_, _tmp6_, (gsize) _tmp6__length1, NULL, FALSE, G_FILE_CREATE_REPLACE_DESTINATION, NULL, NULL, &_inner_error_);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1703 "libvirt-machine-properties.c"
				goto __catch32_g_error;
			}
		}
		goto __finally32;
		__catch32_g_error:
		{
			GError* e = NULL;
			Block30Data* _data30_;
			GtkFileChooserDialog* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
			GError* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
			gchar* _tmp11_ = NULL;
			gchar* _tmp12_ = NULL;
			GtkMessageDialog* _tmp13_ = NULL;
			GtkMessageDialog* _tmp14_ = NULL;
			GtkMessageDialog* _tmp15_ = NULL;
			GtkMessageDialog* _tmp16_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_ = g_slice_new0 (Block30Data);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_->_ref_count_ = 1;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_->_data29_ = block29_data_ref (_data29_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _data29_->chooser;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _ ("Error saving: %s");
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = e;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _tmp9_->message;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = g_strdup_printf (_tmp8_, _tmp10_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = _tmp11_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) _tmp7_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, _tmp12_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp13_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _tmp13_;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp12_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_->m = _tmp14_;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = _data30_->m;
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_show_all ((GtkWidget*) _tmp15_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _data30_->m;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_data ((GtkDialog*) _tmp16_, "response", (GCallback) _____lambda136__gtk_dialog_response, block30_data_ref (_data30_), (GClosureNotify) block30_data_unref, 0);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block30_data_unref (_data30_);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data30_ = NULL;
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (file);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 1772 "libvirt-machine-properties.c"
		}
		__finally32:
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (file);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 1785 "libvirt-machine-properties.c"
		}
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data29_->chooser;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp17_);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (file);
#line 1793 "libvirt-machine-properties.c"
	} else {
		GtkFileChooserDialog* _tmp18_ = NULL;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = _data29_->chooser;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp18_);
#line 1800 "libvirt-machine-properties.c"
	}
}


static void ____lambda135__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda135_ (self, response_id);
#line 1808 "libvirt-machine-properties.c"
}


static void __lambda134_ (Block28Data* _data28_, gint response_id) {
	BoxesLibvirtMachineProperties* self;
	gint _tmp0_ = 0;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data28_->self;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response_id;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == 100) {
#line 1821 "libvirt-machine-properties.c"
		Block29Data* _data29_;
		const gchar* _tmp1_ = NULL;
		BoxesAppWindow* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		GtkFileChooserDialog* _tmp4_ = NULL;
		GtkFileChooserDialog* _tmp5_ = NULL;
		GtkFileChooserDialog* _tmp6_ = NULL;
		GtkFileChooserDialog* _tmp7_ = NULL;
		GtkFileChooserDialog* _tmp8_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_ = g_slice_new0 (Block29Data);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->_ref_count_ = 1;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->_data28_ = block28_data_ref (_data28_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _ ("Save log");
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_app_window;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _ ("_Save");
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp1_, (GtkWindow*) _tmp2_, GTK_FILE_CHOOSER_ACTION_SAVE, _tmp3_, GTK_RESPONSE_OK, NULL);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp4_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_->chooser = _tmp4_;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _data29_->chooser;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp5_, FALSE);
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data29_->chooser;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_do_overwrite_confirmation ((GtkFileChooser*) _tmp6_, TRUE);
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _data29_->chooser;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GtkDialog*) _tmp7_, "response", (GCallback) ____lambda135__gtk_dialog_response, block29_data_ref (_data29_), (GClosureNotify) block29_data_unref, 0);
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data29_->chooser;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp8_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block29_data_unref (_data29_);
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data29_ = NULL;
#line 1869 "libvirt-machine-properties.c"
	} else {
		gint _tmp9_ = 0;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = response_id;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ == 101) {
#line 1876 "libvirt-machine-properties.c"
			GdkDisplay* _tmp10_ = NULL;
			GtkClipboard* _tmp11_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = gtk_widget_get_display ((GtkWidget*) _data28_->dialog);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = gtk_clipboard_get_for_display (_tmp10_, GDK_SELECTION_CLIPBOARD);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_clipboard_set_text (_tmp11_, _data28_->log, -1);
#line 1885 "libvirt-machine-properties.c"
		} else {
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_destroy ((GtkWidget*) _data28_->dialog);
#line 1889 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda134__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda134_ (self, response_id);
#line 1898 "libvirt-machine-properties.c"
}


static void ___lambda133_ (BoxesLibvirtMachineProperties* self) {
	Block28Data* _data28_;
	gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	GtkDialog* _tmp6_ = NULL;
	GtkTextView* text = NULL;
	GtkTextView* _tmp7_ = NULL;
	GtkScrolledWindow* scroll = NULL;
	GtkScrolledWindow* _tmp8_ = NULL;
	GtkBox* _tmp9_ = NULL;
	GtkTextBuffer* _tmp10_ = NULL;
	GtkTextBuffer* _tmp11_ = NULL;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = g_slice_new0 (Block28Data);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->_ref_count_ = 1;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->self = g_object_ref (self);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = boxes_libvirt_machine_properties_collect_logs (self);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->log = _tmp0_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _ ("Troubleshooting log");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_app_window;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _ ("_Save");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _ ("Copy to clipboard");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = _ ("_Close");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = (GtkDialog*) gtk_dialog_new_with_buttons (_tmp1_, (GtkWindow*) _tmp2_, GTK_DIALOG_DESTROY_WITH_PARENT, _tmp3_, 100, _tmp4_, 101, _tmp5_, GTK_RESPONSE_OK, NULL);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp6_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_->dialog = _tmp6_;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_window_set_default_size ((GtkWindow*) _data28_->dialog, 640, 480);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = (GtkTextView*) gtk_text_view_new ();
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp7_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	text = _tmp7_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_text_view_set_editable (text, FALSE);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp8_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	scroll = _tmp8_;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) scroll, (GtkWidget*) text);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_set_vexpand ((GtkWidget*) scroll, TRUE);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = (GtkBox*) gtk_dialog_get_content_area (_data28_->dialog);
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp9_, (GtkWidget*) scroll);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gtk_text_view_get_buffer (text);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = _tmp10_;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_text_buffer_set_text (_tmp11_, _data28_->log, -1);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_show_all ((GtkWidget*) _data28_->dialog);
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_data28_->dialog, "response", (GCallback) ___lambda134__gtk_dialog_response, block28_data_ref (_data28_), (GClosureNotify) block28_data_unref, 0);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (scroll);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (text);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block28_data_unref (_data28_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data28_ = NULL;
#line 1986 "libvirt-machine-properties.c"
}


static void ____lambda133__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda133_ ((BoxesLibvirtMachineProperties*) self);
#line 1993 "libvirt-machine-properties.c"
}


static Block31Data* block31_data_ref (Block31Data* _data31_) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data31_->_ref_count_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data31_;
#line 2002 "libvirt-machine-properties.c"
}


static void block31_data_unref (void * _userdata_) {
	Block31Data* _data31_;
	_data31_ = (Block31Data*) _userdata_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data31_->_ref_count_)) {
#line 2011 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data31_->self;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data31_->property);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block31Data, _data31_);
#line 2021 "libvirt-machine-properties.c"
	}
}


static void ____lambda139_ (Block31Data* _data31_) {
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data31_->self;
#line 2031 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_ = NULL;
		BoxesProperty* _tmp1_ = NULL;
		BoxesProperty* _tmp2_ = NULL;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_usb_redir (self, &_inner_error_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2040 "libvirt-machine-properties.c"
			goto __catch34_g_error;
		}
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data31_->property;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data31_->property;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp2_, TRUE);
#line 2055 "libvirt-machine-properties.c"
	}
	goto __finally34;
	__catch34_g_error:
	{
		GError* _error_ = NULL;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:241: Failed to enable usb");
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 2069 "libvirt-machine-properties.c"
	}
	__finally34:
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2080 "libvirt-machine-properties.c"
	}
}


static void _____lambda139__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda139_ (self);
#line 2088 "libvirt-machine-properties.c"
}


static Block32Data* block32_data_ref (Block32Data* _data32_) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data32_->_ref_count_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data32_;
#line 2097 "libvirt-machine-properties.c"
}


static void block32_data_unref (void * _userdata_) {
	Block32Data* _data32_;
	_data32_ = (Block32Data*) _userdata_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data32_->_ref_count_)) {
#line 2106 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data32_->self;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data32_->property);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block32Data, _data32_);
#line 2116 "libvirt-machine-properties.c"
	}
}


static void ____lambda140_ (Block32Data* _data32_) {
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data32_->self;
#line 2126 "libvirt-machine-properties.c"
	{
		BoxesLibvirtMachine* _tmp0_ = NULL;
		BoxesProperty* _tmp1_ = NULL;
		BoxesProperty* _tmp2_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_try_enable_smartcard (self, &_inner_error_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2135 "libvirt-machine-properties.c"
			goto __catch35_g_error;
		}
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp0_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data32_->property;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_emit_by_name (_tmp1_, "refresh-properties");
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data32_->property;
#line 257 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp2_, TRUE);
#line 2150 "libvirt-machine-properties.c"
	}
	goto __finally35;
	__catch35_g_error:
	{
		GError* _error_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:259: Failed to enable smartcard");
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 2164 "libvirt-machine-properties.c"
	}
	__finally35:
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 2175 "libvirt-machine-properties.c"
	}
}


static void _____lambda140__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	____lambda140_ (self);
#line 2183 "libvirt-machine-properties.c"
}


static GList* boxes_libvirt_machine_properties_real_get_properties (BoxesIPropertiesProvider* base, BoxesPropertiesPage page, PropertyCreationFlag* flags) {
	BoxesLibvirtMachineProperties * self;
	GList* result = NULL;
	GList* list = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesPropertiesPage _tmp9_ = 0;
	GError * _inner_error_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = (BoxesLibvirtMachineProperties*) base;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	list = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_machine_is_on ((BoxesMachine*) _tmp1_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_) {
#line 2206 "libvirt-machine-properties.c"
		BoxesLibvirtMachine* _tmp3_ = NULL;
		BoxesDisplay* _tmp4_ = NULL;
		BoxesDisplay* _tmp5_ = NULL;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_get_display ((BoxesMachine*) _tmp3_);
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp4_;
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp5_ == NULL;
#line 2218 "libvirt-machine-properties.c"
	} else {
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = FALSE;
#line 2222 "libvirt-machine-properties.c"
	}
#line 105 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 2226 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp6_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = self->priv->machine;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_update_display (_tmp6_, &_inner_error_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2235 "libvirt-machine-properties.c"
				goto __catch31_g_error;
			}
		}
		goto __finally31;
		__catch31_g_error:
		{
			GError* e = NULL;
			GError* _tmp7_ = NULL;
			const gchar* _tmp8_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = e;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _tmp7_->message;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_warning ("libvirt-machine-properties.vala:109: %s", _tmp8_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 2257 "libvirt-machine-properties.c"
		}
		__finally31:
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__g_list_free__g_object_unref0_0 (list);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return NULL;
#line 2270 "libvirt-machine-properties.c"
		}
	}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = page;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_tmp9_) {
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 2279 "libvirt-machine-properties.c"
		{
			BoxesStringProperty* property = NULL;
			const gchar* _tmp10_ = NULL;
			BoxesLibvirtMachine* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			BoxesStringProperty* _tmp14_ = NULL;
			BoxesStringProperty* _tmp15_ = NULL;
			BoxesStringProperty* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			BoxesLibvirtMachine* _tmp18_ = NULL;
			BoxesCollectionSource* _tmp19_ = NULL;
			gchar* _tmp20_ = NULL;
			gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
			BoxesStringProperty* _tmp23_ = NULL;
			BoxesStringProperty* _tmp24_ = NULL;
			BoxesLibvirtMachine* _tmp25_ = NULL;
			BoxesDisplay* _tmp26_ = NULL;
			BoxesDisplay* _tmp27_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _ ("Name");
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = self->priv->machine;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp11_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = _tmp12_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp10_, _tmp13_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			property = _tmp14_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = property;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_string_property_set_editable (_tmp15_, TRUE);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = property;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp16_, "changed", (GCallback) ____lambda128__boxes_string_property_changed, self, 0);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _ ("Virtualizer");
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = self->priv->machine;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = ((BoxesMachine*) _tmp18_)->source;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = boxes_collection_source_get_uri (_tmp19_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = _tmp20_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _tmp21_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp17_, _tmp22_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp24_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp22_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = self->priv->machine;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = boxes_machine_get_display ((BoxesMachine*) _tmp25_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = _tmp26_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp27_ != NULL) {
#line 2348 "libvirt-machine-properties.c"
				const gchar* _tmp28_ = NULL;
				BoxesLibvirtMachine* _tmp29_ = NULL;
				BoxesDisplay* _tmp30_ = NULL;
				BoxesDisplay* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
				gchar* _tmp33_ = NULL;
				gchar* _tmp34_ = NULL;
				BoxesStringProperty* _tmp35_ = NULL;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp28_ = _ ("URI");
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp29_ = self->priv->machine;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp30_ = boxes_machine_get_display ((BoxesMachine*) _tmp29_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp31_ = _tmp30_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp32_ = boxes_display_get_uri (_tmp31_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp33_ = _tmp32_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp34_ = _tmp33_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp35_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp28_, _tmp34_);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (property);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				property = _tmp35_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_free0 (_tmp34_);
#line 2379 "libvirt-machine-properties.c"
			}
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (property);
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2385 "libvirt-machine-properties.c"
		}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 2389 "libvirt-machine-properties.c"
		{
			BoxesSizeProperty* ram_property = NULL;
			BoxesSizeProperty* _tmp36_ = NULL;
			BoxesSizeProperty* storage_property = NULL;
			BoxesSizeProperty* _tmp37_ = NULL;
			BoxesSizeProperty* _tmp38_ = NULL;
			BoxesSizeProperty* _tmp39_ = NULL;
			GtkButton* button = NULL;
			const gchar* _tmp40_ = NULL;
			GtkButton* _tmp41_ = NULL;
			GtkButton* _tmp42_ = NULL;
			GtkButton* _tmp43_ = NULL;
			BoxesProperty* _tmp44_ = NULL;
			BoxesProperty* _tmp45_ = NULL;
			GtkButton* _tmp46_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = boxes_libvirt_machine_properties_add_ram_property (self, &list);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			ram_property = _tmp36_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = boxes_libvirt_machine_properties_add_storage_property (self, &list);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			storage_property = _tmp37_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = ram_property;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = storage_property;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_mark_recommended_resources (self, _tmp38_, _tmp39_, NULL, NULL);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = _ ("Troubleshooting log");
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = (GtkButton*) gtk_button_new_with_label (_tmp40_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_ref_sink (_tmp41_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			button = _tmp41_;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = button;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_widget_set_halign ((GtkWidget*) _tmp42_, GTK_ALIGN_START);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp43_ = button;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp44_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, NULL, (GtkWidget*) _tmp43_, NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp45_ = _tmp44_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp45_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp46_ = button;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp46_, "clicked", (GCallback) ____lambda133__gtk_button_clicked, self, 0);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (button);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (storage_property);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (ram_property);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2451 "libvirt-machine-properties.c"
		}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 2455 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp47_ = NULL;
			BoxesDisplay* _tmp48_ = NULL;
			BoxesDisplay* _tmp49_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = self->priv->machine;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = boxes_machine_get_display ((BoxesMachine*) _tmp47_);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = _tmp48_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp49_ != NULL) {
#line 2468 "libvirt-machine-properties.c"
				const gchar* _tmp50_ = NULL;
				BoxesLibvirtMachine* _tmp51_ = NULL;
				BoxesDisplay* _tmp52_ = NULL;
				BoxesDisplay* _tmp53_ = NULL;
				const gchar* _tmp54_ = NULL;
				const gchar* _tmp55_ = NULL;
				BoxesStringProperty* _tmp56_ = NULL;
				BoxesStringProperty* _tmp57_ = NULL;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp50_ = _ ("Protocol");
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp51_ = self->priv->machine;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp52_ = boxes_machine_get_display ((BoxesMachine*) _tmp51_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp53_ = _tmp52_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp54_ = boxes_display_get_protocol (_tmp53_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp55_ = _tmp54_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp56_ = boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp50_, _tmp55_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp57_ = _tmp56_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (_tmp57_);
#line 2495 "libvirt-machine-properties.c"
			}
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2499 "libvirt-machine-properties.c"
		}
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case BOXES_PROPERTIES_PAGE_DEVICES:
#line 2503 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp58_ = NULL;
			GVirConfigDomain* _tmp59_ = NULL;
			GVirConfigDomain* _tmp60_ = NULL;
			GList* _tmp61_ = NULL;
			gboolean has_usb_redir = FALSE;
			gboolean has_smartcard = FALSE;
			gboolean _tmp85_ = FALSE;
			gboolean _tmp87_ = FALSE;
			gboolean _tmp88_ = FALSE;
			gboolean _tmp96_ = FALSE;
			gboolean _tmp97_ = FALSE;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp58_ = self->priv->machine;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp59_ = boxes_libvirt_machine_get_domain_config (_tmp58_);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp60_ = _tmp59_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp61_ = gvir_config_domain_get_devices (_tmp60_);
#line 2524 "libvirt-machine-properties.c"
			{
				GList* device_config_collection = NULL;
				GList* device_config_it = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				device_config_collection = _tmp61_;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 2532 "libvirt-machine-properties.c"
					GVirConfigDomainDevice* _tmp62_ = NULL;
					GVirConfigDomainDevice* device_config = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_tmp62_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_config = _tmp62_;
#line 2539 "libvirt-machine-properties.c"
					{
						GVirConfigDomainDevice* _tmp63_ = NULL;
						GVirConfigDomainDisk* disk_config = NULL;
						GVirConfigDomainDevice* _tmp64_ = NULL;
						GVirConfigDomainDisk* _tmp65_ = NULL;
						GVirConfigDomainDiskGuestDeviceType disk_type = 0;
						GVirConfigDomainDisk* _tmp66_ = NULL;
						GVirConfigDomainDiskGuestDeviceType _tmp67_ = 0;
						GVirConfigDomainDiskGuestDeviceType _tmp68_ = 0;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp63_ = device_config;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp63_, gvir_config_domain_disk_get_type ())) {
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device_config);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							continue;
#line 2557 "libvirt-machine-properties.c"
						}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp64_ = device_config;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp65_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp64_) : NULL);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_config = _tmp65_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp66_ = disk_config;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp67_ = gvir_config_domain_disk_get_guest_device_type (_tmp66_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						disk_type = _tmp67_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp68_ = disk_type;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						if (_tmp68_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_CDROM) {
#line 2575 "libvirt-machine-properties.c"
							GVirConfigDomainDisk* _tmp69_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp69_ = disk_config;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							boxes_libvirt_machine_properties_add_cdrom_property (self, _tmp69_, &list);
#line 2581 "libvirt-machine-properties.c"
						}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (disk_config);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_g_object_unref0 (device_config);
#line 2587 "libvirt-machine-properties.c"
					}
				}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (device_config_collection);
#line 2592 "libvirt-machine-properties.c"
			}
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_usb_redir = FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			has_smartcard = FALSE;
#line 2598 "libvirt-machine-properties.c"
			{
				GVirConfigDomain* inactive_config = NULL;
				BoxesLibvirtMachine* _tmp70_ = NULL;
				GVirDomain* _tmp71_ = NULL;
				GVirDomain* _tmp72_ = NULL;
				GVirConfigDomain* _tmp73_ = NULL;
				GVirConfigDomain* _tmp74_ = NULL;
				GList* _tmp75_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp70_ = self->priv->machine;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp71_ = boxes_libvirt_machine_get_domain (_tmp70_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp72_ = _tmp71_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp73_ = gvir_domain_get_config (_tmp72_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				inactive_config = _tmp73_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2619 "libvirt-machine-properties.c"
					goto __catch33_g_error;
				}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp74_ = inactive_config;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp75_ = gvir_config_domain_get_devices (_tmp74_);
#line 2626 "libvirt-machine-properties.c"
				{
					GList* device_collection = NULL;
					GList* device_it = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					device_collection = _tmp75_;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					for (device_it = device_collection; device_it != NULL; device_it = device_it->next) {
#line 2634 "libvirt-machine-properties.c"
						GVirConfigDomainDevice* _tmp76_ = NULL;
						GVirConfigDomainDevice* device = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						_tmp76_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_it->data);
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
						device = _tmp76_;
#line 2641 "libvirt-machine-properties.c"
						{
							GVirConfigDomainDevice* _tmp77_ = NULL;
							GVirConfigDomainDevice* _tmp78_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp77_ = device;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, gvir_config_domain_redirdev_get_type ())) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_usb_redir = TRUE;
#line 2651 "libvirt-machine-properties.c"
							}
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_tmp78_ = device;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp78_, gvir_config_domain_smartcard_get_type ())) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
								has_smartcard = TRUE;
#line 2659 "libvirt-machine-properties.c"
							}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
							_g_object_unref0 (device);
#line 2663 "libvirt-machine-properties.c"
						}
					}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					__g_list_free__g_object_unref0_0 (device_collection);
#line 2668 "libvirt-machine-properties.c"
				}
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (inactive_config);
#line 2672 "libvirt-machine-properties.c"
			}
			goto __finally33;
			__catch33_g_error:
			{
				GError* _error_ = NULL;
				BoxesLibvirtMachine* _tmp79_ = NULL;
				GVirDomain* _tmp80_ = NULL;
				GVirDomain* _tmp81_ = NULL;
				const gchar* _tmp82_ = NULL;
				GError* _tmp83_ = NULL;
				const gchar* _tmp84_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_error_ = _inner_error_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_inner_error_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp79_ = self->priv->machine;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp80_ = boxes_libvirt_machine_get_domain (_tmp79_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp81_ = _tmp80_;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp82_ = gvir_domain_get_name (_tmp81_);
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp83_ = _error_;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp84_ = _tmp83_->message;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_warning ("libvirt-machine-properties.vala:220: Failed to fetch configuration for" \
" domain '%s': %s", _tmp82_, _tmp84_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_error_free0 (_error_);
#line 2704 "libvirt-machine-properties.c"
			}
			__finally33:
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				__g_list_free__g_object_unref0_0 (list);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_clear_error (&_inner_error_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				return NULL;
#line 2717 "libvirt-machine-properties.c"
			}
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp85_ = has_usb_redir;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp85_) {
#line 2723 "libvirt-machine-properties.c"
				PropertyCreationFlag _tmp86_ = 0;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp86_ = *flags;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				*flags = _tmp86_ | PROPERTY_CREATION_FLAG_NO_USB;
#line 2729 "libvirt-machine-properties.c"
			}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp88_ = has_usb_redir;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp88_) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp87_ = HAVE_USBREDIR;
#line 2737 "libvirt-machine-properties.c"
			} else {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp87_ = FALSE;
#line 2741 "libvirt-machine-properties.c"
			}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp87_) {
#line 2745 "libvirt-machine-properties.c"
				Block31Data* _data31_;
				GtkButton* button = NULL;
				const gchar* _tmp89_ = NULL;
				GtkButton* _tmp90_ = NULL;
				GtkButton* _tmp91_ = NULL;
				const gchar* _tmp92_ = NULL;
				GtkButton* _tmp93_ = NULL;
				BoxesProperty* _tmp94_ = NULL;
				GtkButton* _tmp95_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_ = g_slice_new0 (Block31Data);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_->_ref_count_ = 1;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_->self = g_object_ref (self);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp89_ = _ ("Add support to guest");
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp90_ = (GtkButton*) gtk_button_new_with_label (_tmp89_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp90_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp90_;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp91_ = button;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp91_, GTK_ALIGN_START);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp92_ = _ ("USB device support");
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp93_ = button;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp94_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp92_, (GtkWidget*) _tmp93_, NULL);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_->property = _tmp94_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp95_ = button;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp95_, "clicked", (GCallback) _____lambda139__gtk_button_clicked, block31_data_ref (_data31_), (GClosureNotify) block31_data_unref, 0);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block31_data_unref (_data31_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data31_ = NULL;
#line 2791 "libvirt-machine-properties.c"
			}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp97_ = has_smartcard;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (!_tmp97_) {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp96_ = HAVE_SMARTCARD;
#line 2799 "libvirt-machine-properties.c"
			} else {
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp96_ = FALSE;
#line 2803 "libvirt-machine-properties.c"
			}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp96_) {
#line 2807 "libvirt-machine-properties.c"
				Block32Data* _data32_;
				GtkButton* button = NULL;
				const gchar* _tmp98_ = NULL;
				GtkButton* _tmp99_ = NULL;
				GtkButton* _tmp100_ = NULL;
				const gchar* _tmp101_ = NULL;
				GtkButton* _tmp102_ = NULL;
				BoxesProperty* _tmp103_ = NULL;
				GtkButton* _tmp104_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_ = g_slice_new0 (Block32Data);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_->_ref_count_ = 1;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_->self = g_object_ref (self);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp98_ = _ ("Add support to guest");
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp99_ = (GtkButton*) gtk_button_new_with_label (_tmp98_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_ref_sink (_tmp99_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				button = _tmp99_;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp100_ = button;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gtk_widget_set_halign ((GtkWidget*) _tmp100_, GTK_ALIGN_START);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp101_ = _ ("Smartcard support");
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp102_ = button;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp103_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, &list, _tmp101_, (GtkWidget*) _tmp102_, NULL);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_->property = _tmp103_;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp104_ = button;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_signal_connect_data (_tmp104_, "clicked", (GCallback) _____lambda140__gtk_button_clicked, block32_data_ref (_data32_), (GClosureNotify) block32_data_unref, 0);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_g_object_unref0 (button);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block32_data_unref (_data32_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data32_ = NULL;
#line 2853 "libvirt-machine-properties.c"
			}
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			break;
#line 2857 "libvirt-machine-properties.c"
		}
		default:
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		break;
#line 2862 "libvirt-machine-properties.c"
	}
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = list;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 2868 "libvirt-machine-properties.c"
}


static Block33Data* block33_data_ref (Block33Data* _data33_) {
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data33_->_ref_count_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data33_;
#line 2877 "libvirt-machine-properties.c"
}


static void block33_data_unref (void * _userdata_) {
	Block33Data* _data33_;
	_data33_ = (Block33Data*) _userdata_;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data33_->_ref_count_)) {
#line 2886 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data33_->self;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data33_->button_label);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data33_->label);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data33_->disk_config);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block33Data, _data33_);
#line 2900 "libvirt-machine-properties.c"
	}
}


static Block34Data* block34_data_ref (Block34Data* _data34_) {
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data34_->_ref_count_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data34_;
#line 2910 "libvirt-machine-properties.c"
}


static void block34_data_unref (void * _userdata_) {
	Block34Data* _data34_;
	_data34_ = (Block34Data*) _userdata_;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data34_->_ref_count_)) {
#line 2919 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data34_->_data33_->self;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data34_->dialog);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block33_data_unref (_data34_->_data33_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->_data33_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block34Data, _data34_);
#line 2931 "libvirt-machine-properties.c"
	}
}


static void ___lambda138_ (Block34Data* _data34_, gint response) {
	Block33Data* _data33_;
	BoxesLibvirtMachineProperties* self;
	gint _tmp0_ = 0;
	GtkFileChooserDialog* _tmp33_ = NULL;
	GError * _inner_error_ = NULL;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_ = _data34_->_data33_;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data33_->self;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = response;
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 2950 "libvirt-machine-properties.c"
		gchar* path = NULL;
		GtkFileChooserDialog* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GVirConfigDomainDisk* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _data34_->dialog;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = gtk_file_chooser_get_filename ((GtkFileChooser*) _tmp1_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		path = _tmp2_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data33_->disk_config;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = path;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp3_, _tmp4_);
#line 2968 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp5_ = NULL;
			GVirDomain* _tmp6_ = NULL;
			GVirDomain* _tmp7_ = NULL;
			GVirConfigDomainDisk* _tmp8_ = NULL;
			GtkLabel* _tmp9_ = NULL;
			const gchar* _tmp10_ = NULL;
			GtkLabel* _tmp11_ = NULL;
			const gchar* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain (_tmp5_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = _tmp6_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp8_ = _data33_->disk_config;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp7_, (GVirConfigDomainDevice*) _tmp8_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2992 "libvirt-machine-properties.c"
				goto __catch36_g_error;
			}
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp9_ = _data33_->button_label;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = _ ("Remove");
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp9_, _tmp10_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = _data33_->label;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp12_ = path;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp13_ = boxes_get_utf8_basename (_tmp12_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp14_ = _tmp13_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp11_, _tmp14_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp14_);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data33_->empty = FALSE;
#line 3015 "libvirt-machine-properties.c"
		}
		goto __finally36;
		__catch36_g_error:
		{
			GError* e = NULL;
			gchar* path_basename = NULL;
			const gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* msg = NULL;
			const gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			BoxesLibvirtMachine* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			BoxesLibvirtMachine* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			const gchar* _tmp24_ = NULL;
			gchar* _tmp25_ = NULL;
			gchar* _tmp26_ = NULL;
			const gchar* _tmp27_ = NULL;
			BoxesLibvirtMachine* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			const gchar* _tmp30_ = NULL;
			GError* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp15_ = path;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = boxes_get_utf8_basename (_tmp15_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			path_basename = _tmp16_;
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _ ("Insertion of '%s' as a CD/DVD into '%s' failed");
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = g_strdup (_tmp17_);
#line 338 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			msg = _tmp18_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = self->priv->machine;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = msg;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = path_basename;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = self->priv->machine;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp22_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _tmp23_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = g_strdup_printf (_tmp20_, _tmp21_, _tmp24_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp25_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp19_, "got-error", _tmp26_);
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp26_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = path_basename;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = self->priv->machine;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp28_);
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _tmp29_;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = e;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_->message;
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:340: Error inserting '%s' as CD into '" \
"%s': %s", _tmp27_, _tmp30_, _tmp32_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (msg);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (path_basename);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3097 "libvirt-machine-properties.c"
		}
		__finally36:
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (path);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3110 "libvirt-machine-properties.c"
		}
#line 326 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (path);
#line 3114 "libvirt-machine-properties.c"
	}
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp33_ = _data34_->dialog;
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp33_);
#line 3120 "libvirt-machine-properties.c"
}


static void ____lambda138__gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda138_ (self, response_id);
#line 3127 "libvirt-machine-properties.c"
}


static void __lambda137_ (Block33Data* _data33_) {
	BoxesLibvirtMachineProperties* self;
	gboolean _tmp0_ = FALSE;
	GError * _inner_error_ = NULL;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data33_->self;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data33_->empty;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 3141 "libvirt-machine-properties.c"
		Block34Data* _data34_;
		const gchar* _tmp1_ = NULL;
		BoxesAppWindow* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GtkFileChooserDialog* _tmp5_ = NULL;
		GtkFileChooserDialog* _tmp6_ = NULL;
		GtkFileChooserDialog* _tmp7_ = NULL;
		GtkFileChooserDialog* _tmp8_ = NULL;
		GtkFileChooserDialog* _tmp9_ = NULL;
		GtkFileFilter* _tmp10_ = NULL;
		GtkFileFilter* _tmp11_ = NULL;
		GtkFileChooserDialog* _tmp12_ = NULL;
		GtkFileFilter* _tmp13_ = NULL;
		GtkFileFilter* _tmp14_ = NULL;
		GtkFileChooserDialog* _tmp15_ = NULL;
		GtkFileChooserDialog* _tmp16_ = NULL;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_ = g_slice_new0 (Block34Data);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->_ref_count_ = 1;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->_data33_ = block33_data_ref (_data33_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = _ ("Select a device or ISO file");
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_app_window;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _ ("_Cancel");
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _ ("_Open");
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp1_, (GtkWindow*) _tmp2_, GTK_FILE_CHOOSER_ACTION_OPEN, _tmp3_, GTK_RESPONSE_CANCEL, _tmp4_, GTK_RESPONSE_ACCEPT, NULL);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp5_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_->dialog = _tmp5_;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _data34_->dialog;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_window_set_modal ((GtkWindow*) _tmp6_, TRUE);
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _data34_->dialog;
#line 321 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_show_hidden ((GtkFileChooser*) _tmp7_, FALSE);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data34_->dialog;
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_local_only ((GtkFileChooser*) _tmp8_, TRUE);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _data34_->dialog;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = gtk_file_filter_new ();
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_ref_sink (_tmp10_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = _tmp10_;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_chooser_set_filter ((GtkFileChooser*) _tmp9_, _tmp11_);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp11_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = _data34_->dialog;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp12_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_file_filter_add_mime_type (_tmp14_, "application/x-cd-image");
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = _data34_->dialog;
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GtkDialog*) _tmp15_, "response", (GCallback) ____lambda138__gtk_dialog_response, block34_data_ref (_data34_), (GClosureNotify) block34_data_unref, 0);
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data34_->dialog;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_widget_show_all ((GtkWidget*) _tmp16_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block34_data_unref (_data34_);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data34_ = NULL;
#line 3223 "libvirt-machine-properties.c"
	} else {
		GVirConfigDomainDisk* _tmp17_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _data33_->disk_config;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_disk_set_source (_tmp17_, "");
#line 3230 "libvirt-machine-properties.c"
		{
			BoxesLibvirtMachine* _tmp18_ = NULL;
			GVirDomain* _tmp19_ = NULL;
			GVirDomain* _tmp20_ = NULL;
			GVirConfigDomainDisk* _tmp21_ = NULL;
			GtkLabel* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			GtkLabel* _tmp24_ = NULL;
			const gchar* _tmp25_ = NULL;
			gchar* _tmp26_ = NULL;
			gchar* _tmp27_ = NULL;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = self->priv->machine;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp19_ = boxes_libvirt_machine_get_domain (_tmp18_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp20_ = _tmp19_;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp21_ = _data33_->disk_config;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gvir_domain_update_device (_tmp20_, (GVirConfigDomainDevice*) _tmp21_, (guint) GVIR_DOMAIN_UPDATE_DEVICE_CURRENT, &_inner_error_);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3254 "libvirt-machine-properties.c"
				goto __catch37_g_error;
			}
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data33_->empty = TRUE;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp22_ = _data33_->button_label;
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = _ ("Select");
#line 351 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_text (_tmp22_, _tmp23_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = _data33_->label;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _ ("empty");
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = g_markup_printf_escaped ("<i>%s</i>", _tmp25_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = _tmp26_;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			gtk_label_set_markup (_tmp24_, _tmp27_);
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp27_);
#line 3277 "libvirt-machine-properties.c"
		}
		goto __finally37;
		__catch37_g_error:
		{
			GError* e = NULL;
			BoxesLibvirtMachine* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			BoxesLibvirtMachine* _tmp30_ = NULL;
			const gchar* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			gchar* _tmp34_ = NULL;
			BoxesLibvirtMachine* _tmp35_ = NULL;
			const gchar* _tmp36_ = NULL;
			const gchar* _tmp37_ = NULL;
			GError* _tmp38_ = NULL;
			const gchar* _tmp39_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			e = _inner_error_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_inner_error_ = NULL;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = self->priv->machine;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _ ("Removal of CD/DVD from '%s' failed");
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = self->priv->machine;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp30_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = _tmp31_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = g_strdup_printf (_tmp29_, _tmp32_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = _tmp33_;
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_emit_by_name ((BoxesMachine*) _tmp28_, "got-error", _tmp34_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_tmp34_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = self->priv->machine;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp35_);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = _tmp36_;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = e;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = _tmp38_->message;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:356: Error ejecting CD from '%s': %s", _tmp37_, _tmp39_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_error_free0 (e);
#line 3331 "libvirt-machine-properties.c"
		}
		__finally37:
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_inner_error_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3342 "libvirt-machine-properties.c"
		}
	}
}


static void ___lambda137__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__lambda137_ (self);
#line 3351 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_add_cdrom_property (BoxesLibvirtMachineProperties* self, GVirConfigDomainDisk* disk_config, GList** list) {
	Block33Data* _data33_;
	GVirConfigDomainDisk* _tmp0_ = NULL;
	GVirConfigDomainDisk* _tmp1_ = NULL;
	GtkGrid* grid = NULL;
	GtkGrid* _tmp2_ = NULL;
	GtkGrid* _tmp3_ = NULL;
	GtkGrid* _tmp4_ = NULL;
	GtkLabel* _tmp5_ = NULL;
	GtkLabel* _tmp6_ = NULL;
	GtkGrid* _tmp7_ = NULL;
	GtkLabel* _tmp8_ = NULL;
	gchar* source = NULL;
	GVirConfigDomainDisk* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_ = NULL;
	gboolean _tmp15_ = FALSE;
	BoxesLibvirtMachine* _tmp24_ = NULL;
	BoxesVMCreator* _tmp25_ = NULL;
	BoxesVMCreator* _tmp26_ = NULL;
	GtkLabel* _tmp51_ = NULL;
	GtkButton* button = NULL;
	GtkButton* _tmp52_ = NULL;
	GtkButton* _tmp53_ = NULL;
	GtkLabel* _tmp54_ = NULL;
	GtkGrid* _tmp55_ = NULL;
	GtkButton* _tmp56_ = NULL;
	gboolean _tmp57_ = FALSE;
	GtkButton* _tmp62_ = NULL;
	const gchar* _tmp63_ = NULL;
	GtkGrid* _tmp64_ = NULL;
	BoxesProperty* _tmp65_ = NULL;
	BoxesProperty* _tmp66_ = NULL;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (disk_config != NULL);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_ = g_slice_new0 (Block33Data);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->_ref_count_ = 1;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->self = g_object_ref (self);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = disk_config;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data33_->disk_config);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->disk_config = _tmp1_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = (GtkGrid*) gtk_grid_new ();
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp2_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	grid = _tmp2_;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = grid;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_orientable_set_orientation ((GtkOrientable*) _tmp3_, GTK_ORIENTATION_HORIZONTAL);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = grid;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_grid_set_column_spacing (_tmp4_, (guint) 12);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp5_);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->label = _tmp5_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _data33_->label;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_label_set_ellipsize (_tmp6_, PANGO_ELLIPSIZE_END);
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = grid;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp8_ = _data33_->label;
#line 277 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp7_, (GtkWidget*) _tmp8_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = _data33_->disk_config;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = gvir_config_domain_disk_get_source (_tmp9_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = g_strdup (_tmp10_);
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	source = _tmp11_;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = source;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp13_ == NULL) {
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = TRUE;
#line 3452 "libvirt-machine-properties.c"
	} else {
		const gchar* _tmp14_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = source;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = g_strcmp0 (_tmp14_, "") == 0;
#line 3459 "libvirt-machine-properties.c"
	}
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->empty = _tmp12_;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp15_ = _data33_->empty;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp15_) {
#line 3467 "libvirt-machine-properties.c"
		GtkLabel* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = _data33_->label;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _ ("empty");
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = g_markup_printf_escaped ("<i>%s</i>", _tmp17_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_markup (_tmp16_, _tmp19_);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp19_);
#line 3484 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _data33_->label;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = source;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = boxes_get_utf8_basename (_tmp21_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp20_, _tmp23_);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_tmp23_);
#line 3502 "libvirt-machine-properties.c"
	}
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = self->priv->machine;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp25_ = boxes_libvirt_machine_get_vm_creator (_tmp24_);
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp26_ = _tmp25_;
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp26_ != NULL) {
#line 3512 "libvirt-machine-properties.c"
		BoxesInstallerMedia* media = NULL;
		BoxesLibvirtMachine* _tmp27_ = NULL;
		BoxesVMCreator* _tmp28_ = NULL;
		BoxesVMCreator* _tmp29_ = NULL;
		BoxesInstallerMedia* _tmp30_ = NULL;
		BoxesInstallerMedia* _tmp31_ = NULL;
		BoxesInstallerMedia* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		gboolean _tmp34_ = FALSE;
		BoxesInstallerMedia* _tmp35_ = NULL;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = self->priv->machine;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = boxes_libvirt_machine_get_vm_creator (_tmp27_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_vm_creator_get_install_media (_tmp29_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = _g_object_ref0 (_tmp31_);
#line 289 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		media = _tmp32_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = media;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, BOXES_TYPE_UNATTENDED_INSTALLER)) {
#line 3541 "libvirt-machine-properties.c"
			BoxesInstallerMedia* _tmp36_ = NULL;
			BoxesUnattendedSetupBox* _tmp37_ = NULL;
			gboolean _tmp38_ = FALSE;
			gboolean _tmp39_ = FALSE;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = media;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, BOXES_TYPE_UNATTENDED_INSTALLER) ? ((BoxesUnattendedInstaller*) _tmp36_) : NULL)->setup_box;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = boxes_unattended_setup_box_get_express_install (_tmp37_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = _tmp38_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = _tmp39_;
#line 3556 "libvirt-machine-properties.c"
		} else {
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = FALSE;
#line 3560 "libvirt-machine-properties.c"
		}
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp34_) {
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = TRUE;
#line 3566 "libvirt-machine-properties.c"
		} else {
			gboolean _tmp40_ = FALSE;
			BoxesInstallerMedia* _tmp41_ = NULL;
			OsinfoMedia* _tmp42_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp41_ = media;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp42_ = _tmp41_->os_media;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp42_ != NULL) {
#line 3577 "libvirt-machine-properties.c"
				BoxesInstallerMedia* _tmp43_ = NULL;
				OsinfoMedia* _tmp44_ = NULL;
				gboolean _tmp45_ = FALSE;
				gboolean _tmp46_ = FALSE;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp43_ = media;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp44_ = _tmp43_->os_media;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				g_object_get (_tmp44_, "live", &_tmp45_, NULL);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp46_ = _tmp45_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp40_ = _tmp46_;
#line 3592 "libvirt-machine-properties.c"
			} else {
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp40_ = FALSE;
#line 3596 "libvirt-machine-properties.c"
			}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = _tmp40_;
#line 3600 "libvirt-machine-properties.c"
		}
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp33_) {
#line 3604 "libvirt-machine-properties.c"
			const gchar* _tmp47_ = NULL;
			GtkGrid* _tmp48_ = NULL;
			BoxesProperty* _tmp49_ = NULL;
			BoxesProperty* _tmp50_ = NULL;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp47_ = _ ("CD/DVD");
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp48_ = grid;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp49_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp47_, (GtkWidget*) _tmp48_, NULL);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp50_ = _tmp49_;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_tmp50_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (media);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (source);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (grid);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block33_data_unref (_data33_);
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data33_ = NULL;
#line 296 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 3631 "libvirt-machine-properties.c"
		}
#line 288 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (media);
#line 3635 "libvirt-machine-properties.c"
	}
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp51_ = (GtkLabel*) gtk_label_new ("");
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp51_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_->button_label = _tmp51_;
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp52_ = (GtkButton*) gtk_button_new ();
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_ref_sink (_tmp52_);
#line 301 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	button = _tmp52_;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp53_ = button;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp54_ = _data33_->button_label;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp53_, (GtkWidget*) _tmp54_);
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp55_ = grid;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp56_ = button;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	gtk_container_add ((GtkContainer*) _tmp55_, (GtkWidget*) _tmp56_);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp57_ = _data33_->empty;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp57_) {
#line 3665 "libvirt-machine-properties.c"
		GtkLabel* _tmp58_ = NULL;
		const gchar* _tmp59_ = NULL;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp58_ = _data33_->button_label;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp59_ = _ ("Select");
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp58_, _tmp59_);
#line 3674 "libvirt-machine-properties.c"
	} else {
		GtkLabel* _tmp60_ = NULL;
		const gchar* _tmp61_ = NULL;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp60_ = _data33_->button_label;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp61_ = _ ("Remove");
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gtk_label_set_text (_tmp60_, _tmp61_);
#line 3684 "libvirt-machine-properties.c"
	}
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp62_ = button;
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_signal_connect_data (_tmp62_, "clicked", (GCallback) ___lambda137__gtk_button_clicked, block33_data_ref (_data33_), (GClosureNotify) block33_data_unref, 0);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp63_ = _ ("CD/DVD");
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp64_ = grid;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp65_ = boxes_iproperties_provider_add_property ((BoxesIPropertiesProvider*) self, list, _tmp63_, (GtkWidget*) _tmp64_, NULL);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp66_ = _tmp65_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_tmp66_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (button);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (source);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (grid);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block33_data_unref (_data33_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data33_ = NULL;
#line 3710 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_update_ram_property (BoxesLibvirtMachineProperties* self, BoxesProperty* property) {
	GError * _inner_error_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 3720 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp0_ = NULL;
		GVirDomain* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirConfigDomain* _tmp3_ = NULL;
		guint64 actual = 0ULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		GVirConfigDomain* _tmp6_ = NULL;
		guint64 _tmp7_ = 0ULL;
		guint64 _tmp8_ = 0ULL;
		guint64 pending = 0ULL;
		guint64 _tmp9_ = 0ULL;
		guint64 _tmp10_ = 0ULL;
		guint64 _tmp11_ = 0ULL;
		guint64 _tmp12_ = 0ULL;
		BoxesProperty* _tmp13_ = NULL;
		guint64 _tmp14_ = 0ULL;
		guint64 _tmp15_ = 0ULL;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = self->priv->machine;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = boxes_libvirt_machine_get_domain (_tmp0_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _tmp1_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = gvir_domain_get_config (_tmp2_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp3_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3753 "libvirt-machine-properties.c"
			goto __catch38_g_error;
		}
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_domain_config (_tmp4_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_config_domain_get_memory (_tmp6_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		actual = _tmp8_ / 1024;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = gvir_config_domain_get_memory (config);
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pending = _tmp10_ / 1024;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = actual;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = pending;
#line 372 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:372: RAM actual: %llu, pending: %llu", _tmp11_, _tmp12_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = property;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = actual;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pending;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required (_tmp13_, (_tmp14_ - _tmp15_) > ((guint64) 1));
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 3790 "libvirt-machine-properties.c"
	}
	goto __finally38;
	__catch38_g_error:
	{
		GError* e = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		e = _inner_error_;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (e);
#line 3802 "libvirt-machine-properties.c"
	}
	__finally38:
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 365 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 3813 "libvirt-machine-properties.c"
	}
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData, _data_);
#line 3829 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources (BoxesLibvirtMachineProperties* self, BoxesSizeProperty* ram_property, BoxesSizeProperty* storage_property, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesSizeProperty* _tmp1_ = NULL;
	BoxesSizeProperty* _tmp2_ = NULL;
	BoxesSizeProperty* _tmp3_ = NULL;
	BoxesSizeProperty* _tmp4_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_mark_recommended_resources);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_mark_recommended_resources_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = ram_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->ram_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->ram_property = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = storage_property;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->storage_property);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->storage_property = _tmp4_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3868 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3876 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_mark_recommended_resources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_mark_recommended_resources_co (_data_);
#line 3890 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_mark_recommended_resources_co (BoxesLibvirtMachinePropertiesMarkRecommendedResourcesData* _data_) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 3899 "libvirt-machine-properties.c"
		goto _state_0;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 3903 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 3908 "libvirt-machine-properties.c"
	}
	_state_0:
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = _data_->ram_property;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp1_ == NULL) {
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = NULL;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp2_ = _data_->storage_property;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = _data_->_tmp2_ == NULL;
#line 3923 "libvirt-machine-properties.c"
	} else {
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp0_ = FALSE;
#line 3927 "libvirt-machine-properties.c"
	}
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp0_) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3935 "libvirt-machine-properties.c"
		} else {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3939 "libvirt-machine-properties.c"
		}
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3945 "libvirt-machine-properties.c"
	}
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = _data_->self->priv->machine;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_state_ = 1;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine (_data_->self, _data_->_tmp3_, boxes_libvirt_machine_properties_mark_recommended_resources_ready, _data_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 3957 "libvirt-machine-properties.c"
	_state_1:
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = boxes_libvirt_machine_properties_get_os_for_machine_finish (_data_->self, _data_->_res_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os = _data_->_tmp4_;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = _data_->os;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp5_ == NULL) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3977 "libvirt-machine-properties.c"
		} else {
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3981 "libvirt-machine-properties.c"
		}
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 3987 "libvirt-machine-properties.c"
	}
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->self->priv->machine;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp6_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = gvir_config_domain_get_os (_data_->_tmp8_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp11_ = gvir_config_domain_os_get_arch (_data_->_tmp10_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = NULL;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp10_);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->architecture = _data_->_tmp13_;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = NULL;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp14_ = _data_->os;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = NULL;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp15_ = _data_->architecture;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = NULL;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp16_ = boxes_os_database_get_recommended_resources_for_os (_data_->_tmp14_, _data_->_tmp15_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->resources = _data_->_tmp16_;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = NULL;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp17_ = _data_->resources;
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp17_ != NULL) {
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->ram_property;
#line 390 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp18_ != NULL) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp19_ = _data_->ram_property;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp20_ = _data_->resources;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = 0LL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp21_ = osinfo_resources_get_ram (_data_->_tmp20_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = 0LL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp22_ = _data_->_tmp21_;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp19_, (guint64) _data_->_tmp22_);
#line 4069 "libvirt-machine-properties.c"
		}
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = NULL;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp23_ = _data_->storage_property;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_tmp23_ != NULL) {
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp24_ = _data_->storage_property;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = NULL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp25_ = _data_->resources;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = 0LL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp26_ = osinfo_resources_get_storage (_data_->_tmp25_);
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = 0LL;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data_->_tmp27_ = _data_->_tmp26_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_size_property_set_recommended (_data_->_tmp24_, (guint64) _data_->_tmp27_);
#line 4095 "libvirt-machine-properties.c"
		}
	}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->resources);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->architecture);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4108 "libvirt-machine-properties.c"
	} else {
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4112 "libvirt-machine-properties.c"
	}
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4118 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_data_free (gpointer _data) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_slice_free (BoxesLibvirtMachinePropertiesGetOsForMachineData, _data_);
#line 4133 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine (BoxesLibvirtMachineProperties* self, BoxesLibvirtMachine* machine, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
	BoxesLibvirtMachineProperties* _tmp0_ = NULL;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	BoxesLibvirtMachine* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachinePropertiesGetOsForMachineData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_properties_get_os_for_machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_properties_get_os_for_machine_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = machine;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->machine);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->machine = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 4162 "libvirt-machine-properties.c"
}


static OsinfoOs* boxes_libvirt_machine_properties_get_os_for_machine_finish (BoxesLibvirtMachineProperties* self, GAsyncResult* _res_) {
	OsinfoOs* result;
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = _data_->result;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->result = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4177 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_get_os_for_machine_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_ = _user_data_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_source_object_ = source_object;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_res_ = _res_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_get_os_for_machine_co (_data_);
#line 4191 "libvirt-machine-properties.c"
}


static gboolean boxes_libvirt_machine_properties_get_os_for_machine_co (BoxesLibvirtMachinePropertiesGetOsForMachineData* _data_) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	switch (_data_->_state_) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 0:
#line 4200 "libvirt-machine-properties.c"
		goto _state_0;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		case 1:
#line 4204 "libvirt-machine-properties.c"
		goto _state_1;
		default:
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_assert_not_reached ();
#line 4209 "libvirt-machine-properties.c"
	}
	_state_0:
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = NULL;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp0_ = _data_->machine;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = NULL;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_domain_config (_data_->_tmp0_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = NULL;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = NULL;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp3_ = boxes_vm_configurator_get_os_id (_data_->_tmp2_);
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_id = _data_->_tmp3_;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = NULL;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp4_ = _data_->os_id;
#line 399 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_tmp4_ == NULL) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4244 "libvirt-machine-properties.c"
		} else {
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4248 "libvirt-machine-properties.c"
		}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4254 "libvirt-machine-properties.c"
	}
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp5_ = boxes_media_manager_get_instance ();
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp7_ = boxes_media_manager_get_os_db (_data_->_tmp6_);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = NULL;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data_->os_db = _data_->_tmp10_;
#line 4284 "libvirt-machine-properties.c"
	{
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp12_ = _data_->os_db;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp13_ = _data_->os_id;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_state_ = 1;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_os_database_get_os_by_id (_data_->_tmp12_, _data_->_tmp13_, boxes_libvirt_machine_properties_get_os_for_machine_ready, _data_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4300 "libvirt-machine-properties.c"
		_state_1:
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp14_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = _data_->_tmp14_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 4312 "libvirt-machine-properties.c"
				goto __catch39_boxes_os_database_error;
			}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (_data_->os_db);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_free0 (_data_->os_id);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_clear_error (&_data_->_inner_error_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return FALSE;
#line 4325 "libvirt-machine-properties.c"
		}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp15_ = _data_->_tmp11_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp11_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = _data_->_tmp15_;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->_tmp11_);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4345 "libvirt-machine-properties.c"
		} else {
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4349 "libvirt-machine-properties.c"
		}
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4355 "libvirt-machine-properties.c"
	}
	goto __finally39;
	__catch39_boxes_os_database_error:
	{
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_inner_error_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp16_ = _data_->os_id;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp17_ = _data_->_error_;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = NULL;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->_tmp18_ = _data_->_tmp17_->message;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:406: Failed to find OS with ID '%s': %" \
"s", _data_->_tmp16_, _data_->_tmp18_);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data_->result = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_data_->_error_);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data_->os_db);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (_data_->os_id);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_data_->_state_ == 0) {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4390 "libvirt-machine-properties.c"
		} else {
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4394 "libvirt-machine-properties.c"
		}
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_object_unref (_data_->_async_result);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4400 "libvirt-machine-properties.c"
	}
	__finally39:
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_data_->_inner_error_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data_->os_db);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_free0 (_data_->os_id);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_data_->_state_ == 0) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4421 "libvirt-machine-properties.c"
	} else {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4425 "libvirt-machine-properties.c"
	}
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_object_unref (_data_->_async_result);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return FALSE;
#line 4431 "libvirt-machine-properties.c"
}


static Block35Data* block35_data_ref (Block35Data* _data35_) {
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data35_->_ref_count_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data35_;
#line 4440 "libvirt-machine-properties.c"
}


static void block35_data_unref (void * _userdata_) {
	Block35Data* _data35_;
	_data35_ = (Block35Data*) _userdata_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data35_->_ref_count_)) {
#line 4449 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data35_->self;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data35_->property);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block35Data, _data35_);
#line 4459 "libvirt-machine-properties.c"
	}
}


static void _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_ram_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 4467 "libvirt-machine-properties.c"
}


static void ___lambda130_ (Block35Data* _data35_) {
	BoxesLibvirtMachineProperties* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data35_->self;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_machine_is_on ((BoxesMachine*) _tmp0_);
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (!_tmp1_) {
#line 4483 "libvirt-machine-properties.c"
		BoxesSizeProperty* _tmp2_ = NULL;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = _data35_->property;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_reboot_required ((BoxesProperty*) _tmp2_, FALSE);
#line 4489 "libvirt-machine-properties.c"
	}
}


static void ____lambda130__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	___lambda130_ (self);
#line 4497 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_ram_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	GError * _inner_error_ = NULL;
#line 411 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 4506 "libvirt-machine-properties.c"
	{
		Block35Data* _data35_;
		GVirNodeInfo* _tmp0_ = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirConnection* _tmp2_ = NULL;
		GVirConnection* _tmp3_ = NULL;
		GVirNodeInfo* _tmp4_ = NULL;
		gulong max_ram = 0UL;
		GVirNodeInfo* _tmp5_ = NULL;
		GVirNodeInfo* _tmp6_ = NULL;
		gulong _tmp7_ = 0UL;
		gulong _tmp8_ = 0UL;
		const gchar* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp10_ = NULL;
		GVirConfigDomain* _tmp11_ = NULL;
		GVirConfigDomain* _tmp12_ = NULL;
		guint64 _tmp13_ = 0ULL;
		guint64 _tmp14_ = 0ULL;
		gulong _tmp15_ = 0UL;
		BoxesSizeProperty* _tmp16_ = NULL;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		BoxesLibvirtMachine* _tmp19_ = NULL;
		GVirConfigDomain* _tmp20_ = NULL;
		GVirConfigDomain* _tmp21_ = NULL;
		gboolean _tmp22_ = FALSE;
		BoxesLibvirtMachine* _tmp32_ = NULL;
		BoxesSizeProperty* _tmp33_ = NULL;
		BoxesSizeProperty* _tmp34_ = NULL;
		BoxesSizeProperty* _tmp35_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_ = g_slice_new0 (Block35Data);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_->_ref_count_ = 1;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_->self = g_object_ref (self);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_connection (_tmp1_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_connection_get_node_info (_tmp3_, &_inner_error_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp4_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			block35_data_unref (_data35_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_data35_ = NULL;
#line 4559 "libvirt-machine-properties.c"
			goto __catch40_g_error;
		}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = _tmp0_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = NULL;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = _tmp6_->memory;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp6_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		max_ram = _tmp8_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _ ("Memory");
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = self->priv->machine;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = boxes_libvirt_machine_get_domain_config (_tmp10_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = _tmp11_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = gvir_config_domain_get_memory (_tmp12_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = max_ram;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp9_, _tmp14_ * OSINFO_KIBIBYTES, (guint64) (64 * OSINFO_MEBIBYTES), (guint64) (_tmp15_ * OSINFO_KIBIBYTES), (guint64) (64 * OSINFO_MEBIBYTES), G_FORMAT_SIZE_IEC_UNITS);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_->property = _tmp16_;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = self->priv->machine;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = boxes_libvirt_machine_get_domain_config (_tmp19_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = boxes_vm_configurator_is_install_config (_tmp21_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp22_) {
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = TRUE;
#line 4606 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp23_ = NULL;
			GVirConfigDomain* _tmp24_ = NULL;
			GVirConfigDomain* _tmp25_ = NULL;
			gboolean _tmp26_ = FALSE;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp23_ = self->priv->machine;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp24_ = boxes_libvirt_machine_get_domain_config (_tmp23_);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp25_ = _tmp24_;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = boxes_vm_configurator_is_live_config (_tmp25_);
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp18_ = _tmp26_;
#line 4622 "libvirt-machine-properties.c"
		}
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp18_) {
#line 4626 "libvirt-machine-properties.c"
			BoxesApp* _tmp27_ = NULL;
			BoxesUIState _tmp28_ = 0;
			BoxesUIState _tmp29_ = 0;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = boxes_app_app;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp28_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp27_);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp29_ = _tmp28_;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _tmp29_ != BOXES_UI_STATE_WIZARD;
#line 4638 "libvirt-machine-properties.c"
		} else {
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = FALSE;
#line 4642 "libvirt-machine-properties.c"
		}
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp17_) {
#line 4646 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp30_ = NULL;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp30_ = _data35_->property;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp30_, FALSE);
#line 4652 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp31_ = NULL;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp31_ = _data35_->property;
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp31_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_ram_changed_boxes_size_property_changed, self, 0);
#line 4659 "libvirt-machine-properties.c"
		}
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = self->priv->machine;
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_signal_connect_data ((GObject*) _tmp32_, "notify::state", (GCallback) ____lambda130__g_object_notify, block35_data_ref (_data35_), (GClosureNotify) block35_data_unref, 0);
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp33_ = _data35_->property;
#line 434 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_properties_update_ram_property (self, (BoxesProperty*) _tmp33_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = _data35_->property;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = _g_object_ref0 (_tmp34_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp35_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirNodeInfo_free0 (_tmp0_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block35_data_unref (_data35_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data35_ = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4683 "libvirt-machine-properties.c"
	}
	goto __finally40;
	__catch40_g_error:
	{
		GError* _error_ = NULL;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 4699 "libvirt-machine-properties.c"
	}
	__finally40:
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 4708 "libvirt-machine-properties.c"
}


static Block36Data* block36_data_ref (Block36Data* _data36_) {
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data36_->_ref_count_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data36_;
#line 4717 "libvirt-machine-properties.c"
}


static void block36_data_unref (void * _userdata_) {
	Block36Data* _data36_;
	_data36_ = (Block36Data*) _userdata_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data36_->_ref_count_)) {
#line 4726 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data36_->self;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data36_->property);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block36Data, _data36_);
#line 4736 "libvirt-machine-properties.c"
	}
}


static gboolean __lambda129_ (Block36Data* _data36_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	guint64 ram = 0ULL;
	guint64 _tmp0_ = 0ULL;
	BoxesProperty* _tmp24_ = NULL;
	GError * _inner_error_ = NULL;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data36_->self;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = _data36_->value;
#line 445 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	ram = ((_tmp0_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 4754 "libvirt-machine-properties.c"
	{
		GVirConfigDomain* config = NULL;
		BoxesLibvirtMachine* _tmp1_ = NULL;
		GVirDomain* _tmp2_ = NULL;
		GVirDomain* _tmp3_ = NULL;
		GVirConfigDomain* _tmp4_ = NULL;
		GVirConfigDomain* _tmp5_ = NULL;
		guint64 _tmp6_ = 0ULL;
		GVirConfigDomain* _tmp7_ = NULL;
		GObjectClass* _tmp8_ = NULL;
		GParamSpec* _tmp9_ = NULL;
		BoxesLibvirtMachine* _tmp12_ = NULL;
		GVirDomain* _tmp13_ = NULL;
		GVirDomain* _tmp14_ = NULL;
		GVirConfigDomain* _tmp15_ = NULL;
		guint64 _tmp16_ = 0ULL;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = self->priv->machine;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _tmp2_;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = gvir_domain_get_config (_tmp3_, (guint) GVIR_DOMAIN_XML_INACTIVE, &_inner_error_);
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp4_;
#line 447 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4783 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = config;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = ram;
#line 448 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_domain_set_memory (_tmp5_, _tmp6_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = config;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = G_OBJECT_GET_CLASS ((GObject*) _tmp7_);
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = g_object_class_find_property (_tmp8_, "current-memory");
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp9_ != NULL) {
#line 4800 "libvirt-machine-properties.c"
			GVirConfigDomain* _tmp10_ = NULL;
			guint64 _tmp11_ = 0ULL;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp10_ = config;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp11_ = ram;
#line 450 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_object_set ((GObject*) _tmp10_, "current-memory", _tmp11_, NULL);
#line 4809 "libvirt-machine-properties.c"
		}
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = self->priv->machine;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = boxes_libvirt_machine_get_domain (_tmp12_);
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = _tmp13_;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_domain_set_config (_tmp14_, _tmp15_, &_inner_error_);
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 451 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 4825 "libvirt-machine-properties.c"
			goto __catch41_g_error;
		}
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = ram;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:452: RAM changed to %llu KiB", _tmp16_);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 4834 "libvirt-machine-properties.c"
	}
	goto __finally41;
	__catch41_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirDomain* _tmp18_ = NULL;
		GVirDomain* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		guint64 _tmp21_ = 0ULL;
		GError* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_domain (_tmp17_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = gvir_domain_get_name (_tmp19_);
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = ram;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _error_;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->message;
#line 454 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:454: Failed to change RAM of box '%s' " \
"to %llu KiB: %s", _tmp20_, _tmp21_, _tmp23_);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 4869 "libvirt-machine-properties.c"
	}
	__finally41:
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 446 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 4880 "libvirt-machine-properties.c"
	}
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp24_ = _data36_->property;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_update_ram_property (self, _tmp24_);
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 462 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4890 "libvirt-machine-properties.c"
}


static gboolean ___lambda129__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda129_ (self);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 4899 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_ram_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block36Data* _data36_;
	BoxesProperty* _tmp0_ = NULL;
	BoxesProperty* _tmp1_ = NULL;
	guint64 _tmp2_ = 0ULL;
	BoxesProperty* _tmp3_ = NULL;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_ = g_slice_new0 (Block36Data);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->_ref_count_ = 1;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->self = g_object_ref (self);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = property;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (_data36_->property);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->property = _tmp1_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = value;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_->value = _tmp2_;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _data36_->property;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp3_, ___lambda129__gsource_func, block36_data_ref (_data36_), block36_data_unref);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block36_data_unref (_data36_);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data36_ = NULL;
#line 4939 "libvirt-machine-properties.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 4946 "libvirt-machine-properties.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 4953 "libvirt-machine-properties.c"
}


static void _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed (BoxesSizeProperty* _sender, guint64 value, gpointer self) {
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_on_storage_changed ((BoxesLibvirtMachineProperties*) self, _sender, value);
#line 4960 "libvirt-machine-properties.c"
}


static BoxesSizeProperty* boxes_libvirt_machine_properties_add_storage_property (BoxesLibvirtMachineProperties* self, GList** list) {
	BoxesSizeProperty* result = NULL;
	gboolean _tmp0_ = FALSE;
	BoxesLibvirtMachine* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GError * _inner_error_ = NULL;
#line 466 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = self->priv->machine;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = boxes_libvirt_machine_get_importing (_tmp1_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = _tmp2_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp3_) {
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = TRUE;
#line 4983 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _tmp6_ == NULL;
#line 4996 "libvirt-machine-properties.c"
	}
#line 467 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp0_) {
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5004 "libvirt-machine-properties.c"
	}
	{
		GVirStorageVolInfo* volume_info = NULL;
		BoxesLibvirtMachine* _tmp7_ = NULL;
		GVirStorageVol* _tmp8_ = NULL;
		GVirStorageVol* _tmp9_ = NULL;
		GVirStorageVolInfo* _tmp10_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp11_ = NULL;
		GVirConnection* _tmp12_ = NULL;
		GVirConnection* _tmp13_ = NULL;
		GVirStoragePool* _tmp14_ = NULL;
		GVirStoragePoolInfo* pool_info = NULL;
		GVirStoragePool* _tmp15_ = NULL;
		GVirStoragePoolInfo* _tmp16_ = NULL;
		guint64 _tmp17_ = 0ULL;
		guint64 _tmp18_ = 0ULL;
		BoxesSizeProperty* property = NULL;
		const gchar* _tmp19_ = NULL;
		GVirStorageVolInfo* _tmp20_ = NULL;
		guint64 _tmp21_ = 0ULL;
		GVirStoragePoolInfo* _tmp22_ = NULL;
		guint64 _tmp23_ = 0ULL;
		BoxesSizeProperty* _tmp24_ = NULL;
		BoxesSizeProperty* _tmp25_ = NULL;
		gboolean _tmp26_ = FALSE;
		gboolean _tmp27_ = FALSE;
		BoxesLibvirtMachine* _tmp28_ = NULL;
		GVirConfigDomain* _tmp29_ = NULL;
		GVirConfigDomain* _tmp30_ = NULL;
		gboolean _tmp31_ = FALSE;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = self->priv->machine;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = boxes_libvirt_machine_get_storage_volume (_tmp7_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _tmp8_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = gvir_storage_vol_get_info (_tmp9_, &_inner_error_);
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		volume_info = _tmp10_;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5048 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp14_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = pool;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = gvir_storage_pool_get_info (_tmp15_, &_inner_error_);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool_info = _tmp16_;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5073 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_properties_get_minimum_disk_size (self, &_inner_error_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _tmp18_;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5088 "libvirt-machine-properties.c"
			goto __catch42_g_error;
		}
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _ ("Maximum Disk Size");
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = volume_info;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _tmp20_->capacity;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = pool_info;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _tmp22_->available;
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp19_, _tmp21_, _tmp17_, _tmp23_, 256 * BOXES_LIBVIRT_MACHINE_PROPERTIES_MEGABYTES, G_FORMAT_SIZE_DEFAULT);
#line 475 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		property = _tmp24_;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = property;
#line 484 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_property_set_defer_interval ((BoxesProperty*) _tmp25_, (guint) 0);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = boxes_libvirt_machine_get_domain_config (_tmp28_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = _tmp29_;
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = boxes_vm_configurator_is_install_config (_tmp30_);
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp31_) {
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = TRUE;
#line 5121 "libvirt-machine-properties.c"
		} else {
			BoxesLibvirtMachine* _tmp32_ = NULL;
			GVirConfigDomain* _tmp33_ = NULL;
			GVirConfigDomain* _tmp34_ = NULL;
			gboolean _tmp35_ = FALSE;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp32_ = self->priv->machine;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp33_ = boxes_libvirt_machine_get_domain_config (_tmp32_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp34_ = _tmp33_;
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp35_ = boxes_vm_configurator_is_live_config (_tmp34_);
#line 486 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp27_ = _tmp35_;
#line 5137 "libvirt-machine-properties.c"
		}
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp27_) {
#line 5141 "libvirt-machine-properties.c"
			BoxesApp* _tmp36_ = NULL;
			BoxesUIState _tmp37_ = 0;
			BoxesUIState _tmp38_ = 0;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp36_ = boxes_app_app;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp37_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp36_);
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp38_ = _tmp37_;
#line 487 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = _tmp38_ != BOXES_UI_STATE_WIZARD;
#line 5153 "libvirt-machine-properties.c"
		} else {
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp26_ = FALSE;
#line 5157 "libvirt-machine-properties.c"
		}
#line 485 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp26_) {
#line 5161 "libvirt-machine-properties.c"
			BoxesSizeProperty* _tmp39_ = NULL;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp39_ = property;
#line 488 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_property_set_sensitive ((BoxesProperty*) _tmp39_, FALSE);
#line 5167 "libvirt-machine-properties.c"
		} else {
			BoxesSizeProperty* _tmp40_ = NULL;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp40_ = property;
#line 490 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_signal_connect_object (_tmp40_, "changed", (GCallback) _boxes_libvirt_machine_properties_on_storage_changed_boxes_size_property_changed, self, 0);
#line 5174 "libvirt-machine-properties.c"
		}
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = property;
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 492 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5186 "libvirt-machine-properties.c"
	}
	goto __finally42;
	__catch42_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp41_ = NULL;
		GVirStorageVol* _tmp42_ = NULL;
		GVirStorageVol* _tmp43_ = NULL;
		const gchar* _tmp44_ = NULL;
		GError* _tmp45_ = NULL;
		const gchar* _tmp46_ = NULL;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = self->priv->machine;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = boxes_libvirt_machine_get_storage_volume (_tmp41_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = _tmp42_;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp44_ = gvir_storage_vol_get_name (_tmp43_);
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp45_ = _error_;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp46_ = _tmp45_->message;
#line 494 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:494: Failed to get information on volu" \
"me '%s' or it's parent pool: %s", _tmp44_, _tmp46_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = NULL;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5222 "libvirt-machine-properties.c"
	}
	__finally42:
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_clear_error (&_inner_error_);
#line 470 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return NULL;
#line 5231 "libvirt-machine-properties.c"
}


static Block37Data* block37_data_ref (Block37Data* _data37_) {
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data37_->_ref_count_);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data37_;
#line 5240 "libvirt-machine-properties.c"
}


static void block37_data_unref (void * _userdata_) {
	Block37Data* _data37_;
	_data37_ = (Block37Data*) _userdata_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data37_->_ref_count_)) {
#line 5249 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data37_->self;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (self);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block37Data, _data37_);
#line 5257 "libvirt-machine-properties.c"
	}
}


static Block38Data* block38_data_ref (Block38Data* _data38_) {
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_atomic_int_inc (&_data38_->_ref_count_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return _data38_;
#line 5267 "libvirt-machine-properties.c"
}


static void block38_data_unref (void * _userdata_) {
	Block38Data* _data38_;
	_data38_ = (Block38Data*) _userdata_;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (g_atomic_int_dec_and_test (&_data38_->_ref_count_)) {
#line 5276 "libvirt-machine-properties.c"
		BoxesLibvirtMachineProperties* self;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		self = _data38_->_data37_->self;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_data38_->pool);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		block37_data_unref (_data38_->_data37_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_data38_->_data37_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_slice_free (Block38Data, _data38_);
#line 5288 "libvirt-machine-properties.c"
	}
}


static void _____lambda132_ (Block38Data* _data38_, GObject* obj, GAsyncResult* res) {
	Block37Data* _data37_;
	BoxesLibvirtMachineProperties* self;
	GError * _inner_error_ = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = _data38_->_data37_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data37_->self;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (res != NULL);
#line 5303 "libvirt-machine-properties.c"
	{
		GVirStoragePool* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
		BoxesLibvirtMachine* _tmp2_ = NULL;
		guint64 _tmp3_ = 0ULL;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp0_ = _data38_->pool;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp1_ = res;
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_pool_refresh_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 517 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5317 "libvirt-machine-properties.c"
			goto __catch44_g_error;
		}
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp2_ = self->priv->machine;
#line 518 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_update_domain_config (_tmp2_);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = _data38_->size;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_debug ("libvirt-machine-properties.vala:519: Storage changed to %llu KiB", _tmp3_);
#line 5328 "libvirt-machine-properties.c"
	}
	goto __finally44;
	__catch44_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp4_ = NULL;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		guint64 _tmp8_ = 0ULL;
		GError* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = self->priv->machine;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp5_ = boxes_libvirt_machine_get_storage_volume (_tmp4_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp6_ = _tmp5_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = gvir_storage_vol_get_name (_tmp6_);
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _data38_->size;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = _error_;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->message;
#line 521 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:521: Failed to change storage capacity" \
" of volume '%s' to %llu KiB: %s", _tmp7_, _tmp8_, _tmp10_);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5363 "libvirt-machine-properties.c"
	}
	__finally44:
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 516 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 5374 "libvirt-machine-properties.c"
	}
}


static void ______lambda132__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_____lambda132_ (self, source_object, res);
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block38_data_unref (self);
#line 5384 "libvirt-machine-properties.c"
}


static gboolean __lambda131_ (Block37Data* _data37_) {
	BoxesLibvirtMachineProperties* self;
	gboolean result = FALSE;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = _data37_->self;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 504 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp2_ == NULL) {
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = FALSE;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5409 "libvirt-machine-properties.c"
	}
	{
		BoxesLibvirtMachine* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp3_ = self->priv->machine;
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = boxes_machine_is_running ((BoxesMachine*) _tmp3_);
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (_tmp4_) {
#line 5420 "libvirt-machine-properties.c"
			GVirDomainDisk* disk = NULL;
			BoxesLibvirtMachine* _tmp5_ = NULL;
			GVirDomainDisk* _tmp6_ = NULL;
			GVirDomainDisk* _tmp7_ = NULL;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp5_ = self->priv->machine;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp6_ = boxes_libvirt_machine_get_domain_disk (_tmp5_, &_inner_error_);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			disk = _tmp6_;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5433 "libvirt-machine-properties.c"
				goto __catch43_g_error;
			}
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp7_ = disk;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (_tmp7_ != NULL) {
#line 5440 "libvirt-machine-properties.c"
				Block38Data* _data38_;
				guint64 _tmp8_ = 0ULL;
				GVirDomainDisk* _tmp9_ = NULL;
				guint64 _tmp10_ = 0ULL;
				BoxesLibvirtMachine* _tmp11_ = NULL;
				GVirConnection* _tmp12_ = NULL;
				GVirConnection* _tmp13_ = NULL;
				GVirStoragePool* _tmp14_ = NULL;
				GVirStoragePool* _tmp15_ = NULL;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data38_ = g_slice_new0 (Block38Data);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data38_->_ref_count_ = 1;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data38_->_data37_ = block37_data_ref (_data37_);
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp8_ = _data37_->value;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data38_->size = ((_tmp8_ + OSINFO_KIBIBYTES) - 1) / OSINFO_KIBIBYTES;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp9_ = disk;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp10_ = _data38_->size;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_domain_disk_resize (_tmp9_, _tmp10_, (guint) 0, &_inner_error_);
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					block38_data_unref (_data38_);
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_data38_ = NULL;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
					_g_object_unref0 (disk);
#line 5474 "libvirt-machine-properties.c"
					goto __catch43_g_error;
				}
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp11_ = self->priv->machine;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp12_ = boxes_libvirt_machine_get_connection (_tmp11_);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp13_ = _tmp12_;
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp14_ = boxes_get_storage_pool (_tmp13_);
#line 514 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data38_->pool = _tmp14_;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_tmp15_ = _data38_->pool;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				gvir_storage_pool_refresh_async (_tmp15_, NULL, ______lambda132__gasync_ready_callback, block38_data_ref (_data38_));
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				block38_data_unref (_data38_);
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
				_data38_ = NULL;
#line 5495 "libvirt-machine-properties.c"
			}
#line 508 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (disk);
#line 5499 "libvirt-machine-properties.c"
		} else {
			guint64 _tmp16_ = 0ULL;
			guint64 _tmp17_ = 0ULL;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp16_ = _data37_->value;
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			boxes_libvirt_machine_properties_resize_storage_volume (self, _tmp16_, &_inner_error_);
#line 529 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5509 "libvirt-machine-properties.c"
				goto __catch43_g_error;
			}
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_tmp17_ = _data37_->value;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_debug ("libvirt-machine-properties.vala:530: Storage changed to %llu", _tmp17_);
#line 5516 "libvirt-machine-properties.c"
		}
	}
	goto __finally43;
	__catch43_g_error:
	{
		GError* _error_ = NULL;
		BoxesLibvirtMachine* _tmp18_ = NULL;
		GVirStorageVol* _tmp19_ = NULL;
		GVirStorageVol* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		guint64 _tmp22_ = 0ULL;
		GError* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_error_ = _inner_error_;
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_inner_error_ = NULL;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = self->priv->machine;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = boxes_libvirt_machine_get_storage_volume (_tmp18_);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = gvir_storage_vol_get_name (_tmp20_);
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _data37_->value;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = _error_;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_->message;
#line 533 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_warning ("libvirt-machine-properties.vala:533: Failed to change storage capacity" \
" of volume '%s' to %llu: %s", _tmp21_, _tmp22_, _tmp24_);
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_error_free0 (_error_);
#line 5552 "libvirt-machine-properties.c"
	}
	__finally43:
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_clear_error (&_inner_error_);
#line 507 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return FALSE;
#line 5563 "libvirt-machine-properties.c"
	}
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	result = FALSE;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5569 "libvirt-machine-properties.c"
}


static gboolean ___lambda131__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda131_ (self);
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	return result;
#line 5578 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_on_storage_changed (BoxesLibvirtMachineProperties* self, BoxesProperty* property, guint64 value) {
	Block37Data* _data37_;
	guint64 _tmp0_ = 0ULL;
	BoxesProperty* _tmp1_ = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (property != NULL);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = g_slice_new0 (Block37Data);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->_ref_count_ = 1;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->self = g_object_ref (self);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = value;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_->value = _tmp0_;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = property;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_property_set_deferred_change (_tmp1_, ___lambda131__gsource_func, block37_data_ref (_data37_), block37_data_unref);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	block37_data_unref (_data37_);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_data37_ = NULL;
#line 5608 "libvirt-machine-properties.c"
}


static guint64 boxes_libvirt_machine_properties_get_minimum_disk_size (BoxesLibvirtMachineProperties* self, GError** error) {
	guint64 result = 0ULL;
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVolInfo* _tmp3_ = NULL;
	BoxesLibvirtMachine* _tmp4_ = NULL;
	BoxesVMCreator* _tmp5_ = NULL;
	BoxesVMCreator* _tmp6_ = NULL;
	OsinfoResources* minimum_resources = NULL;
	BoxesLibvirtMachine* _tmp9_ = NULL;
	BoxesVMCreator* _tmp10_ = NULL;
	BoxesVMCreator* _tmp11_ = NULL;
	BoxesInstallerMedia* _tmp12_ = NULL;
	BoxesInstallerMedia* _tmp13_ = NULL;
	OsinfoOs* _tmp14_ = NULL;
	OsinfoResources* _tmp33_ = NULL;
	GError * _inner_error_ = NULL;
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_val_if_fail (self != NULL, 0ULL);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return 0ULL;
#line 5649 "libvirt-machine-properties.c"
	}
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp4_ = self->priv->machine;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = boxes_libvirt_machine_get_vm_creator (_tmp4_);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = _tmp5_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp6_ == NULL) {
#line 5659 "libvirt-machine-properties.c"
		GVirStorageVolInfo* _tmp7_ = NULL;
		guint64 _tmp8_ = 0ULL;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp7_ = volume_info;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = _tmp7_->capacity;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp8_;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5672 "libvirt-machine-properties.c"
	}
#line 551 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	minimum_resources = NULL;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp9_ = self->priv->machine;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp10_ = boxes_libvirt_machine_get_vm_creator (_tmp9_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp11_ = _tmp10_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp12_ = boxes_vm_creator_get_install_media (_tmp11_);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp13_ = _tmp12_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp14_ = _tmp13_->os;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp14_ != NULL) {
#line 5690 "libvirt-machine-properties.c"
		OsinfoOs* os = NULL;
		BoxesLibvirtMachine* _tmp15_ = NULL;
		BoxesVMCreator* _tmp16_ = NULL;
		BoxesVMCreator* _tmp17_ = NULL;
		BoxesInstallerMedia* _tmp18_ = NULL;
		BoxesInstallerMedia* _tmp19_ = NULL;
		OsinfoOs* _tmp20_ = NULL;
		OsinfoOs* _tmp21_ = NULL;
		gchar* architecture = NULL;
		BoxesLibvirtMachine* _tmp22_ = NULL;
		GVirConfigDomain* _tmp23_ = NULL;
		GVirConfigDomain* _tmp24_ = NULL;
		GVirConfigDomainOs* _tmp25_ = NULL;
		GVirConfigDomainOs* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		OsinfoOs* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		OsinfoResources* _tmp32_ = NULL;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = self->priv->machine;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = boxes_libvirt_machine_get_vm_creator (_tmp15_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = _tmp16_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_vm_creator_get_install_media (_tmp17_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = _tmp19_->os;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		os = _tmp21_;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = self->priv->machine;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_libvirt_machine_get_domain_config (_tmp22_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp23_;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = gvir_config_domain_get_os (_tmp24_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = _tmp25_;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_config_domain_os_get_arch (_tmp26_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = g_strdup (_tmp27_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = _tmp28_;
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp26_);
#line 555 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		architecture = _tmp29_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = os;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = architecture;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = boxes_os_database_get_minimum_resources_for_os (_tmp30_, _tmp31_);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		minimum_resources = _tmp32_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_free0 (architecture);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (os);
#line 5761 "libvirt-machine-properties.c"
	}
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp33_ = minimum_resources;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp33_ != NULL) {
#line 5767 "libvirt-machine-properties.c"
		OsinfoResources* _tmp34_ = NULL;
		gint64 _tmp35_ = 0LL;
		gint64 _tmp36_ = 0LL;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp34_ = minimum_resources;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp35_ = osinfo_resources_get_storage (_tmp34_);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp36_ = _tmp35_;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = (guint64) _tmp36_;
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 560 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5785 "libvirt-machine-properties.c"
	} else {
		OsinfoResources* default_resources = NULL;
		OsinfoResources* _tmp37_ = NULL;
		GVirStorageVolInfo* _tmp38_ = NULL;
		guint64 _tmp39_ = 0ULL;
		OsinfoResources* _tmp40_ = NULL;
		gint64 _tmp41_ = 0LL;
		gint64 _tmp42_ = 0LL;
		guint64 _tmp43_ = 0ULL;
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp37_ = boxes_os_database_get_default_resources ();
#line 562 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		default_resources = _tmp37_;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp38_ = volume_info;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp39_ = _tmp38_->capacity;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp40_ = default_resources;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp41_ = osinfo_resources_get_storage (_tmp40_);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp42_ = _tmp41_;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp43_ = MIN (_tmp39_, (guint64) _tmp42_);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		result = _tmp43_;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (default_resources);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (minimum_resources);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return result;
#line 5821 "libvirt-machine-properties.c"
	}
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_g_object_unref0 (minimum_resources);
#line 543 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5827 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_resize_storage_volume (BoxesLibvirtMachineProperties* self, guint64 size, GError** error) {
	GVirStorageVolInfo* volume_info = NULL;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	GVirStorageVol* _tmp1_ = NULL;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVolInfo* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	BoxesLibvirtMachine* _tmp5_ = NULL;
	BoxesVMCreator* _tmp6_ = NULL;
	BoxesVMCreator* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_return_if_fail (self != NULL);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp0_ = self->priv->machine;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp1_ = boxes_libvirt_machine_get_storage_volume (_tmp0_);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp2_ = _tmp1_;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp3_ = gvir_storage_vol_get_info (_tmp2_, &_inner_error_);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	volume_info = _tmp3_;
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		g_propagate_error (error, _inner_error_);
#line 568 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		return;
#line 5860 "libvirt-machine-properties.c"
	}
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp5_ = self->priv->machine;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp6_ = boxes_libvirt_machine_get_vm_creator (_tmp5_);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	_tmp7_ = _tmp6_;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp7_ != NULL) {
#line 5870 "libvirt-machine-properties.c"
		guint64 _tmp8_ = 0ULL;
		GVirStorageVolInfo* _tmp9_ = NULL;
		guint64 _tmp10_ = 0ULL;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp8_ = size;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp9_ = volume_info;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp10_ = _tmp9_->capacity;
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = _tmp8_ < _tmp10_;
#line 5882 "libvirt-machine-properties.c"
	} else {
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp4_ = FALSE;
#line 5886 "libvirt-machine-properties.c"
	}
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	if (_tmp4_) {
#line 5890 "libvirt-machine-properties.c"
		GVirConfigStorageVol* config = NULL;
		BoxesLibvirtMachine* _tmp11_ = NULL;
		GVirStorageVol* _tmp12_ = NULL;
		GVirStorageVol* _tmp13_ = NULL;
		GVirConfigStorageVol* _tmp14_ = NULL;
		GVirConfigStorageVol* _tmp15_ = NULL;
		guint64 _tmp16_ = 0ULL;
		BoxesLibvirtMachine* _tmp17_ = NULL;
		GVirStorageVol* _tmp18_ = NULL;
		GVirStorageVol* _tmp19_ = NULL;
		GVirStoragePool* pool = NULL;
		BoxesLibvirtMachine* _tmp20_ = NULL;
		GVirConnection* _tmp21_ = NULL;
		GVirConnection* _tmp22_ = NULL;
		GVirStoragePool* _tmp23_ = NULL;
		GVirStorageVol* _tmp24_ = NULL;
		GVirStoragePool* _tmp25_ = NULL;
		GVirConfigStorageVol* _tmp26_ = NULL;
		GVirStorageVol* _tmp27_ = NULL;
		BoxesLibvirtMachine* _tmp28_ = NULL;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp11_ = self->priv->machine;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp12_ = boxes_libvirt_machine_get_storage_volume (_tmp11_);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp13_ = _tmp12_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp14_ = gvir_storage_vol_get_config (_tmp13_, (guint) GVIR_DOMAIN_XML_NONE, &_inner_error_);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		config = _tmp14_;
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 571 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 5929 "libvirt-machine-properties.c"
		}
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp15_ = config;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp16_ = size;
#line 572 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_config_storage_vol_set_capacity (_tmp15_, _tmp16_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp17_ = self->priv->machine;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp18_ = boxes_libvirt_machine_get_storage_volume (_tmp17_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp19_ = _tmp18_;
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_delete (_tmp19_, (guint) 0, &_inner_error_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 573 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 5955 "libvirt-machine-properties.c"
		}
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp20_ = self->priv->machine;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp21_ = boxes_libvirt_machine_get_connection (_tmp20_);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp22_ = _tmp21_;
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp23_ = boxes_get_storage_pool (_tmp22_);
#line 575 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		pool = _tmp23_;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp25_ = pool;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp26_ = config;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp27_ = gvir_storage_pool_create_volume (_tmp25_, _tmp26_, &_inner_error_);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp24_ = _tmp27_;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (pool);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			_g_object_unref0 (config);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 5987 "libvirt-machine-properties.c"
		}
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp28_ = self->priv->machine;
#line 576 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		boxes_libvirt_machine_set_storage_volume (_tmp28_, _tmp24_);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (_tmp24_);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (pool);
#line 569 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_g_object_unref0 (config);
#line 5999 "libvirt-machine-properties.c"
	} else {
		BoxesLibvirtMachine* _tmp29_ = NULL;
		GVirStorageVol* _tmp30_ = NULL;
		GVirStorageVol* _tmp31_ = NULL;
		guint64 _tmp32_ = 0ULL;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp29_ = self->priv->machine;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp30_ = boxes_libvirt_machine_get_storage_volume (_tmp29_);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp31_ = _tmp30_;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		_tmp32_ = size;
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		gvir_storage_vol_resize (_tmp31_, _tmp32_, GVIR_STORAGE_VOL_RESIZE_NONE, &_inner_error_);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			g_propagate_error (error, _inner_error_);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 578 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
			return;
#line 6023 "libvirt-machine-properties.c"
		}
	}
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	__vala_GVirStorageVolInfo_free0 (volume_info);
#line 6028 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_class_init (BoxesLibvirtMachinePropertiesClass * klass) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePropertiesPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_properties_finalize;
#line 6039 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init (BoxesIPropertiesProviderIface * iface) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	boxes_libvirt_machine_properties_boxes_iproperties_provider_parent_iface = g_type_interface_peek_parent (iface);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	iface->get_properties = (GList* (*)(BoxesIPropertiesProvider*, BoxesPropertiesPage, PropertyCreationFlag*)) boxes_libvirt_machine_properties_real_get_properties;
#line 6048 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_instance_init (BoxesLibvirtMachineProperties * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_PROPERTIES_GET_PRIVATE (self);
#line 6055 "libvirt-machine-properties.c"
}


static void boxes_libvirt_machine_properties_finalize (GObject* obj) {
	BoxesLibvirtMachineProperties * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE_PROPERTIES, BoxesLibvirtMachineProperties);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine-properties.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_properties_parent_class)->finalize (obj);
#line 6065 "libvirt-machine-properties.c"
}


GType boxes_libvirt_machine_properties_get_type (void) {
	static volatile gsize boxes_libvirt_machine_properties_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_properties_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachinePropertiesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_properties_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachineProperties), 0, (GInstanceInitFunc) boxes_libvirt_machine_properties_instance_init, NULL };
		static const GInterfaceInfo boxes_iproperties_provider_info = { (GInterfaceInitFunc) boxes_libvirt_machine_properties_boxes_iproperties_provider_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_libvirt_machine_properties_type_id;
		boxes_libvirt_machine_properties_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesLibvirtMachineProperties", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_libvirt_machine_properties_type_id, BOXES_TYPE_IPROPERTIES_PROVIDER, &boxes_iproperties_provider_info);
		g_once_init_leave (&boxes_libvirt_machine_properties_type_id__volatile, boxes_libvirt_machine_properties_type_id);
	}
	return boxes_libvirt_machine_properties_type_id__volatile;
}



