/* app.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from app.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>
#include <glib/gi18n-lib.h>
#include <config.h>
#include <libvirt-gobject/libvirt-gobject.h>


#define BOXES_TYPE_BROKER (boxes_broker_get_type ())
#define BOXES_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_BROKER, BoxesBroker))
#define BOXES_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_BROKER, BoxesBrokerClass))
#define BOXES_IS_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_BROKER))
#define BOXES_IS_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_BROKER))
#define BOXES_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_BROKER, BoxesBrokerClass))

typedef struct _BoxesBroker BoxesBroker;
typedef struct _BoxesBrokerClass BoxesBrokerClass;
typedef struct _BoxesBrokerPrivate BoxesBrokerPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesBrokerAddSourceData BoxesBrokerAddSourceData;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
typedef struct _BoxesAppWindowPrivate BoxesAppWindowPrivate;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_LIBVIRT_BROKER (boxes_libvirt_broker_get_type ())
#define BOXES_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBroker))
#define BOXES_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))
#define BOXES_IS_LIBVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_IS_LIBVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_BROKER))
#define BOXES_LIBVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_BROKER, BoxesLibvirtBrokerClass))

typedef struct _BoxesLibvirtBroker BoxesLibvirtBroker;
typedef struct _BoxesLibvirtBrokerClass BoxesLibvirtBrokerClass;

#define BOXES_TYPE_OVIRT_BROKER (boxes_ovirt_broker_get_type ())
#define BOXES_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBroker))
#define BOXES_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))
#define BOXES_IS_OVIRT_BROKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_IS_OVIRT_BROKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OVIRT_BROKER))
#define BOXES_OVIRT_BROKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OVIRT_BROKER, BoxesOvirtBrokerClass))

typedef struct _BoxesOvirtBroker BoxesOvirtBroker;
typedef struct _BoxesOvirtBrokerClass BoxesOvirtBrokerClass;
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;
#define _g_option_context_free0(var) ((var == NULL) ? NULL : (var = (g_option_context_free (var), NULL)))
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;

#define BOXES_TYPE_REMOTE_MACHINE (boxes_remote_machine_get_type ())
#define BOXES_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachine))
#define BOXES_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))
#define BOXES_IS_REMOTE_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_IS_REMOTE_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REMOTE_MACHINE))
#define BOXES_REMOTE_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REMOTE_MACHINE, BoxesRemoteMachineClass))

typedef struct _BoxesRemoteMachine BoxesRemoteMachine;
typedef struct _BoxesRemoteMachineClass BoxesRemoteMachineClass;
typedef struct _BoxesAppAddCollectionSourceData BoxesAppAddCollectionSourceData;
typedef struct _Block5Data Block5Data;
typedef struct _BoxesAppSetupSourcesData BoxesAppSetupSourcesData;
typedef struct _Block6Data Block6Data;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block7Data Block7Data;
#define _g_main_context_unref0(var) ((var == NULL) ? NULL : (var = (g_main_context_unref (var), NULL)))
typedef struct _Block8Data Block8Data;

struct _BoxesBroker {
	GObject parent_instance;
	BoxesBrokerPrivate * priv;
};

struct _BoxesBrokerClass {
	GObjectClass parent_class;
	void (*add_source) (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*add_source_finish) (BoxesBroker* self, GAsyncResult* _res_);
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollectionItem* current_item;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesBrokerAddSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesBroker* self;
	BoxesCollectionSource* source;
	GList* used_configs;
	BoxesApp* _tmp0_;
	BoxesCollection* _tmp1_;
	GPtrArray* _tmp2_;
	gpointer* _tmp3_;
	gint _tmp3__length1;
	BoxesCollectionItem** item_collection;
	gint item_collection_length1;
	gint _item_collection_size_;
	gint item_it;
	BoxesCollectionItem* _tmp4_;
	BoxesCollectionItem* item;
	BoxesCollectionItem* _tmp5_;
	BoxesCollectionItem* _tmp6_;
	BoxesBoxConfig* _tmp7_;
	BoxesBoxConfig* _tmp8_;
	BoxesCollectionSource* _tmp9_;
	GList* _tmp10_;
};

struct _BoxesAppPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	gchar* _uri;
	gboolean is_ready;
	GHashTable* brokers;
	GHashTable* sources;
	GBinding* status_bind;
	gulong got_error_id;
	gboolean _selection_mode;
};

struct _BoxesAppWindow {
	GtkApplicationWindow parent_instance;
	BoxesAppWindowPrivate * priv;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesSidebar* sidebar;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	GtkStack* below_bin;
	BoxesCollectionView* view;
	GSettings* settings;
};

struct _BoxesAppWindowClass {
	GtkApplicationWindowClass parent_class;
};

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

typedef void (*BoxesAppCallReadyFunc) (void* user_data);
struct _Block1Data {
	int _ref_count_;
	BoxesApp* self;
	BoxesAppCallReadyFunc func;
	gpointer func_target;
	GDestroyNotify func_target_destroy_notify;
};

struct _Block2Data {
	int _ref_count_;
	BoxesApp* self;
	BoxesApp* app;
};

struct _Block3Data {
	int _ref_count_;
	Block2Data * _data2_;
	gchar* uuid;
};

struct _Block4Data {
	int _ref_count_;
	Block2Data * _data2_;
	gchar* arg;
};

struct _BoxesAppAddCollectionSourceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GHashTable* _tmp3_;
	BoxesCollectionSource* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gconstpointer _tmp8_;
	gboolean _tmp9_;
	BoxesCollectionSource* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	BoxesCollectionSource* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GQuark _tmp19_;
	BoxesRemoteMachine* machine;
	BoxesCollectionSource* _tmp20_;
	BoxesRemoteMachine* _tmp21_;
	BoxesCollection* _tmp22_;
	BoxesRemoteMachine* _tmp23_;
	GError* _error_;
	GError* _tmp24_;
	const gchar* _tmp25_;
	BoxesBroker* broker;
	GHashTable* _tmp26_;
	BoxesCollectionSource* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	gconstpointer _tmp31_;
	BoxesBroker* _tmp32_;
	BoxesBroker* _tmp33_;
	BoxesBroker* _tmp34_;
	BoxesBroker* _tmp35_;
	BoxesCollectionSource* _tmp36_;
	GHashTable* _tmp37_;
	BoxesCollectionSource* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	BoxesCollectionSource* _tmp41_;
	BoxesCollectionSource* _tmp42_;
	BoxesCollectionSource* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gboolean _tmp47_;
	BoxesCollectionSource* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GError * _inner_error_;
};

struct _Block5Data {
	int _ref_count_;
	BoxesApp* self;
	GList* new_sources;
	gpointer _async_data_;
};

struct _BoxesAppSetupSourcesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesApp* self;
	Block5Data* _data5_;
	gchar* path;
	gchar* _tmp0_;
	gboolean create_session_source;
	GFile* file;
	GFile* _tmp1_;
	GFileInfo* info;
	GFileInfo* _tmp2_;
	guint64 _tmp3_;
	GError* _error_;
	GError* _tmp4_;
	const gchar* _tmp5_;
	gboolean _tmp6_;
	GFile* src;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GFile* _tmp9_;
	GFile* _tmp10_;
	GFile* dst;
	GFile* _tmp11_;
	GFile* _tmp12_;
	GFile* _tmp13_;
	GError* _vala1__error_;
	GError* _tmp14_;
	const gchar* _tmp15_;
	GFile* dir;
	gchar* _tmp16_;
	gchar* _tmp17_;
	GFile* _tmp18_;
	GFile* _tmp19_;
	GFile* _tmp20_;
	GList* _tmp21_;
	GList* source_collection;
	GList* source_it;
	BoxesCollectionSource* _tmp22_;
	BoxesCollectionSource* source;
	BoxesCollectionSource* _tmp23_;
	GVirConnection* _tmp24_;
	GVirConnection* _tmp25_;
	GVirConnection* _tmp26_;
	gboolean _tmp27_;
	GError * _inner_error_;
};

struct _Block6Data {
	int _ref_count_;
	BoxesApp* self;
	gint waiting_counter;
};

struct _Block7Data {
	int _ref_count_;
	Block6Data * _data6_;
	BoxesLibvirtMachine* machine;
};

typedef void (*BoxesAppUndoNotifyCallback) (void* user_data);
struct _Block8Data {
	int _ref_count_;
	BoxesApp* self;
	GList* items;
	BoxesAppUndoNotifyCallback undo_notify_callback;
	gpointer undo_notify_callback_target;
	GDestroyNotify undo_notify_callback_target_destroy_notify;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationCancelFunc) (void* user_data);

static gpointer boxes_broker_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_app_parent_class = NULL;
BoxesApp* boxes_app_app = NULL;
extern BoxesAppWindow* boxes_app_window;
BoxesAppWindow* boxes_app_window = NULL;
static gboolean boxes_app_opt_fullscreen;
static gboolean boxes_app_opt_fullscreen = FALSE;
static gboolean boxes_app_opt_help;
static gboolean boxes_app_opt_help = FALSE;
static gchar* boxes_app_opt_open_uuid;
static gchar* boxes_app_opt_open_uuid = NULL;
static gchar** boxes_app_opt_uris;
static gint boxes_app_opt_uris_length1;
static gchar** boxes_app_opt_uris = NULL;
static gint boxes_app_opt_uris_length1 = 0;
static gint _boxes_app_opt_uris_size_ = 0;
static gchar** boxes_app_opt_search;
static gint boxes_app_opt_search_length1;
static gchar** boxes_app_opt_search = NULL;
static gint boxes_app_opt_search_length1 = 0;
static gint _boxes_app_opt_search_size_ = 0;
static BoxesUIIface* boxes_app_boxes_ui_parent_iface = NULL;

GType boxes_broker_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_BROKER_DUMMY_PROPERTY
};
static void boxes_broker_real_add_source_data_free (gpointer _data);
static void boxes_broker_real_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_);
static gboolean boxes_broker_real_add_source_co (BoxesBrokerAddSourceData* _data_);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
BoxesBroker* boxes_broker_construct (GType object_type);
#define BOXES_APP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_APP, BoxesAppPrivate))
enum  {
	BOXES_APP_DUMMY_PROPERTY,
	BOXES_APP_PREVIOUS_UI_STATE,
	BOXES_APP_UI_STATE,
	BOXES_APP_URI,
	BOXES_APP_DEFAULT_CONNECTION,
	BOXES_APP_DEFAULT_SOURCE,
	BOXES_APP_SELECTION_MODE,
	BOXES_APP_SELECTED_ITEMS
};
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesApp* boxes_app_new (void);
BoxesApp* boxes_app_construct (GType object_type);
static void _g_free0_ (gpointer var);
BoxesCollectionFilter* boxes_collection_filter_new (void);
BoxesCollectionFilter* boxes_collection_filter_construct (GType object_type);
static void __lambda161_ (BoxesApp* self);
gboolean boxes_app_quit_app (BoxesApp* self);
static void ___lambda161__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda162_ (BoxesApp* self);
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static void ___lambda162__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda163_ (BoxesApp* self);
static void ___lambda163__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda164_ (BoxesApp* self);
static void ___lambda164__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda165_ (BoxesApp* self);
static void ___lambda165__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void __lambda166_ (BoxesApp* self);
static void ___lambda166__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self);
static void boxes_app_ui_state_changed (BoxesApp* self);
static void _boxes_app_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_app_real_startup (GApplication* base);
BoxesCollection* boxes_collection_new (void);
BoxesCollection* boxes_collection_construct (GType object_type);
static void __lambda167_ (BoxesApp* self, BoxesCollectionItem* item);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static void ___lambda167__boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void __lambda168_ (BoxesApp* self, BoxesCollectionItem* item);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static void ___lambda168__boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
GType boxes_libvirt_broker_get_type (void) G_GNUC_CONST;
BoxesLibvirtBroker* boxes_libvirt_broker_get_default (void);
GType boxes_ovirt_broker_get_type (void) G_GNUC_CONST;
BoxesOvirtBroker* boxes_ovirt_broker_get_default (void);
static void boxes_app_setup_sources (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_app_setup_sources_finish (BoxesApp* self, GAsyncResult* _res_);
static void __lambda173_ (BoxesApp* self, GObject* obj, GAsyncResult* _result_);
static void ___lambda173__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type);
void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda158_ (Block1Data* _data1_);
static void ___lambda158__boxes_app_ready (BoxesApp* _sender, gpointer self);
static void boxes_app_real_activate (GApplication* base);
BoxesAppWindow* boxes_app_window_new (GtkApplication* app);
BoxesAppWindow* boxes_app_window_construct (GType object_type, GtkApplication* app);
void boxes_app_window_setup_ui (BoxesAppWindow* self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
static gint boxes_app_real_command_line (GApplication* base, GApplicationCommandLine* cmdline);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void ___lambda174_ (Block3Data* _data3_);
gboolean boxes_app_open_uuid (BoxesApp* self, const gchar* uuid);
static void ____lambda174__boxes_app_call_ready_func (gpointer self);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void ____lambda175_ (Block4Data* _data4_);
void boxes_wizard_open_with_uri (BoxesWizard* self, const gchar* uri, gboolean skip_review_for_live);
void boxes_app_open_name (BoxesApp* self, const gchar* name);
static void _____lambda175__boxes_app_call_ready_func (gpointer self);
static void ___lambda176_ (BoxesApp* self);
void boxes_searchbar_set_text (BoxesSearchbar* self, const gchar* value);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void ____lambda176__boxes_app_call_ready_func (gpointer self);
void boxes_app_window_set_fullscreened (BoxesAppWindow* self, gboolean value);
static gboolean __lambda159_ (BoxesApp* self);
static gboolean ___lambda159__gsource_func (gpointer self);
static void boxes_app_real_shutdown (GApplication* base);
void boxes_notificationbar_cancel (BoxesNotificationbar* self);
void boxes_wizard_cleanup (BoxesWizard* self);
static void boxes_app_suspend_machines (BoxesApp* self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item);
void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
void boxes_collection_remove_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_app_add_collection_source_data_free (gpointer _data);
void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_);
static gboolean boxes_app_add_collection_source_co (BoxesAppAddCollectionSourceData* _data_);
GType boxes_remote_machine_get_type (void) G_GNUC_CONST;
BoxesRemoteMachine* boxes_remote_machine_new (BoxesCollectionSource* source, GError** error);
BoxesRemoteMachine* boxes_remote_machine_construct (GType object_type, BoxesCollectionSource* source, GError** error);
void boxes_collection_add_item (BoxesCollection* self, BoxesCollectionItem* item);
static void boxes_app_add_collection_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_app_setup_sources_data_free (gpointer _data);
static gboolean boxes_app_setup_sources_co (BoxesAppSetupSourcesData* _data_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void boxes_app_setup_sources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static gboolean __lambda172_ (Block5Data* _data5_, const gchar* filename, GError** error);
static gboolean ___lambda172__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error);
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
void boxes_topbar_set_status (BoxesTopbar* self, const gchar* value);
GCancellable* boxes_machine_get_connecting_cancellable (BoxesMachine* self);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
static Block7Data* block7_data_ref (Block7Data* _data7_);
static void block7_data_unref (void * _userdata_);
void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void ______lambda177_ (Block7Data* _data7_);
static void _______lambda177__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
void boxes_app_show_properties (BoxesApp* self);
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static void __lambda55_ (Block8Data* _data8_);
static void ___lambda55__boxes_notification_ok_func (gpointer self);
static void __lambda56_ (Block8Data* _data8_);
static void ___lambda56__boxes_notification_cancel_func (gpointer self);
GdNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
void boxes_app_remove_selected_items (BoxesApp* self);
void boxes_app_connect_to (BoxesApp* self, BoxesMachine* machine);
static void __lambda127_ (BoxesApp* self, const gchar* message);
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
static void ___lambda127__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
const gchar* boxes_app_get_uri (BoxesApp* self);
void boxes_app_set_uri (BoxesApp* self, const gchar* value);
GVirConnection* boxes_libvirt_broker_get_connection (BoxesLibvirtBroker* self, const gchar* name);
BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void boxes_app_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_app_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_app_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GOptionEntry BOXES_APP_options[8] = {{"version", (gchar) 0, 0, G_OPTION_ARG_NONE, NULL, "Display version number", NULL}, {"help", 'h', (gint) G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &boxes_app_opt_help, NULL, NULL}, {"full-screen", 'f', 0, G_OPTION_ARG_NONE, &boxes_app_opt_fullscreen, "Open in full screen", NULL}, {"checks", (gchar) 0, 0, G_OPTION_ARG_NONE, NULL, "Check virtualization capabilities", NULL}, {"open-uuid", (gchar) 0, 0, G_OPTION_ARG_STRING, &boxes_app_opt_open_uuid, "Open box with UUID", NULL}, {"search", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &boxes_app_opt_search, "Search term", NULL}, {"", (gchar) 0, 0, G_OPTION_ARG_STRING_ARRAY, &boxes_app_opt_uris, "URI to display, broker or installer media", NULL}, {NULL}};

static void boxes_broker_real_add_source_data_free (gpointer _data) {
	BoxesBrokerAddSourceData* _data_;
	_data_ = _data;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesBrokerAddSourceData, _data_);
#line 850 "app.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return self ? g_object_ref (self) : NULL;
#line 857 "app.c"
}


static void boxes_broker_real_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesBrokerAddSourceData* _data_;
	BoxesBroker* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesBrokerAddSourceData);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_broker_real_add_source);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_broker_real_add_source_data_free);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = source;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->source = _tmp2_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_broker_real_add_source_co (_data_);
#line 886 "app.c"
}


static void boxes_broker_real_add_source_finish (BoxesBroker* self, GAsyncResult* _res_) {
	BoxesBrokerAddSourceData* _data_;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 894 "app.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 901 "app.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_list_free (self);
#line 910 "app.c"
}


static gboolean boxes_broker_real_add_source_co (BoxesBrokerAddSourceData* _data_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 919 "app.c"
		goto _state_0;
		default:
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 924 "app.c"
	}
	_state_0:
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->used_configs = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_app_app;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = _data_->_tmp0_->collection;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = _data_->_tmp1_->items;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3__length1 = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->_tmp2_->pdata;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3__length1 = (gint) _data_->_tmp2_->len;
#line 949 "app.c"
	{
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection_length1 = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_item_collection_size_ = 0;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection = _data_->_tmp3_;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->item_collection_length1 = _data_->_tmp3__length1;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (_data_->item_it = 0; _data_->item_it < _data_->_tmp3__length1; _data_->item_it = _data_->item_it + 1) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp4_ = NULL;
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp4_ = _g_object_ref0 (_data_->item_collection[_data_->item_it]);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->item = _data_->_tmp4_;
#line 967 "app.c"
			{
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp5_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp5_ = _data_->item;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp5_, BOXES_TYPE_MACHINE)) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (_data_->item);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 979 "app.c"
				}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp6_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp6_ = _data_->item;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp7_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp6_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _data_->_tmp6_) : NULL)->config;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp8_ = NULL;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp8_ = _g_object_ref0 (_data_->_tmp7_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->used_configs = g_list_append (_data_->used_configs, _data_->_tmp8_);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->item);
#line 997 "app.c"
			}
		}
	}
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = _data_->source;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp10_ = _data_->used_configs;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_source_purge_stale_box_configs (_data_->_tmp9_, _data_->_tmp10_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (_data_->used_configs);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1017 "app.c"
	} else {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1021 "app.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 1027 "app.c"
}


void boxes_broker_add_source (BoxesBroker* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_GET_CLASS (self)->add_source (self, source, _callback_, _user_data_);
#line 1034 "app.c"
}


void boxes_broker_add_source_finish (BoxesBroker* self, GAsyncResult* _res_) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_GET_CLASS (self)->add_source_finish (self, _res_);
#line 1041 "app.c"
}


BoxesBroker* boxes_broker_construct (GType object_type) {
	BoxesBroker * self = NULL;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesBroker*) g_object_new (object_type, NULL);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1051 "app.c"
}


static void boxes_broker_class_init (BoxesBrokerClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_broker_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_CLASS (klass)->add_source = boxes_broker_real_add_source;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	BOXES_BROKER_CLASS (klass)->add_source_finish = boxes_broker_real_add_source_finish;
#line 1062 "app.c"
}


static void boxes_broker_instance_init (BoxesBroker * self) {
}


GType boxes_broker_get_type (void) {
	static volatile gsize boxes_broker_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_broker_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesBrokerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_broker_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesBroker), 0, (GInstanceInitFunc) boxes_broker_instance_init, NULL };
		GType boxes_broker_type_id;
		boxes_broker_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesBroker", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&boxes_broker_type_id__volatile, boxes_broker_type_id);
	}
	return boxes_broker_type_id__volatile;
}


static void _g_free0_ (gpointer var) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	var = (g_free (var), NULL);
#line 1085 "app.c"
}


static void __lambda161_ (BoxesApp* self) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_quit_app (self);
#line 1092 "app.c"
}


static void ___lambda161__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda161_ ((BoxesApp*) self);
#line 1099 "app.c"
}


static void __lambda162_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_select (_tmp1_, BOXES_SELECTION_CRITERIA_ALL);
#line 1112 "app.c"
}


static void ___lambda162__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda162_ ((BoxesApp*) self);
#line 1119 "app.c"
}


static void __lambda163_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_select (_tmp1_, BOXES_SELECTION_CRITERIA_RUNNING);
#line 1132 "app.c"
}


static void ___lambda163__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda163_ ((BoxesApp*) self);
#line 1139 "app.c"
}


static void __lambda164_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_select (_tmp1_, BOXES_SELECTION_CRITERIA_NONE);
#line 1152 "app.c"
}


static void ___lambda164__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda164_ ((BoxesApp*) self);
#line 1159 "app.c"
}


static void __lambda165_ (BoxesApp* self) {
	GError * _inner_error_ = NULL;
	{
		BoxesAppWindow* _tmp0_ = NULL;
		GdkScreen* _tmp1_ = NULL;
		guint32 _tmp2_ = 0U;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = boxes_app_window;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp1_ = gtk_window_get_screen ((GtkWindow*) _tmp0_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = gtk_get_current_event_time ();
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		gtk_show_uri (_tmp1_, "help:gnome-boxes", _tmp2_, &_inner_error_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1179 "app.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		e = _inner_error_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = e;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = _tmp3_->message;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:76: Failed to display help: %s", _tmp4_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (e);
#line 1201 "app.c"
	}
	__finally0:
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 1212 "app.c"
	}
}


static void ___lambda165__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda165_ ((BoxesApp*) self);
#line 1220 "app.c"
}


static void __lambda166_ (BoxesApp* self) {
	gchar** authors = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar** _tmp4_ = NULL;
	gint authors_length1 = 0;
	gint _authors_size_ = 0;
	gchar** artists = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar** _tmp7_ = NULL;
	gint artists_length1 = 0;
	gint _artists_size_ = 0;
	BoxesAppWindow* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_strdup ("Alexander Larsson <alexl@redhat.com>");
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup ("Christophe Fergeau <cfergeau@redhat.com>");
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_strdup ("Marc-André Lureau <marcandre.lureau@gmail.com>");
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_strdup ("Zeeshan Ali (Khattak) <zeeshanak@gnome.org>");
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_new0 (gchar*, 4 + 1);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[0] = _tmp0_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[1] = _tmp1_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[2] = _tmp2_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_[3] = _tmp3_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	authors = _tmp4_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	authors_length1 = 4;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_authors_size_ = authors_length1;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_strdup ("Jon McCann <jmccann@redhat.com>");
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_strdup ("Jakub Steiner <jsteiner@redhat.com>");
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_new0 (gchar*, 2 + 1);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_[0] = _tmp5_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_[1] = _tmp6_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	artists = _tmp7_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	artists_length1 = 2;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_artists_size_ = artists_length1;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = boxes_app_window;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _ ("translator-credits");
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = _ ("A simple GNOME 3 application to access remote or virtual systems");
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_show_about_dialog ((GtkWindow*) _tmp8_, "artists", artists, "authors", authors, "translator-credits", _tmp9_, "comments", _tmp10_, "copyright", "Copyright 2011 Red Hat, Inc.", "license-type", GTK_LICENSE_LGPL_2_1, "logo-icon-name", "gnome-boxes", "version", VERSION, "website", "http://live.gnome.org/Boxes", "wrap-license", TRUE, NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	artists = (_vala_array_free (artists, artists_length1, (GDestroyNotify) g_free), NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	authors = (_vala_array_free (authors, authors_length1, (GDestroyNotify) g_free), NULL);
#line 1294 "app.c"
}


static void ___lambda166__g_simple_action_activate (GSimpleAction* _sender, GVariant* parameter, gpointer self) {
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda166_ ((BoxesApp*) self);
#line 1301 "app.c"
}


static void _boxes_app_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_ui_state_changed ((BoxesApp*) self);
#line 1308 "app.c"
}


BoxesApp* boxes_app_construct (GType object_type) {
	BoxesApp * self = NULL;
	GApplicationFlags _tmp0_ = 0;
	GApplicationFlags _tmp1_ = 0;
	BoxesApp* _tmp2_ = NULL;
	GHashFunc _tmp3_ = NULL;
	GEqualFunc _tmp4_ = NULL;
	GHashTable* _tmp5_ = NULL;
	GHashFunc _tmp6_ = NULL;
	GEqualFunc _tmp7_ = NULL;
	GHashTable* _tmp8_ = NULL;
	BoxesCollectionFilter* _tmp9_ = NULL;
	GSimpleAction* action = NULL;
	GSimpleAction* _tmp10_ = NULL;
	GSimpleAction* _tmp11_ = NULL;
	GSimpleAction* _tmp12_ = NULL;
	GSimpleAction* _tmp13_ = NULL;
	GSimpleAction* _tmp14_ = NULL;
	GSimpleAction* _tmp15_ = NULL;
	GSimpleAction* _tmp16_ = NULL;
	GSimpleAction* _tmp17_ = NULL;
	GSimpleAction* _tmp18_ = NULL;
	GSimpleAction* _tmp19_ = NULL;
	GSimpleAction* _tmp20_ = NULL;
	GSimpleAction* _tmp21_ = NULL;
	GSimpleAction* _tmp22_ = NULL;
	GSimpleAction* _tmp23_ = NULL;
	GSimpleAction* _tmp24_ = NULL;
	GSimpleAction* _tmp25_ = NULL;
	GSimpleAction* _tmp26_ = NULL;
	GSimpleAction* _tmp27_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) g_object_new (object_type, NULL);
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_set_application_id ((GApplication*) self, "org.gnome.Boxes");
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_application_get_flags ((GApplication*) self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_set_flags ((GApplication*) self, _tmp1_ | G_APPLICATION_HANDLES_COMMAND_LINE);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (self);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (boxes_app_app);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_app = _tmp2_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_str_hash;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_str_equal;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_hash_table_new_full (_tmp3_, _tmp4_, _g_free0_, _g_object_unref0_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->sources);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->sources = _tmp5_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = g_str_hash;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_str_equal;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = g_hash_table_new_full (_tmp6_, _tmp7_, _g_free0_, _g_object_unref0_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->brokers);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->brokers = _tmp8_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = boxes_collection_filter_new ();
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->filter);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->filter = _tmp9_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = g_simple_action_new ("quit", NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp10_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = action;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp11_, "activate", (GCallback) ___lambda161__g_simple_action_activate, self, 0);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = action;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp12_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = g_simple_action_new ("select-all", NULL);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp13_;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = action;
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp14_, "activate", (GCallback) ___lambda162__g_simple_action_activate, self, 0);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = action;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp15_);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = g_simple_action_new ("select-running", NULL);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp16_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp17_ = action;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp17_, "activate", (GCallback) ___lambda163__g_simple_action_activate, self, 0);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = action;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp18_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = g_simple_action_new ("select-none", NULL);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp19_;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = action;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp20_, "activate", (GCallback) ___lambda164__g_simple_action_activate, self, 0);
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp21_ = action;
#line 67 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp21_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp22_ = g_simple_action_new ("help", NULL);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp22_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp23_ = action;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp23_, "activate", (GCallback) ___lambda165__g_simple_action_activate, self, 0);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = action;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp24_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp25_ = g_simple_action_new ("about", NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	action = _tmp25_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp26_ = action;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp26_, "activate", (GCallback) ___lambda166__g_simple_action_activate, self, 0);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp27_ = action;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_action_map_add_action ((GActionMap*) self, (GAction*) _tmp27_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_app_ui_state_changed_g_object_notify, self, 0);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (action);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return self;
#line 1473 "app.c"
}


BoxesApp* boxes_app_new (void) {
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return boxes_app_construct (BOXES_TYPE_APP);
#line 1480 "app.c"
}


static void __lambda167_ (BoxesApp* self, BoxesCollectionItem* item) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = item;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_add_item (_tmp1_, _tmp2_);
#line 1498 "app.c"
}


static void ___lambda167__boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda167_ ((BoxesApp*) self, item);
#line 1505 "app.c"
}


static void __lambda168_ (BoxesApp* self, BoxesCollectionItem* item) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = item;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_view_remove_item (_tmp1_, _tmp2_);
#line 1523 "app.c"
}


static void ___lambda168__boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda168_ ((BoxesApp*) self, item);
#line 1530 "app.c"
}


static void __lambda173_ (BoxesApp* self, GObject* obj, GAsyncResult* _result_) {
	GAsyncResult* _tmp0_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (_result_ != NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _result_;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_finish (self, _tmp0_);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->is_ready = TRUE;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_emit_by_name (self, "ready");
#line 1546 "app.c"
}


static void ___lambda173__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda173_ ((BoxesApp*) self, source_object, res);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (self);
#line 1555 "app.c"
}


static void boxes_app_real_startup (GApplication* base) {
	BoxesApp * self;
	gchar** args = NULL;
	gchar** _tmp0_ = NULL;
	gint args_length1 = 0;
	gint _args_size_ = 0;
	gchar** args2 = NULL;
	gchar** _tmp1_ = NULL;
	gint _tmp1__length1 = 0;
	gint args2_length1 = 0;
	gint _args2_size_ = 0;
	GMenu* menu = NULL;
	GMenu* _tmp2_ = NULL;
	GMenu* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	GMenu* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	GMenu* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	GMenu* _tmp9_ = NULL;
	BoxesCollection* _tmp10_ = NULL;
	BoxesCollection* _tmp11_ = NULL;
	BoxesCollection* _tmp12_ = NULL;
	GHashTable* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	BoxesLibvirtBroker* _tmp15_ = NULL;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_app_parent_class)->startup ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_APPLICATION, GtkApplication));
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args = _tmp0_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args_length1 = 0;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_args_size_ = args_length1;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = args;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__length1 = args_length1;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args2 = _tmp1_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args2_length1 = _tmp1__length1;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_args2_size_ = args2_length1;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_init (&args2_length1, &args2);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_menu_new ();
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	menu = _tmp2_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = menu;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _ ("Help");
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp3_, _tmp4_, "app.help");
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = menu;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _ ("About");
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp5_, _tmp6_, "app.about");
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = menu;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = _ ("Quit");
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_menu_append (_tmp7_, _tmp8_, "app.quit");
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = menu;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_application_set_app_menu ((GtkApplication*) self, (GMenuModel*) _tmp9_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = boxes_collection_new ();
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->collection);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->collection = _tmp10_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = self->collection;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp11_, "item-added", (GCallback) ___lambda167__boxes_collection_item_added, self, 0);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = self->collection;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_object (_tmp12_, "item-removed", (GCallback) ___lambda168__boxes_collection_item_removed, self, 0);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = self->priv->brokers;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = g_strdup ("libvirt");
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp15_ = boxes_libvirt_broker_get_default ();
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_hash_table_insert (_tmp13_, _tmp14_, (BoxesBroker*) _tmp15_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (HAVE_OVIRT) {
#line 1659 "app.c"
		GHashTable* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		BoxesOvirtBroker* _tmp18_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = self->priv->brokers;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = g_strdup ("ovirt");
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = boxes_ovirt_broker_get_default ();
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_hash_table_insert (_tmp16_, _tmp17_, (BoxesBroker*) _tmp18_);
#line 1671 "app.c"
	}
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources (self, ___lambda173__gasync_ready_callback, g_object_ref (self));
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_check_cpu_vt_capability (NULL, NULL);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_check_module_kvm_loaded (NULL, NULL);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (menu);
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	args = (_vala_array_free (args, args_length1, (GDestroyNotify) g_free), NULL);
#line 1683 "app.c"
}


gboolean boxes_app_has_broker_for_source_type (BoxesApp* self, const gchar* type) {
	gboolean result = FALSE;
	GHashTable* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (type != NULL, FALSE);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->brokers;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = type;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = g_hash_table_contains (_tmp0_, _tmp1_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp2_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 1706 "app.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data1_;
#line 1715 "app.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1724 "app.c"
		BoxesApp* self;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data1_->self;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		(_data1_->func_target_destroy_notify == NULL) ? NULL : (_data1_->func_target_destroy_notify (_data1_->func_target), NULL);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data1_->func = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data1_->func_target = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data1_->func_target_destroy_notify = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block1Data, _data1_);
#line 1740 "app.c"
	}
}


static void __lambda158_ (Block1Data* _data1_) {
	BoxesApp* self;
	BoxesAppCallReadyFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data1_->self;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data1_->func;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0__target = _data1_->func_target;
#line 157 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ (_tmp0__target);
#line 1757 "app.c"
}


static void ___lambda158__boxes_app_ready (BoxesApp* _sender, gpointer self) {
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda158_ (self);
#line 1764 "app.c"
}


void boxes_app_call_when_ready (BoxesApp* self, BoxesAppCallReadyFunc func, void* func_target, GDestroyNotify func_target_destroy_notify) {
	Block1Data* _data1_;
	BoxesAppCallReadyFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	gboolean _tmp1_ = FALSE;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->_ref_count_ = 1;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->self = g_object_ref (self);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = func;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0__target = func_target;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(_data1_->func_target_destroy_notify == NULL) ? NULL : (_data1_->func_target_destroy_notify (_data1_->func_target), NULL);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target_destroy_notify = NULL;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func = _tmp0_;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target = _tmp0__target;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_->func_target_destroy_notify = func_target_destroy_notify;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = self->priv->is_ready;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp1_) {
#line 1803 "app.c"
		BoxesAppCallReadyFunc _tmp2_ = NULL;
		void* _tmp2__target = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ = _data1_->func;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2__target = _data1_->func_target;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp2_ (_tmp2__target);
#line 1812 "app.c"
	}
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_connect_data (self, "ready", (GCallback) ___lambda158__boxes_app_ready, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block1_data_unref (_data1_);
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data1_ = NULL;
#line 1820 "app.c"
}


static void boxes_app_real_activate (GApplication* base) {
	BoxesApp * self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_app_parent_class)->activate ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_APPLICATION, GtkApplication));
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_ != NULL) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 1840 "app.c"
	}
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_app_window_new ((GtkApplication*) self);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_ref_sink (_tmp1_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (boxes_app_window);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window = _tmp1_;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window;
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_window_setup_ui (_tmp2_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_app_window;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_window_present ((GtkWindow*) _tmp3_);
#line 1860 "app.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data2_;
#line 1869 "app.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1878 "app.c"
		BoxesApp* self;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data2_->self;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data2_->app);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block2Data, _data2_);
#line 1888 "app.c"
	}
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data3_;
#line 1898 "app.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1907 "app.c"
		BoxesApp* self;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data3_->_data2_->self;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data3_->uuid);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data3_->_data2_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->_data2_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block3Data, _data3_);
#line 1919 "app.c"
	}
}


static void ___lambda174_ (Block3Data* _data3_) {
	Block2Data* _data2_;
	BoxesApp* self;
	BoxesApp* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = _data3_->_data2_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data2_->self;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data2_->app;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _data3_->uuid;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_open_uuid (_tmp0_, _tmp1_);
#line 1939 "app.c"
}


static void ____lambda174__boxes_app_call_ready_func (gpointer self) {
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda174_ (self);
#line 1946 "app.c"
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data4_;
#line 1955 "app.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1964 "app.c"
		BoxesApp* self;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data4_->_data2_->self;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data4_->arg);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data4_->_data2_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data4_->_data2_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block4Data, _data4_);
#line 1976 "app.c"
	}
}


static void ____lambda175_ (Block4Data* _data4_) {
	Block2Data* _data2_;
	BoxesApp* self;
	GFile* file = NULL;
	const gchar* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean is_uri = FALSE;
	const gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	GFile* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = _data4_->_data2_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data2_->self;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data4_->arg;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_file_new_for_commandline_arg (_tmp0_);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	file = _tmp1_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data4_->arg;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_uri_parse_scheme (_tmp2_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_ != NULL;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp4_);
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	is_uri = _tmp5_;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = file;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = g_file_query_exists (_tmp6_, NULL);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp7_) {
#line 2022 "app.c"
		gboolean _tmp8_ = FALSE;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = is_uri;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp8_) {
#line 2028 "app.c"
			BoxesAppWindow* _tmp9_ = NULL;
			BoxesWizard* _tmp10_ = NULL;
			const gchar* _tmp11_ = NULL;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = boxes_app_window;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = _tmp9_->wizard;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp11_ = _data4_->arg;
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp10_, _tmp11_, TRUE);
#line 2040 "app.c"
		} else {
			BoxesAppWindow* _tmp12_ = NULL;
			BoxesWizard* _tmp13_ = NULL;
			GFile* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp12_ = boxes_app_window;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp13_ = _tmp12_->wizard;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = file;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = g_file_get_uri (_tmp14_);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp16_ = _tmp15_;
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp13_, _tmp16_, TRUE);
#line 244 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_tmp16_);
#line 2061 "app.c"
		}
	} else {
		gboolean _tmp17_ = FALSE;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = is_uri;
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp17_) {
#line 2069 "app.c"
			BoxesAppWindow* _tmp18_ = NULL;
			BoxesWizard* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp18_ = boxes_app_window;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp19_ = _tmp18_->wizard;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp20_ = _data4_->arg;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_wizard_open_with_uri (_tmp19_, _tmp20_, TRUE);
#line 2081 "app.c"
		} else {
			const gchar* _tmp21_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp21_ = _data4_->arg;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_open_name (self, _tmp21_);
#line 2088 "app.c"
		}
	}
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (file);
#line 2093 "app.c"
}


static void _____lambda175__boxes_app_call_ready_func (gpointer self) {
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	____lambda175_ (self);
#line 2100 "app.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
#line 964 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 964 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 965 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		separator = "";
#line 2117 "app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 2127 "app.c"
	} else {
		gchar** _tmp4_ = NULL;
		gint _tmp4__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 2137 "app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 2143 "app.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_ = NULL;
		gint _tmp6__length1 = 0;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == (-1)) {
#line 2154 "app.c"
			gchar** _tmp7_ = NULL;
			gint _tmp7__length1 = 0;
			const gchar* _tmp8_ = NULL;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 2166 "app.c"
		} else {
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 2170 "app.c"
		}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 2174 "app.c"
	}
#line 967 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 2178 "app.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_ = 0;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		gsize _tmp35_ = 0UL;
		const gchar* _tmp36_ = NULL;
		gint _tmp37_ = 0;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		const gchar* res = NULL;
		gsize _tmp40_ = 0UL;
		void* _tmp41_ = NULL;
		void* ptr = NULL;
		const gchar* _tmp42_ = NULL;
		gchar** _tmp43_ = NULL;
		gint _tmp43__length1 = 0;
		const gchar* _tmp44_ = NULL;
		void* _tmp45_ = NULL;
		const gchar* _tmp62_ = NULL;
#line 969 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 2201 "app.c"
		{
			gboolean _tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			i = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2210 "app.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_ = NULL;
				gint _tmp13__length1 = 0;
				gint _tmp21_ = 0;
				gchar** _tmp22_ = NULL;
				gint _tmp22__length1 = 0;
				gint _tmp23_ = 0;
				const gchar* _tmp24_ = NULL;
				gsize _tmp30_ = 0UL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 2223 "app.c"
					gint _tmp10_ = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 2229 "app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != (-1)) {
#line 2239 "app.c"
					gint _tmp14_ = 0;
					gchar** _tmp15_ = NULL;
					gint _tmp15__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 2251 "app.c"
				} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 2255 "app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 2261 "app.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_ = NULL;
					gint _tmp17__length1 = 0;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == (-1)) {
#line 2272 "app.c"
						gchar** _tmp18_ = NULL;
						gint _tmp18__length1 = 0;
						gint _tmp19_ = 0;
						const gchar* _tmp20_ = NULL;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 2287 "app.c"
					} else {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 2291 "app.c"
					}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 2295 "app.c"
				}
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 970 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					break;
#line 2301 "app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 2313 "app.c"
					gchar** _tmp25_ = NULL;
					gint _tmp25__length1 = 0;
					gint _tmp26_ = 0;
					const gchar* _tmp27_ = NULL;
					gint _tmp28_ = 0;
					gint _tmp29_ = 0;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 2334 "app.c"
				} else {
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 2338 "app.c"
				}
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 971 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 2344 "app.c"
			}
		}
#line 973 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 973 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 2351 "app.c"
			gchar* _tmp32_ = NULL;
#line 974 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 974 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 974 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			return result;
#line 2359 "app.c"
		}
#line 976 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 976 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 976 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 977 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 979 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 979 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 979 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 980 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 2397 "app.c"
		{
			gboolean _tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			i = 1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 2406 "app.c"
				gint _tmp48_ = 0;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				void* _tmp50_ = NULL;
				const gchar* _tmp51_ = NULL;
				void* _tmp52_ = NULL;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_ = NULL;
				gint _tmp54__length1 = 0;
				gint _tmp55_ = 0;
				const gchar* _tmp56_ = NULL;
				void* _tmp60_ = NULL;
				void* _tmp61_ = NULL;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 2422 "app.c"
					gint _tmp47_ = 0;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 2428 "app.c"
				}
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 981 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					break;
#line 2442 "app.c"
				}
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 982 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 2462 "app.c"
					gchar** _tmp57_ = NULL;
					gint _tmp57__length1 = 0;
					gint _tmp58_ = 0;
					const gchar* _tmp59_ = NULL;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 2477 "app.c"
				} else {
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 2481 "app.c"
				}
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 983 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 2489 "app.c"
			}
		}
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		res = NULL;
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 986 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		return result;
#line 2500 "app.c"
	} else {
		gchar* _tmp63_ = NULL;
#line 988 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 988 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 988 "/home/zeenix/jhbuild/share/vala-0.26/vapi/glib-2.0.vapi"
		return result;
#line 2509 "app.c"
	}
}


static void ___lambda176_ (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	BoxesUIState _tmp5_ = 0;
	BoxesUIState _tmp6_ = 0;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_opt_search;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2__length1 = boxes_app_opt_search_length1;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _vala_g_strjoinv (" ", _tmp2_, _tmp2__length1);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_searchbar_set_text (_tmp1_, _tmp4_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp4_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _tmp5_;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp6_ == BOXES_UI_STATE_COLLECTION) {
#line 2545 "app.c"
		BoxesAppWindow* _tmp7_ = NULL;
		BoxesSearchbar* _tmp8_ = NULL;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = boxes_app_window;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = _tmp7_->searchbar;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_set ((GtkSearchBar*) _tmp8_, "search-mode-enabled", TRUE, NULL);
#line 2554 "app.c"
	}
}


static void ____lambda176__boxes_app_call_ready_func (gpointer self) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	___lambda176_ ((BoxesApp*) self);
#line 2562 "app.c"
}


static gint boxes_app_real_command_line (GApplication* base, GApplicationCommandLine* cmdline) {
	BoxesApp * self;
	gint result = 0;
	Block2Data* _data2_;
	gchar* parameter_string = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GOptionContext* opt_context = NULL;
	const gchar* _tmp2_ = NULL;
	GOptionContext* _tmp3_ = NULL;
	GOptionContext* _tmp4_ = NULL;
	GOptionContext* _tmp5_ = NULL;
	gboolean _tmp18_ = FALSE;
	gboolean _tmp23_ = FALSE;
	gchar** _tmp24_ = NULL;
	gint _tmp24__length1 = 0;
	BoxesApp* _tmp34_ = NULL;
	const gchar* _tmp35_ = NULL;
	gchar** _tmp42_ = NULL;
	gint _tmp42__length1 = 0;
	gboolean _tmp43_ = FALSE;
	GError * _inner_error_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (cmdline != NULL, 0);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->_ref_count_ = 1;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->self = g_object_ref (self);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_fullscreen = FALSE;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_help = FALSE;
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (boxes_app_opt_open_uuid);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_open_uuid = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris = (_vala_array_free (boxes_app_opt_uris, boxes_app_opt_uris_length1, (GDestroyNotify) g_free), NULL);
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris = NULL;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_uris_length1 = 0;
#line 195 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_boxes_app_opt_uris_size_ = boxes_app_opt_uris_length1;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search = (_vala_array_free (boxes_app_opt_search, boxes_app_opt_search_length1, (GDestroyNotify) g_free), NULL);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_opt_search_length1 = 0;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_boxes_app_opt_search_size_ = boxes_app_opt_search_length1;
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _ ("- A simple application to access remote or virtual machines");
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 198 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	parameter_string = _tmp1_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = parameter_string;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = g_option_context_new (_tmp2_);
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	opt_context = _tmp3_;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = opt_context;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_option_context_add_main_entries (_tmp4_, BOXES_APP_options, NULL);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = opt_context;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_option_context_set_help_enabled (_tmp5_, FALSE);
#line 2642 "app.c"
	{
		gchar** args1 = NULL;
		GApplicationCommandLine* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gchar** _tmp8_ = NULL;
		gint args1_length1 = 0;
		gint _args1_size_ = 0;
		gchar** args2 = NULL;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		gint args2_length1 = 0;
		gint _args2_size_ = 0;
		GOptionContext* _tmp10_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = cmdline;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = g_application_command_line_get_arguments (_tmp6_, &_tmp7_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args1 = _tmp8_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args1_length1 = _tmp7_;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_args1_size_ = args1_length1;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = args1;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9__length1 = args1_length1;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args2 = _tmp9_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args2_length1 = _tmp9__length1;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_args2_size_ = args2_length1;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = opt_context;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_option_context_parse (_tmp10_, &args2_length1, &args2, &_inner_error_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			if (_inner_error_->domain == G_OPTION_ERROR) {
#line 2686 "app.c"
				goto __catch1_g_option_error;
			}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_option_context_free0 (opt_context);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (parameter_string);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			block2_data_unref (_data2_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data2_ = NULL;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_clear_error (&_inner_error_);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			return 0;
#line 2705 "app.c"
		}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		args1 = (_vala_array_free (args1, args1_length1, (GDestroyNotify) g_free), NULL);
#line 2709 "app.c"
	}
	goto __finally1;
	__catch1_g_option_error:
	{
		GError* _error_ = NULL;
		GApplicationCommandLine* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GApplicationCommandLine* _tmp14_ = NULL;
		GOptionContext* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_error_ = _inner_error_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_inner_error_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = cmdline;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _error_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = _tmp12_->message;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp11_, "%s\n", _tmp13_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp14_ = cmdline;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = opt_context;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = g_option_context_get_help (_tmp15_, TRUE, NULL);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = _tmp16_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp14_, "%s", _tmp17_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp17_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 2760 "app.c"
	}
	__finally1:
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_inner_error_);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return 0;
#line 2779 "app.c"
	}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = boxes_app_opt_help;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp18_) {
#line 2785 "app.c"
		GApplicationCommandLine* _tmp19_ = NULL;
		GOptionContext* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = cmdline;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp20_ = opt_context;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp21_ = g_option_context_get_help (_tmp20_, TRUE, NULL);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp22_ = _tmp21_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp19_, "%s", _tmp22_);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp22_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 2814 "app.c"
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24_ = boxes_app_opt_uris;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp24__length1 = boxes_app_opt_uris_length1;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp24__length1 > 1) {
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = TRUE;
#line 2824 "app.c"
	} else {
		gboolean _tmp25_ = FALSE;
		const gchar* _tmp26_ = NULL;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp26_ = boxes_app_opt_open_uuid;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp26_ != NULL) {
#line 2832 "app.c"
			gchar** _tmp27_ = NULL;
			gint _tmp27__length1 = 0;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27_ = boxes_app_opt_uris;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp27__length1 = boxes_app_opt_uris_length1;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = _tmp27_ != NULL;
#line 2841 "app.c"
		} else {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp25_ = FALSE;
#line 2845 "app.c"
		}
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp23_ = _tmp25_;
#line 2849 "app.c"
	}
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp23_) {
#line 2853 "app.c"
		GApplicationCommandLine* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		GApplicationCommandLine* _tmp30_ = NULL;
		GOptionContext* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp28_ = cmdline;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp29_ = _ ("Too many command line arguments specified.\n");
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp28_, "%s", _tmp29_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp30_ = cmdline;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp31_ = opt_context;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp32_ = g_option_context_get_help (_tmp31_, TRUE, NULL);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp33_ = _tmp32_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_command_line_printerr (_tmp30_, "%s", _tmp33_);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp33_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		result = 1;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_option_context_free0 (opt_context);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (parameter_string);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block2_data_unref (_data2_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data2_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return result;
#line 2890 "app.c"
	}
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_activate ((GApplication*) self);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp34_ = _g_object_ref0 (self);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_->app = _tmp34_;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp35_ = boxes_app_opt_open_uuid;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp35_ != NULL) {
#line 2902 "app.c"
		Block3Data* _data3_;
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_ = g_slice_new0 (Block3Data);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->_ref_count_ = 1;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->_data2_ = block2_data_ref (_data2_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp36_ = boxes_app_opt_open_uuid;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_->uuid = _tmp37_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_call_when_ready (self, ____lambda174__boxes_app_call_ready_func, block3_data_ref (_data3_), block3_data_unref);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block3_data_unref (_data3_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data3_ = NULL;
#line 2924 "app.c"
	} else {
		gchar** _tmp38_ = NULL;
		gint _tmp38__length1 = 0;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp38_ = boxes_app_opt_uris;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp38__length1 = boxes_app_opt_uris_length1;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp38_ != NULL) {
#line 2934 "app.c"
			Block4Data* _data4_;
			gchar** _tmp39_ = NULL;
			gint _tmp39__length1 = 0;
			const gchar* _tmp40_ = NULL;
			gchar* _tmp41_ = NULL;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_ = g_slice_new0 (Block4Data);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_->_ref_count_ = 1;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_->_data2_ = block2_data_ref (_data2_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp39_ = boxes_app_opt_uris;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp39__length1 = boxes_app_opt_uris_length1;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp40_ = _tmp39_[0];
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp41_ = g_strdup (_tmp40_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_->arg = _tmp41_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_call_when_ready (self, _____lambda175__boxes_app_call_ready_func, block4_data_ref (_data4_), block4_data_unref);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			block4_data_unref (_data4_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data4_ = NULL;
#line 2962 "app.c"
		}
	}
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp42_ = boxes_app_opt_search;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp42__length1 = boxes_app_opt_search_length1;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp42_ != NULL) {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_call_when_ready (self, ____lambda176__boxes_app_call_ready_func, g_object_ref (self), g_object_unref);
#line 2973 "app.c"
	}
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp43_ = boxes_app_opt_fullscreen;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp43_) {
#line 2979 "app.c"
		BoxesAppWindow* _tmp44_ = NULL;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp44_ = boxes_app_window;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_window_set_fullscreened (_tmp44_, TRUE);
#line 2985 "app.c"
	}
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = 0;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_option_context_free0 (opt_context);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (parameter_string);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block2_data_unref (_data2_);
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data2_ = NULL;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 2999 "app.c"
}


static gboolean __lambda159_ (BoxesApp* self) {
	gboolean result = FALSE;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_application_quit ((GApplication*) self);
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 272 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3011 "app.c"
}


static gboolean ___lambda159__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda159_ ((BoxesApp*) self);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3020 "app.c"
}


gboolean boxes_app_quit_app (BoxesApp* self) {
	gboolean result = FALSE;
	BoxesAppWindow* _tmp0_ = NULL;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	gtk_widget_hide ((GtkWidget*) _tmp0_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda159__gsource_func, g_object_ref (self), g_object_unref);
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = TRUE;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3039 "app.c"
}


static void boxes_app_real_shutdown (GApplication* base) {
	BoxesApp * self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesNotificationbar* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesWizard* _tmp3_ = NULL;
#line 278 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (boxes_app_parent_class)->shutdown ((GApplication*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_APPLICATION, GtkApplication));
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->notificationbar;
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_notificationbar_cancel (_tmp1_);
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_app_window;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_->wizard;
#line 282 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_wizard_cleanup (_tmp3_);
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_suspend_machines (self);
#line 3067 "app.c"
}


void boxes_app_open_name (BoxesApp* self, const gchar* name) {
	BoxesCollection* _tmp0_ = NULL;
	GPtrArray* _tmp1_ = NULL;
	gpointer* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 286 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (name != NULL);
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->collection;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->items;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_->pdata;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2__length1 = (gint) _tmp1_->len;
#line 3090 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp2_;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp2__length1;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp2__length1; item_it = item_it + 1) {
#line 3102 "app.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp3_ = _g_object_ref0 (item_collection[item_it]);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp3_;
#line 3109 "app.c"
			{
				BoxesCollectionItem* _tmp4_ = NULL;
				const gchar* _tmp5_ = NULL;
				const gchar* _tmp6_ = NULL;
				const gchar* _tmp7_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = item;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = boxes_collection_item_get_name (_tmp4_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = _tmp5_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = name;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (g_strcmp0 (_tmp6_, _tmp7_) == 0) {
#line 3125 "app.c"
					BoxesCollectionItem* _tmp8_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp8_ = item;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_app_select_item (self, _tmp8_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					break;
#line 3135 "app.c"
				}
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 3139 "app.c"
			}
		}
	}
}


gboolean boxes_app_open_uuid (BoxesApp* self, const gchar* uuid) {
	gboolean result = FALSE;
	BoxesCollection* _tmp0_ = NULL;
	GPtrArray* _tmp1_ = NULL;
	gpointer* _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 299 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (uuid != NULL, FALSE);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_COLLECTION);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->collection;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->items;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_->pdata;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2__length1 = (gint) _tmp1_->len;
#line 3166 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp2_;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp2__length1;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp2__length1; item_it = item_it + 1) {
#line 3178 "app.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp3_ = _g_object_ref0 (item_collection[item_it]);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp3_;
#line 3185 "app.c"
			{
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
				BoxesBoxConfig* _tmp8_ = NULL;
				gchar* _tmp9_ = NULL;
				gchar* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
				gboolean _tmp13_ = FALSE;
				BoxesCollectionItem* _tmp14_ = NULL;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = item;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE)) {
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 305 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 3207 "app.c"
				}
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = item;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp6_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = machine;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp8_ = _tmp7_->config;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp9_ = boxes_box_config_get_uuid (_tmp8_);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp10_ = _tmp9_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp11_ = _tmp10_;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp12_ = uuid;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp13_ = g_strcmp0 (_tmp11_, _tmp12_) != 0;
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_free0 (_tmp11_);
#line 308 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp13_) {
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (machine);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (item);
#line 309 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					continue;
#line 3239 "app.c"
				}
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp14_ = item;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_select_item (self, _tmp14_);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				result = TRUE;
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 312 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				return result;
#line 3253 "app.c"
			}
		}
	}
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3261 "app.c"
}


void boxes_app_delete_machine (BoxesApp* self, BoxesMachine* machine, gboolean by_user) {
	BoxesMachine* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	BoxesCollection* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = by_user;
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_machine_delete (_tmp0_, _tmp1_);
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = self->collection;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = machine;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_collection_remove_item (_tmp2_, (BoxesCollectionItem*) _tmp3_);
#line 3286 "app.c"
}


static void boxes_app_add_collection_source_data_free (gpointer _data) {
	BoxesAppAddCollectionSourceData* _data_;
	_data_ = _data;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppAddCollectionSourceData, _data_);
#line 3299 "app.c"
}


void boxes_app_add_collection_source (BoxesApp* self, BoxesCollectionSource* source, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppAddCollectionSourceData* _data_;
	BoxesApp* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppAddCollectionSourceData);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_add_collection_source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_add_collection_source_data_free);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = source;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->source);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->source = _tmp2_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_add_collection_source_co (_data_);
#line 3328 "app.c"
}


void boxes_app_add_collection_source_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppAddCollectionSourceData* _data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3336 "app.c"
}


static void boxes_app_add_collection_source_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppAddCollectionSourceData* _data_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_add_collection_source_co (_data_);
#line 3350 "app.c"
}


static gboolean boxes_app_add_collection_source_co (BoxesAppAddCollectionSourceData* _data_) {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	static GQuark _tmp18_label0 = 0;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	static GQuark _tmp18_label1 = 0;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 3363 "app.c"
		goto _state_0;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 3367 "app.c"
		goto _state_1;
		default:
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 3372 "app.c"
	}
	_state_0:
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = _data_->source;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = FALSE;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp1_ = boxes_collection_source_get_enabled (_data_->_tmp0_);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = FALSE;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (!_data_->_tmp2_) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_state_ == 0) {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3393 "app.c"
		} else {
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3397 "app.c"
		}
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_unref (_data_->_async_result);
#line 325 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3403 "app.c"
	}
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp3_ = _data_->self->priv->sources;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp4_ = _data_->source;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp5_ = boxes_collection_source_get_name (_data_->_tmp4_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp7_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp8_ = g_hash_table_lookup (_data_->_tmp3_, _data_->_tmp7_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = FALSE;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp9_ = ((BoxesCollectionSource*) _data_->_tmp8_) != NULL;
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp7_);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp9_) {
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = _data_->source;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = boxes_collection_source_get_name (_data_->_tmp10_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp12_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp12_ = _data_->_tmp11_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp13_ = NULL;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp13_ = _data_->_tmp12_;
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_warning ("app.vala:328: Attempt to add duplicate collection source '%s', ignorin" \
"g..", _data_->_tmp13_);
#line 328 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp13_);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_data_->_state_ == 0) {
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3461 "app.c"
		} else {
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3465 "app.c"
		}
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_object_unref (_data_->_async_result);
#line 329 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3471 "app.c"
	}
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp14_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp14_ = _data_->source;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp15_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp15_ = boxes_collection_source_get_source_type (_data_->_tmp14_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = NULL;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = 0U;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = (NULL == _data_->_tmp17_) ? 0 : g_quark_from_string (_data_->_tmp17_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_free (_data_->_tmp17_);
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if ((_data_->_tmp19_ == ((0 != _tmp18_label0) ? _tmp18_label0 : (_tmp18_label0 = g_quark_from_static_string ("vnc")))) || (_data_->_tmp19_ == ((0 != _tmp18_label1) ? _tmp18_label1 : (_tmp18_label1 = g_quark_from_static_string ("spice"))))) {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		switch (0) {
#line 3499 "app.c"
			default:
			{
				{
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp20_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp20_ = _data_->source;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp21_ = NULL;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp21_ = boxes_remote_machine_new (_data_->_tmp20_, &_data_->_inner_error_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->machine = _data_->_tmp21_;
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						if (_data_->_inner_error_->domain == BOXES_ERROR) {
#line 3517 "app.c"
							goto __catch2_boxes_error;
						}
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_clear_error (&_data_->_inner_error_);
#line 336 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						return FALSE;
#line 3526 "app.c"
					}
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp22_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp22_ = _data_->self->collection;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp23_ = NULL;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp23_ = _data_->machine;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_collection_add_item (_data_->_tmp22_, (BoxesCollectionItem*) _data_->_tmp23_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_object_unref0 (_data_->machine);
#line 3540 "app.c"
				}
				goto __finally2;
				__catch2_boxes_error:
				{
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_inner_error_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp24_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp24_ = _data_->_error_;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp25_ = NULL;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp25_ = _data_->_tmp24_->message;
#line 339 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_warning ("app.vala:339: %s", _data_->_tmp25_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_error_free0 (_data_->_error_);
#line 3561 "app.c"
				}
				__finally2:
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_clear_error (&_data_->_inner_error_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					return FALSE;
#line 3572 "app.c"
				}
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 3576 "app.c"
			}
		}
	} else {
#line 332 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		switch (0) {
#line 3582 "app.c"
			default:
			{
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp26_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp26_ = _data_->self->priv->brokers;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp27_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp27_ = _data_->source;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp28_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp28_ = boxes_collection_source_get_source_type (_data_->_tmp27_);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp29_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp29_ = _data_->_tmp28_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp30_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp30_ = _data_->_tmp29_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp31_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp31_ = g_hash_table_lookup (_data_->_tmp26_, _data_->_tmp30_);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp32_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp32_ = _g_object_ref0 ((BoxesBroker*) _data_->_tmp31_);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp33_ = NULL;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp33_ = _data_->_tmp32_;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_free0 (_data_->_tmp30_);
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->broker = _data_->_tmp33_;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp34_ = NULL;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp34_ = _data_->broker;
#line 345 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (_data_->_tmp34_ != NULL) {
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp35_ = NULL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp35_ = _data_->broker;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp36_ = NULL;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp36_ = _data_->source;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_state_ = 1;
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_broker_add_source (_data_->_tmp35_, _data_->_tmp36_, boxes_app_add_collection_source_ready, _data_);
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					return FALSE;
#line 3641 "app.c"
					_state_1:
#line 346 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_broker_add_source_finish (_data_->_tmp35_, _data_->_res_);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp37_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp37_ = _data_->self->priv->sources;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp38_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp38_ = _data_->source;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp39_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp39_ = boxes_collection_source_get_name (_data_->_tmp38_);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp40_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp40_ = _data_->_tmp39_;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp41_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp41_ = _data_->source;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp42_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp42_ = _g_object_ref0 (_data_->_tmp41_);
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_hash_table_insert (_data_->_tmp37_, _data_->_tmp40_, _data_->_tmp42_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp43_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp43_ = _data_->source;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp44_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp44_ = boxes_collection_source_get_name (_data_->_tmp43_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp45_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp45_ = _data_->_tmp44_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp46_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp46_ = _data_->_tmp45_;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp47_ = FALSE;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp47_ = g_strcmp0 (_data_->_tmp46_, "QEMU Session") == 0;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_free0 (_data_->_tmp46_);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					if (_data_->_tmp47_) {
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_object_notify ((GObject*) _data_->self, "default-connection");
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						g_object_notify ((GObject*) _data_->self, "default-source");
#line 3699 "app.c"
					}
				} else {
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp48_ = NULL;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp48_ = _data_->source;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp49_ = NULL;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp49_ = boxes_collection_source_get_source_type (_data_->_tmp48_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp50_ = NULL;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp50_ = _data_->_tmp49_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp51_ = NULL;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data_->_tmp51_ = _data_->_tmp50_;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					g_warning ("app.vala:353: Unsupported source type %s", _data_->_tmp51_);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_g_free0 (_data_->_tmp51_);
#line 3722 "app.c"
				}
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->broker);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 3728 "app.c"
			}
		}
	}
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3736 "app.c"
	} else {
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3740 "app.c"
	}
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 3746 "app.c"
}


static void boxes_app_setup_sources_data_free (gpointer _data) {
	BoxesAppSetupSourcesData* _data_;
	_data_ = _data;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_slice_free (BoxesAppSetupSourcesData, _data_);
#line 3757 "app.c"
}


static void boxes_app_setup_sources (BoxesApp* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesAppSetupSourcesData* _data_;
	BoxesApp* _tmp0_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_slice_new0 (BoxesAppSetupSourcesData);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_app_setup_sources);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_app_setup_sources_data_free);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->self = _tmp0_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_co (_data_);
#line 3776 "app.c"
}


static void boxes_app_setup_sources_finish (BoxesApp* self, GAsyncResult* _res_) {
	BoxesAppSetupSourcesData* _data_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 3784 "app.c"
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data5_;
#line 3793 "app.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 3802 "app.c"
		BoxesApp* self;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data5_->self;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (_data5_->new_sources);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block5Data, _data5_);
#line 3812 "app.c"
	}
}


static void boxes_app_setup_sources_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesAppSetupSourcesData* _data_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_ = _user_data_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_source_object_ = source_object;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_res_ = _res_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_setup_sources_co (_data_);
#line 3827 "app.c"
}


static gboolean __lambda172_ (Block5Data* _data5_, const gchar* filename, GError** error) {
	BoxesApp* self;
	gboolean result = FALSE;
	BoxesCollectionSource* source = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesCollectionSource* _tmp1_ = NULL;
	BoxesCollectionSource* _tmp2_ = NULL;
	GError * _inner_error_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data5_->self;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (filename != NULL, FALSE);
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = filename;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_source_new_with_file (_tmp0_, &_inner_error_);
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	source = _tmp1_;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_propagate_error (error, _inner_error_);
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3855 "app.c"
	}
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _g_object_ref0 (source);
#line 387 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data5_->new_sources = g_list_append (_data5_->new_sources, _tmp2_);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = FALSE;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (source);
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3867 "app.c"
}


static gboolean ___lambda172__boxes_foreach_filename_from_dir_func (const gchar* filename, gpointer self, GError** error) {
	gboolean result;
	result = __lambda172_ (self, filename, error);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 3876 "app.c"
}


static gboolean boxes_app_setup_sources_co (BoxesAppSetupSourcesData* _data_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (_data_->_state_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 0:
#line 3885 "app.c"
		goto _state_0;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 1:
#line 3889 "app.c"
		goto _state_1;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 2:
#line 3893 "app.c"
		goto _state_2;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 3:
#line 3897 "app.c"
		goto _state_3;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case 4:
#line 3901 "app.c"
		goto _state_4;
		default:
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_assert_not_reached ();
#line 3906 "app.c"
	}
	_state_0:
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_ = g_slice_new0 (Block5Data);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->_ref_count_ = 1;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->self = g_object_ref (_data_->self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->_async_data_ = _data_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = NULL;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp0_ = boxes_get_user_pkgconfig_source ("QEMU Session");
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->path = _data_->_tmp0_;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->create_session_source = TRUE;
#line 3925 "app.c"
	{
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp1_ = NULL;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp1_ = g_file_new_for_path (_data_->path);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->file = _data_->_tmp1_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_state_ = 1;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_file_query_info_async (_data_->file, G_FILE_ATTRIBUTE_STANDARD_SIZE, G_FILE_QUERY_INFO_NONE, G_PRIORITY_DEFAULT, NULL, boxes_app_setup_sources_ready, _data_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 3939 "app.c"
		_state_1:
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp2_ = NULL;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp2_ = g_file_query_info_finish (_data_->file, _data_->_res_, &_data_->_inner_error_);
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->info = _data_->_tmp2_;
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 364 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->file);
#line 3951 "app.c"
			goto __catch3_g_error;
		}
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp3_ = 0ULL;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp3_ = g_file_info_get_attribute_uint64 (_data_->info, G_FILE_ATTRIBUTE_STANDARD_SIZE);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->create_session_source = _data_->_tmp3_ <= ((guint64) 0);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->info);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->file);
#line 3964 "app.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_inner_error_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp4_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp4_ = _data_->_error_;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp5_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_debug ("app.vala:370: Failed to query '%s': %s. Assuming it doesn't exist.", _data_->path, _data_->_tmp5_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_error_free0 (_data_->_error_);
#line 3985 "app.c"
	}
	__finally3:
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->path);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block5_data_unref (_data_->_data5_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_data5_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_clear_error (&_data_->_inner_error_);
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return FALSE;
#line 4002 "app.c"
	}
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = FALSE;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp6_ = _data_->create_session_source;
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp6_) {
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp7_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp7_ = boxes_get_pkgdata_source ("QEMU_Session");
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp8_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp8_ = _data_->_tmp7_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp9_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp9_ = g_file_new_for_path (_data_->_tmp8_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_data_->_tmp8_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->src = _data_->_tmp10_;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = NULL;
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->_tmp11_ = g_file_new_for_path (_data_->path);
#line 375 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->dst = _data_->_tmp11_;
#line 4036 "app.c"
		{
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp12_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp12_ = _data_->src;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp13_ = NULL;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp13_ = _data_->dst;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_state_ = 2;
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_file_copy_async (_data_->_tmp12_, _data_->_tmp13_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, boxes_app_setup_sources_ready, _data_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			return FALSE;
#line 4052 "app.c"
			_state_2:
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_file_copy_finish (_data_->_tmp12_, _data_->_res_, &_data_->_inner_error_);
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 4058 "app.c"
				goto __catch4_g_error;
			}
		}
		goto __finally4;
		__catch4_g_error:
		{
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_vala1__error_ = _data_->_inner_error_;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_inner_error_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp14_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp14_ = _data_->_vala1__error_;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp15_ = NULL;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp15_ = _data_->_tmp14_->message;
#line 379 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("app.vala:379: Can't setup default sources: %s", _data_->_tmp15_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_error_free0 (_data_->_vala1__error_);
#line 4081 "app.c"
		}
		__finally4:
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->dst);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (_data_->src);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_free0 (_data_->path);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			block5_data_unref (_data_->_data5_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_data5_ = NULL;
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_clear_error (&_data_->_inner_error_);
#line 376 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			return FALSE;
#line 4102 "app.c"
		}
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->dst);
#line 373 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data_->src);
#line 4108 "app.c"
	}
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp16_ = boxes_get_user_pkgconfig_source (NULL);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp18_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp18_ = g_file_new_for_path (_data_->_tmp17_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = NULL;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->_tmp17_);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->dir = _data_->_tmp19_;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_->new_sources = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp20_ = NULL;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp20_ = _data_->dir;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_state_ = 3;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_foreach_filename_from_dir (_data_->_tmp20_, ___lambda172__boxes_foreach_filename_from_dir_func, _data_->_data5_, boxes_app_setup_sources_ready, _data_);
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 4142 "app.c"
	_state_3:
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_foreach_filename_from_dir_finish (_data_->_res_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp21_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp21_ = _data_->_data5_->new_sources;
#line 4150 "app.c"
	{
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data_->source_collection = _data_->_tmp21_;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (_data_->source_it = _data_->source_collection; _data_->source_it != NULL; _data_->source_it = _data_->source_it->next) {
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp22_ = NULL;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->_tmp22_ = _g_object_ref0 ((BoxesCollectionSource*) _data_->source_it->data);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_data_->source = _data_->_tmp22_;
#line 4162 "app.c"
			{
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp23_ = NULL;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_tmp23_ = _data_->source;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_data_->_state_ = 4;
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_add_collection_source (_data_->self, _data_->_tmp23_, boxes_app_setup_sources_ready, _data_);
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				return FALSE;
#line 4174 "app.c"
				_state_4:
#line 392 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_app_add_collection_source_finish (_data_->self, _data_->_res_);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (_data_->source);
#line 4180 "app.c"
			}
		}
	}
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp24_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp24_ = boxes_app_get_default_connection (_data_->self);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp25_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp25_ = _data_->_tmp24_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp26_ = NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp27_ = FALSE;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_tmp27_ = _data_->_tmp26_ == NULL;
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->_tmp26_);
#line 394 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_tmp27_) {
#line 395 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_printerr ("Missing or failing default libvirt connection\n");
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_application_release ((GApplication*) _data_->self);
#line 4208 "app.c"
	}
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_data_->dir);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_data_->path);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block5_data_unref (_data_->_data5_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data_->_data5_ = NULL;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_data_->_state_ == 0) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4222 "app.c"
	} else {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4226 "app.c"
	}
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_unref (_data_->_async_result);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return FALSE;
#line 4232 "app.c"
}


static void boxes_app_ui_state_changed (BoxesApp* self) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	BoxesUIState _tmp3_ = 0;
	BoxesUIState _tmp4_ = 0;
	BoxesCollectionItem* _tmp16_ = NULL;
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp0_, _tmp2_);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp4_ == BOXES_UI_STATE_COLLECTION) {
#line 4259 "app.c"
		BoxesAppWindow* _tmp5_ = NULL;
		BoxesTopbar* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self->priv->status_bind);
#line 404 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self->priv->status_bind = NULL;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = boxes_app_window;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = _tmp5_->topbar;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_topbar_set_status (_tmp6_, NULL);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = self->current_item;
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_MACHINE)) {
#line 4277 "app.c"
			BoxesMachine* machine = NULL;
			BoxesCollectionItem* _tmp8_ = NULL;
			BoxesMachine* _tmp9_ = NULL;
			gulong _tmp10_ = 0UL;
			BoxesMachine* _tmp13_ = NULL;
			GCancellable* _tmp14_ = NULL;
			GCancellable* _tmp15_ = NULL;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp8_ = self->current_item;
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp8_) : NULL);
#line 407 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			machine = _tmp9_;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = self->priv->got_error_id;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			if (_tmp10_ != ((gulong) 0)) {
#line 4295 "app.c"
				BoxesMachine* _tmp11_ = NULL;
				gulong _tmp12_ = 0UL;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp11_ = machine;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp12_ = self->priv->got_error_id;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				g_signal_handler_disconnect ((GObject*) _tmp11_, _tmp12_);
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				self->priv->got_error_id = (gulong) 0;
#line 4306 "app.c"
			}
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp13_ = machine;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = boxes_machine_get_connecting_cancellable (_tmp13_);
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = _tmp14_;
#line 413 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_cancellable_cancel (_tmp15_);
#line 406 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (machine);
#line 4318 "app.c"
		}
	}
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp16_ = self->current_item;
#line 417 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp16_ != NULL) {
#line 4325 "app.c"
		BoxesCollectionItem* _tmp17_ = NULL;
		BoxesUIState _tmp18_ = 0;
		BoxesUIState _tmp19_ = 0;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = self->current_item;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp18_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp19_ = _tmp18_;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_state ((BoxesUI*) _tmp17_, _tmp19_);
#line 4337 "app.c"
	}
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data6_;
#line 4347 "app.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 4356 "app.c"
		BoxesApp* self;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data6_->self;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block6Data, _data6_);
#line 4364 "app.c"
	}
}


static Block7Data* block7_data_ref (Block7Data* _data7_) {
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data7_->_ref_count_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data7_;
#line 4374 "app.c"
}


static void block7_data_unref (void * _userdata_) {
	Block7Data* _data7_;
	_data7_ = (Block7Data*) _userdata_;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data7_->_ref_count_)) {
#line 4383 "app.c"
		BoxesApp* self;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data7_->_data6_->self;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (_data7_->machine);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block6_data_unref (_data7_->_data6_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data7_->_data6_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block7Data, _data7_);
#line 4395 "app.c"
	}
}


static void ______lambda177_ (Block7Data* _data7_) {
	Block6Data* _data6_;
	BoxesApp* self;
	BoxesLibvirtMachine* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_ = _data7_->_data6_;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data6_->self;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data7_->machine;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp0_);
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 443 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:443: %s suspended", _tmp2_);
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _data6_->waiting_counter;
#line 444 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->waiting_counter = _tmp3_ - 1;
#line 4423 "app.c"
}


static void _______lambda177__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	______lambda177_ (self);
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block7_data_unref (self);
#line 4432 "app.c"
}


static void boxes_app_suspend_machines (BoxesApp* self) {
	Block6Data* _data6_;
	BoxesCollection* _tmp0_ = NULL;
	GMainContext* context = NULL;
	GMainContext* _tmp1_ = NULL;
	GMainContext* _tmp2_ = NULL;
	BoxesCollection* _tmp3_ = NULL;
	GPtrArray* _tmp4_ = NULL;
	gpointer* _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	GMainContext* _tmp14_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->_ref_count_ = 1;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->self = g_object_ref (self);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->collection;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_ == NULL) {
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		block6_data_unref (_data6_);
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data6_ = NULL;
#line 425 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 4465 "app.c"
	}
#line 427 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:427: Suspending running boxes");
#line 429 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_->waiting_counter = 0;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_main_context_new ();
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	context = _tmp1_;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = context;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_main_context_push_thread_default (_tmp2_);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = self->collection;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_->items;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = _tmp4_->pdata;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5__length1 = (gint) _tmp4_->len;
#line 4487 "app.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp5_;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection_length1 = _tmp5__length1;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = 0; item_it < _tmp5__length1; item_it = item_it + 1) {
#line 4499 "app.c"
			BoxesCollectionItem* _tmp6_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp6_ = _g_object_ref0 (item_collection[item_it]);
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp6_;
#line 4506 "app.c"
			{
				BoxesCollectionItem* _tmp7_ = NULL;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp7_ = item;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 4513 "app.c"
					Block7Data* _data7_;
					BoxesCollectionItem* _tmp8_ = NULL;
					BoxesLibvirtMachine* _tmp9_ = NULL;
					BoxesLibvirtMachine* _tmp10_ = NULL;
					gboolean _tmp11_ = FALSE;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data7_ = g_slice_new0 (Block7Data);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data7_->_ref_count_ = 1;
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data7_->_data6_ = block6_data_ref (_data6_);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp8_ = item;
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp8_) : NULL);
#line 438 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data7_->machine = _tmp9_;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp10_ = _data7_->machine;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp11_ = ((BoxesMachine*) _tmp10_)->suspend_at_exit;
#line 440 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					if (_tmp11_) {
#line 4537 "app.c"
						gint _tmp12_ = 0;
						BoxesLibvirtMachine* _tmp13_ = NULL;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						_tmp12_ = _data6_->waiting_counter;
#line 441 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						_data6_->waiting_counter = _tmp12_ + 1;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						_tmp13_ = _data7_->machine;
#line 442 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
						boxes_libvirt_machine_suspend (_tmp13_, _______lambda177__gasync_ready_callback, block7_data_ref (_data7_));
#line 4548 "app.c"
					}
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					block7_data_unref (_data7_);
#line 437 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_data7_ = NULL;
#line 4554 "app.c"
				}
#line 436 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 4558 "app.c"
			}
		}
	}
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp14_ = context;
#line 449 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_main_context_pop_thread_default (_tmp14_);
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	while (TRUE) {
#line 4568 "app.c"
		gint _tmp15_ = 0;
		GMainContext* _tmp16_ = NULL;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = _data6_->waiting_counter;
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (!(_tmp15_ > 0)) {
#line 452 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			break;
#line 4577 "app.c"
		}
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = context;
#line 453 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_main_context_iteration (_tmp16_, TRUE);
#line 4583 "app.c"
	}
#line 455 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:455: Running boxes suspended");
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_main_context_unref0 (context);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block6_data_unref (_data6_);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data6_ = NULL;
#line 4593 "app.c"
}


void boxes_app_show_properties (BoxesApp* self) {
	GList* selected_items = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_collection_view_get_selected_items (_tmp1_);
#line 472 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = _tmp2_;
#line 474 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_set_selection_mode (self, FALSE);
#line 4614 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = selected_items;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 4622 "app.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 477 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp3_;
#line 4629 "app.c"
			{
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesCollectionItem* _tmp5_ = NULL;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = item;
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = _g_object_ref0 (_tmp4_);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (self->current_item);
#line 478 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				self->current_item = _tmp5_;
#line 479 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 480 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				break;
#line 4647 "app.c"
			}
		}
	}
#line 471 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 4653 "app.c"
}


/**
     * Deletes specified items, while allowing user to undo it.
     *
     * @param items the list of machines
     * @param message The message to be shown together with the undo button
     * @param callback optional function that, if provided, is called after the undo operation
     *
     * @attention the ownership for items is required since GLib.List is a compact class.
     */
static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return _data8_;
#line 4671 "app.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 4680 "app.c"
		BoxesApp* self;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self = _data8_->self;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (_data8_->items);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		(_data8_->undo_notify_callback_target_destroy_notify == NULL) ? NULL : (_data8_->undo_notify_callback_target_destroy_notify (_data8_->undo_notify_callback_target), NULL);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data8_->undo_notify_callback = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data8_->undo_notify_callback_target = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_data8_->undo_notify_callback_target_destroy_notify = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_slice_free (Block8Data, _data8_);
#line 4698 "app.c"
	}
}


static void __lambda55_ (Block8Data* _data8_) {
	BoxesApp* self;
	GList* _tmp0_ = NULL;
	BoxesAppUndoNotifyCallback _tmp6_ = NULL;
	void* _tmp6__target = NULL;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data8_->self;
#line 500 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:500: Box deletion cancelled by user. Re-adding to view");
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data8_->items;
#line 4714 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp0_;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 4722 "app.c"
			BoxesCollectionItem* _tmp1_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp1_;
#line 4729 "app.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp2_ = NULL;
				BoxesMachine* _tmp3_ = NULL;
				BoxesCollection* _tmp4_ = NULL;
				BoxesMachine* _tmp5_ = NULL;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = item;
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 502 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp3_;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = self->collection;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = machine;
#line 503 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_collection_add_item (_tmp4_, (BoxesCollectionItem*) _tmp5_);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 501 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 4752 "app.c"
			}
		}
	}
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _data8_->undo_notify_callback;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6__target = _data8_->undo_notify_callback_target;
#line 505 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp6_ != NULL) {
#line 4762 "app.c"
		BoxesAppUndoNotifyCallback _tmp7_ = NULL;
		void* _tmp7__target = NULL;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = _data8_->undo_notify_callback;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7__target = _data8_->undo_notify_callback_target;
#line 506 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ (_tmp7__target);
#line 4771 "app.c"
	}
}


static void ___lambda55__boxes_notification_ok_func (gpointer self) {
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda55_ (self);
#line 4779 "app.c"
}


static void __lambda56_ (Block8Data* _data8_) {
	BoxesApp* self;
	GList* _tmp0_ = NULL;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = _data8_->self;
#line 510 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_debug ("app.vala:510: User did not cancel deletion. Deleting now...");
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = _data8_->items;
#line 4792 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp0_;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 4800 "app.c"
			BoxesCollectionItem* _tmp1_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp1_;
#line 4807 "app.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp2_ = NULL;
				BoxesMachine* _tmp3_ = NULL;
				BoxesMachine* _tmp4_ = NULL;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp2_ = item;
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 512 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				machine = _tmp3_;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = machine;
#line 513 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				if (_tmp4_ != NULL) {
#line 4823 "app.c"
					BoxesMachine* _tmp5_ = NULL;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					_tmp5_ = machine;
#line 515 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
					boxes_machine_delete (_tmp5_, TRUE);
#line 4829 "app.c"
				}
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (machine);
#line 511 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 4835 "app.c"
			}
		}
	}
}


static void ___lambda56__boxes_notification_cancel_func (gpointer self) {
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda56_ (self);
#line 4845 "app.c"
}


void boxes_app_delete_machines_undoable (BoxesApp* self, GList* items, const gchar* message, BoxesAppUndoNotifyCallback undo_notify_callback, void* undo_notify_callback_target, GDestroyNotify undo_notify_callback_target_destroy_notify) {
	Block8Data* _data8_;
	GList* _tmp0_ = NULL;
	BoxesAppUndoNotifyCallback _tmp1_ = NULL;
	void* _tmp1__target = NULL;
	GList* _tmp2_ = NULL;
	BoxesNotificationOKFunc undo = NULL;
	void* undo_target = NULL;
	GDestroyNotify undo_target_destroy_notify = NULL;
	BoxesNotificationCancelFunc really_remove = NULL;
	void* really_remove_target = NULL;
	GDestroyNotify really_remove_target_destroy_notify = NULL;
	BoxesAppWindow* _tmp6_ = NULL;
	BoxesNotificationbar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	BoxesNotificationOKFunc _tmp10_ = NULL;
	void* _tmp10__target = NULL;
	GDestroyNotify _tmp10__target_destroy_notify = NULL;
	BoxesNotificationCancelFunc _tmp11_ = NULL;
	void* _tmp11__target = NULL;
	GDestroyNotify _tmp11__target_destroy_notify = NULL;
	GdNotification* _tmp12_ = NULL;
	GdNotification* _tmp13_ = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (message != NULL);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_ = g_slice_new0 (Block8Data);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->_ref_count_ = 1;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->self = g_object_ref (self);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = items;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (_data8_->items);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->items = _tmp0_;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = undo_notify_callback;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1__target = undo_notify_callback_target;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(_data8_->undo_notify_callback_target_destroy_notify == NULL) ? NULL : (_data8_->undo_notify_callback_target_destroy_notify (_data8_->undo_notify_callback_target), NULL);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->undo_notify_callback = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->undo_notify_callback_target = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->undo_notify_callback_target_destroy_notify = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->undo_notify_callback = _tmp1_;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->undo_notify_callback_target = _tmp1__target;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_->undo_notify_callback_target_destroy_notify = undo_notify_callback_target_destroy_notify;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _data8_->items;
#line 4909 "app.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		item_collection = _tmp2_;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 4917 "app.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			item = _tmp3_;
#line 4924 "app.c"
			{
				BoxesCollection* _tmp4_ = NULL;
				BoxesCollectionItem* _tmp5_ = NULL;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp4_ = self->collection;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_tmp5_ = item;
#line 497 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				boxes_collection_remove_item (_tmp4_, _tmp5_);
#line 496 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
				_g_object_unref0 (item);
#line 4936 "app.c"
			}
		}
	}
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo = ___lambda55__boxes_notification_ok_func;
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target = block8_data_ref (_data8_);
#line 499 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = block8_data_unref;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove = ___lambda56__boxes_notification_cancel_func;
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target = block8_data_ref (_data8_);
#line 509 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = block8_data_unref;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = boxes_app_window;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = _tmp6_->notificationbar;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = message;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = _ ("_Undo");
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = undo;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10__target = undo_target;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10__target_destroy_notify = undo_target_destroy_notify;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = NULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11_ = really_remove;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11__target = really_remove_target;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp11__target_destroy_notify = really_remove_target_destroy_notify;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = NULL;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp12_ = boxes_notificationbar_display_for_action (_tmp7_, _tmp8_, _tmp9_, _tmp10_, _tmp10__target, _tmp10__target_destroy_notify, _tmp11_, _tmp11__target, _tmp11__target_destroy_notify, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp13_ = _tmp12_;
#line 519 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp13_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(really_remove_target_destroy_notify == NULL) ? NULL : (really_remove_target_destroy_notify (really_remove_target), NULL);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	really_remove_target_destroy_notify = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	(undo_target_destroy_notify == NULL) ? NULL : (undo_target_destroy_notify (undo_target), NULL);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	undo_target_destroy_notify = NULL;
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	block8_data_unref (_data8_);
#line 493 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_data8_ = NULL;
#line 5002 "app.c"
}


void boxes_app_remove_selected_items (BoxesApp* self) {
	GList* selected_items = NULL;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	guint num_selected = 0U;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	guint _tmp5_ = 0U;
	gchar* _tmp6_ = NULL;
	guint _tmp7_ = 0U;
	gchar* message = NULL;
	gchar* _tmp18_ = NULL;
	GList* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_collection_view_get_selected_items (_tmp1_);
#line 523 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = _tmp2_;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = selected_items;
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 524 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	num_selected = _tmp4_;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = num_selected;
#line 525 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp5_ == ((guint) 0)) {
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		__g_list_free__g_object_unref0_0 (selected_items);
#line 526 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		return;
#line 5045 "app.c"
	}
#line 528 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_set_selection_mode (self, FALSE);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = num_selected;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp7_ == ((guint) 1)) {
#line 5053 "app.c"
		const gchar* _tmp8_ = NULL;
		GList* _tmp9_ = NULL;
		gconstpointer _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp8_ = _ ("Box '%s' has been deleted");
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp9_ = selected_items;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp10_ = _tmp9_->data;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp10_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = _tmp11_;
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = g_strdup_printf (_tmp8_, _tmp12_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp6_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = _tmp13_;
#line 5076 "app.c"
	} else {
		guint _tmp14_ = 0U;
		const gchar* _tmp15_ = NULL;
		guint _tmp16_ = 0U;
		gchar* _tmp17_ = NULL;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp14_ = num_selected;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp15_ = ngettext ("%u box has been deleted", "%u boxes have been deleted", (gulong) _tmp14_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp16_ = num_selected;
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp17_ = g_strdup_printf (_tmp15_, _tmp16_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_free0 (_tmp6_);
#line 531 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = _tmp17_;
#line 5094 "app.c"
	}
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp18_ = g_strdup (_tmp6_);
#line 530 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	message = _tmp18_;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp19_ = selected_items;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	selected_items = NULL;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp20_ = message;
#line 535 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_delete_machines_undoable (self, _tmp19_, _tmp20_, NULL, NULL, NULL);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (message);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (_tmp6_);
#line 522 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__g_list_free__g_object_unref0_0 (selected_items);
#line 5114 "app.c"
}


static void __lambda127_ (BoxesApp* self, const gchar* message) {
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesNotificationbar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GdNotification* _tmp3_ = NULL;
	GdNotification* _tmp4_ = NULL;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (message != NULL);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->notificationbar;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = message;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_notificationbar_display_error (_tmp1_, _tmp2_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_;
#line 545 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp4_);
#line 5138 "app.c"
}


static void ___lambda127__boxes_machine_got_error (BoxesMachine* _sender, const gchar* message, gpointer self) {
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	__lambda127_ ((BoxesApp*) self, message);
#line 5145 "app.c"
}


void boxes_app_connect_to (BoxesApp* self, BoxesMachine* machine) {
	BoxesMachine* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesMachine* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesTopbar* _tmp4_ = NULL;
	GBinding* _tmp5_ = NULL;
	GBinding* _tmp6_ = NULL;
	BoxesMachine* _tmp7_ = NULL;
	gulong _tmp8_ = 0UL;
	BoxesUIState _tmp9_ = 0;
	BoxesUIState _tmp10_ = 0;
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 538 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (machine != NULL);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = machine;
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _g_object_ref0 ((BoxesCollectionItem*) _tmp0_);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->current_item);
#line 539 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->current_item = _tmp1_;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = machine;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = boxes_app_window;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp4_ = _tmp3_->topbar;
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp5_ = g_object_bind_property_with_closures ((GObject*) _tmp2_, "status", (GObject*) _tmp4_, "status", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 542 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->status_bind = _tmp6_;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp7_ = machine;
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp8_ = g_signal_connect_object (_tmp7_, "got-error", (GCallback) ___lambda127__boxes_machine_got_error, self, 0);
#line 544 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->got_error_id = _tmp8_;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp9_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp10_ = _tmp9_;
#line 548 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp10_ != BOXES_UI_STATE_CREDS) {
#line 549 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_CREDS);
#line 5201 "app.c"
	}
}


void boxes_app_select_item (BoxesApp* self, BoxesCollectionItem* item) {
	gboolean _tmp0_ = FALSE;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 552 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (item != NULL);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = _tmp1_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp2_ == BOXES_UI_STATE_COLLECTION) {
#line 5220 "app.c"
		gboolean _tmp3_ = FALSE;
		gboolean _tmp4_ = FALSE;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp3_ = boxes_app_get_selection_mode (self);
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp4_ = _tmp3_;
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = !_tmp4_;
#line 5229 "app.c"
	} else {
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp0_ = FALSE;
#line 5233 "app.c"
	}
#line 553 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	if (_tmp0_) {
#line 5237 "app.c"
		BoxesCollectionItem* _tmp5_ = NULL;
		BoxesCollectionItem* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
		BoxesCollectionItem* _tmp11_ = NULL;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp5_ = item;
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp6_ = _g_object_ref0 (_tmp5_);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_g_object_unref0 (self->current_item);
#line 554 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		self->current_item = _tmp6_;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp7_ = self->current_item;
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, BOXES_TYPE_MACHINE)) {
#line 5254 "app.c"
			BoxesMachine* machine = NULL;
			BoxesCollectionItem* _tmp8_ = NULL;
			BoxesMachine* _tmp9_ = NULL;
			BoxesMachine* _tmp10_ = NULL;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp8_ = self->current_item;
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp8_) : NULL);
#line 557 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			machine = _tmp9_;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp10_ = machine;
#line 559 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_app_connect_to (self, _tmp10_);
#line 556 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (machine);
#line 5271 "app.c"
		} else {
#line 561 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			g_warning ("app.vala:561: unknown item, fix your code");
#line 5275 "app.c"
		}
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp11_ = item;
#line 563 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_signal_emit_by_name (self, "item-selected", _tmp11_);
#line 5281 "app.c"
	} else {
		BoxesUIState _tmp12_ = 0;
		BoxesUIState _tmp13_ = 0;
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp12_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		_tmp13_ = _tmp12_;
#line 564 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		if (_tmp13_ == BOXES_UI_STATE_WIZARD) {
#line 5291 "app.c"
			BoxesCollectionItem* _tmp14_ = NULL;
			BoxesCollectionItem* _tmp15_ = NULL;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp14_ = item;
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_tmp15_ = _g_object_ref0 (_tmp14_);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			_g_object_unref0 (self->current_item);
#line 565 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			self->current_item = _tmp15_;
#line 567 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
			boxes_ui_set_state ((BoxesUI*) self, BOXES_UI_STATE_PROPERTIES);
#line 5304 "app.c"
		}
	}
}


static BoxesUIState boxes_app_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesApp* self;
	BoxesUIState _tmp0_ = 0;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5322 "app.c"
}


static void boxes_app_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesApp* self;
	BoxesUIState _tmp0_ = 0;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = value;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 5337 "app.c"
}


static BoxesUIState boxes_app_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesApp* self;
	BoxesUIState _tmp0_ = 0;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_ui_state;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5353 "app.c"
}


static void boxes_app_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesApp* self;
	BoxesUIState _tmp0_ = 0;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = (BoxesApp*) base;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = value;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_ui_state = _tmp0_;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 5368 "app.c"
}


const gchar* boxes_app_get_uri (BoxesApp* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_uri;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5383 "app.c"
}


void boxes_app_set_uri (BoxesApp* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = value;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (self->priv->_uri);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_uri = _tmp1_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "uri");
#line 5402 "app.c"
}


GVirConnection* boxes_app_get_default_connection (BoxesApp* self) {
	GVirConnection* result;
	BoxesLibvirtBroker* _tmp0_ = NULL;
	BoxesLibvirtBroker* _tmp1_ = NULL;
	GVirConnection* _tmp2_ = NULL;
	GVirConnection* _tmp3_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_libvirt_broker_get_default ();
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_libvirt_broker_get_connection (_tmp1_, "QEMU Session");
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp3_ = _tmp2_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (_tmp1_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp3_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5428 "app.c"
}


BoxesCollectionSource* boxes_app_get_default_source (BoxesApp* self) {
	BoxesCollectionSource* result;
	GHashTable* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->sources;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = g_hash_table_lookup (_tmp0_, "QEMU Session");
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = (BoxesCollectionSource*) _tmp1_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5446 "app.c"
}


gboolean boxes_app_get_selection_mode (BoxesApp* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = self->priv->_selection_mode;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp0_;
#line 459 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5461 "app.c"
}


void boxes_app_set_selection_mode (BoxesApp* self, gboolean value) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
	gboolean _tmp2_ = FALSE;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (self != NULL);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_;
#line 461 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_if_fail (_tmp1_ == BOXES_UI_STATE_COLLECTION);
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = value;
#line 463 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv->_selection_mode = _tmp2_;
#line 460 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_notify ((GObject *) self, "selection-mode");
#line 5483 "app.c"
}


GList* boxes_app_get_selected_items (BoxesApp* self) {
	GList* result;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesCollectionView* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp0_ = boxes_app_window;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp1_ = _tmp0_->view;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_tmp2_ = boxes_collection_view_get_selected_items (_tmp1_);
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	result = _tmp2_;
#line 468 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	return result;
#line 5504 "app.c"
}


static void boxes_app_class_init (BoxesAppClass * klass) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_parent_class = g_type_class_peek_parent (klass);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_type_class_add_private (klass, sizeof (BoxesAppPrivate));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->startup = boxes_app_real_startup;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->activate = boxes_app_real_activate;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->command_line = boxes_app_real_command_line;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_APPLICATION_CLASS (klass)->shutdown = boxes_app_real_shutdown;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_app_get_property;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_app_set_property;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_app_finalize;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_DEFAULT_CONNECTION, g_param_spec_object ("default-connection", "default-connection", "default-connection", gvir_connection_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_DEFAULT_SOURCE, g_param_spec_object ("default-source", "default-source", "default-source", BOXES_TYPE_COLLECTION_SOURCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_SELECTION_MODE, g_param_spec_boolean ("selection-mode", "selection-mode", "selection-mode", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_APP_SELECTED_ITEMS, g_param_spec_pointer ("selected-items", "selected-items", "selected-items", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_new ("ready", BOXES_TYPE_APP, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	g_signal_new ("item_selected", BOXES_TYPE_APP, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, BOXES_TYPE_COLLECTION_ITEM);
#line 5545 "app.c"
}


static void boxes_app_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	boxes_app_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	iface->get_previous_ui_state = boxes_app_real_get_previous_ui_state;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	iface->set_previous_ui_state = boxes_app_real_set_previous_ui_state;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	iface->get_ui_state = boxes_app_real_get_ui_state;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	iface->set_ui_state = boxes_app_real_set_ui_state;
#line 5560 "app.c"
}


static void boxes_app_instance_init (BoxesApp * self) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self->priv = BOXES_APP_GET_PRIVATE (self);
#line 5567 "app.c"
}


static void boxes_app_finalize (GObject* obj) {
	BoxesApp * self;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_APP, BoxesApp);
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->current_item);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_free0 (self->priv->_uri);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->collection);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->filter);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->brokers);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_hash_table_unref0 (self->priv->sources);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	_g_object_unref0 (self->priv->status_bind);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	G_OBJECT_CLASS (boxes_app_parent_class)->finalize (obj);
#line 5591 "app.c"
}


GType boxes_app_get_type (void) {
	static volatile gsize boxes_app_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_app_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesAppClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_app_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesApp), 0, (GInstanceInitFunc) boxes_app_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_app_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_app_type_id;
		boxes_app_type_id = g_type_register_static (GTK_TYPE_APPLICATION, "BoxesApp", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_app_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_app_type_id__volatile, boxes_app_type_id);
	}
	return boxes_app_type_id__volatile;
}


static void _vala_boxes_app_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesApp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP, BoxesApp);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (property_id) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_PREVIOUS_UI_STATE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_UI_STATE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_URI:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_string (value, boxes_app_get_uri (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_DEFAULT_CONNECTION:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_take_object (value, boxes_app_get_default_connection (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_DEFAULT_SOURCE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_object (value, boxes_app_get_default_source (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTION_MODE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_boolean (value, boxes_app_get_selection_mode (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTED_ITEMS:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		g_value_set_pointer (value, boxes_app_get_selected_items (self));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 5656 "app.c"
		default:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 5662 "app.c"
	}
}


static void _vala_boxes_app_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesApp * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_APP, BoxesApp);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
	switch (property_id) {
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_PREVIOUS_UI_STATE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_UI_STATE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_URI:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_uri (self, g_value_get_string (value));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		case BOXES_APP_SELECTION_MODE:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		boxes_app_set_selection_mode (self, g_value_get_boolean (value));
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 5696 "app.c"
		default:
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/app.vala"
		break;
#line 5702 "app.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



